@@ -13,6 +13,8 @@ OC.L10N.register(
     "More activities" : "Thêm hoạt động",
     "Daily activity summary for %s" : "Tóm tắt hoạt động hàng ngày cho %s",
     "_and %n more…_::_and %n more…_" : ["và %n còn nữa...."],
+    "You can disable daily digest emails in the <a href=\"%s\">settings</a>." : "Bạn có thể tắt email tổng hợp hằng ngày trong mục <a href=\"%s\">cài đặt</a>.",
+    "You can disable daily digest emails in the settings: %s" : "Bạn có thể tắt email tổng hợp hằng ngày trong phần cài đặt: %s",
     "All activities" : "Tất cả các hoạt động",
     "By others" : "Bởi người khác",
     "By you" : "Bởi bạn",
@@ -21,6 +23,7 @@ OC.L10N.register(
     "Hello %s," : "Xin chào %s,",
     "There was some activity at %s" : "Có một số hoạt động tại %s",
     "_and %n more _::_and %n more _" : ["và %n thêm"],
+    "You can change the frequency of these emails or disable them in the <a href=\"%s\">settings</a>." : "Bạn có thể điều chỉnh tần suất gửi hoặc vô hiệu hóa các email này trong <a href=\"%s\">cài đặt</a>.",
     "You can change the frequency of these emails or disable them in the settings: %s" : "Bạn có thể thay đổi tần suất nhận những email này hoặc tắt chúng trong cài đặt: %s",
     "Mail" : "Thư điện tử",
     "Push" : "Đẩy",
