@@ -1,6 +1,7 @@
 OC.L10N.register(
     "bruteforcesettings",
     {
-    "Add" : "சேர்க்க"
+    "Add" : "சேர்க்க",
+    "Save" : "சேமிக்க "
 },
 "nplurals=2; plural=(n != 1);");
