@@ -143,9 +143,18 @@ OC.L10N.register(
     "%1$s shared some content with you. You should have already received a separate email with a link to access it." : "%1$s hat einen Inhalt mit dir geteilt. Du solltest bereits eine weitere E-Mail mit einem Link für den Zugriff erhalten haben.",
     "Password to access content shared with you by %1$s" : "Passwort für den Zugriff auf den Inhalt, der von %1$s mit dir geteilt wurde.",
     "Password to access content" : "Passwort für den Zugriff auf den Inhalt",
+    "Federated Teams" : "Federated-Teams",
     "This item is already shared with this team" : "Dieses Element wurde bereits mit diesem Team geteilt",
     "Bring cloud-users closer together." : "Bringe Cloudnutzer näher zueinander.",
     "Teams allows people to create their own groups of people/colleagues/friends.\nThose groups of people can then be used by any other app for sharing purpose." : "Mittels Teams können Personen ihre eigenen Gruppen mit Personen/Kollegen/Freunden erstellen.\nDiese Personengruppen können dann von jeder anderen App zum Teilen verwendet werden.",
+    "Unable to update federated teams config" : "Die Einstellungen der Federated-Teams können nicht aktualisiert werden",
+    "Invalid URL format. Please provide a valid URL." : "Ungültiges URL-Format. Bitte eine gültige URL eingeben.",
+    "Changed frontal cloud URL" : "Frontal-Cloud-URL geändert",
+    "Federation allows you to share teams with other trusted servers and make them discoverable across instances." : "Federation ermöglicht Teams mit anderen vertrauenswürdigen Servern zu teilen und sie instanzübergreifend auffindbar zu machen.",
+    "Enable federated teams" : "Federated-Teams aktivieren",
+    "Frontal URL" : "Frontal-URL",
+    "https://…" : "https://…",
+    "The public URL used by other instances to discover and connect to your teams." : "Die öffentliche URL, die von anderen Instanzen verwendet wird, um deine Teams zu entdecken und eine Verbindung zu ihnen herzustellen.",
     "Failed to load teams" : "Teams konnten nicht geladen werden",
     "Try again" : "Nochmals versuchen",
     "No teams found" : "Keine Teams gefunden",
