@@ -143,9 +143,18 @@ OC.L10N.register(
     "%1$s shared some content with you. You should have already received a separate email with a link to access it." : "%1$s heeft enige informatie met je gedeeld.\nJe moet al een aparte e-mail hebben ontvangen met een link om er te komen.",
     "Password to access content shared with you by %1$s" : "Wachtwoord om toegang te krijgen tot inhoud gedeeld met u door %1$s",
     "Password to access content" : "Wachtwoord voor toegang tot info",
+    "Federated Teams" : "Federatieve Teams",
     "This item is already shared with this team" : "Dit object is al gedeeld met dit team",
     "Bring cloud-users closer together." : "Breng cloudgebruikers dichter bij elkaar.",
     "Teams allows people to create their own groups of people/colleagues/friends.\nThose groups of people can then be used by any other app for sharing purpose." : "Teams stelt mensen in staat om hun eigen groepen van mensen/collega's/vrienden aan te maken. Deze groepen kunnen vervolgens door andere apps worden gebruikt om gegevens te delen.",
+    "Unable to update federated teams config" : "Kan configuratie van federatieve teams niet bijwerken",
+    "Invalid URL format. Please provide a valid URL." : "Ongeldig URL-formaat. Geef een geldige URL op.",
+    "Changed frontal cloud URL" : "Voorfront cloud URL gewijzigd",
+    "Federation allows you to share teams with other trusted servers and make them discoverable across instances." : "Met Federation kunt u teams delen met andere vertrouwde servers en ze vindbaar maken voor alle instanties.",
+    "Enable federated teams" : "Federatieve teams inschakelen",
+    "Frontal URL" : "Voorfront URL",
+    "https://…" : "https://…",
+    "The public URL used by other instances to discover and connect to your teams." : "De openbare URL die door andere instanties wordt gebruikt om uw teams te vinden en er verbinding mee te maken.",
     "Failed to load teams" : "Teams laden is mislukt",
     "Try again" : "Probeer opnieuw",
     "No teams found" : "Geen teams gevonden",
