@@ -1,7 +1,6 @@
 OC.L10N.register(
     "circles",
     {
-    "Teams" : "Zespoły",
     "You created the team {circle}" : "Utworzyłeś zespół {circle}",
     "{author} created the team {circle}" : "{author} utworzył zespół {circle}",
     "You deleted {circle}" : "Usunąłeś {circle}",
@@ -52,6 +51,7 @@ OC.L10N.register(
     "{member} sent a request to join {circle}" : "{member} wysłał prośbę o dołączenie do kręgu {circle}",
     "You are the new owner of {circle}" : "Jesteś nowym właścicielem {circle}",
     "{member} is the new owner of {circle}" : "{member} został nowym właścicielem {circle}",
+    "Teams" : "Zespoły",
     "On events happening in a <strong>team</strong> of which you are a member" : "O wydarzeniach w <strong>zespole</strong>, którego jesteś członkiem",
     "Any important event in a <strong>team</strong> you are moderating" : "Każde ważne wydarzenie w <strong>zespole</strong>, który moderujesz",
     "On global events happening in any <strong>team</strong>" : "O wydarzeniach globalnych w dowolnym <strong>zespole</strong>",
@@ -106,12 +106,12 @@ OC.L10N.register(
     "Circles App Initialization" : "Inicjalizacja aplikacji Zespołów",
     "Fresh installation status" : "Stan nowej instalacji",
     "Building Local Database" : "Tworzenie lokalnej bazy danych",
-    "Testing Basic Circle Creation" : "Testowanie tworzenia podstawowego zespołu",
+    "Testing Basic Team Creation" : "Testowanie podstawowego tworzenia zespołu",
     "Adding local users and moderators" : "Dodawanie lokalnych użytkowników i moderatorów",
     "Show all teams" : "Pokaż wszystkie zespoły",
     "Create a new team" : "Utwórz nowy zespół",
     "Files" : "Pliki",
-    "This feature is not available for personal circles" : "Ta funkcja nie jest dostępna dla kręgów osobistych",
+    "This feature is not available for personal teams" : "Ta funkcja nie jest dostępna dla zespołów osobistych",
     "The team is not federated" : "Zespół nie jest sfederowany",
     "You cannot join this team" : "Nie możesz dołączyć do tego zespołu",
     "This member is not a moderator" : "Ten członek nie jest moderatorem",
@@ -119,10 +119,10 @@ OC.L10N.register(
     "This member does not exist" : "Ten członek nie istnieje",
     "This member is the owner of the team" : "Ten członek jest właścicielem zespołu",
     "Level cannot be changed for this type of member" : "Nie można zmienić poziomu dla tego typu członka",
-    "You are already a member of this circle" : "Już jesteś członkiem tego kręgu",
-    "You have been blocked from this circle" : "Zostałeś zablokowany w tym zespole",
-    "The account is already a member of this circle" : "Konto jest już członkiem tego zespołu",
-    "The account has already been invited into this circle" : "Konto zostało już zaproszone do tego zespołu",
+    "You are already a member of this team" : "Jesteś już członkiem tego zespołu",
+    "You have been blocked from this team" : "Zostałeś zablokowany w tym zespole",
+    "The account is already a member of this team" : "To konto jest już członkiem tego zespołu",
+    "The account has already been invited into this team" : "To konto zostało już zaproszone do tego zespołu",
     "%s (Team owned by %s)" : "%s (Zespół należący do %s)",
     "You are now a member of the Team \"%2$s\"" : "Jesteś teraz członkiem zespołu „%2$s”",
     "You have been invited by %1$s into the Team \"%2$s\"" : "Zostałeś zaproszony przez %1$s do zespołu „%2$s”",
@@ -143,9 +143,18 @@ OC.L10N.register(
     "%1$s shared some content with you. You should have already received a separate email with a link to access it." : "%1$s udostępnił Tobie niektóre treści. Powinieneś już otrzymać osobną wiadomość e-mail z linkiem, aby uzyskać do niego dostęp.",
     "Password to access content shared with you by %1$s" : "Hasło dostępu do treści udostępnionej Tobie przez %1$s",
     "Password to access content" : "Hasło dostępu do treści",
+    "Federated Teams" : "Zespoły federacyjne",
     "This item is already shared with this team" : "Ten element został już udostępniony temu zespołowi",
     "Bring cloud-users closer together." : "Integruje użytkowników chmury.",
     "Teams allows people to create their own groups of people/colleagues/friends.\nThose groups of people can then be used by any other app for sharing purpose." : "Zespoły umożliwiają tworzenie własnych grup osób/współpracowników/przyjaciół.\nTe grupy osób mogą być następnie wykorzystywane przez dowolną inną aplikację do celów udostępniania.",
+    "Unable to update federated teams config" : "Nie można zaktualizować konfiguracji zespołów federacyjnych",
+    "Invalid URL format. Please provide a valid URL." : "Nieprawidłowy format URL. Podaj prawidłowy adres URL.",
+    "Changed frontal cloud URL" : "Zmieniono czołowy URL chmury ",
+    "Federation allows you to share teams with other trusted servers and make them discoverable across instances." : "Federacja umożliwia udostępnianie zespołów innym zaufanym serwerom oraz ich wykrywanie między instancjami.",
+    "Enable federated teams" : "Włącz zespoły federacyjne",
+    "Frontal URL" : "Czołowy URL ",
+    "https://…" : "https://…",
+    "The public URL used by other instances to discover and connect to your teams." : "Publiczny adres URL używany przez inne instancje do wykrywania i łączenia się z Twoimi zespołami.",
     "Failed to load teams" : "Nie udało się wczytać zespołów",
     "Try again" : "Spróbuj ponownie",
     "No teams found" : "Nie znaleziono żadnych zespołów",
@@ -158,11 +167,6 @@ OC.L10N.register(
     "Name" : "Nazwa",
     "Size" : "Rozmiar",
     "Modified" : "Zmodyfikowano",
-    "Teams' files" : "Pliki zespołów",
-    "Select team to filter by" : "Wybierz zespół, według którego chcesz filtrować",
-    "Please select teams to filter by" : "Wybierz zespoły, według których chcesz filtrować",
-    "No files found for the selected teams" : "Nie znaleziono plików dla wybranych zespołów",
-    "Shared to Circles" : "Udostępnione dla zespołów",
-    "Circle" : "Krąg"
+    "Shared to Circles" : "Udostępnione dla zespołów"
 },
 "nplurals=4; plural=(n==1 ? 0 : (n%10>=2 && n%10<=4) && (n%100<12 || n%100>14) ? 1 : n!=1 && (n%10>=0 && n%10<=1) || (n%10>=5 && n%10<=9) || (n%100>=12 && n%100<=14) ? 2 : 3);");
