@@ -143,9 +143,18 @@ OC.L10N.register(
     "%1$s shared some content with you. You should have already received a separate email with a link to access it." : "%1$s compartilhou algum conteúdo com você. Você já deve ter recebido um e-mail separado com um link para acessá-lo.",
     "Password to access content shared with you by %1$s" : "Senha para acessar o conteúdo compartilhado com você por %1$s",
     "Password to access content" : "Senha para acessar o conteúdo",
+    "Federated Teams" : "Equipes federadas",
     "This item is already shared with this team" : "Este item já está compartilhado com esta equipe",
     "Bring cloud-users closer together." : "Reúna os usuários da nuvem.",
     "Teams allows people to create their own groups of people/colleagues/friends.\nThose groups of people can then be used by any other app for sharing purpose." : "O Equipes permite que as pessoas criem seus próprios grupos de pessoas/colegas/amigos. \nEsses grupos de pessoas podem então ser usados ​​por qualquer outro aplicativo para fins de compartilhamento.",
+    "Unable to update federated teams config" : "Não foi possível atualizar a configuração das equipes federadas",
+    "Invalid URL format. Please provide a valid URL." : "Formato de URL inválido. Por favor, fornece um URL válido.",
+    "Changed frontal cloud URL" : "URL de nuvem frontal alterado",
+    "Federation allows you to share teams with other trusted servers and make them discoverable across instances." : "A federação permite que você compartilhe equipes com outros servidores confiáveis e as torne detectáveis em todas as instâncias.",
+    "Enable federated teams" : "Ativar equipes federadas",
+    "Frontal URL" : "URL frontal",
+    "https://…" : "https://…",
+    "The public URL used by other instances to discover and connect to your teams." : "O URL público usado por outras instâncias para descobrir e se conectar às suas equipes.",
     "Failed to load teams" : "Falha ao carregar equipes",
     "Try again" : "Tentar novamente",
     "No teams found" : "Nenhuma equipe encontrada",
