@@ -199,6 +199,7 @@ class MemberRequest extends MemberRequestBuilder {
 		?IFederatedUser $initiator = null,
 		?MemberProbe $probe = null,
 		int $limit = 0,
+		bool $fullDetails = false,
 	): array {
 		if (is_null($probe)) {
 			$probe = new MemberProbe();
@@ -218,8 +219,20 @@ class MemberRequest extends MemberRequestBuilder {
 			)
 		);
 
-		$qb->leftJoinCircle(CoreQueryBuilder::MEMBER, $initiator);
-		$qb->leftJoinInvitedBy(CoreQueryBuilder::MEMBER);
+		if ($fullDetails) {
+			$qb->leftJoinCircle(CoreQueryBuilder::MEMBER, $initiator);
+			$qb->leftJoinInvitedBy(CoreQueryBuilder::MEMBER);
+		} elseif (!is_null($initiator)) {
+			// still need to confirm initiator level in relation to the circle
+			$aliasCircle = $qb->generateAlias(CoreQueryBuilder::MEMBER, CoreQueryBuilder::CIRCLE, $options);
+			$qb->leftJoin(
+				CoreQueryBuilder::MEMBER,
+				CoreRequestBuilder::TABLE_CIRCLE,
+				$aliasCircle,
+				$qb->expr()->eq($aliasCircle . '.unique_id', CoreQueryBuilder::MEMBER . '.circle_id')
+			);
+			$qb->limitToInitiator($aliasCircle, $initiator);
+		}
 
 		if ($probe->hasFilterRemoteInstance()) {
 			$aliasCircle = $qb->generateAlias(CoreQueryBuilder::MEMBER, CoreQueryBuilder::CIRCLE);
