@@ -73,19 +73,7 @@ OC.L10N.register(
     "Where: %s" : "Ubicació: %s",
     "%1$s via %2$s" : "%1$s mitjançant %2$s",
     "In the past on %1$s for the entire day" : "En el passat a %1$s durant tot el dia",
-    "_In a minute on %1$s for the entire day_::_In %n minutes on %1$s for the entire day_" : ["En un minut a %1$s durant tot el dia","En %n minuts a %1$s durant tot el dia"],
-    "_In a hour on %1$s for the entire day_::_In %n hours on %1$s for the entire day_" : ["En una hora a %1$s durant tot el dia","En %n hores a %1$s durant tot el dia"],
-    "_In a day on %1$s for the entire day_::_In %n days on %1$s for the entire day_" : ["En un dia a %1$s durant tot el dia","En %n dies a %1$s durant tot el dia"],
-    "_In a week on %1$s for the entire day_::_In %n weeks on %1$s for the entire day_" : ["En una setmana a %1$s durant tot el dia","En %n setmanes a %1$s durant tot el dia"],
-    "_In a month on %1$s for the entire day_::_In %n months on %1$s for the entire day_" : ["En un mes el %1$s durant tot el dia","En %n mesos el %1$s durant tot el dia"],
-    "_In a year on %1$s for the entire day_::_In %n years on %1$s for the entire day_" : ["En un any a %1$s durant tot el dia","En %n anys a %1$s durant tot el dia"],
     "In the past on %1$s between %2$s - %3$s" : "En el passat el dia %1$s entre les %2$s i les %3$s",
-    "_In a minute on %1$s between %2$s - %3$s_::_In %n minutes on %1$s between %2$s - %3$s_" : ["D'aquí a un minut el %1$s entre les %2$s i les %3$s","D’aquí a %n minuts el %1$s entre les %2$s i les %3$s"],
-    "_In a hour on %1$s between %2$s - %3$s_::_In %n hours on %1$s between %2$s - %3$s_" : ["D'aquí a una hora el %1$s entre les %2$s i les %3$s","D’aquí a %n hores el %1$s entre les %2$s i les %3$s"],
-    "_In a day on %1$s between %2$s - %3$s_::_In %n days on %1$s between %2$s - %3$s_" : ["En un dia el %1$s entre les %2$s i les %3$s","En %n dies el %1$s entre les %2$s i les %3$s"],
-    "_In a week on %1$s between %2$s - %3$s_::_In %n weeks on %1$s between %2$s - %3$s_" : ["En una setmana el %1$s entre les %2$s i les %3$s","En %n setmanes el %1$s entre les %2$s i les %3$s"],
-    "_In a month on %1$s between %2$s - %3$s_::_In %n months on %1$s between %2$s - %3$s_" : ["D'aquí a un mes el %1$s entre les %2$s i les %3$s","D’aquí a %n mesos el %1$s entre les %2$s i les %3$s"],
-    "_In a year on %1$s between %2$s - %3$s_::_In %n years on %1$s between %2$s - %3$s_" : ["D'aquí a un any el %1$s entre les %2$s i les %3$s","D’aquí %n anys el %1$s entre les %2$s i les %3$s"],
     "Could not generate when statement" : "No s'ha pogut generar la declaració de quan",
     "Every Day for the entire day" : "Cada dia durant tot el dia",
     "Every Day for the entire day until %1$s" : "Cada dia durant tot el dia fins a les %1$s",
@@ -123,26 +111,8 @@ OC.L10N.register(
     "On specific dates for the entire day until %1$s" : "En dates específiques durant tot el dia fins a les %1$s",
     "On specific dates between %1$s - %2$s until %3$s" : "En dates específiques entre les %1$s i les %2$s fins a %3$s",
     "In the past on %1$s" : "En el passat a %1$s",
-    "_In a minute on %1$s_::_In %n minutes on %1$s_" : ["En un minut a %1$s durant tot el dia","En %n minuts a %1$s durant tot el dia"],
-    "_In a hour on %1$s_::_In %n hours on %1$s_" : ["D'aquí a una hora a %1$s","D’aquí %n hores a %1$s"],
-    "_In a day on %1$s_::_In %n days on %1$s_" : ["En un dia el %1$s","En %n dies el %1$s"],
-    "_In a week on %1$s_::_In %n weeks on %1$s_" : ["D'aquí a una setmana el %1$s","D’aquí %n setmanes el %1$s"],
-    "_In a month on %1$s_::_In %n months on %1$s_" : ["D'aquí a un mes el %1$s","D’aquí %n mesos el %1$s"],
-    "_In a year on %1$s_::_In %n years on %1$s_" : ["D'aquí a un any el %1$s","D’aquí %n anys el %1$s"],
     "In the past on %1$s then on %2$s" : "En el passat el %1$s i després el %2$s",
-    "_In a minute on %1$s then on %2$s_::_In %n minutes on %1$s then on %2$s_" : ["D'aquí a un minut el %1$s i després el %2$s","D’aquí a %n minuts el %1$s i després el %2$s"],
-    "_In a hour on %1$s then on %2$s_::_In %n hours on %1$s then on %2$s_" : ["D'aquí a una hora el %1$s i després el %2$s","D’aquí %n hores el %1$s i després el %2$s"],
-    "_In a day on %1$s then on %2$s_::_In %n days on %1$s then on %2$s_" : ["En un dia el %1$s i després el %2$s","En %n dies el %1$s i després el %2$s"],
-    "_In a week on %1$s then on %2$s_::_In %n weeks on %1$s then on %2$s_" : ["D'aquí a una setmana el %1$s i després el %2$s","D’aquí %n setmanes el %1$s i després el %2$s"],
-    "_In a month on %1$s then on %2$s_::_In %n months on %1$s then on %2$s_" : ["D'aquí a un mes el %1$s i després el %2$s","D’aquí %n mesos el %1$s i després el %2$s"],
-    "_In a year on %1$s then on %2$s_::_In %n years on %1$s then on %2$s_" : ["D'aquí a un any el %1$s i després el %2$s","D’aquí %n anys el %1$s i després el %2$s"],
     "In the past on %1$s then on %2$s and %3$s" : "En el passat el %1$s, després el %2$s i el %3$s",
-    "_In a minute on %1$s then on %2$s and %3$s_::_In %n minutes on %1$s then on %2$s and %3$s_" : ["D'aquí a un minut el %1$s i després el %2$s i el %3$s","D’aquí a %n minuts el %1$s i després el %2$s i el %3$s"],
-    "_In a hour on %1$s then on %2$s and %3$s_::_In %n hours on %1$s then on %2$s and %3$s_" : ["D'aquí a una hora el %1$s i després el %2$s i el %3$s","D’aquí a %n hores el %1$s i després el %2$s i el %3$s"],
-    "_In a day on %1$s then on %2$s and %3$s_::_In %n days on %1$s then on %2$s and %3$s_" : ["D'aquí a un dia el %1$s i després el %2$s i el %3$s","D’aquí a %n dies el %1$s i després el %2$s i el %3$s"],
-    "_In a week on %1$s then on %2$s and %3$s_::_In %n weeks on %1$s then on %2$s and %3$s_" : ["D'aquí a una setmana el %1$s i després el %2$s i el %3$s","D’aquí a %n setmanes el %1$s i després el %2$s i el %3$s"],
-    "_In a month on %1$s then on %2$s and %3$s_::_In %n months on %1$s then on %2$s and %3$s_" : ["D'aquí a un mes el %1$s i després el %2$s i el %3$s","D’aquí a %n mesos el %1$s i després el %2$s i el %3$s"],
-    "_In a year on %1$s then on %2$s and %3$s_::_In %n years on %1$s then on %2$s and %3$s_" : ["D'aquí a un any el %1$s i després el %2$s i el %3$s","D’aquí a %n anys el %1$s i després el %2$s i el %3$s"],
     "Could not generate next recurrence statement" : "No s'ha pogut generar la següent instrucció de recurrència",
     "Cancelled: %1$s" : "S'ha cancel·lat: %1$s",
     "\"%1$s\" has been canceled" : "S'ha cancel·lat «%1$s»",
@@ -232,8 +202,6 @@ OC.L10N.register(
     "Could not rename part file to final file, canceled by hook" : "No s'ha pogut canviar el nom del fitxer de part al fitxer final perquè el ganxo ho ha cancel·lat",
     "Could not rename part file to final file" : "No s'ha pogut canviar el nom del fitxer de part al fitxer final",
     "Failed to check file size: %1$s" : "No s'ha pogut comprovar la mida del fitxer: %1$s",
-    "Could not open file: %1$s, file does seem to exist" : "No s'ha pogut obrir el fitxer: %1$s, el fitxer sembla que existeix",
-    "Could not open file: %1$s, file doesn't seem to exist" : "No s'ha pogut obrir el fitxer: %1$s, sembla que el fitxer no existeix",
     "Encryption not ready: %1$s" : "El xifratge no està preparat: %1$s",
     "Failed to open file: %1$s" : "No s'ha pogut obrir el fitxer: %1$s",
     "Failed to unlink: %1$s" : "No s'ha pogut desenllaçar: %1$s",
@@ -272,8 +240,6 @@ OC.L10N.register(
     "Last day (inclusive)" : "Darrer dia (inclòs)",
     "Out of office replacement (optional)" : "Substitució fora de l'oficina (opcional)",
     "Name of the replacement" : "Nom del substitut",
-    "No results." : "Cap resultat.",
-    "Start typing." : "Comença a escriure.",
     "Short absence status" : "Estat d'absència breu",
     "Long absence Message" : "Missatge d'absència llarga",
     "Save" : "Desa",
@@ -281,7 +247,6 @@ OC.L10N.register(
     "Failed to load availability" : "No s'ha pogut carregar la disponibilitat",
     "Saved availability" : "S'ha desat la disponibilitat",
     "Failed to save availability" : "No s'ha pogut desar la disponibilitat",
-    "Time zone:" : "Fus horari:",
     "to" : "a",
     "Delete slot" : "Suprimeix la franja",
     "No working hours set" : "No s'ha definit cap horari laboral",
@@ -290,10 +255,10 @@ OC.L10N.register(
     "Pick a start time for {dayName}" : "Trieu una hora d'inici per a {dayName}",
     "Pick a end time for {dayName}" : "Trieu una hora de finalització per a {dayName}",
     "Automatically set user status to \"Do not disturb\" outside of availability to mute all notifications." : "Estableix automàticament l'estat de l'usuari com a \"No molesteu” fora de la disponibilitat per a silenciar totes les notificacions.",
-    "Availability" : "Disponibilitat",
-    "If you configure your working hours, other people will see when you are out of office when they book a meeting." : "Si configureu el vostre horari laboral, la resta de persones veuran quan sou fora de l'oficina quan planifiquin una reunió.",
-    "Absence" : "Absència",
-    "Configure your next absence period." : "Configureu el pròxim període d'absència.",
+    "Cancel" : "Cancel·la",
+    "Import" : "Importa",
+    "Error while saving settings" : "S'ha produït un error en desar els paràmetres",
+    "Reset to default" : "Reinicialitza els valors per defecte",
     "Also install the {calendarappstoreopen}Calendar app{linkclose}, or {calendardocopen}connect your desktop & mobile for syncing ↗{linkclose}." : "Instal·leu també {calendarappstoreopen}l'aplicació Calendari{linkclose} o {calendardocopen}connecteu el vostre dispositiu d'escriptori i el mòbil per a sincronitzar-los ↗{linkclose}.",
     "Please make sure to properly set up {emailopen}the email server{linkclose}." : "Assegureu-vos de configurar correctament el{emailopen}servidor de correu electrònic{linkclose}.",
     "Calendar server" : "Servidor de calendari",
@@ -306,17 +271,49 @@ OC.L10N.register(
     "Send reminder notifications to calendar sharees as well" : "Envia també notificacions de recordatori als usuaris amb qui s'ha compartit el calendari",
     "Reminders are always sent to organizers and attendees." : "Sempre s'envien recordatoris als organitzadors i als assistents.",
     "Enable notifications for events via push" : "Habilita les notificacions automàtiques per als esdeveniments",
-    "Cancel" : "Cancel·la",
-    "Import" : "Importa",
-    "Error while saving settings" : "S'ha produït un error en desar els paràmetres",
+    "Availability" : "Disponibilitat",
+    "If you configure your working hours, other people will see when you are out of office when they book a meeting." : "Si configureu el vostre horari laboral, la resta de persones veuran quan sou fora de l'oficina quan planifiquin una reunió.",
+    "Absence" : "Absència",
+    "Configure your next absence period." : "Configureu el pròxim període d'absència.",
     "There was an error updating your attendance status." : "S'ha produït un error en actualitzar l'estat d'assistència.",
     "Please contact the organizer directly." : "Contacteu amb l'organització directament.",
     "Are you accepting the invitation?" : "Accepteu la invitació?",
     "Tentative" : "Provisional",
     "Your attendance was updated successfully." : "S'ha actualitzat correctament l'assistència.",
-    "Time:" : "Hora:",
-    "Could not open file" : "No s'ha pogut obrir el fitxer",
-    "Invalid chunk name" : "El nom del fragment no és vàlid",
-    "Could not rename part file assembled from chunks" : "No s'ha pogut canviar el nom del fitxer de part muntat a partir de fragments"
+    "_In a minute on %1$s for the entire day_::_In %n minutes on %1$s for the entire day_" : ["En un minut a %1$s durant tot el dia","En %n minuts a %1$s durant tot el dia"],
+    "_In a hour on %1$s for the entire day_::_In %n hours on %1$s for the entire day_" : ["En una hora a %1$s durant tot el dia","En %n hores a %1$s durant tot el dia"],
+    "_In a day on %1$s for the entire day_::_In %n days on %1$s for the entire day_" : ["En un dia a %1$s durant tot el dia","En %n dies a %1$s durant tot el dia"],
+    "_In a week on %1$s for the entire day_::_In %n weeks on %1$s for the entire day_" : ["En una setmana a %1$s durant tot el dia","En %n setmanes a %1$s durant tot el dia"],
+    "_In a month on %1$s for the entire day_::_In %n months on %1$s for the entire day_" : ["En un mes el %1$s durant tot el dia","En %n mesos el %1$s durant tot el dia"],
+    "_In a year on %1$s for the entire day_::_In %n years on %1$s for the entire day_" : ["En un any a %1$s durant tot el dia","En %n anys a %1$s durant tot el dia"],
+    "_In a minute on %1$s between %2$s - %3$s_::_In %n minutes on %1$s between %2$s - %3$s_" : ["D'aquí a un minut el %1$s entre les %2$s i les %3$s","D’aquí a %n minuts el %1$s entre les %2$s i les %3$s"],
+    "_In a hour on %1$s between %2$s - %3$s_::_In %n hours on %1$s between %2$s - %3$s_" : ["D'aquí a una hora el %1$s entre les %2$s i les %3$s","D’aquí a %n hores el %1$s entre les %2$s i les %3$s"],
+    "_In a day on %1$s between %2$s - %3$s_::_In %n days on %1$s between %2$s - %3$s_" : ["En un dia el %1$s entre les %2$s i les %3$s","En %n dies el %1$s entre les %2$s i les %3$s"],
+    "_In a week on %1$s between %2$s - %3$s_::_In %n weeks on %1$s between %2$s - %3$s_" : ["En una setmana el %1$s entre les %2$s i les %3$s","En %n setmanes el %1$s entre les %2$s i les %3$s"],
+    "_In a month on %1$s between %2$s - %3$s_::_In %n months on %1$s between %2$s - %3$s_" : ["D'aquí a un mes el %1$s entre les %2$s i les %3$s","D’aquí a %n mesos el %1$s entre les %2$s i les %3$s"],
+    "_In a year on %1$s between %2$s - %3$s_::_In %n years on %1$s between %2$s - %3$s_" : ["D'aquí a un any el %1$s entre les %2$s i les %3$s","D’aquí %n anys el %1$s entre les %2$s i les %3$s"],
+    "_In a minute on %1$s_::_In %n minutes on %1$s_" : ["En un minut a %1$s durant tot el dia","En %n minuts a %1$s durant tot el dia"],
+    "_In a hour on %1$s_::_In %n hours on %1$s_" : ["D'aquí a una hora a %1$s","D’aquí %n hores a %1$s"],
+    "_In a day on %1$s_::_In %n days on %1$s_" : ["En un dia el %1$s","En %n dies el %1$s"],
+    "_In a week on %1$s_::_In %n weeks on %1$s_" : ["D'aquí a una setmana el %1$s","D’aquí %n setmanes el %1$s"],
+    "_In a month on %1$s_::_In %n months on %1$s_" : ["D'aquí a un mes el %1$s","D’aquí %n mesos el %1$s"],
+    "_In a year on %1$s_::_In %n years on %1$s_" : ["D'aquí a un any el %1$s","D’aquí %n anys el %1$s"],
+    "_In a minute on %1$s then on %2$s_::_In %n minutes on %1$s then on %2$s_" : ["D'aquí a un minut el %1$s i després el %2$s","D’aquí a %n minuts el %1$s i després el %2$s"],
+    "_In a hour on %1$s then on %2$s_::_In %n hours on %1$s then on %2$s_" : ["D'aquí a una hora el %1$s i després el %2$s","D’aquí %n hores el %1$s i després el %2$s"],
+    "_In a day on %1$s then on %2$s_::_In %n days on %1$s then on %2$s_" : ["En un dia el %1$s i després el %2$s","En %n dies el %1$s i després el %2$s"],
+    "_In a week on %1$s then on %2$s_::_In %n weeks on %1$s then on %2$s_" : ["D'aquí a una setmana el %1$s i després el %2$s","D’aquí %n setmanes el %1$s i després el %2$s"],
+    "_In a month on %1$s then on %2$s_::_In %n months on %1$s then on %2$s_" : ["D'aquí a un mes el %1$s i després el %2$s","D’aquí %n mesos el %1$s i després el %2$s"],
+    "_In a year on %1$s then on %2$s_::_In %n years on %1$s then on %2$s_" : ["D'aquí a un any el %1$s i després el %2$s","D’aquí %n anys el %1$s i després el %2$s"],
+    "_In a minute on %1$s then on %2$s and %3$s_::_In %n minutes on %1$s then on %2$s and %3$s_" : ["D'aquí a un minut el %1$s i després el %2$s i el %3$s","D’aquí a %n minuts el %1$s i després el %2$s i el %3$s"],
+    "_In a hour on %1$s then on %2$s and %3$s_::_In %n hours on %1$s then on %2$s and %3$s_" : ["D'aquí a una hora el %1$s i després el %2$s i el %3$s","D’aquí a %n hores el %1$s i després el %2$s i el %3$s"],
+    "_In a day on %1$s then on %2$s and %3$s_::_In %n days on %1$s then on %2$s and %3$s_" : ["D'aquí a un dia el %1$s i després el %2$s i el %3$s","D’aquí a %n dies el %1$s i després el %2$s i el %3$s"],
+    "_In a week on %1$s then on %2$s and %3$s_::_In %n weeks on %1$s then on %2$s and %3$s_" : ["D'aquí a una setmana el %1$s i després el %2$s i el %3$s","D’aquí a %n setmanes el %1$s i després el %2$s i el %3$s"],
+    "_In a month on %1$s then on %2$s and %3$s_::_In %n months on %1$s then on %2$s and %3$s_" : ["D'aquí a un mes el %1$s i després el %2$s i el %3$s","D’aquí a %n mesos el %1$s i després el %2$s i el %3$s"],
+    "_In a year on %1$s then on %2$s and %3$s_::_In %n years on %1$s then on %2$s and %3$s_" : ["D'aquí a un any el %1$s i després el %2$s i el %3$s","D’aquí a %n anys el %1$s i després el %2$s i el %3$s"],
+    "Could not open file: %1$s, file does seem to exist" : "No s'ha pogut obrir el fitxer: %1$s, el fitxer sembla que existeix",
+    "Could not open file: %1$s, file doesn't seem to exist" : "No s'ha pogut obrir el fitxer: %1$s, sembla que el fitxer no existeix",
+    "No results." : "Cap resultat.",
+    "Start typing." : "Comença a escriure.",
+    "Time zone:" : "Fus horari:"
 },
 "nplurals=2; plural=(n != 1);");
