@@ -73,19 +73,19 @@ OC.L10N.register(
     "Where: %s" : "場所:%s",
     "%1$s via %2$s" : "%1$s に %2$s から",
     "In the past on %1$s for the entire day" : "過去に%1$sで終日",
-    "_In a minute on %1$s for the entire day_::_In %n minutes on %1$s for the entire day_" : ["終日%1$sの%n分"],
-    "_In a hour on %1$s for the entire day_::_In %n hours on %1$s for the entire day_" : ["終日%1$sの%n時間"],
-    "_In a day on %1$s for the entire day_::_In %n days on %1$s for the entire day_" : ["終日%1$sの%n日"],
-    "_In a week on %1$s for the entire day_::_In %n weeks on %1$s for the entire day_" : ["終日%1$sの%n週間"],
-    "_In a month on %1$s for the entire day_::_In %n months on %1$s for the entire day_" : ["終日%1$sの%nヶ月"],
-    "_In a year on %1$s for the entire day_::_In %n years on %1$s for the entire day_" : ["終日%1$sの%n年間"],
+    "_In %n minute on %1$s for the entire day_::_In %n minutes on %1$s for the entire day_" : ["終日%1$sの%n分"],
+    "_In %n hour on %1$s for the entire day_::_In %n hours on %1$s for the entire day_" : ["終日%1$sの%n時間"],
+    "_In %n day on %1$s for the entire day_::_In %n days on %1$s for the entire day_" : ["終日%1$sの%n日"],
+    "_In %n week on %1$s for the entire day_::_In %n weeks on %1$s for the entire day_" : ["終日%1$sの%n週間"],
+    "_In %n month on %1$s for the entire day_::_In %n months on %1$s for the entire day_" : ["終日%1$sの%nヶ月"],
+    "_In %n year on %1$s for the entire day_::_In %n years on %1$s for the entire day_" : ["終日%1$sの%n年間"],
     "In the past on %1$s between %2$s - %3$s" : "過去%1$s、%2$s～%3$sの間",
-    "_In a minute on %1$s between %2$s - %3$s_::_In %n minutes on %1$s between %2$s - %3$s_" : ["%2$s～%3$sの間の%1$sの%n分"],
-    "_In a hour on %1$s between %2$s - %3$s_::_In %n hours on %1$s between %2$s - %3$s_" : ["%2$s～%3$sの間の%1$sの%n時間"],
-    "_In a day on %1$s between %2$s - %3$s_::_In %n days on %1$s between %2$s - %3$s_" : ["%2$s～%3$sの間の%1$sの%n日間"],
-    "_In a week on %1$s between %2$s - %3$s_::_In %n weeks on %1$s between %2$s - %3$s_" : ["%2$s～%3$sの間の%1$sの%n週間"],
-    "_In a month on %1$s between %2$s - %3$s_::_In %n months on %1$s between %2$s - %3$s_" : ["%2$s～%3$sの間の%1$sの%nヶ月"],
-    "_In a year on %1$s between %2$s - %3$s_::_In %n years on %1$s between %2$s - %3$s_" : ["%2$s～%3$sの間の%1$sの%n年間"],
+    "_In %n minute on %1$s between %2$s - %3$s_::_In %n minutes on %1$s between %2$s - %3$s_" : ["%2$s～%3$sの間の%1$sの%n分"],
+    "_In %n hour on %1$s between %2$s - %3$s_::_In %n hours on %1$s between %2$s - %3$s_" : ["%2$s～%3$sの間の%1$sの%n時間"],
+    "_In %n day on %1$s between %2$s - %3$s_::_In %n days on %1$s between %2$s - %3$s_" : ["%2$s～%3$sの間の%1$sの%n日間"],
+    "_In %n week on %1$s between %2$s - %3$s_::_In %n weeks on %1$s between %2$s - %3$s_" : ["%2$s～%3$sの間の%1$sの%n週間"],
+    "_In %n month on %1$s between %2$s - %3$s_::_In %n months on %1$s between %2$s - %3$s_" : ["%2$s～%3$sの間の%1$sの%nヶ月"],
+    "_In %n year on %1$s between %2$s - %3$s_::_In %n years on %1$s between %2$s - %3$s_" : ["%2$s～%3$sの間の%1$sの%n年間"],
     "Could not generate when statement" : "when文を生成できませんでした",
     "Every Day for the entire day" : "毎日、終日",
     "Every Day for the entire day until %1$s" : "%1$sまでの終日、毎日",
@@ -123,26 +123,26 @@ OC.L10N.register(
     "On specific dates for the entire day until %1$s" : "%1$sまでの特定の日付の終日",
     "On specific dates between %1$s - %2$s until %3$s" : "%1$s～%2$sの間、%3$sまでの特定の日付",
     "In the past on %1$s" : "過去%1$s",
-    "_In a minute on %1$s_::_In %n minutes on %1$s_" : ["%1$sの%n分間"],
-    "_In a hour on %1$s_::_In %n hours on %1$s_" : ["%1$sの%n時間"],
-    "_In a day on %1$s_::_In %n days on %1$s_" : ["%1$sの%n日間"],
-    "_In a week on %1$s_::_In %n weeks on %1$s_" : ["%1$sの%n週間"],
-    "_In a month on %1$s_::_In %n months on %1$s_" : ["%1$sの%nヶ月"],
-    "_In a year on %1$s_::_In %n years on %1$s_" : ["%1$sの%n年間"],
+    "_In %n minute on %1$s_::_In %n minutes on %1$s_" : ["%1$sの%n分間"],
+    "_In %n hour on %1$s_::_In %n hours on %1$s_" : ["%1$sの%n時間"],
+    "_In %n day on %1$s_::_In %n days on %1$s_" : ["%1$sの%n日間"],
+    "_In %n week on %1$s_::_In %n weeks on %1$s_" : ["%1$sの%n週間"],
+    "_In %n month on %1$s_::_In %n months on %1$s_" : ["%1$sの%nヶ月"],
+    "_In %n year on %1$s_::_In %n years on %1$s_" : ["%1$sの%n年間"],
     "In the past on %1$s then on %2$s" : "過去%1$s、その後%2$s",
-    "_In a minute on %1$s then on %2$s_::_In %n minutes on %1$s then on %2$s_" : ["過去%1$sの%n分間、その後%2$s"],
-    "_In a hour on %1$s then on %2$s_::_In %n hours on %1$s then on %2$s_" : ["過去%1$sの%n時間、その後%2$s"],
-    "_In a day on %1$s then on %2$s_::_In %n days on %1$s then on %2$s_" : ["過去%1$sの%n日間、その後%2$s"],
-    "_In a week on %1$s then on %2$s_::_In %n weeks on %1$s then on %2$s_" : ["過去%1$sの%n週間、その後%2$s"],
-    "_In a month on %1$s then on %2$s_::_In %n months on %1$s then on %2$s_" : ["過去%1$sの%nヶ月、その後%2$s"],
-    "_In a year on %1$s then on %2$s_::_In %n years on %1$s then on %2$s_" : ["過去%1$sの%n年間、その後%2$s"],
+    "_In %n minute on %1$s then on %2$s_::_In %n minutes on %1$s then on %2$s_" : ["過去%1$sの%n分間、その後%2$s"],
+    "_In %n hour on %1$s then on %2$s_::_In %n hours on %1$s then on %2$s_" : ["過去%1$sの%n時間、その後%2$s"],
+    "_In %n day on %1$s then on %2$s_::_In %n days on %1$s then on %2$s_" : ["過去%1$sの%n日間、その後%2$s"],
+    "_In %n week on %1$s then on %2$s_::_In %n weeks on %1$s then on %2$s_" : ["過去%1$sの%n週間、その後%2$s"],
+    "_In %n month on %1$s then on %2$s_::_In %n months on %1$s then on %2$s_" : ["過去%1$sの%nヶ月、その後%2$s"],
+    "_In %n year on %1$s then on %2$s_::_In %n years on %1$s then on %2$s_" : ["過去%1$sの%n年間、その後%2$s"],
     "In the past on %1$s then on %2$s and %3$s" : "過去%1$s、その後%2$sと%3$s",
-    "_In a minute on %1$s then on %2$s and %3$s_::_In %n minutes on %1$s then on %2$s and %3$s_" : ["%1$sの%n分間、その後%2$sと%3$s"],
-    "_In a hour on %1$s then on %2$s and %3$s_::_In %n hours on %1$s then on %2$s and %3$s_" : ["%1$sの%n時間、その後%2$sと%3$s"],
-    "_In a day on %1$s then on %2$s and %3$s_::_In %n days on %1$s then on %2$s and %3$s_" : ["%1$sの%n日間、その後%2$sと%3$s"],
-    "_In a week on %1$s then on %2$s and %3$s_::_In %n weeks on %1$s then on %2$s and %3$s_" : ["%1$sの%n週間、その後%2$sと%3$s"],
-    "_In a month on %1$s then on %2$s and %3$s_::_In %n months on %1$s then on %2$s and %3$s_" : ["%1$sの%nヶ月、その後%2$sと%3$s"],
-    "_In a year on %1$s then on %2$s and %3$s_::_In %n years on %1$s then on %2$s and %3$s_" : ["%1$sの%n年間、その後%2$sと%3$s"],
+    "_In %n minute on %1$s then on %2$s and %3$s_::_In %n minutes on %1$s then on %2$s and %3$s_" : ["%1$sの%n分間、その後%2$sと%3$s"],
+    "_In %n hour on %1$s then on %2$s and %3$s_::_In %n hours on %1$s then on %2$s and %3$s_" : ["%1$sの%n時間、その後%2$sと%3$s"],
+    "_In %n day on %1$s then on %2$s and %3$s_::_In %n days on %1$s then on %2$s and %3$s_" : ["%1$sの%n日間、その後%2$sと%3$s"],
+    "_In %n week on %1$s then on %2$s and %3$s_::_In %n weeks on %1$s then on %2$s and %3$s_" : ["%1$sの%n週間、その後%2$sと%3$s"],
+    "_In %n month on %1$s then on %2$s and %3$s_::_In %n months on %1$s then on %2$s and %3$s_" : ["%1$sの%nヶ月、その後%2$sと%3$s"],
+    "_In %n year on %1$s then on %2$s and %3$s_::_In %n years on %1$s then on %2$s and %3$s_" : ["%1$sの%n年間、その後%2$sと%3$s"],
     "Could not generate next recurrence statement" : "次の再帰ステートメントを生成できませんでした",
     "Cancelled: %1$s" : "キャンセル: %1$s",
     "\"%1$s\" has been canceled" : "%1$sはキャンセルされました",
@@ -220,6 +220,8 @@ OC.L10N.register(
     "{actor} updated contact {card} in address book {addressbook}" : "{actor}がアドレス帳 {addressbook}の連絡先 {card}を更新しました",
     "You updated contact {card} in address book {addressbook}" : "アドレス帳 {addressbook}の連絡先 {card}を更新しました",
     "A <strong>contact</strong> or <strong>address book</strong> was modified" : "連絡先やアドレス帳が変更されたとき",
+    "System address book disabled" : "システムアドレス帳が無効化されました",
+    "The system contacts address book has been automatically disabled during upgrade. This means that the address book will no longer be available to users in the contacts app or other clients. The system contacts address book was disabled because the amount of contacts in the address book exceeded the maximum recommended number of contacts. This limit is set to prevent performance issues. You can re-enable the system address book with the following command {command}" : "システム連絡先アドレス帳はアップグレード中に自動的に無効化されました。これにより、連絡先アプリやその他のクライアントでユーザーがアドレス帳を利用できなくなります。システム連絡先アドレス帳が無効化されたのは、アドレス帳内の連絡先数が推奨最大数を超過したためです。この制限はパフォーマンス問題を防ぐために設定されています。以下のコマンドでシステムアドレス帳を再有効化できます {command}",
     "Accounts" : "アカウント",
     "System address book which holds all accounts" : "全アカウントが記録されているシステムアドレス帳",
     "File is not updatable: %1$s" : "ファイルが更新できません:%1$s",
@@ -232,8 +234,8 @@ OC.L10N.register(
     "Could not rename part file to final file, canceled by hook" : "最終ファイルの名前の変更が出来なかったため、フックによりキャンセルされました",
     "Could not rename part file to final file" : "最終ファイルの名前の変更が出来ませんでした",
     "Failed to check file size: %1$s" : "ファイルサイズの確認に失敗: %1$s",
-    "Could not open file: %1$s, file does seem to exist" : "ファイルを開けませんでした： %1$s、ファイルは存在するようです",
-    "Could not open file: %1$s, file doesn't seem to exist" : "ファイルを開けませんでした： %1$s ファイルが存在しないようです。",
+    "Could not open file: %1$s (%2$d), file does seem to exist" : "ファイルを開けませんでした: %1$s (%2$d)、ファイルは存在するようです",
+    "Could not open file: %1$s (%2$d), file doesn't seem to exist" : "ファイルを開けませんでした: %1$s (%2$d)、ファイルが存在しないようです",
     "Encryption not ready: %1$s" : "暗号化の準備が出来ていません: %1$s",
     "Failed to open file: %1$s" : "ファイルを開くのに失敗: %1$s",
     "Failed to unlink: %1$s" : "リンクの解除に失敗: %1$s",
@@ -258,6 +260,10 @@ OC.L10N.register(
     "DAV system address book" : "DAVシステムアドレス帳",
     "No outstanding DAV system address book sync." : "DAVシステムアドレス帳の同期が完了していません。",
     "The DAV system address book sync has not run yet as your instance has more than 1000 users or because an error occurred. Please run it manually by calling \"occ dav:sync-system-addressbook\"." : "DAVシステムのアドレス帳同期は、インスタンスに1000人以上のユーザーがいるか、エラーが発生したためまだ実行されていません。手動で実行するには、\"occ dav:sync-system-addressbook\"を呼び出してください。",
+    "DAV system address book size" : "DAVシステムアドレス帳のサイズ",
+    "The system address book is disabled" : "システムアドレス帳は無効化されています",
+    "The system address book is enabled, but contains more than the configured limit of %d contacts" : "システムアドレス帳は有効ですが、設定された上限の%d件を超える連絡先が含まれています",
+    "The system address book is enabled and contains less than the configured limit of %d contacts" : "システムアドレス帳は有効化されており、設定された上限である %d 件の連絡先を下回っています",
     "WebDAV endpoint" : "WebDAVエンドポイント",
     "Could not check that your web server is properly set up to allow file synchronization over WebDAV. Please check manually." : "WebDAVでのファイル同期を許可するようにWebサーバーが正しく設定されているか確認できませんでした。手動で確認してください。",
     "Your web server is not yet properly set up to allow file synchronization, because the WebDAV interface seems to be broken." : "WebDAVインターフェースが動作していないようです。Webサーバーは、ファイルの同期を許可するよう適切に設定されていません。",
@@ -274,8 +280,6 @@ OC.L10N.register(
     "Last day (inclusive)" : "最終日（含む）",
     "Out of office replacement (optional)" : "不在時の代理者（オプション）",
     "Name of the replacement" : "交代要員の氏名",
-    "No results." : "結果はありません。",
-    "Start typing." : "入力を開始する。",
     "Short absence status" : "短い不在のステータス",
     "Long absence Message" : "長期不在のメッセージ",
     "Save" : "保存",
@@ -283,7 +287,6 @@ OC.L10N.register(
     "Failed to load availability" : "可用性の読み込みに失敗",
     "Saved availability" : "可用性を保存しました",
     "Failed to save availability" : "可用性を保存しました",
-    "Time zone:" : "タイムゾーン：",
     "to" : "宛先",
     "Delete slot" : "スロットを削除",
     "No working hours set" : "勤務時間未設定",
@@ -311,10 +314,6 @@ OC.L10N.register(
     "Import calendar event" : "カレンダーイベントのインポート",
     "Uploading a new event will overwrite the existing one." : "新しいイベントをアップロードすると既存のイベントは上書きされます。",
     "Upload event" : "イベントをアップロード",
-    "Availability" : "応対可能日時",
-    "If you configure your working hours, other people will see when you are out of office when they book a meeting." : "勤務時間を設定すると、他のユーザが会議を予約する際に、あなたがいつ不在であるかがわかります。",
-    "Absence" : "不在",
-    "Configure your next absence period." : "次の不在期間を設定します。",
     "Also install the {calendarappstoreopen}Calendar app{linkclose}, or {calendardocopen}connect your desktop & mobile for syncing ↗{linkclose}." : "{calendarappstoreopen}カレンダーアプリ{linkclose}、または{calendardocopen}を同期させるためにデスクトップとモバイルを接続する ↗{linkclose}もインストールしてください。",
     "Please make sure to properly set up {emailopen}the email server{linkclose}." : "{emailopen}メールサーバー{linkclose}を正しく設定してください。",
     "Calendar server" : "カレンダーサーバー",
@@ -329,10 +328,49 @@ OC.L10N.register(
     "Enable notifications for events via push" : "イベントのプッシュ通知を有効にする",
     "Example content" : "コンテンツ例",
     "Example content serves to showcase the features of Nextcloud. Default content is shipped with Nextcloud, and can be replaced by custom content." : "コンテンツ例はNextcloudの機能を紹介するものです。デフォルトのコンテンツはNextcloudに同梱されており、カスタムコンテンツで置き換えることができます。",
+    "Availability" : "応対可能日時",
+    "If you configure your working hours, other people will see when you are out of office when they book a meeting." : "勤務時間を設定すると、他のユーザが会議を予約する際に、あなたがいつ不在であるかがわかります。",
+    "Absence" : "不在",
+    "Configure your next absence period." : "次の不在期間を設定します。",
     "There was an error updating your attendance status." : "出席状況の更新中にエラーが発生しました。",
     "Please contact the organizer directly." : "主催者に直接お問い合わせください。",
     "Are you accepting the invitation?" : "招待を受け入れていますか？",
     "Tentative" : "暫定的",
-    "Your attendance was updated successfully." : "出席は正常に更新されました。"
+    "Your attendance was updated successfully." : "出席は正常に更新されました。",
+    "_In a minute on %1$s for the entire day_::_In %n minutes on %1$s for the entire day_" : ["終日%1$sの%n分"],
+    "_In a hour on %1$s for the entire day_::_In %n hours on %1$s for the entire day_" : ["終日%1$sの%n時間"],
+    "_In a day on %1$s for the entire day_::_In %n days on %1$s for the entire day_" : ["終日%1$sの%n日"],
+    "_In a week on %1$s for the entire day_::_In %n weeks on %1$s for the entire day_" : ["終日%1$sの%n週間"],
+    "_In a month on %1$s for the entire day_::_In %n months on %1$s for the entire day_" : ["終日%1$sの%nヶ月"],
+    "_In a year on %1$s for the entire day_::_In %n years on %1$s for the entire day_" : ["終日%1$sの%n年間"],
+    "_In a minute on %1$s between %2$s - %3$s_::_In %n minutes on %1$s between %2$s - %3$s_" : ["%2$s～%3$sの間の%1$sの%n分"],
+    "_In a hour on %1$s between %2$s - %3$s_::_In %n hours on %1$s between %2$s - %3$s_" : ["%2$s～%3$sの間の%1$sの%n時間"],
+    "_In a day on %1$s between %2$s - %3$s_::_In %n days on %1$s between %2$s - %3$s_" : ["%2$s～%3$sの間の%1$sの%n日間"],
+    "_In a week on %1$s between %2$s - %3$s_::_In %n weeks on %1$s between %2$s - %3$s_" : ["%2$s～%3$sの間の%1$sの%n週間"],
+    "_In a month on %1$s between %2$s - %3$s_::_In %n months on %1$s between %2$s - %3$s_" : ["%2$s～%3$sの間の%1$sの%nヶ月"],
+    "_In a year on %1$s between %2$s - %3$s_::_In %n years on %1$s between %2$s - %3$s_" : ["%2$s～%3$sの間の%1$sの%n年間"],
+    "_In a minute on %1$s_::_In %n minutes on %1$s_" : ["%1$sの%n分間"],
+    "_In a hour on %1$s_::_In %n hours on %1$s_" : ["%1$sの%n時間"],
+    "_In a day on %1$s_::_In %n days on %1$s_" : ["%1$sの%n日間"],
+    "_In a week on %1$s_::_In %n weeks on %1$s_" : ["%1$sの%n週間"],
+    "_In a month on %1$s_::_In %n months on %1$s_" : ["%1$sの%nヶ月"],
+    "_In a year on %1$s_::_In %n years on %1$s_" : ["%1$sの%n年間"],
+    "_In a minute on %1$s then on %2$s_::_In %n minutes on %1$s then on %2$s_" : ["過去%1$sの%n分間、その後%2$s"],
+    "_In a hour on %1$s then on %2$s_::_In %n hours on %1$s then on %2$s_" : ["過去%1$sの%n時間、その後%2$s"],
+    "_In a day on %1$s then on %2$s_::_In %n days on %1$s then on %2$s_" : ["過去%1$sの%n日間、その後%2$s"],
+    "_In a week on %1$s then on %2$s_::_In %n weeks on %1$s then on %2$s_" : ["過去%1$sの%n週間、その後%2$s"],
+    "_In a month on %1$s then on %2$s_::_In %n months on %1$s then on %2$s_" : ["過去%1$sの%nヶ月、その後%2$s"],
+    "_In a year on %1$s then on %2$s_::_In %n years on %1$s then on %2$s_" : ["過去%1$sの%n年間、その後%2$s"],
+    "_In a minute on %1$s then on %2$s and %3$s_::_In %n minutes on %1$s then on %2$s and %3$s_" : ["%1$sの%n分間、その後%2$sと%3$s"],
+    "_In a hour on %1$s then on %2$s and %3$s_::_In %n hours on %1$s then on %2$s and %3$s_" : ["%1$sの%n時間、その後%2$sと%3$s"],
+    "_In a day on %1$s then on %2$s and %3$s_::_In %n days on %1$s then on %2$s and %3$s_" : ["%1$sの%n日間、その後%2$sと%3$s"],
+    "_In a week on %1$s then on %2$s and %3$s_::_In %n weeks on %1$s then on %2$s and %3$s_" : ["%1$sの%n週間、その後%2$sと%3$s"],
+    "_In a month on %1$s then on %2$s and %3$s_::_In %n months on %1$s then on %2$s and %3$s_" : ["%1$sの%nヶ月、その後%2$sと%3$s"],
+    "_In a year on %1$s then on %2$s and %3$s_::_In %n years on %1$s then on %2$s and %3$s_" : ["%1$sの%n年間、その後%2$sと%3$s"],
+    "Could not open file: %1$s, file does seem to exist" : "ファイルを開けませんでした： %1$s、ファイルは存在するようです",
+    "Could not open file: %1$s, file doesn't seem to exist" : "ファイルを開けませんでした： %1$s ファイルが存在しないようです。",
+    "No results." : "結果はありません。",
+    "Start typing." : "入力を開始する。",
+    "Time zone:" : "タイムゾーン："
 },
 "nplurals=1; plural=0;");
