@@ -25,14 +25,14 @@ OC.L10N.register(
     "Provide federated file sharing across servers" : "Zezwalaj na udostępnianie federacyjne plików na serwerach",
     "Confirm data upload to lookup server" : "Potwierdź przesyłanie danych do serwera wyszukiwania",
     "When enabled, all account properties (e.g. email address) with scope visibility set to \"published\", will be automatically synced and transmitted to an external system and made available in a public, global address book." : "Po włączeniu wszystkie właściwości konta (np. adres e-mail) z ustawioną widocznością na \"opublikowana” będą automatycznie synchronizowane i przesyłane do zewnętrznego systemu oraz udostępniane w publicznej, globalnej książce adresowej.",
-    "Disable upload" : "Wyłącz przesyłanie",
     "Enable data upload" : "Włącz przesyłanie danych",
+    "Disable upload" : "Wyłącz przesyłanie",
     "Confirm querying lookup server" : "Potwierdź zapytania do serwera wyszukiwania",
     "When enabled, the search input when creating shares will be sent to an external system that provides a public and global address book." : "Po włączeniu pole wyszukiwania podczas udostępniania zostanie wysłane do zewnętrznego systemu, który udostępnia publiczną i globalną książkę adresową.",
     "This is used to retrieve the federated cloud ID to make federated sharing easier." : "Służy do pobierania ID Chmury Federacyjnej, aby ułatwić udostępnianie federacyjne.",
     "Moreover, email addresses of users might be sent to that system in order to verify them." : "Ponadto adresy e-mail użytkowników mogą być wysyłane do tego systemu w celu ich weryfikacji.",
-    "Disable querying" : "Wyłącz zapytania",
     "Enable querying" : "Włącz zapytania",
+    "Disable querying" : "Wyłącz zapytania",
     "Unable to update federated files sharing config" : "Nie można zaktualizować konfiguracji udostępniania federacyjnego plików",
     "Adjust how people can share between servers. This includes shares between people on this server as well if they are using federated sharing." : "Dostosuj sposób udostępniania między serwerami. Obejmuje to również udostępnianie między ludźmi na tym serwerze, jeśli korzystają z udostępniania federacyjnego.",
     "Allow people on this server to send shares to other servers (this option also allows WebDAV access to public shares)" : "Zezwalaj ludziom na tym serwerze na wysłanie udostępnień do innych serwerów (opcja ta umożliwia również dostęp WebDAV do udostępnień publicznych)",
@@ -55,11 +55,9 @@ OC.L10N.register(
     "You can share with anyone who uses a {productName} server or other Open Cloud Mesh (OCM) compatible servers and services! Just put their Federated Cloud ID in the share dialog. It looks like person@cloud.example.com" : "Możesz udostępniać każdemu, kto korzysta z serwera {productName} lub innych serwerów i usług kompatybilnych z Open Cloud Mesh (OCM)! Wystarczy wpisać ich Federated Cloud ID w oknie dialogowym udostępniania. Wygląda to tak: person@cloud.example.com",
     "Your Federated Cloud ID" : "Twój Federowany identyfikator chmury",
     "Share it so your friends can share files with you:" : "Udostępnij, aby Twoi znajomi mogli udostępniać Tobie pliki:",
-    "Facebook" : "Facebook",
-    "X (formerly Twitter)" : "X (dawniej Twitter)",
-    "formerly Twitter" : "dawny Twitter",
-    "Mastodon" : "Mastodon",
     "Bluesky" : "Bluesky",
+    "Facebook" : "Facebook",
+    "Mastodon" : "Mastodon",
     "Add to your website" : "Dodaj do swojej strony",
     "Share with me via {productName}" : "Udostępnij mi przez {productName}",
     "HTML Code:" : "Kod HTML:",
@@ -71,6 +69,8 @@ OC.L10N.register(
     "Incoming share could not be processed" : "Nie można przetworzyć przychodzącego udostępnienia",
     "Cloud ID copied to the clipboard" : "ID chmury skopiowany do schowka",
     "Copy to clipboard" : "Kopiuj do schowka",
-    "You can share with anyone who uses a Nextcloud server or other Open Cloud Mesh (OCM) compatible servers and services! Just put their Federated Cloud ID in the share dialog. It looks like person@cloud.example.com" : "Możesz udostępniać każdemu, kto używa serwera Nextcloud lub innych serwerów i usług kompatybilnych z Open Cloud Mesh (OCM). Wystarczy, że wpiszesz ID Chmury Federacyjnej w oknie udostępniania, według przykładu: osoba@chmura.przykładowa.com"
+    "You can share with anyone who uses a Nextcloud server or other Open Cloud Mesh (OCM) compatible servers and services! Just put their Federated Cloud ID in the share dialog. It looks like person@cloud.example.com" : "Możesz udostępniać każdemu, kto używa serwera Nextcloud lub innych serwerów i usług kompatybilnych z Open Cloud Mesh (OCM). Wystarczy, że wpiszesz ID Chmury Federacyjnej w oknie udostępniania, według przykładu: osoba@chmura.przykładowa.com",
+    "X (formerly Twitter)" : "X (dawniej Twitter)",
+    "formerly Twitter" : "dawny Twitter"
 },
 "nplurals=4; plural=(n==1 ? 0 : (n%10>=2 && n%10<=4) && (n%100<12 || n%100>14) ? 1 : n!=1 && (n%10>=0 && n%10<=1) || (n%10>=5 && n%10<=9) || (n%100>=12 && n%100<=14) ? 2 : 3);");
