@@ -11,7 +11,18 @@ OC.L10N.register(
     "Federation" : "Federování",
     "Federation allows you to connect with other trusted servers to exchange the account directory." : "Federování umožňuje propojit s ostatními servery, kterým věříte a vyměňovat si tak adresář účtů.",
     "Federation allows you to connect with other trusted servers to exchange the account directory. For example this will be used to auto-complete external accounts for federated sharing." : "Federování umožňuje propojit s ostatními servery, kterým věříte a vyměňovat si tak adresář uživatelských účtů. Používá se toho například pro automatické doplňování externích účtů při federovaném sdílení.",
+    "Could not add trusted server. Please try again later." : "Nebylo možné přidat důvěryhodný server. Zkuste to prosím později znovu.",
+    "Add trusted server" : "Přidat dúvěryhodný server",
+    "Server url" : "URL serveru",
     "Add" : "Přidat",
+    "Server ok" : "Server v pořádku",
+    "User list was exchanged at least once successfully with the remote server." : "Seznam uživatelů byl alespoň jednou úspěšně vyměněn se vzdáleným serverem.",
+    "Server pending" : "Server čekající",
+    "Waiting for shared secret or initial user list exchange." : "Čeká se na sdílené tajemství nebo úvodní výměnu seznamu uživatelů.",
+    "Server access revoked" : "Přístup serveru odvolán",
+    "Server failure" : "Selhání serveru",
+    "Connection to the remote server failed or the remote server is misconfigured." : "Připojení ke vzdálenému serveru se nezdařilo nebo vzdálený server není správně nastavený.",
+    "Failed to delete trusted server. Please try again later." : "Nepodařilo se smazat důvěryhodný server. Zkuste to prosím později znovu.",
     "Delete" : "Smazat",
     "Federation allows you to connect with other trusted servers to exchange the account directory. For example this will be used to auto-complete external accounts for federated sharing. It is not necessary to add a server as trusted server in order to create a federated share." : "Federování umožňuje propojit se s ostatními servery, kterým věříte a vyměňovat si tak adresář uživatelských účtů. Používá se toho například pro automatické dokončování externích účtů při federovaném sdílení. Nicméně pro vytvoření federovaného sdílení jako takového není nezbytné přidávat server jako důvěryhodný.",
     "Each server must validate the other. This process may require a few cron cycles." : "Je třeba, aby každý server ověřil ten druhý. Tento proces může vyžadovat několik cyklů plánovače.",
