@@ -74,6 +74,7 @@ OC.L10N.register(
     "Reload current directory" : "إعادة تحميل المجلد الحالي",
     "Go to the \"{dir}\" directory" : "إنتقل إلى المجلد \"{dir}\"",
     "Current directory path" : "مسار المجلد الحالي",
+    "Share" : "مشاركة",
     "Your have used your space quota and cannot upload files anymore" : "لقد استنفذت حصتك التخزينية و لم يعد بإمكانك رفع أي ملفات الآن",
     "You do not have permission to upload or create files here." : "أنت ليس لديك إذنٌ برفع أو إنشاء الملفات هنا.",
     "Drag and drop files here to upload" : "إسحب وأفلت الملفات هنا لرفعها",
@@ -88,18 +89,29 @@ OC.L10N.register(
     "This node is unavailable" : "هذه العُقْدَة node غير متوفرة ",
     "Another entry with the same name already exists." : "توجد سلفاً إدخالية أخرى بنفس هذا الاسم.",
     "Invalid filename." : "اسم ملف غير صحيح.",
-    "Renamed \"{oldName}\" to \"{newName}\"" : "تمت إعادة تسمية \"{oldName}\" إلى \"{newName}\"",
     "Rename file" : "إعادة تسمية الملف",
     "Folder" : "مجلد",
     "Unknown file type" : "نوع ملف غير معروف",
     "Pending" : "قيد الانتظار",
     "Unknown date" : "تاريخ غير معروف",
-    "Clear filter" : "إزالة التصفية",
-    "Modified" : "التعديل",
-    "Search everywhere" : "البحث الشامل",
-    "Type" : "النوع",
     "Active filters" : "فلاتر نشطة",
     "Remove filter" : "إزالة عامل التصفية ",
+    "Today" : "اليوم",
+    "Last 7 days" : "آخر 7 أيام",
+    "Last 30 days" : "آخر 30 يوماً",
+    "This year ({year})" : "هذا العام ({year})",
+    "Last year ({year})" : "العام الماضي ({year})",
+    "Custom date range" : "نطاق زمني مخصص",
+    "Search everywhere" : "البحث الشامل",
+    "Documents" : "المستندات",
+    "Spreadsheets" : "الجداول الالكترونية",
+    "Presentations" : "العروض",
+    "PDFs" : "ملفات PDF",
+    "Folders" : "المجلدات",
+    "Audio" : "صوت",
+    "Images" : "الصِّوَر",
+    "Videos" : "مقاطع فيديو",
+    "Filters" : "فلاتر",
     "Appearance" : "المظهر",
     "Show hidden files" : "عرض الملفات المخفية",
     "Show file type column" : "عرض عمود نوع الملف",
@@ -126,6 +138,7 @@ OC.L10N.register(
     "Name" : "الاسم",
     "File type" : "نوع الملف",
     "Size" : "الحجم",
+    "Modified" : "التعديل",
     "(selected)" : "(تم اختياره)",
     "List of files and folders." : "قائمة الملفات والمجلدات",
     "You have used your space quota and cannot upload files anymore." : "لقد قمت باستنفاذ كامل حصتك التخزينية و لايمكنك تحميل المزيد من الملفات.",
@@ -133,6 +146,7 @@ OC.L10N.register(
     "This list is not fully rendered for performance reasons. The files will be rendered as you navigate through the list." : "لم يتم عرض هذه القائمة بالكامل لأسباب تتعلق بالأداء. سيتم عرض الملفات تباعاً أثناء التنقل عبر القائمة.",
     "File not found" : "تعذر العثور على الملف",
     "_{count} selected_::_{count} selected_" : ["{count} تمّ تحديده","{count} تمّ تحديده","{count} تمّ تحديده","{count} تمّ تحديده","{count} تمّ تحديده","{count} تمّ تحديده"],
+    "Owner" : "المالك",
     "{usedQuotaByte} used" : "{usedQuotaByte} مستخدمة",
     "{used} of {quota} used" : "{used} من {quota} مستخدم",
     "{relative}% used" : "{relative}% مستخدمة",
@@ -168,12 +182,11 @@ OC.L10N.register(
     "Removing the file extension \"{old}\" may render the file unreadable." : "إزالة الامتداد \"{old}\" من اسم الملف يمكن أن يتسبب في تغيير طريقة تناول و عرض الملف أو يجعله غير قابل للعرض.",
     "Adding the file extension \"{new}\" may render the file unreadable." : "إضافة الامتداد \"{new}\" لاسم الملف يمكن أن يتسبب في تغيير طريقة تناول و عرض الملف أو أن يجعله غير قابل للعرض.",
     "Do not show this dialog again." : "لا تُظهِر هذه النافذة مرة أخرى",
+    "Cancel" : "إلغاء",
+    "Rename" : "إعادة التسمية",
     "Select file or folder to link to" : "اختر ملف أو مجلد للربط معه",
     "Choose {file}" : "إختر {file}",
     "Files settings" : "إعدادات الملفات",
-    "Share" : "مشاركة",
-    "Shared by link" : "شاركته باستخدام رابط مشاركة",
-    "Shared" : "مشاركة",
     "Switch to list view" : "التبديل إلى عرض القائمة",
     "Switch to grid view" : "تبديل إلى العرض الشبكي",
     "The file could not be found" : "تعذّر إيجاد الملف",
@@ -189,14 +202,6 @@ OC.L10N.register(
     "Upload some content or sync with your devices!" : "ارفع بعض المحتوى أو قم بالمزامنة مع أجهزتك!",
     "Go back" : "العودة",
     "Views" : "مشاهدات",
-    "You" : "أنت",
-    "Shared multiple times with different people" : "تمّت مشاركته عدة مرات مع أشخاص متعددين",
-    "Unable to change the favorite state of the file" : "تعذّر تغيير حالة المُفضَّلة للملف",
-    "Error while loading the file data" : "خطأ اثناء تحميل بيانات الملف",
-    "Owner" : "المالك",
-    "Remove from favorites" : "إزالة من المفضلة",
-    "Add to favorites" : "إضافة إلى المفضلة",
-    "Tags" : "الوسوم",
     "Your files" : "ملفاتك",
     "Open in files" : "فتح في تطبيق الملفات",
     "File cannot be accessed" : "الملف لم يمكن الوصول إليه",
@@ -233,23 +238,23 @@ OC.L10N.register(
     "_You are about to permanently delete {count} item_::_You are about to permanently delete {count} items_" : ["أنت على وشك أن تحذف نهائياً  {count} عنصراً","أنت على وشك أن تحذف نهائياً {count} عنصراً","أنت على وشك أن تحذف نهائياً  {count} عنصراً","أنت على وشك أن تحذف نهائياً {count} عناصر","أنت على وشك أن تحذف نهائياً {count} عناصر","أنت على وشك حذف {count} عنصر بشكل نهائي "],
     "_You are about to delete {count} item_::_You are about to delete {count} items_" : ["أنت على وشك أن تحذف {count} عنصراً","أنت على وشك أن تحذف {count} عنصراً","أنت على وشك أن تحذف {count} عنصراً","أنت على وشك أن تحذف {count} عناصر","أنت على وشك أن تحذف {count} عناصر","أنت على وشك أن تحذف {count} عنصراً"],
     "Confirm deletion" : "تأكيد الحذف",
-    "Cancel" : "إلغاء",
     "Download" : "تنزيل",
+    "Add to favorites" : "إضافة إلى المفضلة",
+    "Remove from favorites" : "إزالة من المفضلة",
+    "Move" : "نقل",
+    "Copy" : "نسخ",
+    "Move or copy" : "نقل أو نسخ",
     "Destination is not a folder" : "الوجهة ليست مجلد",
     "This file/folder is already in that directory" : "هذا الملف/المجلد موجود سلفاً في ذلك المجلد",
     "You cannot move a file/folder onto itself or into a subfolder of itself" : "لا يمكنك نقل ملف/مجلد إلى نفسه أو إلى مجلد فرعي منه",
-    "(copy)" : "(نسخ)",
-    "(copy %n)" : "(نسخ %n)",
     "A file or folder with that name already exists in this folder" : "ملف أو مجلد بنفس ذاك الاسم موجود سلفاً في هذا المجلد",
     "The files are locked" : "الملفات مقفلة",
     "The file does not exist anymore" : "الملف لم يعد موجوداً",
     "Choose destination" : "تحديد الوجهة",
     "Copy to {target}" : "نسخ إلى {target}",
-    "Copy" : "نسخ",
     "Move to {target}" : "نقل إلى {target}",
-    "Move" : "نقل",
     "Move or copy operation failed" : "عملية النسخ أو النقل فشلت",
-    "Move or copy" : "نقل أو نسخ",
+    "Open folder" : "فتح المجلد",
     "Open folder {displayName}" : "فتح المجلد {displayName}",
     "Open in Files" : "فتح في \"الملفات\"",
     "Open locally" : "الفتح محلّيّاً",
@@ -258,22 +263,10 @@ OC.L10N.register(
     "The file should now open on your device. If it doesn't, please check that you have the desktop app installed." : "يجب أن يفتح الملف الآن على جهازك. إذا لم يحدث ذلك، فيرجى التأكد من تثبيت تطبيق سطح المكتب.",
     "Retry and close" : "أعِد المحاولة ثم أغلِق",
     "Open online" : "إفتَح مُتَّصِلاً بالإنترنت",
-    "Rename" : "إعادة التسمية",
     "Details" : "التفاصيل",
+    "Unfavorite" : "إبعادٌ من المُفضّلة",
     "View in folder" : "عرض في المجلد",
-    "Today" : "اليوم",
-    "Last 7 days" : "آخر 7 أيام",
-    "Last 30 days" : "آخر 30 يوماً",
-    "This year ({year})" : "هذا العام ({year})",
-    "Last year ({year})" : "العام الماضي ({year})",
-    "Documents" : "المستندات",
-    "Spreadsheets" : "الجداول الالكترونية",
-    "Presentations" : "العروض",
-    "PDFs" : "ملفات PDF",
-    "Folders" : "المجلدات",
-    "Audio" : "صوت",
-    "Images" : "الصِّوَر",
-    "Videos" : "مقاطع فيديو",
+    "Type" : "النوع",
     "Created new folder \"{name}\"" : "تمّ إنشاء مجلد جديد باسم \"{name}\"",
     "Unable to initialize the templates directory" : "تعذر تهيئة دليل القوالب",
     "Create templates folder" : "إنشاء مجلد للقوالب",
@@ -288,10 +281,10 @@ OC.L10N.register(
     "Some files could not be uploaded" : "بعض الملفات لم يمكن رفعها",
     "Files uploaded successfully" : "تمّ رفع الملفات بنجاح",
     "No files to process" : "لا توجد ملفات لمعالجتها",
-    "Some files could not be copied" : "بعض الملفات لا يمكن نسخها",
-    "Some files could not be moved" : "تعذر نقل بعض الملفات",
     "Files copied successfully" : "تمّ نسخ الملفات بنجاح",
     "Files moved successfully" : "تمّ نقل الملفات بنجاح",
+    "Some files could not be copied" : "بعض الملفات لا يمكن نسخها",
+    "Some files could not be moved" : "تعذر نقل بعض الملفات",
     "Conflicts resolution skipped" : "تمّ تخطّي حلّ التعارضات",
     "Upload cancelled" : "تمّ إلغاء الرفع",
     "Could not rename \"{oldName}\", it does not exist any more" : "تعذر إعادة تسمية \"{oldName}\"، لم يعد موجودًا",
@@ -327,10 +320,14 @@ OC.L10N.register(
     "Upload (max. %s)" : "الرفع ( حد اقصى. %s ) ",
     "After enabling the windows compatible filenames, existing files cannot be modified anymore but can be renamed to valid new names by their owner." : "بعد تمكين أسماء الملفات المتوافقة مع نظام التشغيل Windows، لا يمكن تعديل الملفات الموجودة بعد الآن ولكن يمكن إعادة تسميتها إلى أسماء جديدة صالحة بواسطة مالكها.",
     "It is also possible to migrate files automatically after enabling this setting, please refer to the documentation about the occ command." : "من الممكن أيضًا ترحيل الملفات تلقائيًا بعد تمكين هذا الإعداد، يرجى الرجوع إلى الوثائق المتعلقة بأمر occ.",
+    "Renamed \"{oldName}\" to \"{newName}\"" : "تمت إعادة تسمية \"{oldName}\" إلى \"{newName}\"",
+    "Clear filter" : "إزالة التصفية",
     "\"{displayName}\" failed on some elements" : "\"{displayName}\" فشل في بعض العناصر",
     "\"{displayName}\" batch action executed successfully" : "\"{displayName}\" حزمة الأوامر تم تنفيذها بنجاح",
     "\"{displayName}\" action failed" : "\"{displayName}\" الأمر أخفق عند التنفيذ",
     "Submitting fields …" : "إرسال الحقول ...",
+    "Shared by link" : "شاركته باستخدام رابط مشاركة",
+    "Shared" : "مشاركة",
     "\"{displayName}\" action executed successfully" : "\"{displayName}\" الأمر نُفّذ بنجاح",
     "Filter file names …" : "تصفية بأسماء الملفات...",
     "Clipboard is not available" : "الحافظة غير متاحة",
@@ -360,6 +357,11 @@ OC.L10N.register(
     "Navigate to the file on the right (in grid mode)" : "إنتقِل إلى الملف أيمنه (في الشبكة)",
     "Toggle the grid view" : "بدِّل وضعية الشبكة",
     "Open the sidebar for a file" : "إفتَح الشريط الجانبي للملف",
+    "You" : "أنت",
+    "Shared multiple times with different people" : "تمّت مشاركته عدة مرات مع أشخاص متعددين",
+    "Unable to change the favorite state of the file" : "تعذّر تغيير حالة المُفضَّلة للملف",
+    "Error while loading the file data" : "خطأ اثناء تحميل بيانات الملف",
+    "Tags" : "الوسوم",
     "Save as …" : "حفظ باسم ...",
     "Converting files …" : "تحويل الملفات ...",
     "Converting file …" : "تحويل الملف ...",
@@ -367,6 +369,8 @@ OC.L10N.register(
     "Edit locally" : "تحرير الملف محلياً",
     "Moving \"{source}\" to \"{destination}\" …" : "نقل \"{source}\" إلى \"{destination}\" …",
     "Copying \"{source}\" to \"{destination}\" …" : "نسخ \"{source}\" إلى \"{destination}\" …",
+    "(copy)" : "(نسخ)",
+    "(copy %n)" : "(نسخ %n)",
     "Move cancelled" : "تمّ إلغاء النقل",
     "Cancelled move or copy of \"{filename}\"." : "تمّ إلغاء عملية حذف أو نقل الملف \"{filename}\".",
     "Cancelled move or copy operation" : ".عملية النسخ أو النقل تمّ إلغاؤها",
