@@ -63,6 +63,7 @@ OC.L10N.register(
     "Reload current directory" : "Volver cargar el direutoriu actual",
     "Go to the \"{dir}\" directory" : "Dir al direutoriu «{dir}»",
     "Current directory path" : "Camín actual del direutoriu",
+    "Share" : "Compartir",
     "Your have used your space quota and cannot upload files anymore" : "Usesti la to cuota d'espaciu y yá nun pues xubir ficheros",
     "Drag and drop files here to upload" : "Arrastra y suelta los ficheros equí pa xubilos",
     "Favorite" : "Meter en Favoritos",
@@ -72,13 +73,20 @@ OC.L10N.register(
     "Filename" : "Nome de ficheru",
     "Folder name" : "Nome de la carpeta",
     "This node is unavailable" : "Esti noyu nun ta disponible",
-    "Renamed \"{oldName}\" to \"{newName}\"" : "Renomóse «{oldName}» a «{newName}»",
     "Rename file" : "Renomar el ficheru",
     "Folder" : "Carpeta",
     "Pending" : "Pendiente",
-    "Modified" : "Modificóse",
-    "Type" : "Tipu",
     "Remove filter" : "Quitar la peñera",
+    "Today" : "Güei",
+    "Last 7 days" : "Los últimos 7 díes",
+    "Last 30 days" : "Los últimos 30 díes",
+    "Custom date range" : "Intervalu de dates personalizáu",
+    "Documents" : "Documentos",
+    "Folders" : "Carpetes",
+    "Audio" : "Audiu",
+    "Images" : "Imáxenes",
+    "Videos" : "Vídeos",
+    "Filters" : "Filtros",
     "Appearance" : "Aspeutu",
     "Show hidden files" : "Amosar los ficheros anubríos",
     "Crop image previews" : "Recortar la previsualización d'imáxenes",
@@ -98,10 +106,12 @@ OC.L10N.register(
     "Toggle selection for all files and folders" : "Alternar la seleición de tolos ficheros y toles carpetes",
     "Name" : "Nome",
     "Size" : "Tamañu",
+    "Modified" : "Modificóse",
     "List of files and folders." : "Una llista de ficheros y carpetes.",
     "Column headers with buttons are sortable." : "Les testeres de les columnes con botones puen ordenase.",
     "This list is not fully rendered for performance reasons. The files will be rendered as you navigate through the list." : "Esta llista nun ta completa por motivos de rindimientu. Los ficheros van apaecer a midida que navegues pela llista.",
     "File not found" : "Nun s'atopó'l ficheru",
+    "Owner" : "Propietariu",
     "{usedQuotaByte} used" : "{usedQuotaByte} n'usu",
     "{used} of {quota} used" : "{used} de {quota} n'usu",
     "{relative}% used" : "{relative}% n'usu",
@@ -124,12 +134,11 @@ OC.L10N.register(
     "Choose file or folder to transfer" : "Escoyer el ficheru o carpeta a tresferir",
     "Change" : "Camudar",
     "New owner" : "Propietariu nuevu",
+    "Cancel" : "Encaboxar",
+    "Rename" : "Renomar",
     "Select file or folder to link to" : "Seleicionar un ficheru o una carpeta a la qu'enllaciar",
     "Choose {file}" : "Escoyer «{file}»",
     "Files settings" : "Configuración de Ficheros",
-    "Share" : "Compartir",
-    "Shared by link" : "Compartir pente un enllaz",
-    "Shared" : "Compartío",
     "Switch to list view" : "Cambiar a la vista de llista",
     "Switch to grid view" : "Cambiar a la vista de rexáu",
     "Upload was cancelled by user" : "L'usuariu anuló la xuba",
@@ -144,13 +153,6 @@ OC.L10N.register(
     "Upload some content or sync with your devices!" : "¡Xubi conteníu o sincroniza daqué colos tos preseos!",
     "Go back" : "Dir p'atrás",
     "Views" : "Vistes",
-    "You" : "Tu",
-    "Shared multiple times with different people" : "Compartióse múltiples vegaes con otres persones",
-    "Error while loading the file data" : "Hebo un error mentanto de cargaben los datos de los ficheros",
-    "Owner" : "Propietariu",
-    "Remove from favorites" : "Quitar de Favoritos",
-    "Add to favorites" : "Meter en Favoritos",
-    "Tags" : "Etiquetes",
     "Your files" : "Los tos ficheros",
     "Open in files" : "Abrir en Ficheros",
     "File cannot be accessed" : "Nun se pue acceder al ficheru",
@@ -172,38 +174,30 @@ OC.L10N.register(
     "Delete folder" : "Desaniciar la carpeta",
     "Delete folders" : "Desaniciar les carpetes",
     "Confirm deletion" : "Confirmar el desaniciu",
-    "Cancel" : "Encaboxar",
     "Download" : "Baxar",
+    "Add to favorites" : "Meter en Favoritos",
+    "Remove from favorites" : "Quitar de Favoritos",
+    "Move" : "Mover",
+    "Copy" : "Copiar",
+    "Move or copy" : "Mover o copiar",
     "Destination is not a folder" : "El destín nun ye una carpeta",
     "This file/folder is already in that directory" : "Esti ficheru o esta carpeta yá ta nel direutoriu",
     "You cannot move a file/folder onto itself or into a subfolder of itself" : "Nun pues mover un ficheru/carpeta a sigo mesma o la mesma socarpeta de la mesma carpeta",
-    "(copy)" : "(copia)",
-    "(copy %n)" : "(copia %n)",
     "A file or folder with that name already exists in this folder" : "Nesta carpeta, yá estie un ficheru o una carpeta con esi nome",
     "The files are locked" : "Los ficheros tán bloquiaos",
     "The file does not exist anymore" : "El ficheru yá nun esiste",
     "Choose destination" : "Escoyer el destín",
     "Copy to {target}" : "Copiar a {target}",
-    "Copy" : "Copiar",
     "Move to {target}" : "Mover a {target}",
-    "Move" : "Mover",
     "Move or copy operation failed" : "La operación de mover o copiar falló",
-    "Move or copy" : "Mover o copiar",
+    "Open folder" : "Abrir la carpeta",
     "Open folder {displayName}" : "Abrir la carpeta «{displayName}»",
     "Open in Files" : "Abrir en Ficheros",
     "Open locally" : "Abrir llocalmente",
     "Failed to redirect to client" : "Nun se pue redirixir al veceru",
-    "Rename" : "Renomar",
     "Details" : "Detalles",
     "View in folder" : "Ver na carpeta",
-    "Today" : "Güei",
-    "Last 7 days" : "Los últimos 7 díes",
-    "Last 30 days" : "Los últimos 30 díes",
-    "Documents" : "Documentos",
-    "Folders" : "Carpetes",
-    "Audio" : "Audiu",
-    "Images" : "Imáxenes",
-    "Videos" : "Vídeos",
+    "Type" : "Tipu",
     "Created new folder \"{name}\"" : "Creóse la carpeta «{name}»",
     "Unable to initialize the templates directory" : "Nun ye posible aniciar el direutoriu de plantíes",
     "Templates" : "Plantíes",
@@ -217,10 +211,10 @@ OC.L10N.register(
     "Some files could not be uploaded" : "Nun se pudieron xubir dalgunos ficheros",
     "Files uploaded successfully" : "Los ficheros xubiéronse correutamente",
     "No files to process" : "Nun hai nengún ficheru pa procesar",
-    "Some files could not be copied" : "Nun se pudieron copiar dalgunos ficheros",
-    "Some files could not be moved" : "Nun se pudieron copiar dalgunos ficheros",
     "Files copied successfully" : "Los ficheros copiáronse correutamente",
     "Files moved successfully" : "Los ficheros copiáronse correutamente",
+    "Some files could not be copied" : "Nun se pudieron copiar dalgunos ficheros",
+    "Some files could not be moved" : "Nun se pudieron copiar dalgunos ficheros",
     "Conflicts resolution skipped" : "Saltóse la resolución de conflictos",
     "Upload cancelled" : "Encaboxóse la busca",
     "Could not rename \"{oldName}\", it does not exist any more" : "Nun se pue renomar «{oldName}». Yá nun esiste",
@@ -246,8 +240,11 @@ OC.L10N.register(
     "Upload too large" : "La xuba ye mui grande",
     "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Los ficheros que tentes de xubir superen el tamañu máximu qu'esti sirvidor permite.",
     "Upload (max. %s)" : "Xubir (%s como máximu)",
+    "Renamed \"{oldName}\" to \"{newName}\"" : "Renomóse «{oldName}» a «{newName}»",
     "\"{displayName}\" batch action executed successfully" : "L'aición per llotes «{displayName}» executóse correutamente",
     "\"{displayName}\" action failed" : "L'aición «{displayName}» falló",
+    "Shared by link" : "Compartir pente un enllaz",
+    "Shared" : "Compartío",
     "\"{displayName}\" action executed successfully" : "L'aición «{displayName}» executóse correutamente",
     "Clipboard is not available" : "El cartafueyu nun ta disponible",
     "WebDAV URL copied to clipboard" : "La URL de WebDAV copióse nel cartafueyu",
@@ -257,8 +254,14 @@ OC.L10N.register(
     "Use this address to access your Files via WebDAV" : "Usa esta direición p'acceder a los ficheros per WebDAV",
     "If you have enabled 2FA, you must create and use a new app password by clicking here." : "Si tienes activada l'autenticación en dos pasos, tienes de crear y usar una contraseña p'aplicaciones nueva calcando equí.",
     "Keyboard shortcuts" : "Atayos del tecláu",
+    "You" : "Tu",
+    "Shared multiple times with different people" : "Compartióse múltiples vegaes con otres persones",
+    "Error while loading the file data" : "Hebo un error mentanto de cargaben los datos de los ficheros",
+    "Tags" : "Etiquetes",
     "Deletion cancelled" : "Anulóse'l desaniciu",
     "Edit locally" : "Editar llocalmente",
+    "(copy)" : "(copia)",
+    "(copy %n)" : "(copia %n)",
     "Move cancelled" : "Anulóse la operación de mover",
     "Cancelled move or copy operation" : "Anulóse la operación de mover o copiar",
     "Open details" : "Abrir los detalles",
