@@ -78,6 +78,7 @@ OC.L10N.register(
     "Reload current directory" : "Перазагрузіць бягучы каталог",
     "Go to the \"{dir}\" directory" : "Перайсці да каталога \"{dir}\"",
     "Current directory path" : "Бягучы шлях да каталога",
+    "Share" : "Абагуліць",
     "Your have used your space quota and cannot upload files anymore" : "Вы выкарысталі сваю квоту прасторы і больш не можаце запампоўваць файлы",
     "You do not have permission to upload or create files here." : "У вас няма дазволу на запампоўванне або стварэнне файлаў тут.",
     "Drag and drop files here to upload" : "Перацягніце файлы сюды, каб запампаваць іх",
@@ -92,7 +93,6 @@ OC.L10N.register(
     "This node is unavailable" : "Гэты вузел недаступны",
     "Another entry with the same name already exists." : "Запіс з такой назвай ужо існуе.",
     "Invalid filename." : "Памылковая назва файла.",
-    "Renamed \"{oldName}\" to \"{newName}\"" : "\"{oldName}\" перайменаваны ў \"{newName}\"",
     "Rename file" : "Перайменаваць файл",
     "Folder" : "Папка",
     "Unknown file type" : "Невядомы тып файла",
@@ -102,21 +102,65 @@ OC.L10N.register(
     "{ext} text" : "Тэкст {ext}",
     "Pending" : "У чаканні",
     "Unknown date" : "Невядомая дата",
-    "Clear filter" : "Ачысціць фільтр",
-    "Modified" : "Зменены",
-    "Search everywhere" : "Шукаць усюды",
-    "Type" : "Тып",
     "Active filters" : "Актыўныя фільтры",
     "Remove filter" : "Выдаліць фільтр",
+    "Today" : "Сёння",
+    "Last 7 days" : "Апошнія 7 дзён",
+    "Last 30 days" : "Апошнія 30 дзён",
+    "This year ({year})" : "Гэты год ({year})",
+    "Last year ({year})" : "Мінулы год ({year})",
+    "Custom date range" : "Карыстальніцкі дыяпазон дат",
+    "Search everywhere" : "Шукаць усюды",
+    "Documents" : "Дакументы",
+    "Spreadsheets" : "Табліцы",
+    "Presentations" : "Прэзентацыі",
+    "PDFs" : "PDF-файлы",
+    "Folders" : "Папкі",
+    "Audio" : "Аўдыя",
+    "Images" : "Відарысы",
+    "Videos" : "Відэа",
+    "Filters" : "Фільтры",
+    "Appearance" : "Знешні выгляд",
+    "Show hidden files" : "Паказваць схаваныя файлы",
+    "Show file type column" : "Паказаць слупок тыпу файла",
+    "Show file extensions" : "Паказваць пашырэнні файлаў",
+    "Crop image previews" : "Абразаць перадпрагляд малюнкаў",
+    "General" : "Агульныя",
+    "Sort favorites first" : "Спачатку паказваць абраныя",
+    "Sort folders before files" : "Паказваць папкі перад файламі",
+    "Default view" : "Прадвызначаны выгляд",
+    "All files" : "Усе файлы",
+    "Personal files" : "Асабістыя файлы",
+    "Additional settings" : "Дадатковыя налады",
+    "Actions" : "Дзеянні",
+    "File actions" : "Дзеянні з файламі",
+    "Selection" : "Выбар",
+    "Select all files" : "Выбраць усе файлы",
+    "Deselect all" : "Скасаваць выбар усіх",
+    "Select or deselect" : "Выбраць або скасаваць выбар",
+    "Select a range" : "Выбраць дыяпазон",
+    "Navigation" : "Навігацыя",
+    "Go to parent folder" : "Перайсці ў бацькоўскую папку",
+    "Go to file above" : "Перайсці да файла вышэй",
+    "Go to file below" : "Перайсці да файла ніжэй",
+    "Go left in grid" : "Перайсці лявей па сетцы",
+    "Go right in grid" : "Перайсці правей па сетцы",
+    "View" : "Выгляд",
+    "Toggle grid view" : "Пераключыць выгляд сеткі",
+    "Show those shortcuts" : "Паказаць гэтыя спалучэнні клавіш",
+    "Warnings" : "Папярэджанні",
+    "Warn before changing a file extension" : "Папярэджваць перад зменай пашырэння файла",
+    "WebDAV URL" : "URL-адрас WebDAV",
+    "How to access files using WebDAV" : "Як атрымаць доступ да файлаў з дапамогай WebDAV",
     "Total rows summary" : "Зводка па ўсіх радках",
     "Toggle selection for all files and folders" : "Пераключыць выбар для ўсіх файлаў і папак",
     "Name" : "Назва",
     "File type" : "Тып файла",
     "Size" : "Памер",
+    "Modified" : "Зменены",
     "{displayName}: failed on some elements" : "{displayName}: не атрымалася на некаторых элементах",
     "{displayName}: done" : "{displayName}: гатова",
     "{displayName}: failed" : "{displayName}: не атрымалася",
-    "Actions" : "Дзеянні",
     "(selected)" : "(выбраны)",
     "List of files and folders." : "Спіс файлаў і папак.",
     "You have used your space quota and cannot upload files anymore." : "Вы выкарысталі сваю квоту прасторы і больш не можаце запампоўваць файлы.",
@@ -124,10 +168,11 @@ OC.L10N.register(
     "This list is not fully rendered for performance reasons. The files will be rendered as you navigate through the list." : "Гэты спіс не апрацоўваецца цалкам з меркаванняў прадукцыйнасці. Файлы будуць апрацоўвацца па меры навігацыі па спісе.",
     "File not found" : "Файл не знойдзены",
     "_{count} selected_::_{count} selected_" : ["Выбраны {count}","Выбраны {count}","Выбрана {count}","Выбрана {count}"],
-    "Search everywhere …" : "Шукаць усюды …",
-    "Search here …" : "Шукаць тут …",
+    "Search everywhere …" : "Шукаць усюды …",
+    "Search here …" : "Шукаць тут …",
     "Search scope options" : "Параметры вобласці пошуку",
     "Search here" : "Шукаць тут",
+    "Owner" : "Уладальнік",
     "{usedQuotaByte} used" : "Выкарыстана {usedQuotaByte}",
     "{used} of {quota} used" : "Выкарыстана {used} з {quota}",
     "{relative}% used" : "Выкарыстана {relative}%",
@@ -144,7 +189,7 @@ OC.L10N.register(
     "Failed to refresh filename sanitization status." : "Не атрымалася абнавіць статус ачысткі назваў файла.",
     "Filename sanitization in progress." : "Ідзе ачыстка назваў файлаў.",
     "Currently {processedUsers} of {totalUsers} accounts are already processed." : "На дадзены момант ужо апрацавана {processedUsers} з {totalUsers} уліковых запісаў.",
-    "Preparing …" : "Падрыхтоўка …",
+    "Preparing …" : "Падрыхтоўка …",
     "Refresh" : "Абнавіць",
     "All files have been santized for Windows filename support." : "Усе назвы файлаў былі ачашчаны для падтрымкі ў Windows.",
     "Some files could not be sanitized, please check your logs." : "Некаторыя файлы не ўдалося ачысціць. Паглядзіце журналы.",
@@ -159,7 +204,7 @@ OC.L10N.register(
     "Sanitize filenames" : "Ачысціць назвы файлаў",
     "(starting)" : "(пачынаецца)",
     "Fill template fields" : "Запоўніце палі шаблону",
-    "Submitting fields …" : "Адпраўка палёў …",
+    "Submitting fields …" : "Адпраўка палёў …",
     "Submit" : "Адправіць",
     "Choose a file or folder to transfer" : "Выберыце файл або папку для перадачы",
     "Transfer" : "Перадаць",
@@ -181,11 +226,11 @@ OC.L10N.register(
     "Removing the file extension \"{old}\" may render the file unreadable." : "Выдаленне пашырэння файла \"{old}\" можа зрабіць файл нечытэльным.",
     "Adding the file extension \"{new}\" may render the file unreadable." : "Даданне пашырэння файла \"{new}\" можа зрабіць файл нечытэльным.",
     "Do not show this dialog again." : "Больш не паказваць гэта дыялогавае акно.",
+    "Cancel" : "Скасаваць",
+    "Rename" : "Перайменаваць",
     "Select file or folder to link to" : "Выберыце файл або каталог, на які трэба зрабіць спасылку",
     "Choose {file}" : "Выбраць {file}",
-    "Share" : "Абагуліць",
-    "Shared by link" : "Абагулена праз спасылку",
-    "Shared" : "Абагуленыя",
+    "Files settings" : "Налады Файлаў",
     "Switch to list view" : "Пераключыцца ў выгляд спісу",
     "Switch to grid view" : "Пераключыцца ў выгляд сеткі",
     "The file could not be found" : "Файл не знойдзены",
@@ -200,90 +245,36 @@ OC.L10N.register(
     "No files in here" : "Тут няма файлаў",
     "Upload some content or sync with your devices!" : "Запампуйце што-небудзь або сінхранізуйце са сваімі прыладамі!",
     "Go back" : "Назад",
-    "Files settings" : "Налады Файлаў",
+    "Loading …" : "Загрузка …",
     "Your files" : "Вашы файлы",
     "Open in files" : "Адкрыць у Файлах",
     "File cannot be accessed" : "Немагчыма атрымаць доступ да файла",
     "The file could not be found or you do not have permissions to view it. Ask the sender to share it." : "Файл не знойдзены, або ў вас няма правоў на яго прагляд. Папрасіце адпраўніка абагуліць яго.",
     "No search results for “{query}”" : "Няма вынікаў пошуку па запыце \"{query}\"",
     "Search for files" : "Пошук файлаў",
-    "Clipboard is not available" : "Буфер абмену недаступны",
-    "WebDAV URL copied" : "URL-адрас WebDAV скапіяваны",
-    "General" : "Агульныя",
-    "Default view" : "Прадвызначаны выгляд",
-    "All files" : "Усе файлы",
-    "Personal files" : "Асабістыя файлы",
-    "Sort favorites first" : "Спачатку паказваць абраныя",
-    "Sort folders before files" : "Паказваць папкі перад файламі",
-    "Folder tree" : "Дрэва папак",
-    "Appearance" : "Знешні выгляд",
-    "Show hidden files" : "Паказваць схаваныя файлы",
-    "Show file type column" : "Паказаць слупок тыпу файла",
-    "Show file extensions" : "Паказваць пашырэнні файлаў",
-    "Crop image previews" : "Абразаць перадпрагляд малюнкаў",
-    "Additional settings" : "Дадатковыя налады",
-    "WebDAV" : "WebDAV",
-    "WebDAV URL" : "URL-адрас WebDAV",
-    "Copy" : "Капіяваць",
-    "How to access files using WebDAV" : "Як атрымаць доступ да файлаў з дапамогай WebDAV",
-    "Two-Factor Authentication is enabled for your account, and therefore you need to use an app password to connect an external WebDAV client." : "Для вашага ўліковага запісу ўключана двухфактарная аўтэнтыфікацыя, таму для падключэння да знешняга кліента WebDAV вам трэба выкарыстоўваць пароль праграмы.",
-    "Warnings" : "Папярэджанні",
-    "Warn before changing a file extension" : "Папярэджваць перад зменай пашырэння файла",
-    "Warn before deleting files" : "Папярэджваць перад выдаленнем файлаў",
-    "Keyboard shortcuts" : "Спалучэнні клавіш",
-    "File actions" : "Дзеянні з файламі",
-    "Rename" : "Перайменаваць",
-    "Delete" : "Выдаліць",
-    "Add or remove favorite" : "Дадаць або выдаліць з абранага",
-    "Manage tags" : "Кіраванне тэгамі",
-    "Selection" : "Выбар",
-    "Select all files" : "Выбраць усе файлы",
-    "Deselect all" : "Скасаваць выбар усіх",
-    "Select or deselect" : "Выбраць або скасаваць выбар",
-    "Select a range" : "Выбраць дыяпазон",
-    "Navigation" : "Навігацыя",
-    "Go to parent folder" : "Перайсці ў бацькоўскую папку",
-    "Go to file above" : "Перайсці да файла вышэй",
-    "Go to file below" : "Перайсці да файла ніжэй",
-    "Go left in grid" : "Перайсці лявей па сетцы",
-    "Go right in grid" : "Перайсці правей па сетцы",
-    "View" : "Выгляд",
-    "Toggle grid view" : "Пераключыць выгляд сеткі",
-    "Open file sidebar" : "Адкрыць бакавую панэль файла",
-    "Show those shortcuts" : "Паказаць гэтыя спалучэнні клавіш",
     "Allow to restrict filenames to ensure files can be synced with all clients. By default all filenames valid on POSIX (e.g. Linux or macOS) are allowed." : "Дазволіць абмежоўваць назвы файлаў, каб забяспечыць сінхранізацыю файлаў з усімі кліентамі. Прадвызначана дазволены ўсе назвы файлаў, якія дзейнічаюць у POSIX (напрыклад, Linux або macOS).",
     "After enabling the Windows compatible filenames, existing files cannot be modified anymore but can be renamed to valid new names by their owner." : "Пасля ўключэння сумяшчальнасці назваў файлаў з Windows існуючыя файлы больш нельга будзе змяняць, але іх уладальнік можа даць ім новыя правільныя назвы.",
     "Failed to toggle Windows filename support" : "Не ўдалося пераключыць падтрымку назваў файлаў Windows",
     "Files compatibility" : "Сумяшчальнасць файлаў",
     "Enforce Windows compatibility" : "Забяспечыць сумяшчальнасць з Windows",
     "This will block filenames not valid on Windows systems, like using reserved names or special characters. But this will not enforce compatibility of case sensitivity." : "Будуць блакіравацца назвы файлаў, недазволеныя ў сістэмах Windows, напрыклад, з выкарыстаннем зарэзерваваных назваў або спецыяльных сімвалаў. Але гэта не забяспечыць сумяшчальнасць у плане адчувальнасці да рэгістра.",
-    "You" : "Вы",
-    "Shared multiple times with different people" : "Абагулены некалькі разоў з рознымі людзьмі",
-    "Unable to change the favorite state of the file" : "Не ўдалося змяніць статус абранага для файла",
-    "Error while loading the file data" : "Памылка пры загрузцы даных файла",
-    "Owner" : "Уладальнік",
-    "Remove from favorites" : "Выдаліць з абранага",
-    "Add to favorites" : "У абранае",
-    "Tags" : "Тэгі",
     "Blank" : "Пусты",
     "Unable to create new file from template" : "Немагчыма стварыць новы файл з шаблона",
     "Pick a template for {name}" : "Выберыце шаблон для {name}",
     "Create a new file with the selected template" : "Стварыць файл на падставе выбранага шаблона",
     "Creating file" : "Стварэнне файла",
     "Save as {displayName}" : "Захаваць як {displayName}",
-    "Save as …" : "Захаваць як …",
-    "Converting files …" : "Канвертацыя файлаў …",
+    "Save as …" : "Захаваць як …",
+    "Converting files …" : "Канвертацыя файлаў …",
     "Failed to convert files: {message}" : "Не ўдалося сканвертаваць файлы: {message}",
     "All files failed to be converted" : "Не ўдалося сканвертаваць усе файлы",
     "One file could not be converted: {message}" : "Не ўдалося сканвертаваць адзін файл: {message}",
-    "_One file could not be converted_::_%n files could not be converted_" : ["Не ўдалося сканвертаваць адзін файл","Не ўдалося сканвертаваць %n файлы","Не ўдалося сканвертаваць %n файлаў","Не ўдалося сканвертаваць %n файлаў"],
-    "_One file successfully converted_::_%n files successfully converted_" : ["Адзін файл паспяхова сканвертаваны","%n файлы паспяхова сканвертаваны","%n файлаў паспяхова сканвертавана","%n файлаў паспяхова сканвертавана"],
-    "Files successfully converted" : "Файлы паспяхова сканвертаваны",
     "Failed to convert files" : "Не ўдалося сканвертаваць файлы",
-    "Converting file …" : "Канвертацыя файла …",
+    "Converting file …" : "Канвертацыя файла …",
     "File successfully converted" : "Файл паспяхова сканвертаваны",
     "Failed to convert file: {message}" : "Не ўдалося сканвертаваць файл: {message}",
     "Failed to convert file" : "Не ўдалося сканвертаваць файл",
+    "Delete" : "Выдаліць",
     "Leave this share" : "Пакінуць гэта абагульванне",
     "Leave these shares" : "Пакінуць гэтыя абагульванні",
     "Disconnect storage" : "Адлучыць сховішча",
@@ -297,26 +288,27 @@ OC.L10N.register(
     "_You are about to permanently delete {count} item_::_You are about to permanently delete {count} items_" : ["Вы збіраецеся назаўжды выдаліць {count} элемент","Вы збіраецеся назаўжды выдаліць {count} элементы","Вы збіраецеся назаўжды выдаліць {count} элементаў","Вы збіраецеся назаўжды выдаліць {count} элементаў"],
     "_You are about to delete {count} item_::_You are about to delete {count} items_" : ["Вы збіраецеся выдаліць {count} элемент","Вы збіраецеся выдаліць {count} элементы","Вы збіраецеся выдаліць {count} элементаў","Вы збіраецеся выдаліць {count} элементаў"],
     "Confirm deletion" : "Пацвердзіць выдаленне",
-    "Cancel" : "Скасаваць",
     "Download" : "Спампаваць",
     "The requested file is not available." : "Запытаны файл недаступны.",
     "The requested files are not available." : "Запытаныя файлы недаступны.",
-    "Moving \"{source}\" to \"{destination}\" …" : "Перамяшчэнне \"{source}\" у \"{destination}\" …",
-    "Copying \"{source}\" to \"{destination}\" …" : "Капіяванне \"{source}\" у \"{destination}\" …",
+    "Add to favorites" : "У абранае",
+    "Remove from favorites" : "Выдаліць з абранага",
+    "Add or remove favorite" : "Дадаць або выдаліць з абранага",
+    "Move" : "Перамясціць",
+    "Copy" : "Капіяваць",
+    "Move or copy" : "Перамясціць або капіяваць",
     "Destination is not a folder" : "Месца прызначэння не з'яўляецца папкай",
     "This file/folder is already in that directory" : "Гэты файл/папка ўжо знаходзіцца ў гэтым каталогу",
     "You cannot move a file/folder onto itself or into a subfolder of itself" : "Нельга перамясціць файл/папку ў сябе або ў падпапку самой сябе",
-    "(copy)" : "(копія)",
-    "(copy %n)" : "(копія %n)",
     "A file or folder with that name already exists in this folder" : "Файл або папка з такой назвай ужо існуе ў гэтай папцы",
     "The files are locked" : "Файлы заблакіраваны",
     "The file does not exist anymore" : "Файл больш не існуе",
+    "Moving \"{source}\" to \"{destination}\" …" : "Перамяшчэнне \"{source}\" у \"{destination}\" …",
+    "Copying \"{source}\" to \"{destination}\" …" : "Капіяванне \"{source}\" у \"{destination}\" …",
     "Choose destination" : "Выберыце прызначэнне",
     "Copy to {target}" : "Капіяваць у {target}",
     "Move to {target}" : "Перамясціць у {target}",
-    "Move" : "Перамясціць",
     "Move or copy operation failed" : "Не ўдалося перамясціць або скапіяваць",
-    "Move or copy" : "Перамясціць або капіяваць",
     "Open folder {displayName}" : "Адкрыць папку {displayName}",
     "Open in Files" : "Адкрыць у Файлах",
     "Open locally" : "Адкрыць лакальна",
@@ -327,19 +319,7 @@ OC.L10N.register(
     "Open online" : "Адкрыць анлайн",
     "Details" : "Падрабязнасці",
     "View in folder" : "Праглядзець у папцы",
-    "Today" : "Сёння",
-    "Last 7 days" : "Апошнія 7 дзён",
-    "Last 30 days" : "Апошнія 30 дзён",
-    "This year ({year})" : "Гэты год ({year})",
-    "Last year ({year})" : "Мінулы год ({year})",
-    "Documents" : "Дакументы",
-    "Spreadsheets" : "Табліцы",
-    "Presentations" : "Прэзентацыі",
-    "PDFs" : "PDF-файлы",
-    "Folders" : "Папкі",
-    "Audio" : "Аўдыя",
-    "Images" : "Відарысы",
-    "Videos" : "Відэа",
+    "Type" : "Тып",
     "Created new folder \"{name}\"" : "Створана новая папка \"{name}\"",
     "Unable to initialize the templates directory" : "Немагчыма ініцыялізаваць каталог шаблонаў",
     "Create templates folder" : "Стварыць папку шаблонаў",
@@ -355,10 +335,10 @@ OC.L10N.register(
     "Some files could not be uploaded" : "Некаторыя файлы не ўдалося запампаваць",
     "Files uploaded successfully" : "Файлы паспяхова запампаваныя",
     "No files to process" : "Няма файлаў для апрацоўкі",
-    "Some files could not be copied" : "Некаторыя файлы не ўдалося скапіяваць",
-    "Some files could not be moved" : "Некаторыя файлы не ўдалося перамясціць",
     "Files copied successfully" : "Файлы паспяхова скапіяваны",
     "Files moved successfully" : "Файлы паспяхова перамешчаны",
+    "Some files could not be copied" : "Некаторыя файлы не ўдалося скапіяваць",
+    "Some files could not be moved" : "Некаторыя файлы не ўдалося перамясціць",
     "Conflicts resolution skipped" : "Рашэнне канфліктаў прапушчана",
     "Upload cancelled" : "Запампоўванне скасавана",
     "Could not rename \"{oldName}\", it does not exist any more" : "Не атрымалася перайменаваць \"{oldName}\", ён больш не існуе",
@@ -380,6 +360,7 @@ OC.L10N.register(
     "No favorites yet" : "Пакуль няма абраных",
     "Files and folders you mark as favorite will show up here" : "Тут будуць адлюстроўвацца файлы і папкі, якія вы пазначаеце як абраныя",
     "List of your files and folders." : "Спіс вашых файлаў і папак.",
+    "Folder tree" : "Дрэва папак",
     "List of your files and folders that are not shared." : "Спіс вашых неабагуленых файлаў і папак.",
     "No personal files found" : "Асабістых файлаў не знойдзена",
     "Files that are not shared will show up here." : "Тут будуць адлюстроўвацца неабагуленыя файлы.",
@@ -393,120 +374,33 @@ OC.L10N.register(
     "Select all" : "Выбраць усе",
     "Upload too large" : "Запампоўка занадта вялікая",
     "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Памер файлаў, якія вы спрабуеце запампаваць, перавышае максімальны дазволены памер для запампоўвання на гэтым серверы.",
-    "File could not be found" : "Файл не знойдзены",
-    "Show list view" : "Паказаць спісам",
-    "Show grid view" : "Паказаць сеткай",
-    "Close" : "Закрыць",
-    "Could not create folder \"{dir}\"" : "Не ўдалося стварыць папку \"{dir}\"",
-    "This will stop your current uploads." : "Гэта спыніць вашы бягучыя запампоўкі.",
-    "Upload cancelled." : "Запампоўванне скасавана.",
-    "Processing files …" : "Апрацоўка файлаў …",
-    "…" : "…",
-    "Unable to upload {filename} as it is a directory or has 0 bytes" : "Немагчыма запампаваць {filename}, бо гэта каталог або ён мае памер 0 байтаў",
-    "Not enough free space, you are uploading {size1} but only {size2} is left" : "Недастаткова вольнай прасторы, вы запампоўваеце {size1}, але засталося толькі {size2}",
-    "Target folder \"{dir}\" does not exist any more" : "Мэтавая папка \"{dir}\" больш не існуе",
-    "An unknown error has occurred" : "Узнікла невядомая памылка",
-    "File could not be uploaded" : "Не ўдалося запампаваць файл",
-    "Uploading …" : "Запампоўванне …",
-    "{remainingTime} ({currentNumber}/{total})" : "{remainingTime} ({currentNumber}/{total})",
-    "Uploading … ({currentNumber}/{total})" : "Запампоўванне … ({currentNumber}/{total})",
-    "{loadedSize} of {totalSize} ({bitrate})" : "{loadedSize} з {totalSize} ({bitrate})",
-    "Uploading that item is not supported" : "Запампоўванне гэтага элемента не падтрымліваецца",
-    "Error when assembling chunks, status code {status}" : "Памылка пры зборцы частак, код стану {status}",
-    "Choose target folder" : "Выберыце мэтавую папку",
-    "Set reminder" : "Задаць напамін",
-    "Edit locally" : "Рэдагаваць лакальна",
-    "Open" : "Адкрыць",
-    "Could not load info for file \"{file}\"" : "Не ўдалося загрузіць інфармацыю для файла \"{file}\"",
-    "Please select tag(s) to add to the selection" : "Выберыце, якія тэгі дадаць выбраным файлам",
-    "Apply tag(s) to selection" : "Ужыць тэг(і) да выбраных файлаў",
-    "Select directory \"{dirName}\"" : "Выбраць каталог \"{dirName}\"",
-    "Select file \"{fileName}\"" : "Выбраць файл \"{fileName}\"",
-    "Unable to determine date" : "Немагчыма вызначыць дату",
-    "This directory is unavailable, please check the logs or contact the administrator" : "Гэты каталог недаступны, праверце журналы або звярніцеся да адміністратара",
-    "Could not move \"{file}\", target exists" : "Не удалося перамясціць \"{file}\", файл з такой назвай ужо існуе",
-    "Could not move \"{file}\"" : "Не удалося перамясціць \"{file}\"",
-    "copy" : "копія",
-    "Could not copy \"{file}\", target exists" : "Не удалося скапіяваць \"{file}\", файл з такой назвай ужо існуе",
-    "Could not copy \"{file}\"" : "Не удалося скапіяваць \"{file}\"",
-    "Copied {origin} inside {destination}" : "Скапіяваны {origin} у {destination}",
-    "Copied {origin} and {nbfiles} other files inside {destination}" : "Скапіяваны {origin} і {nbfiles} іншых файлаў у {destination}",
-    "{newName} already exists" : "{newName} ужо існуе",
-    "Could not create file \"{file}\"" : "Не ўдалося стварыць файл \"{file}\"",
-    "Could not create file \"{file}\" because it already exists" : "Не ўдалося стварыць файл \"{file}\", бо ён ужо існуе",
-    "Could not create folder \"{dir}\" because it already exists" : "Не ўдалося стварыць папку \"{dir}\", бо яна ўжо існуе",
-    "Could not fetch file details \"{file}\"" : "Не ўдалося атрымаць падрабязныя звесткі пра файл \"{file}\"",
-    "Error deleting file \"{fileName}\"." : "Памылка пры выдаленні файла \"{fileName}\".",
-    "No search results in other folders for {tag}{filter}{endtag}" : "Няма вынікаў пошуку ў іншых папках для {tag}{filter}{endtag}",
-    "Enter more than two characters to search in other folders" : "Увядзіце больш за два сімвалы для пошуку ў іншых папках",
-    "{dirs} and {files}" : "{dirs} і {files}",
-    "_including %n hidden_::_including %n hidden_" : ["у тым ліку %n схаваны","у тым ліку %n схаваныя","у тым ліку %n схаваных","у тым ліку %n схаваных"],
-    "You do not have permission to upload or create files here" : "У вас няма дазволу на запампоўванне або стварэнне файлаў тут",
-    "_Uploading %n file_::_Uploading %n files_" : ["Запампоўванне %n файла","Запампоўванне %n файлаў","Запампоўванне %n файлаў","Запампоўванне %n файлаў"],
-    "New" : "Новы",
-    "New file/folder menu" : "Меню новага файла/папкі",
-    "Select file range" : "Выберыце дыяпазон файлаў",
-    "{used}%" : "{used}%",
-    "{used} used" : "Выкарыстана {used}",
-    "\"{name}\" is an invalid file name." : "\"{name}\" – памылковая назва файла.",
-    "File name cannot be empty." : "Назва файла не можа быць пустой.",
-    "\"/\" is not allowed inside a file name." : "Сімвал \"/\" недапушчальны ў назве файла.",
-    "\"{name}\" is not an allowed filetype" : "\"{name}\" не з'яўляецца дазволеным тыпам файла",
-    "Storage of {owner} is full, files cannot be updated or synced anymore!" : "Сховішча {owner} запоўнена, файлы больш нельга абнаўляць або сінхранізаваць!",
-    "Group folder \"{mountPoint}\" is full, files cannot be updated or synced anymore!" : "Папка групы \"{mountPoint}\" запоўнена, файлы больш нельга абнаўляць або сінхранізаваць!",
-    "External storage \"{mountPoint}\" is full, files cannot be updated or synced anymore!" : "Знешняе сховішча \"{mountPoint}\" запоўнена, файлы больш нельга абнаўляць або сінхранізаваць!",
-    "Your storage is full, files cannot be updated or synced anymore!" : "Ваша сховішча запоўнена, файлы больш нельга абнаўляць або сінхранізаваць!",
-    "Storage of {owner} is almost full ({usedSpacePercent}%)." : "Сховішча {owner} амаль запоўнена ({usedSpacePercent}%).",
-    "Group folder \"{mountPoint}\" is almost full ({usedSpacePercent}%)." : "Папка групы \"{mountPoint}\" амаль запоўнена ({usedSpacePercent}%).",
-    "External storage \"{mountPoint}\" is almost full ({usedSpacePercent}%)." : "Знешняе сховішча \"{mountPoint}\" амаль запоўнена ({usedSpacePercent}%).",
-    "Your storage is almost full ({usedSpacePercent}%)." : "Ваша сховішча амаль запоўнена ({usedSpacePercent}%).",
-    "_matches \"{filter}\"_::_match \"{filter}\"_" : ["адпавядае \"{filter}\"","адпавядаюць \"{filter}\"","адпавядаюць  \"{filter}\"","адпавядаюць \"{filter}\""],
-    "Direct link was copied (only works for people who have access to this file/folder)" : "Прамая спасылка скапіявана (працуе толькі для тых, хто мае доступ да гэтага файла/папкі)",
-    "Path" : "Шлях",
-    "_%n byte_::_%n bytes_" : ["%n байт","%n байт","%n байтаў","%n байтаў"],
-    "Favored" : "У абраным",
-    "Favor" : "У абранае",
-    "Copy direct link (only works for people who have access to this file/folder)" : "Скапіяваць прамую спасылку (працуе толькі для тых, хто мае доступ да гэтага файла/папкі)",
-    "Upload file" : "Запампаваць файл",
-    "Not favored" : "Не ў абраным",
-    "An error occurred while trying to update the tags" : "Падчас спробы абнавіць тэгі ўзнікла памылка",
+    "%1$s (renamed)" : "%1$s (перайменаваны)",
+    "renamed file" : "перайменаваны файл",
     "Upload (max. %s)" : "Запампоўванне (макс. %s)",
-    "\"{displayName}\" action executed successfully" : "Дзеянне \"{displayName}\" паспяхова выканана",
-    "\"{displayName}\" action failed" : "Не ўдалося выканаць дзеянне \"{displayName}\"",
+    "After enabling the windows compatible filenames, existing files cannot be modified anymore but can be renamed to valid new names by their owner." : "Пасля ўключэння сумяшчальнасці назваў файлаў з Windows існуючыя файлы больш нельга будзе змяняць, але іх уладальнік можа даць ім новыя правільныя назвы.",
+    "It is also possible to migrate files automatically after enabling this setting, please refer to the documentation about the occ command." : "Пасля ўключэння гэтай налады таксама можна аўтаматычна пераносіць файлы, звярніцеся да дакументацыі па камандзе occ.",
+    "Renamed \"{oldName}\" to \"{newName}\"" : "\"{oldName}\" перайменаваны ў \"{newName}\"",
+    "Clear filter" : "Ачысціць фільтр",
     "\"{displayName}\" failed on some elements" : "Не ўдалося выканаць дзеянне \"{displayName}\" на некаторых элементах",
     "\"{displayName}\" batch action executed successfully" : "Пакетнае дзеянне \"{displayName}\" паспяхова выканана",
-    "Submitting fields…" : "Адпраўка палёў…",
-    "Filter filenames…" : "Фільтраваць назвы файлаў…",
+    "\"{displayName}\" action failed" : "Не ўдалося выканаць дзеянне \"{displayName}\"",
+    "Submitting fields …" : "Адпраўка палёў …",
+    "Shared by link" : "Абагулена праз спасылку",
+    "Shared" : "Абагуленыя",
+    "\"{displayName}\" action executed successfully" : "Дзеянне \"{displayName}\" паспяхова выканана",
+    "Filter file names …" : "Фільтраваць назвы файлаў …",
+    "Clipboard is not available" : "Буфер абмену недаступны",
     "WebDAV URL copied to clipboard" : "URL-адрас WebDAV скапіяваны ў буфер абмену",
     "Enable the grid view" : "Уключыць выгляд сеткі",
     "Enable folder tree" : "Уключыць дрэва папак",
+    "WebDAV" : "WebDAV",
     "Copy to clipboard" : "Капіяваць у буфер абмену",
     "Use this address to access your Files via WebDAV" : "Выкарыстоўвайце гэты адрас для доступу да вашых файлаў праз WebDAV",
     "If you have enabled 2FA, you must create and use a new app password by clicking here." : "Калі вы ўключылі 2FA, вам трэба стварыць і ўжываць новы пароль праграмы, націснуўшы тут.",
-    "Deletion cancelled" : "Выдаленне скасавана",
-    "Move cancelled" : "Перамяшчэнне скасавана",
-    "Cancelled move or copy of \"{filename}\"." : "Аперацыя перамяшчэння або капіявання \"{filename}\" скасавана.",
-    "Cancelled move or copy operation" : "Аперацыя перамяшчэння або капіявання скасавана",
-    "Open details" : "Адкрыць падрабязнасці",
-    "Photos and images" : "Фота і відарысы",
-    "New folder creation cancelled" : "Стварэнне новай папкі скасавана",
-    "_{folderCount} folder_::_{folderCount} folders_" : ["{folderCount} папка","{folderCount} папкі","{folderCount} папак","{folderCount} папак"],
-    "_{fileCount} file_::_{fileCount} files_" : ["{fileCount} файл","{fileCount} файлы","{fileCount} файлаў","{fileCount} файлаў"],
-    "_1 file and {folderCount} folder_::_1 file and {folderCount} folders_" : ["1 файл і {folderCount} папка","1 файл і {folderCount} папкі","1 файл і {folderCount} папак","1 файл і {folderCount} папак"],
-    "_{fileCount} file and 1 folder_::_{fileCount} files and 1 folder_" : ["{fileCount} файл і 1 папка","{fileCount} файлы і 1 папка","{fileCount} файлаў і 1 папка","{fileCount} файлаў і 1 папка"],
-    "{fileCount} files and {folderCount} folders" : "Файлаў: {fileCount}, папак:{folderCount}",
-    "All folders" : "Усе папкі",
-    "Personal Files" : "Асабістыя файлы",
-    "Text file" : "Тэкставы файл",
-    "New text file.txt" : "Новы тэкставы файл.txt",
-    "%1$s (renamed)" : "%1$s (перайменаваны)",
-    "renamed file" : "перайменаваны файл",
-    "After enabling the windows compatible filenames, existing files cannot be modified anymore but can be renamed to valid new names by their owner." : "Пасля ўключэння сумяшчальнасці назваў файлаў з Windows існуючыя файлы больш нельга будзе змяняць, але іх уладальнік можа даць ім новыя правільныя назвы.",
-    "It is also possible to migrate files automatically after enabling this setting, please refer to the documentation about the occ command." : "Пасля ўключэння гэтай налады таксама можна аўтаматычна пераносіць файлы, звярніцеся да дакументацыі па камандзе occ.",
-    "Filter file names …" : "Фільтраваць назвы файлаў …",
     "Prevent warning dialogs from open or reenable them." : "Забараніць папярэджанні або зноў уключыць іх.",
     "Show a warning dialog when changing a file extension." : "Паказваць папярэджанне пры змене пашырэння файла.",
-    "Speed up your Files experience with these quick shortcuts." : "Паскорце працу з Файламі з дапамогай спалучэнняў клавіш.",
+    "Keyboard shortcuts" : "Спалучэнні клавіш",
+    "Speed up your Files experience with these quick shortcuts." : "Паскорце працу ў Файлах з дапамогай спалучэнняў клавіш.",
     "Open the actions menu for a file" : "Адкрыць меню дзеянняў для файла",
     "Rename a file" : "Перайменаваць файл",
     "Delete a file" : "Выдаліць файл",
@@ -521,6 +415,32 @@ OC.L10N.register(
     "Navigate to the file on the left (in grid mode)" : "Перайсці да файла злева (у рэжыме сеткі)",
     "Navigate to the file on the right (in grid mode)" : "Перайсці да файла справа (у рэжыме сеткі)",
     "Toggle the grid view" : "Пераключыць выгляд сеткі",
-    "Open the sidebar for a file" : "Адкрыць бакавую панэль для файла"
+    "Open the sidebar for a file" : "Адкрыць бакавую панэль для файла",
+    "You" : "Вы",
+    "Shared multiple times with different people" : "Абагулены некалькі разоў з рознымі людзьмі",
+    "Unable to change the favorite state of the file" : "Не ўдалося змяніць статус абранага для файла",
+    "Error while loading the file data" : "Памылка пры загрузцы даных файла",
+    "Tags" : "Тэгі",
+    "Save as …" : "Захаваць як …",
+    "Converting files …" : "Канвертацыя файлаў …",
+    "Converting file …" : "Канвертацыя файла …",
+    "Deletion cancelled" : "Выдаленне скасавана",
+    "Edit locally" : "Рэдагаваць лакальна",
+    "Moving \"{source}\" to \"{destination}\" …" : "Перамяшчэнне \"{source}\" у \"{destination}\" …",
+    "Copying \"{source}\" to \"{destination}\" …" : "Капіяванне \"{source}\" у \"{destination}\" …",
+    "(copy)" : "(копія)",
+    "(copy %n)" : "(копія %n)",
+    "Move cancelled" : "Перамяшчэнне скасавана",
+    "Cancelled move or copy of \"{filename}\"." : "Аперацыя перамяшчэння або капіявання \"{filename}\" скасавана.",
+    "Cancelled move or copy operation" : "Аперацыя перамяшчэння або капіявання скасавана",
+    "Open details" : "Адкрыць падрабязнасці",
+    "Photos and images" : "Фота і відарысы",
+    "New folder creation cancelled" : "Стварэнне новай папкі скасавана",
+    "This directory is unavailable, please check the logs or contact the administrator" : "Гэты каталог недаступны, праверце журналы або звярніцеся да адміністратара",
+    "All folders" : "Усе папкі",
+    "Open file sidebar" : "Адкрыць бакавую панэль файла",
+    "Search everywhere …" : "Шукаць усюды …",
+    "Search here …" : "Шукаць тут …",
+    "Preparing …" : "Падрыхтоўка …"
 },
 "nplurals=4; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<12 || n%100>14) ? 1 : n%10==0 || (n%10>=5 && n%10<=9) || (n%100>=11 && n%100<=14)? 2 : 3);");
