@@ -51,6 +51,8 @@ OC.L10N.register(
     "You do not have permission to create a file at the specified location" : "No teniu permís per crear fitxers a la ubicació especificada",
     "The file could not be converted." : "No s'ha pogut convertir el fitxer.",
     "Could not get relative path to converted file" : "No s'ha pogut obtenir el camí relatiu al fitxer convertit",
+    "Limit must be a positive integer." : "El límit ha de ser un enter positiu.",
+    "The replacement character may only be a single character." : "El caràcter de substitució només pot ser un sol caràcter.",
     "Favorite files" : "Fitxers preferits",
     "No favorites" : "No hi ha preferits",
     "More favorites" : "Més preferits",
@@ -68,16 +70,13 @@ OC.L10N.register(
     "The ownership transfer of {path} from {user} has completed." : "S'ha completat la transferència de propietat de {path} de {user}.",
     "in %s" : "%s",
     "Transferred from %1$s on %2$s" : "S'ha transferit de %1$s a %2$s",
-    "Files compatibility" : "Compatibilitat de fitxers",
-    "Allow to restrict filenames to ensure files can be synced with all clients. By default all filenames valid on POSIX (e.g. Linux or macOS) are allowed." : "Permet restringir els noms de fitxers per garantir que els fitxers es puguin sincronitzar amb tots els clients. Per defecte es permeten tots els noms de fitxer vàlids a POSIX (per exemple, Linux o macOS).",
-    "Enforce Windows compatibility" : "Força la compatibilitat amb Windows",
-    "This will block filenames not valid on Windows systems, like using reserved names or special characters. But this will not enforce compatibility of case sensitivity." : "Això bloquejarà els noms de fitxer no vàlids als sistemes Windows, com ara l'ús de noms reservats o caràcters especials. Però això no força la compatibilitat de la distinció entre majúscules i minúscules.",
     "File Management" : "Gestió de fitxers",
     "Home" : "Inici",
     "Target folder does not exist any more" : "La carpeta de destinació ja no existeix",
     "Reload current directory" : "Torna a carregar la carpeta actual",
     "Go to the \"{dir}\" directory" : "Ves a la carpeta «{dir}»",
     "Current directory path" : "Camí de la carpeta actual",
+    "Share" : "Comparteix",
     "Your have used your space quota and cannot upload files anymore" : "Heu utilitzat la quota d'espai i ja no podeu pujar fitxers",
     "You do not have permission to upload or create files here." : "No tens permís per pujar o crear arxius aquí.",
     "Drag and drop files here to upload" : "Arrossegueu i deixeu anar fitxers aquí per a pujar-los",
@@ -92,31 +91,62 @@ OC.L10N.register(
     "This node is unavailable" : "Aquest node no està disponible",
     "Another entry with the same name already exists." : "Ja existeix una altra entrada amb el mateix nom.",
     "Invalid filename." : "Nom de fitxer no vàlid.",
-    "Renamed \"{oldName}\" to \"{newName}\"" : "S'ha canviat el nom de «{oldName}» a «{newName}»",
     "Rename file" : "Canvia el nom del fitxer",
     "Folder" : "Carpeta",
+    "Unknown file type" : "Tipus de fitxer desconegut",
     "Pending" : "Pendent",
     "Unknown date" : "Data desconeguda",
-    "Clear filter" : "Esborra el filtre",
-    "Modified" : "Darrera modificació",
-    "Type" : "Tipus",
     "Active filters" : "Filtres actius",
     "Remove filter" : "Suprimeix el filtre",
+    "Today" : "Avui",
+    "Last 7 days" : "Últims 7 dies",
+    "Last 30 days" : "Últims 30 dies",
+    "This year ({year})" : "Aquest any ({year})",
+    "Last year ({year})" : "L'any passat ({year})",
+    "Custom date range" : "Interval de dates personalitzat",
+    "Search everywhere" : "Cerca a tot arreu",
+    "Documents" : "Documents",
+    "Spreadsheets" : "Fulls de càlcul",
+    "Presentations" : "Presentacions",
+    "PDFs" : "PDFs",
+    "Folders" : "Carpetes",
+    "Audio" : "Àudio",
+    "Images" : "Imatges",
+    "Videos" : "Vídeos",
+    "Filters" : "Filtres",
+    "Appearance" : "Aparença",
+    "Show hidden files" : "Mostra els fitxers ocults",
+    "Crop image previews" : "Retalla les previsualitzacions de les imatges",
+    "General" : "General",
+    "Sort favorites first" : "Ordena primer els preferits",
+    "Sort folders before files" : "Ordena les carpetes abans dels fitxers",
+    "All files" : "Tots els fitxers",
+    "Personal files" : "Fitxers personals",
+    "Additional settings" : "Paràmetres addicionals",
+    "Actions" : "Accions",
+    "File actions" : "Arxivar accions",
+    "Selection" : "Selecció",
+    "Select all files" : "Seleccioneu tots els fitxers",
+    "Deselect all" : "No seleccionis res",
+    "Navigation" : "Navegació",
+    "View" : "Visualització",
+    "Toggle grid view" : "Canvia la visualització de quadrícula",
+    "Show those shortcuts" : "Mostra aquestes dreceres",
+    "Warnings" : "Advertiments",
+    "WebDAV URL" : "URL de WebDAV",
     "Total rows summary" : "Resum de totes les files",
     "Toggle selection for all files and folders" : "Canvia la selecció per a tots els fitxers i carpetes",
     "Name" : "Nom",
+    "File type" : "Tipus de fitxer",
     "Size" : "Mida",
-    "\"{displayName}\" failed on some elements" : "\"{displayName}\" ha fallat en alguns elements",
-    "\"{displayName}\" batch action executed successfully" : "L'acció per lots «{displayName}» s'ha executat correctament",
-    "\"{displayName}\" action failed" : "S'ha produït un error en l'acció «{displayName}»",
-    "Actions" : "Accions",
+    "Modified" : "Darrera modificació",
     "(selected)" : "(seleccionat)",
     "List of files and folders." : "Llista de fitxers i carpetes.",
     "You have used your space quota and cannot upload files anymore." : "Heu utilitzat la quota d'espai i ja no podeu pujar fitxers.",
     "Column headers with buttons are sortable." : "Les capçaleres de columna amb botons es poder ordenar.",
     "This list is not fully rendered for performance reasons. The files will be rendered as you navigate through the list." : "Aquesta llista no es mostra completament per raons de rendiment. Es mostraran els fitxers a mesura que navegueu per la llista.",
     "File not found" : "No s'ha trobat el fitxer",
-    "{count} selected" : "Selecció: {count}",
+    "Owner" : "Propietat",
     "{usedQuotaByte} used" : "{usedQuotaByte} en ús",
     "{used} of {quota} used" : "{used} de {quota} en ús",
     "{relative}% used" : "{relative}% en ús",
@@ -128,8 +158,9 @@ OC.L10N.register(
     "Create new folder" : "Crea una carpeta",
     "This name is already in use." : "Aquest nom ja s'utilitza.",
     "Create" : "Crea",
+    "Refresh" : "Actualitza",
+    "Limit" : "Límit",
     "Fill template fields" : "Ompliu els camps de la plantilla",
-    "Submitting fields …" : "S'estan enviant camps …",
     "Submit" : "Envia",
     "Choose a file or folder to transfer" : "Trieu el fitxer o carpeta que voleu transferir",
     "Transfer" : "Transfereix",
@@ -151,11 +182,11 @@ OC.L10N.register(
     "Removing the file extension \"{old}\" may render the file unreadable." : "Suprimeix l'extensió de fitxer \"{old}\" pot fer que el fitxer sigui il·legible.",
     "Adding the file extension \"{new}\" may render the file unreadable." : "Afegir l'extensió del fitxer \"{new}\" pot fer que el fitxer sigui il·legible.",
     "Do not show this dialog again." : "No torneu a mostrar aquest diàleg.",
+    "Cancel" : "Cancel·la",
+    "Rename" : "Canvia el nom",
     "Select file or folder to link to" : "Seleccioneu el fitxer o la carpeta que voleu enllaçar",
     "Choose {file}" : "Tria {file}",
-    "Share" : "Comparteix",
-    "Shared by link" : "S'ha compartit amb un enllaç",
-    "Shared" : "S'ha compartit",
+    "Files settings" : "Paràmetres de Fitxers",
     "Switch to list view" : "Canvia a la visualització de llista",
     "Switch to grid view" : "Canvia a la visualització de quadrícula",
     "The file could not be found" : "No s'ha pogut trobar el fitxer",
@@ -165,85 +196,34 @@ OC.L10N.register(
     "Error during upload: {message}" : "S'ha produït un error durant la pujada: {message}",
     "Error during upload, status code {status}" : "S'ha produït un error durant la pujada, el codi d'estat és {status}",
     "Unknown error during upload" : "S'ha produït un error desconegut durant la pujada",
-    "\"{displayName}\" action executed successfully" : "L'acció «{displayName}» s'ha executat correctament",
     "Loading current folder" : "S'està carregant la carpeta actual",
     "Retry" : "Torna-ho a provar",
     "No files in here" : "No hi ha cap fitxer aquí",
     "Upload some content or sync with your devices!" : "Pugeu contingut o sincronitzeu els vostres dispositius!",
     "Go back" : "Torna",
-    "Filter file names …" : "Filtra els noms dels fitxers …",
     "Views" : "Vistes",
-    "Files settings" : "Paràmetres de Fitxers",
     "Your files" : "Els vostres fitxers",
     "Open in files" : "Obre a Fitxers",
     "File cannot be accessed" : "No es pot accedir al fitxer",
     "The file could not be found or you do not have permissions to view it. Ask the sender to share it." : "No s'ha trobat el fitxer o no teniu permisos per a visualitzar-lo. Demaneu al remitent que el comparteixi.",
-    "Clipboard is not available" : "El porta-retalls no està disponible",
-    "WebDAV URL copied to clipboard" : "S'ha copiat l'URL de WebDAV al porta-retalls",
-    "Sort favorites first" : "Ordena primer els preferits",
-    "Sort folders before files" : "Ordena les carpetes abans dels fitxers",
-    "Show hidden files" : "Mostra els fitxers ocults",
-    "Crop image previews" : "Retalla les previsualitzacions de les imatges",
-    "Enable the grid view" : "Habilita la visualització de quadrícula",
-    "Enable folder tree" : "Habilita l'arbre de carpetes",
-    "Additional settings" : "Paràmetres addicionals",
-    "WebDAV" : "WebDAV",
-    "WebDAV URL" : "URL de WebDAV",
-    "Copy to clipboard" : "Copia-ho al porta-retalls",
-    "Use this address to access your Files via WebDAV" : "Utilitzeu aquesta adreça per a accedir als vostres fitxers mitjançant WebDAV",
-    "If you have enabled 2FA, you must create and use a new app password by clicking here." : "Si heu habilitat l'autenticació de doble factor, podeu crear i utilitzar una nova contrasenya d'aplicació fent clic aquí.",
-    "Warnings" : "Advertiments",
-    "Prevent warning dialogs from open or reenable them." : "Eviteu que s'obrin els diàlegs d'advertència o torneu-los a habilitar.",
-    "Show a warning dialog when changing a file extension." : "Mostra un diàleg d'avís quan es canvia una extensió de fitxer.",
-    "Keyboard shortcuts" : "Dreceres de teclat",
-    "Speed up your Files experience with these quick shortcuts." : "Accelereu l'experiència Fitxers amb aquestes dreceres ràpides.",
-    "Open the actions menu for a file" : "Obre el menú d'accions per un fitxer",
-    "Rename a file" : "Canvia el nom del fitxer",
-    "Delete a file" : "Suprimeix el fitxer",
-    "Favorite or remove a file from favorites" : "Marca com a preferit o suprimeix un fitxer dels preferits",
-    "Manage tags for a file" : "Administra les etiquetes d'un fitxer",
-    "Selection" : "Selecció",
-    "Select all files" : "Seleccioneu tots els fitxers",
-    "Deselect all files" : "Desseleccioneu tots els fitxers",
-    "Select or deselect a file" : "Seleccioneu o deseleccioneu un fitxer",
-    "Select a range of files" : "Seleccioneu un rang de fitxers",
-    "Navigation" : "Navegació",
-    "Navigate to the parent folder" : "Navegueu a la carpeta principal",
-    "Navigate to the file above" : "Navegueu al fitxer de dalt",
-    "Navigate to the file below" : "Navegueu fins al fitxer següent",
-    "Navigate to the file on the left (in grid mode)" : "Navegueu fins al fitxer de l'esquerra (en mode de quadrícula)",
-    "Navigate to the file on the right (in grid mode)" : "Navegueu fins al fitxer de la dreta (en mode de quadrícula)",
-    "View" : "Visualització",
-    "Toggle the grid view" : "Commuta la vista de la quadrícula",
-    "Open the sidebar for a file" : "Obriu la barra lateral d'un fitxer",
-    "Show those shortcuts" : "Mostra aquestes dreceres",
-    "You" : "Vós",
-    "Shared multiple times with different people" : "S'ha compartit diverses vegades amb persones diferents",
-    "Error while loading the file data" : "S'ha produït un error en carregar la informació del fitxer",
-    "Owner" : "Propietat",
-    "Remove from favorites" : "Suprimeix dels preferits",
-    "Add to favorites" : "Afegeix als preferits",
-    "Tags" : "Etiquetes",
+    "Allow to restrict filenames to ensure files can be synced with all clients. By default all filenames valid on POSIX (e.g. Linux or macOS) are allowed." : "Permet restringir els noms de fitxers per garantir que els fitxers es puguin sincronitzar amb tots els clients. Per defecte es permeten tots els noms de fitxer vàlids a POSIX (per exemple, Linux o macOS).",
+    "Files compatibility" : "Compatibilitat de fitxers",
+    "Enforce Windows compatibility" : "Força la compatibilitat amb Windows",
+    "This will block filenames not valid on Windows systems, like using reserved names or special characters. But this will not enforce compatibility of case sensitivity." : "Això bloquejarà els noms de fitxer no vàlids als sistemes Windows, com ara l'ús de noms reservats o caràcters especials. Però això no força la compatibilitat de la distinció entre majúscules i minúscules.",
     "Blank" : "En blanc",
     "Unable to create new file from template" : "No s'ha pogut crear el fitxer a partir de la plantilla",
     "Pick a template for {name}" : "Trieu una plantilla per a {name}",
     "Create a new file with the selected template" : "Crea un fitxer amb la plantilla seleccionada",
     "Creating file" : "S'està creant el fitxer",
     "Save as {displayName}" : "Desa com a {displayName}",
-    "Save as …" : "Anomena i desa …",
-    "Converting files …" : "Convertint fitxers …",
     "Failed to convert files: {message}" : "No s'han pogut convertir els fitxers: {message}",
     "All files failed to be converted" : "No s'han pogut convertir tots els fitxers",
     "One file could not be converted: {message}" : "No s'ha pogut convertir un fitxer: {message}",
-    "_One file could not be converted_::_%n files could not be converted_" : ["No s'ha pogut convertir un fitxer","No s’han pogut convertir %n fitxers"],
-    "_One file successfully converted_::_%n files successfully converted_" : ["Un fitxer s'ha convertit correctament","%n fitxers s'han convertit correctament"],
-    "Files successfully converted" : "Els fitxers s'han convertit correctament",
     "Failed to convert files" : "No s'han pogut convertir els fitxers",
-    "Converting file …" : "S'està convertint el fitxer …",
     "File successfully converted" : "El fitxer s'ha convertit correctament",
     "Failed to convert file: {message}" : "No s'ha pogut convertir el fitxer: {message}",
     "Failed to convert file" : "No s'ha pogut convertir el fitxer",
-    "Deletion cancelled" : "S'ha cancel·lat la supressió",
+    "Delete" : "Suprimeix",
     "Leave this share" : "Abandona aquest element compartit",
     "Leave these shares" : "Abandona aquests elements compartits",
     "Disconnect storage" : "Desconnecta l'emmagatzematge",
@@ -254,29 +234,26 @@ OC.L10N.register(
     "Delete files" : "Suprimeix els fitxers",
     "Delete folder" : "Suprimeix la carpeta",
     "Delete folders" : "Suprimeix les carpetes",
-    "Delete" : "Suprimeix",
     "_You are about to permanently delete {count} item_::_You are about to permanently delete {count} items_" : ["Esteu a punt de suprimir permanentment {count} element","Esteu a punt de suprimir permanentment {count} elements"],
     "_You are about to delete {count} item_::_You are about to delete {count} items_" : ["Esteu a punt de suprimir {count} element","Esteu a punt de suprimir {count} elements"],
     "Confirm deletion" : "Confirma la supressió",
-    "Cancel" : "Cancel·la",
-    "Moving \"{source}\" to \"{destination}\" …" : "S'està movent \"{source}\" a \"{destination}”…",
-    "Copying \"{source}\" to \"{destination}\" …" : "S'està copiant \"{source}\" a \"{destination}” …",
+    "Download" : "Baixa",
+    "Add to favorites" : "Afegeix als preferits",
+    "Remove from favorites" : "Suprimeix dels preferits",
+    "Move" : "Mou",
+    "Copy" : "Copia",
+    "Move or copy" : "Mou o copia",
+    "Destination is not a folder" : "La destinació no és una carpeta",
+    "This file/folder is already in that directory" : "Aquest fitxer o carpeta ja existeix en aquesta carpeta",
     "You cannot move a file/folder onto itself or into a subfolder of itself" : "No podeu moure un fitxer o carpeta a la mateixa carpeta o a una subcarpeta de la mateixa carpeta",
-    "(copy)" : "(còpia)",
-    "(copy %n)" : "(còpia %n)",
-    "Move cancelled" : "S'ha cancel·lat el desplaçament",
     "A file or folder with that name already exists in this folder" : "Ja existeix un fitxer o carpeta amb aquest nom en aquesta carpeta",
     "The files are locked" : "Els fitxers estan blocats",
     "The file does not exist anymore" : "El fitxer ja no existeix",
     "Choose destination" : "Trieu una destinació",
     "Copy to {target}" : "Copia a {target}",
-    "Copy" : "Copia",
     "Move to {target}" : "Mou a {target}",
-    "Move" : "Mou",
     "Move or copy operation failed" : "Error en l'operació de desplaçament o còpia",
-    "Move or copy" : "Mou o copia",
-    "Cancelled move or copy of \"{filename}\"." : "S'ha cancel·lat el moviment o la còpia de \"{filename}\".",
-    "Cancelled move or copy operation" : "S'ha cancel·lat l'operació de desplaçament o còpia",
+    "Open folder" : "Obre la carpeta",
     "Open folder {displayName}" : "Obre la carpeta {displayName}",
     "Open in Files" : "Obre a Fitxers",
     "Open locally" : "Obre en local",
@@ -285,23 +262,9 @@ OC.L10N.register(
     "The file should now open on your device. If it doesn't, please check that you have the desktop app installed." : "Ara s'hauria d'obrir el fitxer al dispositiu. Si no és així, comproveu que teniu instal·lada l'aplicació d'escriptori.",
     "Retry and close" : "Torna-ho a provar i tanca",
     "Open online" : "Obre en línia",
-    "Rename" : "Canvia el nom",
-    "Open details" : "Obre els detalls",
+    "Details" : "Detalls",
     "View in folder" : "Visualitza-ho en la carpeta",
-    "Today" : "Avui",
-    "Last 7 days" : "Últims 7 dies",
-    "Last 30 days" : "Últims 30 dies",
-    "This year ({year})" : "Aquest any ({year})",
-    "Last year ({year})" : "L'any passat ({year})",
-    "Documents" : "Documents",
-    "Spreadsheets" : "Fulls de càlcul",
-    "Presentations" : "Presentacions",
-    "PDFs" : "PDFs",
-    "Folders" : "Carpetes",
-    "Audio" : "Àudio",
-    "Photos and images" : "Fotografies i imatges",
-    "Videos" : "Vídeos",
-    "New folder creation cancelled" : "S'ha cancel·lat la creació de carpetes noves",
+    "Type" : "Tipus",
     "Created new folder \"{name}\"" : "S'ha creat la carpeta nova «{name}»",
     "Unable to initialize the templates directory" : "No s'ha pogut inicialitzar la carpeta de plantilles",
     "Create templates folder" : "Crea una carpeta de plantilles",
@@ -316,14 +279,16 @@ OC.L10N.register(
     "Some files could not be uploaded" : "No s'han pogut pujar alguns fitxers",
     "Files uploaded successfully" : "Els fitxers s'han pujat correctament",
     "No files to process" : "No hi ha cap fitxer per processar",
-    "Some files could not be copied" : "No s'han pogut copiar alguns fitxers",
-    "Some files could not be moved" : "No s'han pogut moure alguns fitxers",
     "Files copied successfully" : "Els fitxers s'han copiat correctament",
     "Files moved successfully" : "Els fitxers s'han mogut correctament",
+    "Some files could not be copied" : "No s'han pogut copiar alguns fitxers",
+    "Some files could not be moved" : "No s'han pogut moure alguns fitxers",
     "Conflicts resolution skipped" : "S'ha omès la resolució de conflictes",
     "Upload cancelled" : "S'ha cancel·lat la pujada",
+    "Could not rename \"{oldName}\", it does not exist any more" : "No s'ha pogut canviar el nom de «{oldName}», ja no existeix",
+    "The name \"{newName}\" is already used in the folder \"{dir}\". Please choose a different name." : "El nom «{newName}» ja està en ús en la carpeta «{dir}». Trieu un nom diferent.",
+    "Could not rename \"{oldName}\"" : "No s'ha pogut canviar el nom de «{oldName}»",
     "This operation is forbidden" : "Aquesta operació no està permesa",
-    "This directory is unavailable, please check the logs or contact the administrator" : "Aquesta carpeta no està disponible. Consulteu els registres o contacteu amb l'administrador",
     "Storage is temporarily not available" : "L'emmagatzematge no està disponible temporalment",
     "Unexpected error: {error}" : "Error inesperat: {error}",
     "_%n file_::_%n files_" : ["%n fitxer","%n fitxers"],
@@ -336,10 +301,7 @@ OC.L10N.register(
     "List of favorite files and folders." : "Llista de fitxers i carpetes preferits.",
     "No favorites yet" : "Encara no teniu preferits",
     "Files and folders you mark as favorite will show up here" : "Els fitxers i les carpetes que marqueu com a preferits es mostraran aquí",
-    "All files" : "Tots els fitxers",
     "List of your files and folders." : "Llista dels vostres fitxers i carpetes.",
-    "All folders" : "Totes les carpetes",
-    "Personal files" : "Fitxers personals",
     "List of your files and folders that are not shared." : "Llista dels vostres fitxers i carpetes que no compartiu.",
     "No personal files found" : "No s'ha trobat cap fitxer personal",
     "Files that are not shared will show up here." : "Els fitxers que no compartiu es mostraran aquí.",
@@ -347,103 +309,70 @@ OC.L10N.register(
     "List of recently modified files and folders." : "Llista de fitxers i carpetes modificats recentment.",
     "No recently modified files" : "No hi ha cap fitxer modificat recentment",
     "Files and folders you recently modified will show up here." : "Els fitxers i les carpetes que heu modificat recentment es mostraran aquí.",
+    "Search" : "Cercar",
     "No entries found in this folder" : "No s'ha trobat cap entrada en aquesta carpeta",
     "Select all" : "Selecciona-ho tot",
     "Upload too large" : "La pujada és massa gran",
     "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Els fitxers que intenteu pujar superen la mida màxima de pujada de fitxers del servidor.",
-    "File could not be found" : "No s'ha pogut trobar el fitxer",
-    "Download" : "Baixa",
-    "Show list view" : "Mostra la visualització de llista",
-    "Show grid view" : "Mostra la visualització de graella",
-    "Close" : "Tanca",
-    "Could not create folder \"{dir}\"" : "No s'ha pogut crear la carpeta «{dir}»",
-    "This will stop your current uploads." : "Això aturarà les pujades actuals.",
-    "Upload cancelled." : "S'ha cancel·lat la pujada.",
-    "Processing files …" : "S'estan processant els fitxers…",
-    "…" : "…",
-    "Unable to upload {filename} as it is a directory or has 0 bytes" : "No s'ha pogut pujar {filename} perquè és una carpeta o té 0 bytes",
-    "Not enough free space, you are uploading {size1} but only {size2} is left" : "No hi ha prou espai lliure, esteu pujant {size1}, però només teniu {size2} lliures",
-    "Target folder \"{dir}\" does not exist any more" : "La carpeta de destinació «{dir}» ja no existeix",
-    "An unknown error has occurred" : "S'ha produït un error desconegut",
-    "File could not be uploaded" : "No s'ha pogut pujar el fitxer",
-    "Uploading …" : "S'està pujant…",
-    "{remainingTime} ({currentNumber}/{total})" : "{remainingTime} ({currentNumber}/{total})",
-    "Uploading … ({currentNumber}/{total})" : "S'està pujant… ({currentNumber}/{total})",
-    "{loadedSize} of {totalSize} ({bitrate})" : "{loadedSize} de {totalSize} ({bitrate})",
-    "Uploading that item is not supported" : "No s'admet la pujada aquest element",
-    "Error when assembling chunks, status code {status}" : "S'ha produït un error en recopilar els fragments, el codi d'estat és {status}",
-    "Choose target folder" : "Trieu la carpeta de destinació",
-    "Set reminder" : "Defineix un recordatori",
-    "Edit locally" : "Edita localment",
-    "Open" : "Obre",
-    "Could not load info for file \"{file}\"" : "No s'ha pogut carregar la informació del fitxer «{file}»",
-    "Details" : "Detalls",
-    "Please select tag(s) to add to the selection" : "Seleccioneu les etiquetes que voleu afegir a la selecció",
-    "Apply tag(s) to selection" : "Aplica les etiquetes a la selecció",
-    "Select directory \"{dirName}\"" : "Selecciona la carpeta «{dirName}»",
-    "Select file \"{fileName}\"" : "Selecciona el fitxer «{fileName}»",
-    "Unable to determine date" : "No s'ha pogut determinar la data",
-    "Could not move \"{file}\", target exists" : "No s'ha pogut desplaçar «{file}», el fitxer de destinació ja existeix",
-    "Could not move \"{file}\"" : "No s'ha pogut desplaçar «{file}»",
-    "copy" : "còpia",
-    "Could not copy \"{file}\", target exists" : "No s'ha pogut copiar «{file}», el fitxer de destinació ja existeix",
-    "Could not copy \"{file}\"" : "No s'ha pogut copiar «{file}»",
-    "Copied {origin} inside {destination}" : "S'ha copiat {origin} a {destination}",
-    "Copied {origin} and {nbfiles} other files inside {destination}" : "S'han copiat {origin} i {nbfiles} fitxers més a {destination}",
-    "{newName} already exists" : "{newName} ja existeix",
-    "Could not rename \"{fileName}\", it does not exist any more" : "No s'ha pogut canviar el nom de «{fileName}», ja no existeix",
-    "The name \"{targetName}\" is already used in the folder \"{dir}\". Please choose a different name." : "El nom «{targetName}» ja està en ús en la carpeta «{dir}». Trieu un nom diferent.",
-    "Could not rename \"{fileName}\"" : "No s'ha pogut canviar el nom de «{fileName}»",
-    "Could not create file \"{file}\"" : "No s'ha pogut crear el fitxer «{file}»",
-    "Could not create file \"{file}\" because it already exists" : "No s'ha pogut crear el fitxer «{file}» perquè ja existeix",
-    "Could not create folder \"{dir}\" because it already exists" : "No s'ha pogut crear la carpeta «{dir}» perquè ja existeix",
-    "Could not fetch file details \"{file}\"" : "No s'han pogut recuperar els detalls del fitxer «{file}»",
-    "Error deleting file \"{fileName}\"." : "S'ha produït un error en suprimir el fitxer «{fileName}».",
-    "No search results in other folders for {tag}{filter}{endtag}" : "No hi ha cap resultat de cerca en altres carpetes per a {tag}{filter}{endtag}",
-    "Enter more than two characters to search in other folders" : "Introduïu més de dos caràcters per a cercar en altres carpetes",
-    "{dirs} and {files}" : "{dirs} i {files}",
-    "_including %n hidden_::_including %n hidden_" : ["incloent-hi %n element ocult","incloent-hi %n elements ocults"],
-    "You do not have permission to upload or create files here" : "No teniu permís per a pujar o crear fitxers aquí",
-    "_Uploading %n file_::_Uploading %n files_" : ["S'està pujant %n fitxer","S'estan pujant %n fitxers"],
-    "New" : "Crea",
-    "New file/folder menu" : "Menú de fitxer o carpeta nova",
-    "Select file range" : "Selecciona un interval de fitxers",
-    "{used}%" : "{used}%",
-    "{used} used" : "{used} en ús",
-    "\"{name}\" is an invalid file name." : "«{name}» no és un nom de fitxer vàlid.",
-    "File name cannot be empty." : "El nom del fitxer no pot estar buit.",
-    "\"/\" is not allowed inside a file name." : "No es permet l'ús del caràcter «/» en el nom d'un fitxer.",
-    "\"{name}\" is not an allowed filetype" : "«{name}» no és un tipus de fitxer permès",
-    "Storage of {owner} is full, files cannot be updated or synced anymore!" : "L'emmagatzematge de l'usuari {owner} està ple, els fitxers ja no es poden actualitzar ni sincronitzar!",
-    "Group folder \"{mountPoint}\" is full, files cannot be updated or synced anymore!" : "La carpeta de grup «{mountPoint}» està plena, els fitxers ja no es poden actualitzar ni sincronitzar!",
-    "External storage \"{mountPoint}\" is full, files cannot be updated or synced anymore!" : "L'emmagatzematge extern «{mountPoint}» està ple, els fitxers ja no es poden actualitzar ni sincronitzar!",
-    "Your storage is full, files cannot be updated or synced anymore!" : "L'emmagatzematge està ple, els fitxers ja no es poden actualitzar ni sincronitzar!",
-    "Storage of {owner} is almost full ({usedSpacePercent}%)." : "L'emmagatzematge de {owner} està gairebé ple ({usedSpacePercent}%).",
-    "Group folder \"{mountPoint}\" is almost full ({usedSpacePercent}%)." : "La carpeta de grup «{mountPoint}» està gairebé plena ({usedSpacePercent}%).",
-    "External storage \"{mountPoint}\" is almost full ({usedSpacePercent}%)." : "L'emmagatzematge extern «{mountPoint}» està gairebé ple ({usedSpacePercent}%).",
-    "Your storage is almost full ({usedSpacePercent}%)." : "L'emmagatzematge està gairebé ple ({usedSpacePercent}%).",
-    "_matches \"{filter}\"_::_match \"{filter}\"_" : ["coincideix amb «{filter}»","coincideixen amb «{filter}»"],
-    "Direct link was copied (only works for people who have access to this file/folder)" : "S'ha copiat l'enllaç directe (només funciona per a les persones que tenen accés a aquest fitxer o carpeta)",
-    "Path" : "Camí",
-    "_%n byte_::_%n bytes_" : ["%n byte","%n bytes"],
-    "Favored" : "Afavorit",
-    "Favor" : "Afavorir",
-    "Copy direct link (only works for people who have access to this file/folder)" : "Copia l'enllaç directe (només funciona per a les persones que tinguin accés a aquest fitxer o carpeta)",
-    "Upload file" : "Puja un fitxer",
-    "Not favored" : "No afavorit",
-    "An error occurred while trying to update the tags" : "S'ha produït un error en intentar actualitzar les etiquetes",
     "Upload (max. %s)" : "Puja (màx. %s)",
-    "Submitting fields…" : "S'estan enviant camps…",
-    "Filter filenames…" : "Filtra els noms de fitxer…",
-    "_{folderCount} folder_::_{folderCount} folders_" : ["{folderCount} carpeta","{folderCount} carpetes"],
-    "_{fileCount} file_::_{fileCount} files_" : ["{fileCount} fitxer","{fileCount} fitxers"],
-    "_1 file and {folderCount} folder_::_1 file and {folderCount} folders_" : ["1 fitxer i {folderCount} carpeta","1 fitxer i {folderCount} carpetes"],
-    "_{fileCount} file and 1 folder_::_{fileCount} files and 1 folder_" : ["{fileCount} fitxer i 1 carpeta","{fileCount} fitxers i 1 carpeta"],
-    "{fileCount} files and {folderCount} folders" : "{fileCount} fitxers i {folderCount} carpetes",
-    "Personal Files" : "FItxers personals",
-    "Text file" : "Fitxer de text",
-    "New text file.txt" : "Fitxer de text nou.txt",
-    "{count} files could not be converted" : "No s'han pogut convertir {count} fitxers",
-    "{count} files successfully converted" : "{count} fitxers convertits correctament"
+    "Renamed \"{oldName}\" to \"{newName}\"" : "S'ha canviat el nom de «{oldName}» a «{newName}»",
+    "Clear filter" : "Esborra el filtre",
+    "\"{displayName}\" failed on some elements" : "\"{displayName}\" ha fallat en alguns elements",
+    "\"{displayName}\" batch action executed successfully" : "L'acció per lots «{displayName}» s'ha executat correctament",
+    "\"{displayName}\" action failed" : "S'ha produït un error en l'acció «{displayName}»",
+    "Submitting fields …" : "S'estan enviant camps …",
+    "Shared by link" : "S'ha compartit amb un enllaç",
+    "Shared" : "S'ha compartit",
+    "\"{displayName}\" action executed successfully" : "L'acció «{displayName}» s'ha executat correctament",
+    "Filter file names …" : "Filtra els noms dels fitxers …",
+    "Clipboard is not available" : "El porta-retalls no està disponible",
+    "WebDAV URL copied to clipboard" : "S'ha copiat l'URL de WebDAV al porta-retalls",
+    "Enable the grid view" : "Habilita la visualització de quadrícula",
+    "Enable folder tree" : "Habilita l'arbre de carpetes",
+    "WebDAV" : "WebDAV",
+    "Copy to clipboard" : "Copia-ho al porta-retalls",
+    "Use this address to access your Files via WebDAV" : "Utilitzeu aquesta adreça per a accedir als vostres fitxers mitjançant WebDAV",
+    "If you have enabled 2FA, you must create and use a new app password by clicking here." : "Si heu habilitat l'autenticació de doble factor, podeu crear i utilitzar una nova contrasenya d'aplicació fent clic aquí.",
+    "Prevent warning dialogs from open or reenable them." : "Eviteu que s'obrin els diàlegs d'advertència o torneu-los a habilitar.",
+    "Show a warning dialog when changing a file extension." : "Mostra un diàleg d'avís quan es canvia una extensió de fitxer.",
+    "Keyboard shortcuts" : "Dreceres de teclat",
+    "Speed up your Files experience with these quick shortcuts." : "Accelereu l'experiència Fitxers amb aquestes dreceres ràpides.",
+    "Open the actions menu for a file" : "Obre el menú d'accions per un fitxer",
+    "Rename a file" : "Canvia el nom del fitxer",
+    "Delete a file" : "Suprimeix el fitxer",
+    "Favorite or remove a file from favorites" : "Marca com a preferit o suprimeix un fitxer dels preferits",
+    "Manage tags for a file" : "Administra les etiquetes d'un fitxer",
+    "Deselect all files" : "Desseleccioneu tots els fitxers",
+    "Select or deselect a file" : "Seleccioneu o deseleccioneu un fitxer",
+    "Select a range of files" : "Seleccioneu un rang de fitxers",
+    "Navigate to the parent folder" : "Navegueu a la carpeta principal",
+    "Navigate to the file above" : "Navegueu al fitxer de dalt",
+    "Navigate to the file below" : "Navegueu fins al fitxer següent",
+    "Navigate to the file on the left (in grid mode)" : "Navegueu fins al fitxer de l'esquerra (en mode de quadrícula)",
+    "Navigate to the file on the right (in grid mode)" : "Navegueu fins al fitxer de la dreta (en mode de quadrícula)",
+    "Toggle the grid view" : "Commuta la vista de la quadrícula",
+    "Open the sidebar for a file" : "Obriu la barra lateral d'un fitxer",
+    "You" : "Vós",
+    "Shared multiple times with different people" : "S'ha compartit diverses vegades amb persones diferents",
+    "Unable to change the favorite state of the file" : "No es pot canviar l'estat preferit del fitxer",
+    "Error while loading the file data" : "S'ha produït un error en carregar la informació del fitxer",
+    "Tags" : "Etiquetes",
+    "Save as …" : "Anomena i desa …",
+    "Converting files …" : "Convertint fitxers …",
+    "Converting file …" : "S'està convertint el fitxer …",
+    "Deletion cancelled" : "S'ha cancel·lat la supressió",
+    "Edit locally" : "Edita localment",
+    "Moving \"{source}\" to \"{destination}\" …" : "S'està movent \"{source}\" a \"{destination}”…",
+    "Copying \"{source}\" to \"{destination}\" …" : "S'està copiant \"{source}\" a \"{destination}” …",
+    "(copy)" : "(còpia)",
+    "(copy %n)" : "(còpia %n)",
+    "Move cancelled" : "S'ha cancel·lat el desplaçament",
+    "Cancelled move or copy of \"{filename}\"." : "S'ha cancel·lat el moviment o la còpia de \"{filename}\".",
+    "Cancelled move or copy operation" : "S'ha cancel·lat l'operació de desplaçament o còpia",
+    "Open details" : "Obre els detalls",
+    "Photos and images" : "Fotografies i imatges",
+    "New folder creation cancelled" : "S'ha cancel·lat la creació de carpetes noves",
+    "This directory is unavailable, please check the logs or contact the administrator" : "Aquesta carpeta no està disponible. Consulteu els registres o contacteu amb l'administrador",
+    "All folders" : "Totes les carpetes"
 },
 "nplurals=2; plural=(n != 1);");
