@@ -78,6 +78,8 @@ OC.L10N.register(
     "Reload current directory" : "Znovu načíst stávající složku",
     "Go to the \"{dir}\" directory" : "Přejít do složky „{dir}“",
     "Current directory path" : "Stávající popis umístění složky",
+    "Share" : "Nasdílet",
+    "Reload content" : "Znovu načíst obsah",
     "Your have used your space quota and cannot upload files anymore" : "Využili jste celou svou kvótu na prostor a už nemůžete nahrávat další soubory",
     "You do not have permission to upload or create files here." : "Nemáte oprávnění sem nahrávat nebo zde vytvářet soubory.",
     "Drag and drop files here to upload" : "Soubory nahrajete jejich přetažením sem",
@@ -92,7 +94,6 @@ OC.L10N.register(
     "This node is unavailable" : "Tento uzel není k dispozici",
     "Another entry with the same name already exists." : "Už existuje jiná položka se stejným názvem.",
     "Invalid filename." : "Neplatný název souboru.",
-    "Renamed \"{oldName}\" to \"{newName}\"" : "Přejmenováno „{oldName}“ na „{newName}",
     "Rename file" : "Přejmenovat soubor",
     "Folder" : "Složka",
     "Unknown file type" : "Neznámý typ souboru",
@@ -102,12 +103,26 @@ OC.L10N.register(
     "{ext} text" : "{ext} text",
     "Pending" : "Nevyřízené",
     "Unknown date" : "Neznámé datum",
-    "Clear filter" : "Vyčistit filtr",
-    "Modified" : "Změněno",
-    "Search everywhere" : "Hledat všude",
-    "Type" : "Typ",
     "Active filters" : "Zapnuté filtry",
     "Remove filter" : "Odebrat filtr",
+    "Today" : "Dnes",
+    "Last 7 days" : "Uplynulých 7 dnů",
+    "Last 30 days" : "Uplynulých 30 dnů",
+    "This year ({year})" : "Tento rok ({year})",
+    "Last year ({year})" : "Minulý rok ({year})",
+    "Custom range" : "Uživatelsky určený rozsah",
+    "Custom date range" : "Uživatelsky určené datumové rozmezí",
+    "Search everywhere" : "Hledat všude",
+    "Documents" : "Dokumenty",
+    "Spreadsheets" : "Tabulky",
+    "Presentations" : "Prezentace",
+    "PDFs" : "PDF dokumenty",
+    "Folders" : "Složky",
+    "Audio" : "Zvuk",
+    "Images" : "Obrázky",
+    "Videos" : "Videa",
+    "Filters" : "Filtry",
+    "Back to filters" : "Zpět na filtry",
     "Appearance" : "Vzhled",
     "Show hidden files" : "Zobrazit skryté soubory",
     "Show file type column" : "Zobrazovat sloupec Typ souboru",
@@ -136,7 +151,6 @@ OC.L10N.register(
     "Go right in grid" : "Přejít vpravo v mřížce",
     "View" : "Zobrazit",
     "Toggle grid view" : "Vyp/zap. zobrazení v mřížce",
-    "Open file sidebar" : "Otevřít postranní panel souboru",
     "Show those shortcuts" : "Zobrazit tyto zkratky",
     "Warnings" : "Varování",
     "Warn before changing a file extension" : "Varovat před provedením změny přípony souboru",
@@ -150,6 +164,7 @@ OC.L10N.register(
     "Name" : "Název",
     "File type" : "Typ souboru",
     "Size" : "Velikost",
+    "Modified" : "Změněno",
     "{displayName}: failed on some elements" : "{displayName}: nepodařilo se na některých prvcích",
     "{displayName}: done" : "{displayName}: dokončeno",
     "{displayName}: failed" : "{displayName}: nezdařilo se",
@@ -218,12 +233,14 @@ OC.L10N.register(
     "Removing the file extension \"{old}\" may render the file unreadable." : "Odebrání přípony souboru „{old}“ může soubor znečitelnit.",
     "Adding the file extension \"{new}\" may render the file unreadable." : "Přidání přípony souboru „{new}“ může soubor znečitelnit.",
     "Do not show this dialog again." : "Nezobrazovat tento dialog znovu.",
+    "Rename file to hidden" : "Přejmenovat soubor na skrytý",
+    "Prefixing a filename with a dot may render the file hidden." : "Předeslání názvu souboru tečkou může vyústit k jeho skrytí.",
+    "Are you sure you want to rename the file to \"{filename}\"?" : "Opravdu chcete soubor přejmenovat na „{filename}“?",
+    "Cancel" : "Storno",
+    "Rename" : "Přejmenovat",
     "Select file or folder to link to" : "Vyberte soubor nebo složku na kterou odkazovat",
     "Choose {file}" : "Zvolit {file}",
     "Files settings" : "Nastavení pro Soubory",
-    "Share" : "Nasdílet",
-    "Shared by link" : "Sdíleno pomocí odkazu",
-    "Shared" : "Sdíleno",
     "Switch to list view" : "Přepnout do zobrazení v seznamu",
     "Switch to grid view" : "Přepnout do zobrazení v mřížce",
     "The file could not be found" : "Soubor nebylo možné najít",
@@ -233,6 +250,7 @@ OC.L10N.register(
     "Error during upload: {message}" : "Chyba při nahrávání: {message}",
     "Error during upload, status code {status}" : "Chyba při nahrávání – stavový kód {status}",
     "Unknown error during upload" : "Neznámá chyba při nahrávání",
+    "File list is reloading" : "Seznam souborů je načítán",
     "Loading current folder" : "Načítá se stávající složka",
     "Retry" : "Zkusit znovu",
     "No files in here" : "Žádné soubory",
@@ -285,30 +303,29 @@ OC.L10N.register(
     "_You are about to permanently delete {count} item_::_You are about to permanently delete {count} items_" : ["Chystáte se trvale smazat {count} položku","Chystáte se trvale smazat {count} položky","Chystáte se trvale smazat {count} položek","Chystáte se trvale smazat {count} položky"],
     "_You are about to delete {count} item_::_You are about to delete {count} items_" : ["Chystáte se smazat {count} položku","Chystáte se smazat {count} položky","Chystáte se smazat {count} položek","Chystáte se smazat {count} položky"],
     "Confirm deletion" : "Potvrdit smazání",
-    "Cancel" : "Storno",
     "Download" : "Stáhnout",
     "The requested file is not available." : "Požadovaný soubor není k dispozici.",
     "The requested files are not available." : "Požadované soubory nejsou k dispozici.",
     "Add to favorites" : "Přidat do oblíbených",
     "Remove from favorites" : "Odebrat z oblíbených",
     "Add or remove favorite" : "Přidat nebo odebrat oblíbené",
-    "Moving \"{source}\" to \"{destination}\" …" : "Přesouvání „{source}“ do „{destination}“ …",
-    "Copying \"{source}\" to \"{destination}\" …" : "Kopírování „{source}“ do „{destination}“ …",
+    "Move" : "Přesunout",
+    "Copy" : "Kopírovat",
+    "Move or copy" : "Přesunout nebo zkopírovat",
     "Destination is not a folder" : "Cíl není složka",
     "This file/folder is already in that directory" : "V oné složce se už daný soubor/složka nachází",
     "You cannot move a file/folder onto itself or into a subfolder of itself" : "Není možné přesunout soubor/složku do sebe samé nebo do své vlastní podložky",
-    "(copy)" : "(zkopírovat)",
-    "(copy %n)" : "(zkopírovat %n)",
     "A file or folder with that name already exists in this folder" : "V této složce už existuje stejnojmenný soubor či složka",
     "The files are locked" : "Soubory jsou zamknuty",
     "The file does not exist anymore" : "Soubor už neexistuje",
+    "Moving \"{source}\" to \"{destination}\" …" : "Přesouvání „{source}“ do „{destination}“ …",
+    "Moving {count} files to \"{destination}\" …" : "Přesouvání {count} souborů do „{destination}“ …",
+    "Copying \"{source}\" to \"{destination}\" …" : "Kopírování „{source}“ do „{destination}“ …",
+    "Copying {count} files to \"{destination}\" …" : "Kopírování {count} souborů do „{destination}“ …",
     "Choose destination" : "Vyberte cíl",
     "Copy to {target}" : "Zkopírovat do {target}",
-    "Copy" : "Kopírovat",
     "Move to {target}" : "Přesunout do {target}",
-    "Move" : "Přesunout",
     "Move or copy operation failed" : "Operace přesunu či zkopírování se nezdařila",
-    "Move or copy" : "Přesunout nebo zkopírovat",
     "Open folder" : "Otevřít složku",
     "Open folder {displayName}" : "Otevřít složku {displayName}",
     "Open in Files" : "Otevřít v Souborech",
@@ -318,28 +335,18 @@ OC.L10N.register(
     "The file should now open on your device. If it doesn't, please check that you have the desktop app installed." : "Soubor by se nyní měl otevřít na vašem zařízení. Pokud ne, zkontrolujte, zda máte nainstalovanou desktopovou aplikaci.",
     "Retry and close" : "Zkusit znovu a zavřít",
     "Open online" : "Otevřít online",
-    "Rename" : "Přejmenovat",
     "Details" : "Podrobnosti",
+    "Open the details sidebar" : "Otevřít postranní panel podrobností",
+    "Unfavorite" : "Odebrat z oblíbených",
     "View in folder" : "Zobrazit ve složce",
-    "Today" : "Dnes",
-    "Last 7 days" : "Uplynulých 7 dnů",
-    "Last 30 days" : "Uplynulých 30 dnů",
-    "This year ({year})" : "Tento rok ({year})",
-    "Last year ({year})" : "Minulý rok ({year})",
-    "Documents" : "Dokumenty",
-    "Spreadsheets" : "Tabulky",
-    "Presentations" : "Prezentace",
-    "PDFs" : "PDF dokumenty",
-    "Folders" : "Složky",
-    "Audio" : "Zvuk",
-    "Images" : "Obrázky",
-    "Videos" : "Videa",
+    "Type" : "Typ",
     "Created new folder \"{name}\"" : "Vytvořena nová složka „{name}“",
     "Unable to initialize the templates directory" : "Nepodařilo se vytvořit složku pro šablony",
     "Create templates folder" : "Vytvořit složku pro šablony",
     "Templates" : "Šablony",
     "New template folder" : "Nová složka šablon",
     "In folder" : "Ve složce",
+    "Pick folder to search in" : "Vybrat složku k prohledání",
     "Search in all files" : "Hledat ve všech souborech",
     "Search in folder: {folder}" : "Hledat ve složce: {folder}",
     "One of the dropped files could not be processed" : "Jeden z přetažených souborů se nepodařilo zpracovat",
@@ -349,10 +356,10 @@ OC.L10N.register(
     "Some files could not be uploaded" : "Některé soubory nebylo možné nahrát",
     "Files uploaded successfully" : "Soubor úspěšně nahrán",
     "No files to process" : "Žádné soubory ke zpracování",
-    "Some files could not be copied" : "Některé soubory nebylo možné zkopírovat",
-    "Some files could not be moved" : "Některé soubory nebylo možné přesunout",
     "Files copied successfully" : "Soubory úspěšně zkopírovány",
     "Files moved successfully" : "Soubory úspěšně přesunuty",
+    "Some files could not be copied" : "Některé soubory nebylo možné zkopírovat",
+    "Some files could not be moved" : "Některé soubory nebylo možné přesunout",
     "Conflicts resolution skipped" : "Řešení kolizí přeskočeno",
     "Upload cancelled" : "Nahrávání zrušeno",
     "Could not rename \"{oldName}\", it does not exist any more" : "Není možné přejmenovat „{oldName}“ – už neexistuje",
@@ -393,10 +400,14 @@ OC.L10N.register(
     "Upload (max. %s)" : "Nahrát (max. %s)",
     "After enabling the windows compatible filenames, existing files cannot be modified anymore but can be renamed to valid new names by their owner." : "Po povolení názvů souborů, kompatibilních s Windows, stávající soubory už nebude možné změnit, ale je možné je přejmenovat na platné nové názvy jejich vlastníkem.",
     "It is also possible to migrate files automatically after enabling this setting, please refer to the documentation about the occ command." : "Po povolení tohoto natavení je také možné soubory stěhovat automaticky. Další informace viz dokumentace k příkazu occ.",
+    "Renamed \"{oldName}\" to \"{newName}\"" : "Přejmenováno „{oldName}“ na „{newName}",
+    "Clear filter" : "Vyčistit filtr",
     "\"{displayName}\" failed on some elements" : "„{displayName}“ se pro některé prvky nezdařilo",
     "\"{displayName}\" batch action executed successfully" : "Hromadná akce „{displayName}“ úspěšně vykonána",
     "\"{displayName}\" action failed" : "akce „{displayName}“ se nezdařila",
     "Submitting fields …" : "Odesílání kolonek …",
+    "Shared by link" : "Sdíleno pomocí odkazu",
+    "Shared" : "Sdíleno",
     "\"{displayName}\" action executed successfully" : "akce „{displayName}“ úspěšně vykonána",
     "Filter file names …" : "Filtrovat názvy souborů …",
     "Clipboard is not available" : "Schránka není k dispozici",
@@ -438,6 +449,8 @@ OC.L10N.register(
     "Edit locally" : "Upravit lokálně",
     "Moving \"{source}\" to \"{destination}\" …" : "Přesouvání „{source}“ do „{destination}“ …",
     "Copying \"{source}\" to \"{destination}\" …" : "Kopírování „{source}“ do „{destination}“ …",
+    "(copy)" : "(zkopírovat)",
+    "(copy %n)" : "(zkopírovat %n)",
     "Move cancelled" : "Přesunutí zrušeno",
     "Cancelled move or copy of \"{filename}\"." : "Přesunutí nebo zkopírování „{filename}“ zrušeno.",
     "Cancelled move or copy operation" : "Operace přesunutí či zkopírování zrušena",
@@ -446,6 +459,7 @@ OC.L10N.register(
     "New folder creation cancelled" : "Vytváření nové složky zrušeno",
     "This directory is unavailable, please check the logs or contact the administrator" : "Tento adresář není dostupný, zkontrolujte záznamy událostí nebo se obraťte na správce",
     "All folders" : "Všechny složky",
+    "Open file sidebar" : "Otevřít postranní panel souboru",
     "Search everywhere …" : "Hledat všude …",
     "Search here …" : "Hledat zde …",
     "Preparing …" : "Příprava …"
