@@ -78,6 +78,7 @@ OC.L10N.register(
     "Reload current directory" : "Genindlæs den aktuelle mappe",
     "Go to the \"{dir}\" directory" : "Gå til mappen \"{dir}\"",
     "Current directory path" : "Nuværende mappesti",
+    "Share" : "Del",
     "Your have used your space quota and cannot upload files anymore" : "Du har brugt din pladskvote og kan ikke længere uploade filer",
     "You do not have permission to upload or create files here." : "Du har ikke rettigheder til at uploade eller oprette filer her.",
     "Drag and drop files here to upload" : "Træk filer hertil for at uploade",
@@ -92,7 +93,6 @@ OC.L10N.register(
     "This node is unavailable" : "Denne node er ikke tilgængelig ",
     "Another entry with the same name already exists." : "En anden indførsel med det samme navn eksisterer allerede.",
     "Invalid filename." : "Ugyldigt filnavn.",
-    "Renamed \"{oldName}\" to \"{newName}\"" : "Omdøbte \"{oldName}\" til \"{newName}\"",
     "Rename file" : "Omdøb fil",
     "Folder" : "Mappe",
     "Unknown file type" : "Ukendt filtype",
@@ -102,12 +102,24 @@ OC.L10N.register(
     "{ext} text" : "{ext} tekst",
     "Pending" : "Afventer",
     "Unknown date" : "Ukendt dato",
-    "Clear filter" : "Ryd filter",
-    "Modified" : "Ændret",
-    "Search everywhere" : "Søg overalt",
-    "Type" : "Type",
     "Active filters" : "Aktive filtre",
     "Remove filter" : "Fjern filter",
+    "Today" : "I dag",
+    "Last 7 days" : "Sidste 7 dage",
+    "Last 30 days" : "Sidste 30 dage",
+    "This year ({year})" : "Dette år ({year})",
+    "Last year ({year})" : "Sidste år ({year})",
+    "Custom date range" : " Brugerdefineret datointerval",
+    "Search everywhere" : "Søg overalt",
+    "Documents" : "Dokumenter",
+    "Spreadsheets" : "Regneark",
+    "Presentations" : "Præsentationer",
+    "PDFs" : "PDFer",
+    "Folders" : "Mapper",
+    "Audio" : "Lyd",
+    "Images" : "Billeder",
+    "Videos" : "Videoer",
+    "Filters" : "Filtre",
     "Appearance" : "Udseende",
     "Show hidden files" : "Vis skjulte filer",
     "Show file type column" : "Vis filtype kolonne",
@@ -135,7 +147,6 @@ OC.L10N.register(
     "Go right in grid" : "Gå til højre i gitter",
     "View" : "Vis",
     "Toggle grid view" : "Vis som liste",
-    "Open file sidebar" : "Åbn fil sidebjælke",
     "Show those shortcuts" : "Vis disse genveje",
     "Warnings" : "Advarsler",
     "Warn before changing a file extension" : "Advar inden en filendelse ændres",
@@ -146,6 +157,7 @@ OC.L10N.register(
     "Name" : "Navn",
     "File type" : "Filtype",
     "Size" : "Størrelse",
+    "Modified" : "Ændret",
     "{displayName}: failed on some elements" : "{displayName}: fejlede på nogle elementer",
     "{displayName}: done" : "{displayName}: færdig",
     "{displayName}: failed" : "{displayName}: fejlede",
@@ -214,12 +226,11 @@ OC.L10N.register(
     "Removing the file extension \"{old}\" may render the file unreadable." : "Fjernelse af filendelsen \"{old}\" kan gøre filen ulæsbar.",
     "Adding the file extension \"{new}\" may render the file unreadable." : "Tilføjelse af filendelsen \"{new}\" kan efterlade gøre ulæsbar.",
     "Do not show this dialog again." : "Vis ikke denne dialog igen.",
+    "Cancel" : "Annullér",
+    "Rename" : "Omdøb",
     "Select file or folder to link to" : "Vælg fil eller mappe at linke til",
     "Choose {file}" : "Vælg {file}",
     "Files settings" : "indstillinger for filer",
-    "Share" : "Del",
-    "Shared by link" : "Delt via link",
-    "Shared" : "Delt",
     "Switch to list view" : "Skift til listevisning",
     "Switch to grid view" : "Skift til gittervisning",
     "The file could not be found" : "Filen kunne ikke findes",
@@ -281,30 +292,27 @@ OC.L10N.register(
     "_You are about to permanently delete {count} item_::_You are about to permanently delete {count} items_" : ["Du er ved at slette {count} element permanent","Du er ved at slette {count} elementer permanent"],
     "_You are about to delete {count} item_::_You are about to delete {count} items_" : ["Du er ved at slette {count} element","Du er ved at slette {count} elementer"],
     "Confirm deletion" : "Bekræft sletning",
-    "Cancel" : "Annullér",
     "Download" : "Download",
     "The requested file is not available." : "Den forespurgte fil er ikke tilgængelig.",
     "The requested files are not available." : "De forespurgte filer er ikke tilgængelige.",
     "Add to favorites" : "Tilføj til favoritter",
     "Remove from favorites" : "Fjern fra favoritter",
     "Add or remove favorite" : "Tilføj eller fjern fremhævning",
-    "Moving \"{source}\" to \"{destination}\" …" : "Flytter \"{source}\" til \"{destination}\" …",
-    "Copying \"{source}\" to \"{destination}\" …" : "Kopierer \"{source}\" til \"{destination}\" …",
+    "Move" : "Flyt",
+    "Copy" : "Kopier",
+    "Move or copy" : "Flyt eller kopiér",
     "Destination is not a folder" : "Destinationen er ikke en mappe",
     "This file/folder is already in that directory" : "Filen/mappen er allerede i denne mappe",
     "You cannot move a file/folder onto itself or into a subfolder of itself" : "Du kan ikke flytte en fil/mappe ind i sig selv, eller til en mappe inden i sig selv",
-    "(copy)" : "(kopier)",
-    "(copy %n)" : "(kopier %n)",
     "A file or folder with that name already exists in this folder" : "En fil eller mappe med det navn findes allerede i denne mappe",
     "The files are locked" : "Filerne er låste",
     "The file does not exist anymore" : "Filen findes ikke længere",
+    "Moving \"{source}\" to \"{destination}\" …" : "Flytter \"{source}\" til \"{destination}\" …",
+    "Copying \"{source}\" to \"{destination}\" …" : "Kopierer \"{source}\" til \"{destination}\" …",
     "Choose destination" : "Vælg destination",
     "Copy to {target}" : "Kopiér til {target}",
-    "Copy" : "Kopier",
     "Move to {target}" : "Flyt til {target}",
-    "Move" : "Flyt",
     "Move or copy operation failed" : "Flytte- eller kopioperationen fejlede",
-    "Move or copy" : "Flyt eller kopiér",
     "Open folder" : "Åbn mappe",
     "Open folder {displayName}" : "Åben mappe {displayName}",
     "Open in Files" : "Åben i Filer",
@@ -314,22 +322,9 @@ OC.L10N.register(
     "The file should now open on your device. If it doesn't, please check that you have the desktop app installed." : "Filen bør nu åbne på dit apparat. Hvis den ikke gør det, så kontroller venligst at desktop app'en er installeret.",
     "Retry and close" : "Forsøg igen og luk",
     "Open online" : "Åben online",
-    "Rename" : "Omdøb",
     "Details" : "Detaljer",
     "View in folder" : "Vis i mappe",
-    "Today" : "I dag",
-    "Last 7 days" : "Sidste 7 dage",
-    "Last 30 days" : "Sidste 30 dage",
-    "This year ({year})" : "Dette år ({year})",
-    "Last year ({year})" : "Sidste år ({year})",
-    "Documents" : "Dokumenter",
-    "Spreadsheets" : "Regneark",
-    "Presentations" : "Præsentationer",
-    "PDFs" : "PDFer",
-    "Folders" : "Mapper",
-    "Audio" : "Lyd",
-    "Images" : "Billeder",
-    "Videos" : "Videoer",
+    "Type" : "Type",
     "Created new folder \"{name}\"" : "Oprettede ny mappe \"{name}\"",
     "Unable to initialize the templates directory" : "Kan ikke initialisere skabelonmappen",
     "Create templates folder" : "Opret skabelonmappe",
@@ -345,10 +340,10 @@ OC.L10N.register(
     "Some files could not be uploaded" : "Nogle filer kunne ikke uploades",
     "Files uploaded successfully" : "Filer uploadet succesfuldt",
     "No files to process" : "Ingen filer til at behandle",
-    "Some files could not be copied" : "Nogle filer kunne ikke blive kopieret",
-    "Some files could not be moved" : "Nogle filer kunne ikke flyttes",
     "Files copied successfully" : "Filer kopieret succesfuldt",
     "Files moved successfully" : "Filer flyttet succesfuldt",
+    "Some files could not be copied" : "Nogle filer kunne ikke blive kopieret",
+    "Some files could not be moved" : "Nogle filer kunne ikke flyttes",
     "Conflicts resolution skipped" : "Konfliktløsning sprunget over",
     "Upload cancelled" : "Upload annulleret",
     "Could not rename \"{oldName}\", it does not exist any more" : "Kunne ikke omdøbe \"{oldName}\", da den ikke længere findes",
@@ -389,10 +384,14 @@ OC.L10N.register(
     "Upload (max. %s)" : "Upload (max. %s)",
     "After enabling the windows compatible filenames, existing files cannot be modified anymore but can be renamed to valid new names by their owner." : "Efter aktivering af windows kompatible filnavne, så vil eksisterende filer ikke længere kunne ændres, men de kan omdøbes til gyldige filnavne af deres ejer.",
     "It is also possible to migrate files automatically after enabling this setting, please refer to the documentation about the occ command." : "Det er også muligt at migrere filer automatisk efter aktivering af denne indstilling. Se venligst dokumentationen omkring occ kommandoen.",
+    "Renamed \"{oldName}\" to \"{newName}\"" : "Omdøbte \"{oldName}\" til \"{newName}\"",
+    "Clear filter" : "Ryd filter",
     "\"{displayName}\" failed on some elements" : "\"{displayName}\" fejlede på nogle elementer",
     "\"{displayName}\" batch action executed successfully" : "\"{displayName}\"-handling blev udført korrekt",
     "\"{displayName}\" action failed" : "\"{displayName}\"-handling mislykkedes",
     "Submitting fields …" : "Sender felter …",
+    "Shared by link" : "Delt via link",
+    "Shared" : "Delt",
     "\"{displayName}\" action executed successfully" : "\"{displayName}\"-handling blev udført korrekt",
     "Filter file names …" : "Filtrer filnavne ...",
     "Clipboard is not available" : "Udklipsholderen er ikke tilgængelig",
@@ -434,6 +433,8 @@ OC.L10N.register(
     "Edit locally" : "Redigér lokalt",
     "Moving \"{source}\" to \"{destination}\" …" : "Flytter \"{source}\" til \"{destination}\" …",
     "Copying \"{source}\" to \"{destination}\" …" : "Kopierer \"{source}\" til \"{destination}\" …",
+    "(copy)" : "(kopier)",
+    "(copy %n)" : "(kopier %n)",
     "Move cancelled" : "Flytning annulleret",
     "Cancelled move or copy of \"{filename}\"." : "Annullerede flytning eller kopiering af \"{filename}\".",
     "Cancelled move or copy operation" : "Flytning eller kopiering er annulleret",
@@ -442,6 +443,7 @@ OC.L10N.register(
     "New folder creation cancelled" : "Oprettelse af ny mappe annulleret",
     "This directory is unavailable, please check the logs or contact the administrator" : "Denne mappe er utilgængelig, tjek venligst loggene eller kontakt administratoren",
     "All folders" : "Alle mapper",
+    "Open file sidebar" : "Åbn fil sidebjælke",
     "Search everywhere …" : "Søg overalt …",
     "Search here …" : "Søg her …",
     "Preparing …" : "Forbereder ..."
