@@ -78,6 +78,8 @@ OC.L10N.register(
     "Reload current directory" : "Aktuelles Verzeichnis neu laden",
     "Go to the \"{dir}\" directory" : "In das Verzeichnis \"{dir}\" wechseln",
     "Current directory path" : "Aktueller Verzeichnispfad",
+    "Share" : "Teilen",
+    "Reload content" : "Inhalt erneut laden",
     "Your have used your space quota and cannot upload files anymore" : "Ihr Speicherplatzkontigent ist aufgebraucht, Sie können keine weiteren Dateien hochladen",
     "You do not have permission to upload or create files here." : "Sie haben nicht die Berechtigung, hier Dateien hochzuladen oder zu erstellen.",
     "Drag and drop files here to upload" : "Dateien zum Hochladen hierher ziehen und ablegen",
@@ -92,7 +94,6 @@ OC.L10N.register(
     "This node is unavailable" : "Dieser Knoten ist nicht verfügbar",
     "Another entry with the same name already exists." : "Ein anderer Eintrag mit diesem Namen existiert bereits.",
     "Invalid filename." : "Ungültiger Dateiname.",
-    "Renamed \"{oldName}\" to \"{newName}\"" : "\"{oldName}\" in \"{newName}\" umbenannt",
     "Rename file" : "Datei umbenennen",
     "Folder" : "Ordner",
     "Unknown file type" : "Unbekannter Dateityp",
@@ -102,12 +103,26 @@ OC.L10N.register(
     "{ext} text" : "{ext}-Text",
     "Pending" : "Ausstehend",
     "Unknown date" : "Unbekanntes Datum",
-    "Clear filter" : "Filter zurücksetzen",
-    "Modified" : "Geändert",
-    "Search everywhere" : "Überall suchen",
-    "Type" : "Typ",
     "Active filters" : "Aktive Filter",
     "Remove filter" : "Filter entfernen",
+    "Today" : "Heute",
+    "Last 7 days" : "Die letzten 7 Tage",
+    "Last 30 days" : "Die letzten 30 Tage",
+    "This year ({year})" : "Dieses Jahr ({year})",
+    "Last year ({year})" : "Letztes Jahr ({year})",
+    "Custom range" : "Benutzerdefinierter Bereich",
+    "Custom date range" : "Benutzerdefinierter Zeitbereich",
+    "Search everywhere" : "Überall suchen",
+    "Documents" : "Dokumente",
+    "Spreadsheets" : "Tabellenkalkulationen",
+    "Presentations" : "Präsentationen",
+    "PDFs" : "PDFs",
+    "Folders" : "Ordner",
+    "Audio" : "Audio",
+    "Images" : "Bilder",
+    "Videos" : "Videos",
+    "Filters" : "Filter",
+    "Back to filters" : "Zurück zu den Filtern",
     "Appearance" : "Aussehen",
     "Show hidden files" : "Versteckte Dateien anzeigen",
     "Show file type column" : "Dateityp-Spalte anzeigen",
@@ -136,7 +151,6 @@ OC.L10N.register(
     "Go right in grid" : "Im Raster nach rechts gehen",
     "View" : "Ansicht",
     "Toggle grid view" : "Kachelansicht umschalten",
-    "Open file sidebar" : "Datei-Seitenleiste öffnen",
     "Show those shortcuts" : "Diese Tastaturkürzel anzeigen",
     "Warnings" : "Warnungen",
     "Warn before changing a file extension" : "Vor der Änderung einer Dateierweiterung warnen",
@@ -150,6 +164,7 @@ OC.L10N.register(
     "Name" : "Name",
     "File type" : "Dateityp",
     "Size" : "Größe",
+    "Modified" : "Geändert",
     "{displayName}: failed on some elements" : "{displayName}: Ist bei einigen Elementen fehlgeschlagen",
     "{displayName}: done" : "{displayName}: Abgeschlossen",
     "{displayName}: failed" : "{displayName}: Fehlgeschlagen",
@@ -164,6 +179,7 @@ OC.L10N.register(
     "Search here …" : "Hier suchen …",
     "Search scope options" : "Suchbereichsoptionen",
     "Search here" : "Hier suchen",
+    "Owner" : "Besitzer",
     "{usedQuotaByte} used" : "{usedQuotaByte} verwendet",
     "{used} of {quota} used" : "{used} von {quota} verwendet",
     "{relative}% used" : "{relative} % verwendet",
@@ -217,12 +233,14 @@ OC.L10N.register(
     "Removing the file extension \"{old}\" may render the file unreadable." : "Entfernen der Dateierweiterung \"{old}\" kann dazu führen, dass die Datei unlesbar wird.",
     "Adding the file extension \"{new}\" may render the file unreadable." : "Hinzufügen der Dateierweiterung \"{new}\" kann dazu führen, dass die Datei unlesbar wird.",
     "Do not show this dialog again." : "Diesen Dialog nicht mehr anzeigen.",
+    "Rename file to hidden" : "Datei in versteckt umbenennen",
+    "Prefixing a filename with a dot may render the file hidden." : "Das Voranstellen eines Punkts vor einen Dateinamen kann dazu führen, dass die Datei ausgeblendet wird.",
+    "Are you sure you want to rename the file to \"{filename}\"?" : "Soll die Datei in \"{filename}\" umbenannt werden?",
+    "Cancel" : "Abbrechen",
+    "Rename" : "Umbenennen",
     "Select file or folder to link to" : "Datei oder Ordner zum Verknüpfen auswählen",
     "Choose {file}" : "{file} auswählen",
     "Files settings" : "Dateien-Einstellungen",
-    "Share" : "Teilen",
-    "Shared by link" : "Über einen Link geteilt",
-    "Shared" : "Geteilt",
     "Switch to list view" : "Zur Listenansicht wechseln",
     "Switch to grid view" : "Zur Kachelansicht wechseln",
     "The file could not be found" : "Die Datei konnte nicht gefunden werden",
@@ -232,20 +250,14 @@ OC.L10N.register(
     "Error during upload: {message}" : "Fehler beim Hochladen: {message}",
     "Error during upload, status code {status}" : "Fehler beim Hochladen, Statuscode {status}",
     "Unknown error during upload" : "Unbekannter Fehler beim Hochladen",
+    "File list is reloading" : "Dateiliste wird neu geladen",
     "Loading current folder" : "Lade aktuellen Ordner",
     "Retry" : "Wiederholen",
     "No files in here" : "Keine Dateien vorhanden",
     "Upload some content or sync with your devices!" : "Laden Sie Inhalte hoch oder synchronisieren Sie Ihre Geräte!",
     "Go back" : "Zurückgehen",
     "Views" : "Ansichten",
-    "You" : "Sie",
-    "Shared multiple times with different people" : "Mehrmals mit verschiedenen Personen geteilt",
-    "Unable to change the favorite state of the file" : "Der Favoriten-Status der Datei kann nicht geändert werden",
-    "Error while loading the file data" : "Fehler beim Laden der Datei-Daten",
-    "Owner" : "Besitzer",
-    "Remove from favorites" : "Von Favoriten entfernen",
-    "Add to favorites" : "Zu den Favoriten hinzufügen",
-    "Tags" : "Schlagworte",
+    "Loading …" : "Lade …",
     "Your files" : "Ihre Dateien",
     "Open in files" : "In Dateien öffnen",
     "File cannot be accessed" : "Auf die Datei kann nicht zugegriffen werden",
@@ -291,28 +303,30 @@ OC.L10N.register(
     "_You are about to permanently delete {count} item_::_You are about to permanently delete {count} items_" : ["Sie sind dabei, {count} Element endgültig zu löschen","Sie sind dabei, {count} Elemente endgültig zu löschen"],
     "_You are about to delete {count} item_::_You are about to delete {count} items_" : ["Sie sind dabei, {count} Element zu löschen","Sie sind dabei, {count} Elemente zu löschen"],
     "Confirm deletion" : "Löschen bestätigen",
-    "Cancel" : "Abbrechen",
     "Download" : "Herunterladen",
     "The requested file is not available." : "Die angeforderte Datei ist nicht verfügbar.",
     "The requested files are not available." : "Die angeforderten Dateien sind nicht verfügbar.",
+    "Add to favorites" : "Zu den Favoriten hinzufügen",
+    "Remove from favorites" : "Von Favoriten entfernen",
     "Add or remove favorite" : "Favorit hinzufügen oder entfernen",
-    "Moving \"{source}\" to \"{destination}\" …" : "Verschiebe \"{source}\" nach \"{destination}\" …",
-    "Copying \"{source}\" to \"{destination}\" …" : "Kopiere \"{source}\" nach \"{destination}\" …",
+    "Move" : "Verschieben",
+    "Copy" : "Kopieren",
+    "Move or copy" : "Verschieben oder kopieren",
     "Destination is not a folder" : "Ziel ist kein Ordner",
     "This file/folder is already in that directory" : "Diese Datei oder Ordner ist bereits in diesem Verzeichnis vorhanden",
     "You cannot move a file/folder onto itself or into a subfolder of itself" : "Eine Datei oder ein Ordner kann nicht auf sich selbst oder in einen Unterordner von sich selbst verschoben werden",
-    "(copy)" : "(Kopie)",
-    "(copy %n)" : "(Kopie %n)",
     "A file or folder with that name already exists in this folder" : "In diesem Ordner ist bereits eine Datei oder ein Ordner mit diesem Namen vorhanden",
     "The files are locked" : "Die Dateien sind gesperrt",
     "The file does not exist anymore" : "Diese Datei existiert nicht mehr",
+    "Moving \"{source}\" to \"{destination}\" …" : "Verschiebe \"{source}\" nach \"{destination}\" …",
+    "Moving {count} files to \"{destination}\" …" : "Verschiebe {count} Dateien nach \"{destination}\" …",
+    "Copying \"{source}\" to \"{destination}\" …" : "Kopiere \"{source}\" nach \"{destination}\" …",
+    "Copying {count} files to \"{destination}\" …" : "Kopiere {count} Dateien nach \"{destination}\" …",
     "Choose destination" : "Ziel wählen",
     "Copy to {target}" : "Nach {target} kopieren",
-    "Copy" : "Kopieren",
     "Move to {target}" : "Nach {target} verschieben",
-    "Move" : "Verschieben",
     "Move or copy operation failed" : "Verschiebe- oder Kopieroperation ist fehlgeschlagen.",
-    "Move or copy" : "Verschieben oder kopieren",
+    "Open folder" : "Ordner öffnen",
     "Open folder {displayName}" : "Ordner {displayName} öffnen",
     "Open in Files" : "In Dateien öffnen",
     "Open locally" : "Lokal öffnen",
@@ -321,28 +335,18 @@ OC.L10N.register(
     "The file should now open on your device. If it doesn't, please check that you have the desktop app installed." : "Die Datei sollte sich jetzt auf Ihrem Gerät öffnen. Wenn dies nicht der Fall ist, überprüfen Sie, ob Sie die Desktop-App installiert haben.",
     "Retry and close" : "Erneut versuchen und schließen",
     "Open online" : "Online öffnen",
-    "Rename" : "Umbenennen",
     "Details" : "Details",
+    "Open the details sidebar" : "Die Details-Seitenleiste öffnen",
+    "Unfavorite" : "Nicht favorisieren",
     "View in folder" : "In Ordner anzeigen",
-    "Today" : "Heute",
-    "Last 7 days" : "Die letzten 7 Tage",
-    "Last 30 days" : "Die letzten 30 Tage",
-    "This year ({year})" : "Dieses Jahr ({year})",
-    "Last year ({year})" : "Letztes Jahr ({year})",
-    "Documents" : "Dokumente",
-    "Spreadsheets" : "Tabellenkalkulationen",
-    "Presentations" : "Präsentationen",
-    "PDFs" : "PDFs",
-    "Folders" : "Ordner",
-    "Audio" : "Audio",
-    "Images" : "Bilder",
-    "Videos" : "Videos",
+    "Type" : "Typ",
     "Created new folder \"{name}\"" : "Neuer Ordner \"{name}\" wurde erstellt",
     "Unable to initialize the templates directory" : "Der Vorlagenordner kann nicht initialisiert werden",
     "Create templates folder" : "Vorlagenordner erstellen",
     "Templates" : "Vorlagen",
     "New template folder" : "Neuer Vorlagenordner",
     "In folder" : "Im Ordner",
+    "Pick folder to search in" : "Ordner auswählen, in dem gesucht werden soll",
     "Search in all files" : "In allen Dateien suchen",
     "Search in folder: {folder}" : "Im Ordner suchen: {folder}",
     "One of the dropped files could not be processed" : "Eine der abgelegten Dateien konnte nicht verarbeitet werden",
@@ -352,10 +356,10 @@ OC.L10N.register(
     "Some files could not be uploaded" : "Einige Dateien konnten nicht hochgeladen werden.",
     "Files uploaded successfully" : "Dateien hochgeladen",
     "No files to process" : "Keine Dateien zum Verarbeiten",
-    "Some files could not be copied" : "Einige Dateien konnten nicht kopiert werden",
-    "Some files could not be moved" : "Einige Dateien konnten nicht verschoben werden",
     "Files copied successfully" : "Dateien kopiert",
     "Files moved successfully" : "Dateien verschoben",
+    "Some files could not be copied" : "Einige Dateien konnten nicht kopiert werden",
+    "Some files could not be moved" : "Einige Dateien konnten nicht verschoben werden",
     "Conflicts resolution skipped" : "Konfliktelösung übersprungen",
     "Upload cancelled" : "Hochladen abgebrochen",
     "Could not rename \"{oldName}\", it does not exist any more" : "\"{oldName}\" konnte nicht umbenannt werden, da es nicht mehr existiert",
@@ -396,10 +400,14 @@ OC.L10N.register(
     "Upload (max. %s)" : "Hochladen (max. %s)",
     "After enabling the windows compatible filenames, existing files cannot be modified anymore but can be renamed to valid new names by their owner." : "Nach Aktivierung der Windows-kompatiblen Dateinamen können vorhandene Dateien nicht mehr geändert, aber von ihrem Besitzer in gültige neue Namen umbenannt werden.",
     "It is also possible to migrate files automatically after enabling this setting, please refer to the documentation about the occ command." : "Nach dem Aktivieren dieser Einstellung ist es auch möglich, Dateien automatisch zu migrieren. Weitere Informationen finden sich in der Dokumentation zum Befehl \"occ\".",
+    "Renamed \"{oldName}\" to \"{newName}\"" : "\"{oldName}\" in \"{newName}\" umbenannt",
+    "Clear filter" : "Filter zurücksetzen",
     "\"{displayName}\" failed on some elements" : "\"{displayName}\" ist bei einigen Elementen fehlgeschlagen",
     "\"{displayName}\" batch action executed successfully" : "Stapelaktion \"{displayName}\" ausgeführt",
     "\"{displayName}\" action failed" : "Aktion \"{displayName}\" fehlgeschlagen",
     "Submitting fields …" : "Felder werden übermittelt …",
+    "Shared by link" : "Über einen Link geteilt",
+    "Shared" : "Geteilt",
     "\"{displayName}\" action executed successfully" : "Aktion \"{displayName}\" ausgeführt",
     "Filter file names …" : "Dateinamen filtern …",
     "Clipboard is not available" : "Zwischenablage ist nicht verfügbar",
@@ -429,6 +437,11 @@ OC.L10N.register(
     "Navigate to the file on the right (in grid mode)" : "Zur Datei rechts navigieren (in der Kachelansicht)",
     "Toggle the grid view" : "Kachelansicht umschalten",
     "Open the sidebar for a file" : "Seitenleiste für eine Datei öffnen",
+    "You" : "Sie",
+    "Shared multiple times with different people" : "Mehrmals mit verschiedenen Personen geteilt",
+    "Unable to change the favorite state of the file" : "Der Favoriten-Status der Datei kann nicht geändert werden",
+    "Error while loading the file data" : "Fehler beim Laden der Datei-Daten",
+    "Tags" : "Schlagworte",
     "Save as …" : "Speichern als …",
     "Converting files …" : "Dateien werden konvertiert …",
     "Converting file …" : "Datei wird konvertiert …",
@@ -436,6 +449,8 @@ OC.L10N.register(
     "Edit locally" : "Lokal bearbeiten",
     "Moving \"{source}\" to \"{destination}\" …" : "Verschiebe \"{source}\" nach \"{destination}\" …",
     "Copying \"{source}\" to \"{destination}\" …" : "Kopiere \"{source}\" nach \"{destination}\" …",
+    "(copy)" : "(Kopie)",
+    "(copy %n)" : "(Kopie %n)",
     "Move cancelled" : "Verschieben abgebrochen",
     "Cancelled move or copy of \"{filename}\"." : "Verschieben oder Kopieren von \"{filename}\" abgebrochen.",
     "Cancelled move or copy operation" : "Verschieben oder kopieren abgebrochen",
@@ -444,6 +459,7 @@ OC.L10N.register(
     "New folder creation cancelled" : "Erstellung des neuen Ordners abgebrochen",
     "This directory is unavailable, please check the logs or contact the administrator" : "Dieses Verzeichnis ist nicht verfügbar, bitte überprüfen Sie die Protokolldateien oder kontaktieren Sie die Administration",
     "All folders" : "Alle Ordner",
+    "Open file sidebar" : "Datei-Seitenleiste öffnen",
     "Search everywhere …" : "Überall suchen …",
     "Search here …" : "Hier suchen …",
     "Preparing …" : "Bereite vor …"
