@@ -78,6 +78,7 @@ OC.L10N.register(
     "Reload current directory" : "Επαναφόρτωση τρέχοντος καταλόγου",
     "Go to the \"{dir}\" directory" : "Μετάβαση στον κατάλογο \"{dir}\"",
     "Current directory path" : "Τρέχουσα διαδρομή καταλόγου",
+    "Share" : "Διαμοιρασμός",
     "Your have used your space quota and cannot upload files anymore" : "Έχετε χρησιμοποιήσει το όριο χώρου σας και δεν μπορείτε να μεταφορτώσετε αρχεία πλέον",
     "You do not have permission to upload or create files here." : "Δεν έχετε δικαίωμα να μεταφορτώσετε ή να δημιουργήσετε αρχεία εδώ.",
     "Drag and drop files here to upload" : "Σύρετε και αφήστε αρχεία εδώ για να τα μεταφορτώσετε",
@@ -92,7 +93,6 @@ OC.L10N.register(
     "This node is unavailable" : "Αυτός ο κόμβος δεν είναι διαθέσιμος",
     "Another entry with the same name already exists." : "Μια άλλη καταχώρηση με το ίδιο όνομα υπάρχει ήδη.",
     "Invalid filename." : "Μη έγκυρο όνομα αρχείου",
-    "Renamed \"{oldName}\" to \"{newName}\"" : "Μετονομασία του \"{oldName}\" σε \"{newName}\"",
     "Rename file" : "Μετονομασία αρχείου",
     "Folder" : "Φάκελος",
     "Unknown file type" : "Άγνωστος τύπος αρχείου",
@@ -102,12 +102,24 @@ OC.L10N.register(
     "{ext} text" : "Κείμενο {ext}",
     "Pending" : "Εκκρεμεί",
     "Unknown date" : "Άγνωστη ημερομηνία",
-    "Clear filter" : "Εκκαθάριση φίλτρου",
-    "Modified" : "Τροποποιήθηκε",
-    "Search everywhere" : "Αναζητήστε παντού",
-    "Type" : "Τύπος",
     "Active filters" : "Ενεργά φίλτρα",
     "Remove filter" : "Αφαίρεση φίλτρου",
+    "Today" : "Σήμερα",
+    "Last 7 days" : "Τελευταίες 7 ημέρες",
+    "Last 30 days" : "Τελευταίες 30 ημέρες",
+    "This year ({year})" : "Αυτό το έτος ({year})",
+    "Last year ({year})" : "Το περασμένο έτος ({year})",
+    "Custom date range" : "Προσαρμοσμένο διάστημα ημερομηνιών",
+    "Search everywhere" : "Αναζητήστε παντού",
+    "Documents" : "Έγγραφα",
+    "Spreadsheets" : "Υπολογιστικά φύλλα",
+    "Presentations" : "Παρουσιάσεις",
+    "PDFs" : "PDFs",
+    "Folders" : "Φάκελοι",
+    "Audio" : "Ήχος",
+    "Images" : "Εικόνες",
+    "Videos" : "Βίντεο",
+    "Filters" : "Φίλτρα",
     "Appearance" : "Εμφάνιση",
     "Show hidden files" : "Εμφάνιση κρυφών αρχείων",
     "Show file type column" : "Εμφάνιση στήλης τύπου αρχείου",
@@ -135,7 +147,6 @@ OC.L10N.register(
     "Go right in grid" : "Μετάβαση δεξιά στο πλέγμα",
     "View" : "Προβολή",
     "Toggle grid view" : "Εναλλαγή σε προβολή πλέγματος",
-    "Open file sidebar" : "Άνοιγμα πλευρικής μπάρας αρχείου",
     "Show those shortcuts" : "Εμφάνιση αυτών των συντομεύσεων",
     "Warnings" : "Προειδοποιήσεις",
     "Warn before changing a file extension" : "Προειδοποίηση πριν από την αλλαγή επέκτασης αρχείου",
@@ -146,6 +157,7 @@ OC.L10N.register(
     "Name" : "Όνομα",
     "File type" : "Τύπος αρχείου",
     "Size" : "Μέγεθος",
+    "Modified" : "Τροποποιήθηκε",
     "{displayName}: failed on some elements" : "{displayName}: απέτυχε σε ορισμένα στοιχεία",
     "{displayName}: done" : "{displayName}: ολοκληρώθηκε",
     "{displayName}: failed" : "{displayName}: απέτυχε",
@@ -160,6 +172,7 @@ OC.L10N.register(
     "Search here …" : "Αναζήτηση εδώ …",
     "Search scope options" : "Επιλογές εμβέλειας αναζήτησης",
     "Search here" : "Αναζήτηση εδώ",
+    "Owner" : "Κάτοχος",
     "{usedQuotaByte} used" : "{usedQuotaByte} χρησιμοποιείται",
     "{used} of {quota} used" : "Χρήση {used} από {quota} ",
     "{relative}% used" : "{relative}% χρησιμοποιείται",
@@ -213,12 +226,11 @@ OC.L10N.register(
     "Removing the file extension \"{old}\" may render the file unreadable." : "Η αφαίρεση της επέκτασης αρχείου \"{old}\" μπορεί να καταστήσει το αρχείο μη αναγνώσιμο.",
     "Adding the file extension \"{new}\" may render the file unreadable." : "Η προσθήκη της επέκτασης αρχείου \"{new}\" μπορεί να καταστήσει το αρχείο μη αναγνώσιμο.",
     "Do not show this dialog again." : "Να μην εμφανιστεί ξανά αυτό το παράθυρο διαλόγου.",
+    "Cancel" : "Ακύρωση",
+    "Rename" : "Μετονομασία",
     "Select file or folder to link to" : "Επιλέξτε αρχείο ή φάκελο για σύνδεση",
     "Choose {file}" : "Επιλέξτε {file}",
     "Files settings" : "Ρυθμίσεις αρχείων",
-    "Share" : "Διαμοιρασμός",
-    "Shared by link" : "Διαμοιρασμένα μέσω συνδέσμου",
-    "Shared" : "Κοινόχρηστα",
     "Switch to list view" : "Αλλαγή σε προβολή λίστας",
     "Switch to grid view" : "Εναλλαγή σε προβολή πλέγματος",
     "The file could not be found" : "Το αρχείο δεν μπορούσε να βρεθεί",
@@ -234,14 +246,7 @@ OC.L10N.register(
     "Upload some content or sync with your devices!" : "Μεταφόρτωση περιεχομένου ή συγχρονισμός με τις συσκευές σας!",
     "Go back" : "Επιστροφή",
     "Views" : "Προβολές",
-    "You" : "Εσύ",
-    "Shared multiple times with different people" : "Κοινοποιήθηκε πολλές φορές με διαφορετικά άτομα",
-    "Unable to change the favorite state of the file" : "Αδυναμία αλλαγής της κατάστασης αγαπημένου του αρχείου",
-    "Error while loading the file data" : "Σφάλμα κατά την φόρτωση αρχείου δεδομένων",
-    "Owner" : "Κάτοχος",
-    "Remove from favorites" : "Αφαίρεση από τα αγαπημένα",
-    "Add to favorites" : "Προσθήκη στα αγαπημένα",
-    "Tags" : "Ετικέτες",
+    "Loading …" : "Φόρτωση …",
     "Your files" : "Τα αρχεία σας",
     "Open in files" : "Άνοιγμα στα αρχεία",
     "File cannot be accessed" : "Δεν είναι δυνατή η πρόσβαση στο αρχείο",
@@ -284,26 +289,26 @@ OC.L10N.register(
     "_You are about to permanently delete {count} item_::_You are about to permanently delete {count} items_" : ["Πρόκειται να διαγράψετε οριστικά {count} αντικείμενο","Πρόκειται να διαγράψετε οριστικά {count} αντικείμενα"],
     "_You are about to delete {count} item_::_You are about to delete {count} items_" : ["Πρόκειται να διαγράψετε {count} αντικείμενο","Πρόκειται να διαγράψετε {count} αντικείμενα"],
     "Confirm deletion" : "Επιβεβαίωση διαγραφής",
-    "Cancel" : "Ακύρωση",
     "Download" : "Λήψη",
     "The requested file is not available." : "Το ζητούμενο αρχείο δεν είναι διαθέσιμο.",
     "The requested files are not available." : "Τα ζητούμενα αρχεία δεν είναι διαθέσιμα.",
+    "Add to favorites" : "Προσθήκη στα αγαπημένα",
+    "Remove from favorites" : "Αφαίρεση από τα αγαπημένα",
     "Add or remove favorite" : "Προσθήκη ή αφαίρεση αγαπημένου",
+    "Move" : "Μετακίνηση",
+    "Copy" : "Αντιγραφή",
+    "Move or copy" : "Μετακίνηση ή αντιγραφή",
     "Destination is not a folder" : "Ο προορισμός δεν είναι φάκελος",
     "This file/folder is already in that directory" : "Αυτό το αρχείο/φάκελος βρίσκεται ήδη σε αυτόν τον κατάλογο",
     "You cannot move a file/folder onto itself or into a subfolder of itself" : "Δεν μπορείτε να μετακινήσετε ένα αρχείο/φάκελο στον εαυτό του ή σε έναν υποφάκελο του ίδιου του φακέλου.",
-    "(copy)" : "(αντιγραφή)",
-    "(copy %n)" : "(αντιγραφή %n)",
     "A file or folder with that name already exists in this folder" : "Ένα αρχείο ή ένας φάκελος με αυτό το όνομα υπάρχει ήδη σε αυτόν το φάκελο",
     "The files are locked" : "Το αρχεία είναι κλειδωμένα",
     "The file does not exist anymore" : "Το αρχείο δεν υπάρχει πλέον",
     "Choose destination" : "Επιλέξτε προορισμό",
     "Copy to {target}" : "Αντιγραφή σε {target}",
-    "Copy" : "Αντιγραφή",
     "Move to {target}" : "Μετακίνηση σε {target}",
-    "Move" : "Μετακίνηση",
     "Move or copy operation failed" : "Η λειτουργία μετακίνησης ή αντιγραφής απέτυχε",
-    "Move or copy" : "Μετακίνηση ή αντιγραφή",
+    "Open folder" : "Άνοιγμα φακέλου",
     "Open folder {displayName}" : "Άνοιγμα φακέλου {displayName}",
     "Open in Files" : "Άνοιγμα στα Αρχεία",
     "Open locally" : "Άνοιγμα τοπικά",
@@ -312,22 +317,10 @@ OC.L10N.register(
     "The file should now open on your device. If it doesn't, please check that you have the desktop app installed." : "Το αρχείο θα πρέπει τώρα να ανοίξει στη συσκευή σας. Εάν δεν ανοίξει, παρακαλώ ελέγξτε ότι έχετε εγκατεστημένη την εφαρμογή στον υπολογιστή.",
     "Retry and close" : "Δοκιμή ξανά και κλείσιμο",
     "Open online" : "Άνοιγμα online",
-    "Rename" : "Μετονομασία",
     "Details" : "Λεπτομέρειες",
+    "Unfavorite" : "Μη αγαπημένο",
     "View in folder" : "Προβολή στον φάκελο",
-    "Today" : "Σήμερα",
-    "Last 7 days" : "Τελευταίες 7 ημέρες",
-    "Last 30 days" : "Τελευταίες 30 ημέρες",
-    "This year ({year})" : "Αυτό το έτος ({year})",
-    "Last year ({year})" : "Το περασμένο έτος ({year})",
-    "Documents" : "Έγγραφα",
-    "Spreadsheets" : "Υπολογιστικά φύλλα",
-    "Presentations" : "Παρουσιάσεις",
-    "PDFs" : "PDFs",
-    "Folders" : "Φάκελοι",
-    "Audio" : "Ήχος",
-    "Images" : "Εικόνες",
-    "Videos" : "Βίντεο",
+    "Type" : "Τύπος",
     "Created new folder \"{name}\"" : "Δημιουργήθηκε νέος φάκελος \"{name}\"",
     "Unable to initialize the templates directory" : "Δεν είναι δυνατή η προετοιμασία του καταλόγου προτύπων",
     "Create templates folder" : "Δημιουργία φακέλου προτύπων",
@@ -343,10 +336,10 @@ OC.L10N.register(
     "Some files could not be uploaded" : "Μερικά αρχεία δεν μπόρεσαν να μεταφορτωθούν",
     "Files uploaded successfully" : "Τα αρχεία μεταφορτώθηκαν επιτυχώς",
     "No files to process" : "Δεν υπάρχουν αρχεία προς επεξεργασία",
-    "Some files could not be copied" : "Ορισμένα αρχεία δεν μπόρεσαν να αντιγραφούν",
-    "Some files could not be moved" : "Αδυναμία μετακίνησης μερικών αρχείων",
     "Files copied successfully" : "Τα αρχεία αντιγράφηκαν επιτυχώς",
     "Files moved successfully" : "Τα αρχεία μετακινήθηκαν επιτυχώς",
+    "Some files could not be copied" : "Ορισμένα αρχεία δεν μπόρεσαν να αντιγραφούν",
+    "Some files could not be moved" : "Αδυναμία μετακίνησης μερικών αρχείων",
     "Conflicts resolution skipped" : "Η επίλυση συγκρούσεων παραλείφθηκε",
     "Upload cancelled" : "Η μεταφόρτωση ακυρώθηκε",
     "Could not rename \"{oldName}\", it does not exist any more" : "Δεν ήταν δυνατή η μετονομασία του \"{oldName}\", δεν υπάρχει πλέον",
@@ -387,10 +380,14 @@ OC.L10N.register(
     "Upload (max. %s)" : "Μεταφόρτωση (max. %s)",
     "After enabling the windows compatible filenames, existing files cannot be modified anymore but can be renamed to valid new names by their owner." : "Μετά την ενεργοποίηση των συμβατών ονομάτων αρχείων Windows, τα υπάρχοντα αρχεία δεν μπορούν πλέον να τροποποιηθούν αλλά μπορούν να μετονομαστούν σε έγκυρα νέα ονόματα από τον κάτοχό τους.",
     "It is also possible to migrate files automatically after enabling this setting, please refer to the documentation about the occ command." : "Είναι επίσης δυνατή η αυτόματη μετεγκατάσταση αρχείων μετά την ενεργοποίηση αυτής της ρύθμισης, παρακαλώ ανατρέξτε στην τεκμηρίωση σχετικά με την εντολή occ.",
+    "Renamed \"{oldName}\" to \"{newName}\"" : "Μετονομασία του \"{oldName}\" σε \"{newName}\"",
+    "Clear filter" : "Εκκαθάριση φίλτρου",
     "\"{displayName}\" failed on some elements" : "Ο/Η \"{displayName}\" απέτυχε σε ορισμένα στοιχεία",
     "\"{displayName}\" batch action executed successfully" : "Η μαζική ενέργεια του/της \"{displayName}\" εκτελέστηκε επιτυχώς",
     "\"{displayName}\" action failed" : "Η ενέργεια του \"{displayName}\" απέτυχε",
     "Submitting fields …" : "Υποβολή πεδίων …",
+    "Shared by link" : "Διαμοιρασμένα μέσω συνδέσμου",
+    "Shared" : "Κοινόχρηστα",
     "\"{displayName}\" action executed successfully" : "Η ενέργεια του/της \"{displayName}\" εκτελέστηκε επιτυχώς",
     "Filter file names …" : "Φιλτράρισμα ονομάτων αρχείων …",
     "Clipboard is not available" : "Το πρόχειρο δεν είναι διαθέσιμο",
@@ -420,6 +417,11 @@ OC.L10N.register(
     "Navigate to the file on the right (in grid mode)" : "Πλοήγηση στο αρχείο δεξιά (σε λειτουργία πλέγματος)",
     "Toggle the grid view" : "Εναλλαγή προβολής πλέγματος",
     "Open the sidebar for a file" : "Άνοιγμα πλευρικής μπάρας για ένα αρχείο",
+    "You" : "Εσύ",
+    "Shared multiple times with different people" : "Κοινοποιήθηκε πολλές φορές με διαφορετικά άτομα",
+    "Unable to change the favorite state of the file" : "Αδυναμία αλλαγής της κατάστασης αγαπημένου του αρχείου",
+    "Error while loading the file data" : "Σφάλμα κατά την φόρτωση αρχείου δεδομένων",
+    "Tags" : "Ετικέτες",
     "Save as …" : "Αποθήκευση ως …",
     "Converting files …" : "Μετατροπή αρχείων …",
     "Converting file …" : "Μετατροπή αρχείου …",
@@ -427,6 +429,8 @@ OC.L10N.register(
     "Edit locally" : "Επεξεργασία τοπικά",
     "Moving \"{source}\" to \"{destination}\" …" : "Μετακίνηση του \"{source}\" στο \"{destination}\" …",
     "Copying \"{source}\" to \"{destination}\" …" : "Αντιγραφή του \"{source}\" στο \"{destination}\" …",
+    "(copy)" : "(αντιγραφή)",
+    "(copy %n)" : "(αντιγραφή %n)",
     "Move cancelled" : "Μετακίνηση ακυρώθηκε",
     "Cancelled move or copy of \"{filename}\"." : "Ακυρώθηκε η μετακίνηση ή αντιγραφή του \"{filename}\".",
     "Cancelled move or copy operation" : "Ακυρώθηκε η λειτουργία μετακίνησης ή αντιγραφής",
@@ -435,6 +439,7 @@ OC.L10N.register(
     "New folder creation cancelled" : "Ακυρώθηκε η δημιουργία νέου φακέλου",
     "This directory is unavailable, please check the logs or contact the administrator" : "Ο κατάλογος δεν είναι διαθέσιμος, παρακαλούμε ελέγξτε τα αρχεία καταγραφής ή επικοινωνήστε με το διαχειριστή",
     "All folders" : "Όλοι οι φάκελοι",
+    "Open file sidebar" : "Άνοιγμα πλευρικής μπάρας αρχείου",
     "Search everywhere …" : "Αναζήτηση παντού …",
     "Search here …" : "Αναζήτηση εδώ …",
     "Preparing …" : "Προετοιμασία …"
