@@ -78,6 +78,8 @@ OC.L10N.register(
     "Reload current directory" : "Recargar carpeta actual",
     "Go to the \"{dir}\" directory" : "Ir a la carpeta \"{dir}\"",
     "Current directory path" : "Dirección de la carpeta actual",
+    "Share" : "Compartir",
+    "Reload content" : "Recargar contenido",
     "Your have used your space quota and cannot upload files anymore" : "Ha utilizado su cuota de espacio y ya no puede subir más archivos",
     "You do not have permission to upload or create files here." : "No tiene permiso para subir o crear archivos aquí",
     "Drag and drop files here to upload" : "Arrastre y suelte archivos aquí para subirlos",
@@ -92,7 +94,6 @@ OC.L10N.register(
     "This node is unavailable" : "Este nodo no está disponible",
     "Another entry with the same name already exists." : "Ya existe otra entrada con el mismo nombre.",
     "Invalid filename." : "Nombre de archivo inválido.",
-    "Renamed \"{oldName}\" to \"{newName}\"" : "Renombrado \"{oldName}\" a \"{newName}\"",
     "Rename file" : "Renombrar archivo",
     "Folder" : "Carpeta",
     "Unknown file type" : "Tipo de archivo desconocido",
@@ -102,21 +103,71 @@ OC.L10N.register(
     "{ext} text" : "texto {ext}",
     "Pending" : "Pendiente",
     "Unknown date" : "Fecha desconocida",
-    "Clear filter" : "Borrar filtro",
-    "Modified" : "Modificado",
-    "Search everywhere" : "Buscar en todas partes",
-    "Type" : "Tipo",
     "Active filters" : "Filtros activos",
     "Remove filter" : "Quitar filtro",
+    "Today" : "Hoy",
+    "Last 7 days" : "Últimos 7 días",
+    "Last 30 days" : "Últimos 30 días",
+    "This year ({year})" : "Este año ({year})",
+    "Last year ({year})" : "El año pasado ({year})",
+    "Custom range" : "Rango personalizado",
+    "Custom date range" : "Rango de fechas personalizado",
+    "Search everywhere" : "Buscar en todas partes",
+    "Documents" : "Documentos",
+    "Spreadsheets" : "Hojas de cálculo",
+    "Presentations" : "Presentaciones",
+    "PDFs" : "PDFs",
+    "Folders" : "Carpetas",
+    "Audio" : "Audio",
+    "Images" : "Imágenes",
+    "Videos" : "Vídeos",
+    "Filters" : "Filtros",
+    "Back to filters" : "Volver a filtros",
+    "Appearance" : "Apariencia",
+    "Show hidden files" : "Mostrar archivos ocultos",
+    "Show file type column" : "Mostrar la columna de tipo de archivo",
+    "Show file extensions" : "Mostrar extensiones de archivos",
+    "Crop image previews" : "Recortar la previsualización de las imágenes",
+    "General" : "General",
+    "Sort favorites first" : "Ordenar los favoritos primero",
+    "Sort folders before files" : "Ordenar carpetas antes que archivos",
+    "Enable folder tree view" : "Habilitar la vista del árbol de carpetas",
+    "Default view" : "Vista predeterminada",
+    "All files" : "Todos los archivos",
+    "Personal files" : "Archivos personales",
+    "Additional settings" : "Ajustes adicionales",
+    "Actions" : "Acciones",
+    "File actions" : "Acciones de archivo",
+    "Selection" : "Selección",
+    "Select all files" : "Seleccionar todos los archivos",
+    "Deselect all" : "Deseleccionar todos",
+    "Select or deselect" : "Seleccionar o deseleccionar",
+    "Select a range" : "Seleccionar rango",
+    "Navigation" : "Navegación",
+    "Go to parent folder" : "Ir a carpeta superior",
+    "Go to file above" : "Ir al archivo anterior",
+    "Go to file below" : "Ir al archivo siguiente",
+    "Go left in grid" : "Desplazarse a la izquierda en la cuadrícula",
+    "Go right in grid" : "Desplazarse a la derecha en la cuadrícula",
+    "View" : "Vista",
+    "Toggle grid view" : "Alternar vista de cuadrícula",
+    "Show those shortcuts" : "Mostrar estos atajos",
+    "Warnings" : "Advertencias",
+    "Warn before changing a file extension" : "Advertir antes de cambiar la extensión de un archivo.",
+    "Warn before deleting a file" : "Advertir antes de eliminar un archivo",
+    "WebDAV URL" : "URL de WebDAV",
+    "Create an app password" : "Crear nueva contraseña de app",
+    "Required for WebDAV authentication because Two-Factor Authentication is enabled for this account." : "Necesario para la autenticación WebDAV porque la Autenticación de Dos Factores está habilitada para esta cuenta.",
+    "How to access files using WebDAV" : "Como acceder a los archivos usando WebDAV",
     "Total rows summary" : "Resumen de filas totales",
     "Toggle selection for all files and folders" : "Seleccionar/deseleccionar todos los archivos y carpetas",
     "Name" : "Nombre",
     "File type" : "Tipo de archivo",
     "Size" : "Tamaño",
+    "Modified" : "Modificado",
     "{displayName}: failed on some elements" : "{displayName}: falló en algunos elementos",
     "{displayName}: done" : "{displayName}: listo",
     "{displayName}: failed" : "{displayName}: falló",
-    "Actions" : "Acciones",
     "(selected)" : "(seleccionado)",
     "List of files and folders." : "Lista de archivos y carpetas.",
     "You have used your space quota and cannot upload files anymore." : "Ha usado su cuota de almacenamiento y ya no puede subir más archivos.",
@@ -124,10 +175,11 @@ OC.L10N.register(
     "This list is not fully rendered for performance reasons. The files will be rendered as you navigate through the list." : "Esta lista no se muestra completamente por motivos de rendimiento. Los archivos se mostrarán a medida que navega por la lista.",
     "File not found" : "No se ha encontrado el archivo",
     "_{count} selected_::_{count} selected_" : ["{count} seleccionado","{count} seleccionados","{count} seleccionados"],
-    "Search everywhere …" : "Buscar en todas partes …",
-    "Search here …" : "Buscar aquí …",
+    "Search everywhere …" : "Buscar en todas partes …",
+    "Search here …" : "Buscar aquí …",
     "Search scope options" : "Opciones de alcance de la búsqueda",
     "Search here" : "Buscar aquí",
+    "Owner" : "Dueño",
     "{usedQuotaByte} used" : "{usedQuotaByte} utilizados",
     "{used} of {quota} used" : "{used} usados de {quota}",
     "{relative}% used" : "{relative}% utilizado",
@@ -144,7 +196,7 @@ OC.L10N.register(
     "Failed to refresh filename sanitization status." : "Fallo al refrescar el estado del saneamiento de nombres de archivo.",
     "Filename sanitization in progress." : "Saneamiento de nombres de archivo en progreso.",
     "Currently {processedUsers} of {totalUsers} accounts are already processed." : "Actualmente {processedUsers} de {totalUsers} cuentas ya han sido procesadas.",
-    "Preparing …" : "Preparando …",
+    "Preparing …" : "Preparando …",
     "Refresh" : "Refrescar",
     "All files have been santized for Windows filename support." : "Todos los archivos se les ha saneado para el soporte de nombres de archivo Windows.",
     "Some files could not be sanitized, please check your logs." : "Algunos archivos no les pudo sanear el nombre de archivo, por favor, revise sus registros.",
@@ -159,7 +211,7 @@ OC.L10N.register(
     "Sanitize filenames" : "Sanear nombres de archivo",
     "(starting)" : "(iniciando)",
     "Fill template fields" : "Rellenar los campos de la plantilla",
-    "Submitting fields …" : "Enviando campos …",
+    "Submitting fields …" : "Enviando campos …",
     "Submit" : "Enviar",
     "Choose a file or folder to transfer" : "Elegir un archivo o carpeta para transferir",
     "Transfer" : "Transferir",
@@ -181,11 +233,14 @@ OC.L10N.register(
     "Removing the file extension \"{old}\" may render the file unreadable." : "Quitar la extensión \"{old}\" podría hacer a el archivo ilegible.",
     "Adding the file extension \"{new}\" may render the file unreadable." : "Añadir la extensión \"{new}\" podría hacer a el archivo ilegible.",
     "Do not show this dialog again." : "No mostrar este diálogo de nuevo.",
+    "Rename file to hidden" : "Cambiar el nombre del archivo para ocultarlo",
+    "Prefixing a filename with a dot may render the file hidden." : "Si antepones un punto al nombre de un archivo, éste podría quedar oculto.",
+    "Are you sure you want to rename the file to \"{filename}\"?" : "¿Estás seguro que quieres cambiar el nombre del archivo a \"{filename}\"?",
+    "Cancel" : "Cancelar",
+    "Rename" : "Renombrar",
     "Select file or folder to link to" : "Selecciona archivo o carpeta a enlazar",
     "Choose {file}" : "Seleccionar {file}",
-    "Share" : "Compartir",
-    "Shared by link" : "Compartido por enlace",
-    "Shared" : "Compartido",
+    "Files settings" : "Configuración de archivos",
     "Switch to list view" : "Cambiar a vista de lista",
     "Switch to grid view" : "Cambiar a vista de cuadrícula",
     "The file could not be found" : "El archivo no se pudo encontrar",
@@ -195,96 +250,46 @@ OC.L10N.register(
     "Error during upload: {message}" : "Error durante la subida: {message}",
     "Error during upload, status code {status}" : "Error durante la subida, código de estado {status}",
     "Unknown error during upload" : "Error desconocido durante la subida",
+    "File list is reloading" : "La lista de archivos se está recargando",
     "Loading current folder" : "Cargando carpeta actual",
     "Retry" : "Reintentar",
     "No files in here" : "Aquí no hay archivos",
     "Upload some content or sync with your devices!" : "¡Sube contenido o sincroniza tus dispositivos!",
     "Go back" : "Ir atrás",
     "Views" : "Vistas",
-    "Files settings" : "Configuración de archivos",
+    "Loading …" : "Cargando …",
     "Your files" : "Sus archivos",
     "Open in files" : "Abrir en Archivos",
     "File cannot be accessed" : "No se ha podido acceder al archivo",
     "The file could not be found or you do not have permissions to view it. Ask the sender to share it." : "El archivo no fue encontrado o no tiene permisos para verlo. Solicite al remitente que lo comparta.",
     "No search results for “{query}”" : "No hay resultados para “{query}”",
     "Search for files" : "Buscar archivos",
-    "Clipboard is not available" : "El portapapeles no está disponible",
-    "WebDAV URL copied" : "URL de WebDAV copiado",
-    "General" : "General",
-    "Default view" : "Vista predeterminada",
-    "All files" : "Todos los archivos",
-    "Personal files" : "Archivos personales",
-    "Sort favorites first" : "Ordenar los favoritos primero",
-    "Sort folders before files" : "Ordenar carpetas antes que archivos",
-    "Folder tree" : "Árbol de carpetas",
-    "Appearance" : "Apariencia",
-    "Show hidden files" : "Mostrar archivos ocultos",
-    "Show file type column" : "Mostrar la columna de tipo de archivo",
-    "Show file extensions" : "Mostrar extensiones de archivos",
-    "Crop image previews" : "Recortar la previsualización de las imágenes",
-    "Additional settings" : "Ajustes adicionales",
-    "WebDAV" : "WebDAV",
-    "WebDAV URL" : "URL de WebDAV",
-    "Copy" : "Copiar",
-    "How to access files using WebDAV" : "Como acceder a los archivos usando WebDAV",
-    "Two-Factor Authentication is enabled for your account, and therefore you need to use an app password to connect an external WebDAV client." : "La autenticación en dos factores está habilitada para su cuenta y, por lo tanto, debe usar una contraseña de aplicación para conectar un cliente WebDAV externo.",
-    "Warnings" : "Advertencias",
-    "Warn before changing a file extension" : "Advertir antes de cambiar la extensión de un archivo.",
-    "Warn before deleting files" : "Advertir antes de eliminar archivos",
-    "Keyboard shortcuts" : "Atajos de teclado",
-    "File actions" : "Acciones de archivo",
-    "Rename" : "Renombrar",
-    "Delete" : "Eliminar",
-    "Add or remove favorite" : "Añadir o quitar favorito",
-    "Manage tags" : "Gestionar etiquetas",
-    "Selection" : "Selección",
-    "Select all files" : "Seleccionar todos los archivos",
-    "Deselect all" : "Deseleccionar todos",
-    "Select or deselect" : "Seleccionar o deseleccionar",
-    "Select a range" : "Seleccionar rango",
-    "Navigation" : "Navegación",
-    "Go to parent folder" : "Ir a carpeta superior",
-    "Go to file above" : "Ir al archivo anterior",
-    "Go to file below" : "Ir al archivo siguiente",
-    "Go left in grid" : "Desplazarse a la izquierda en la cuadrícula",
-    "Go right in grid" : "Desplazarse a la derecha en la cuadrícula",
-    "View" : "Vista",
-    "Toggle grid view" : "Alternar vista de cuadrícula",
-    "Open file sidebar" : "Abrir la barra lateral de archivo",
-    "Show those shortcuts" : "Mostrar estos atajos",
     "Allow to restrict filenames to ensure files can be synced with all clients. By default all filenames valid on POSIX (e.g. Linux or macOS) are allowed." : "Permitir la restricción en nombres de archivo para asegurar que los archivos se puedan sincronizar con todos los clientes. Por defecto, se permiten todos los nombres de archivos válidos en POSIX (por ejemplo, Linux o macOS).",
     "After enabling the Windows compatible filenames, existing files cannot be modified anymore but can be renamed to valid new names by their owner." : "Una vez habilitados los nombres de archivo compatibles con Windows, los archivos existentes ya no se podrán modificar, pero su propietario podrá renombrarlos a otros nombres válidos de archivo.",
     "Failed to toggle Windows filename support" : "Fallo al conmutar el soporte a nombres de archivo Windows",
     "Files compatibility" : "Compatibilidad de archivos",
     "Enforce Windows compatibility" : "Forzar la compatibilidad con Windows",
     "This will block filenames not valid on Windows systems, like using reserved names or special characters. But this will not enforce compatibility of case sensitivity." : "Esto bloqueará los nombres de archivos inválidos en sistemas Windows, tales como usar nombres reservados o caracteres especiales. Pero no forzará la compatibilidad del uso de mayúsculas y minúsculas.",
-    "You" : "Tú",
-    "Shared multiple times with different people" : "Compartido múltiples veces con diferentes personas",
-    "Unable to change the favorite state of the file" : "No fue posible cambiar el estado de favorito del archivo",
-    "Error while loading the file data" : "Error al cargar los datos del archivo",
-    "Owner" : "Dueño",
-    "Remove from favorites" : "Quitar de favoritos",
-    "Add to favorites" : "Añadir a favoritos",
-    "Tags" : "Etiquetas",
     "Blank" : "Vacío",
     "Unable to create new file from template" : "No se ha podido crear un nuevo archivo desde la plantilla",
     "Pick a template for {name}" : "Elija una plantilla para {name}",
     "Create a new file with the selected template" : "Crear un nuevo archivo con la plantilla seleccionada",
     "Creating file" : "Creando el archivo",
     "Save as {displayName}" : "Guardar como {displayName}",
-    "Save as …" : "Guardar como …",
-    "Converting files …" : "Convirtiendo archivos …",
+    "Save as …" : "Guardar como …",
+    "Converting files …" : "Convirtiendo archivos …",
     "Failed to convert files: {message}" : "Fallo al convertir archivos: {message}",
     "All files failed to be converted" : "Todos los archivos han fallado al convertirse",
     "One file could not be converted: {message}" : "Un archivo no ha podido ser convertido: {message}",
-    "_One file could not be converted_::_%n files could not be converted_" : ["Un archivo no pudo ser convertido","%n archivos no pudieron ser convertidos","%n archivos no pudieron ser convertidos"],
-    "_One file successfully converted_::_%n files successfully converted_" : ["Un archivo convertido exitosamente","%n archivos convertidos exitosamente","%n archivos convertidos exitosamente"],
-    "Files successfully converted" : "Archivos convertidos exitosamente",
+    "_%n file could not be converted_::_%n files could not be converted_" : ["%n archivo no puede ser convertido","%n archivos no pueden ser convertidos","%n archivos no pueden ser convertidos"],
+    "_%n file converted_::_%n files converted_" : ["%n archivo convertido","%n archivos convertidos","%n archivos convertidos"],
+    "Files converted" : "Archivos convertidos",
     "Failed to convert files" : "Fallo al convertir archivos",
-    "Converting file …" : "Convirtiendo archivo …",
+    "Converting file …" : "Convirtiendo archivo …",
     "File successfully converted" : "Archivo convertido exitosamente",
     "Failed to convert file: {message}" : "Fallo al convertir el archivo: {message}",
     "Failed to convert file" : "Fallo al convertir el archivo",
+    "Delete" : "Eliminar",
     "Leave this share" : "Abandonar este recurso compartido",
     "Leave these shares" : "Abandonar estos recursos compartidos",
     "Disconnect storage" : "Desconectar almacenamiento",
@@ -298,26 +303,30 @@ OC.L10N.register(
     "_You are about to permanently delete {count} item_::_You are about to permanently delete {count} items_" : ["Está a punto de eliminar {count} elemento permanentemente","Está a punto de eliminar {count} elementos permanentemente.","Está a punto de eliminar {count} elementos permanentemente"],
     "_You are about to delete {count} item_::_You are about to delete {count} items_" : ["Está a punto de eliminar {count} elemento","Está a punto de eliminar {count} elementos","Está a punto de eliminar {count} elementos"],
     "Confirm deletion" : "Confirmar eliminación",
-    "Cancel" : "Cancelar",
     "Download" : "Descargar",
     "The requested file is not available." : "El archivo solicitado no está disponible.",
     "The requested files are not available." : "Los archivos solicitados no están disponibles.",
-    "Moving \"{source}\" to \"{destination}\" …" : "Moviendo \"{source}\" a \"{destination}\" …",
-    "Copying \"{source}\" to \"{destination}\" …" : "Copiando \"{source}\" a \"{destination}\" …",
+    "Add to favorites" : "Añadir a favoritos",
+    "Remove from favorites" : "Quitar de favoritos",
+    "Add or remove favorite" : "Añadir o quitar favorito",
+    "Move" : "Mover",
+    "Copy" : "Copiar",
+    "Move or copy" : "Mover o copiar",
     "Destination is not a folder" : "El destino no es una carpeta",
     "This file/folder is already in that directory" : "Este archivo/carpeta ya está en ese directorio",
     "You cannot move a file/folder onto itself or into a subfolder of itself" : "No puede mover un archivo/carpeta a sí mismo o a una sub-carpeta de sí mismo",
-    "(copy)" : "(copiar)",
-    "(copy %n)" : "(copiar %n)",
     "A file or folder with that name already exists in this folder" : "Un archivo o carpeta con ese nombre ya existe en esta carpeta",
     "The files are locked" : "Los archivos están bloqueados",
     "The file does not exist anymore" : "El archivo ya no existe",
+    "Moving \"{source}\" to \"{destination}\" …" : "Moviendo \"{source}\" a \"{destination}\" …",
+    "Moving {count} files to \"{destination}\" …" : "Moviendo{count} archivos a \"{destination}\" …",
+    "Copying \"{source}\" to \"{destination}\" …" : "Copiando \"{source}\" a \"{destination}\" …",
+    "Copying {count} files to \"{destination}\" …" : "Copiando {count} archivos a \"{destination}\" …",
     "Choose destination" : "Elegir destino",
     "Copy to {target}" : "Copiar a {target}",
     "Move to {target}" : "Mover a {target}",
-    "Move" : "Mover",
     "Move or copy operation failed" : "La operación de mover o copiar falló",
-    "Move or copy" : "Mover o copiar",
+    "Open folder" : "Abrir carpeta",
     "Open folder {displayName}" : "Abrir carpeta {displayName}",
     "Open in Files" : "Abrir en Archivos",
     "Open locally" : "Abrir localmente",
@@ -327,26 +336,17 @@ OC.L10N.register(
     "Retry and close" : "Reintentar y cerrar",
     "Open online" : "Abrir en línea",
     "Details" : "Detalles",
+    "Open the details sidebar" : "Abrir los detalles en el lateral",
+    "Unfavorite" : "Quitar favorito",
     "View in folder" : "Ver en carpeta",
-    "Today" : "Hoy",
-    "Last 7 days" : "Últimos 7 días",
-    "Last 30 days" : "Últimos 30 días",
-    "This year ({year})" : "Este año ({year})",
-    "Last year ({year})" : "El año pasado ({year})",
-    "Documents" : "Documentos",
-    "Spreadsheets" : "Hojas de cálculo",
-    "Presentations" : "Presentaciones",
-    "PDFs" : "PDFs",
-    "Folders" : "Carpetas",
-    "Audio" : "Audio",
-    "Images" : "Imágenes",
-    "Videos" : "Vídeos",
+    "Type" : "Tipo",
     "Created new folder \"{name}\"" : "Se ha creado la carpeta nueva \"{name}\"",
     "Unable to initialize the templates directory" : "No se ha podido iniciar la carpeta de plantillas",
     "Create templates folder" : "Crear carpeta de plantillas",
     "Templates" : "Plantillas",
     "New template folder" : "Nueva carpeta de plantillas",
     "In folder" : "En carpeta",
+    "Pick folder to search in" : "Selecciona la carpeta en la que buscar",
     "Search in all files" : "Buscar en todos los archivos",
     "Search in folder: {folder}" : "Buscar en carpeta: {folder}",
     "One of the dropped files could not be processed" : "Uno de los archivos arrastrados no puede ser procesado",
@@ -356,10 +356,10 @@ OC.L10N.register(
     "Some files could not be uploaded" : "No se pudieron subir algunos archivos",
     "Files uploaded successfully" : "Se subieron los archivos exitosamente",
     "No files to process" : "No hay archivos para procesar",
-    "Some files could not be copied" : "Algunos archivos no se han podido copiar",
-    "Some files could not be moved" : "No se han podido mover algunos archivos",
     "Files copied successfully" : "Archivos copiados exitosamente",
     "Files moved successfully" : "Archivos movidos exitosamente",
+    "Some files could not be copied" : "Algunos archivos no se han podido copiar",
+    "Some files could not be moved" : "No se han podido mover algunos archivos",
     "Conflicts resolution skipped" : "Resolución de conflictos omitida",
     "Upload cancelled" : "Subida cancelada",
     "Could not rename \"{oldName}\", it does not exist any more" : "No se ha podido renombrar \"{oldName}\", ya no existe",
@@ -381,6 +381,7 @@ OC.L10N.register(
     "No favorites yet" : "Aún no hay favoritos",
     "Files and folders you mark as favorite will show up here" : "Aquí aparecerán los archivos y carpetas que has marcado como favoritos",
     "List of your files and folders." : "Lista de sus archivos y carpetas.",
+    "Folder tree" : "Árbol de carpetas",
     "List of your files and folders that are not shared." : "Lista de sus archivos y carpetas que no están compartidos.",
     "No personal files found" : "No se encontraron archivos personales",
     "Files that are not shared will show up here." : "Los archivos y carpetas que no ha compartido aparecerán aquí.",
@@ -394,119 +395,32 @@ OC.L10N.register(
     "Select all" : "Seleccionar todo",
     "Upload too large" : "Subida demasido grande",
     "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Los archivos que estás intentando subir sobrepasan el tamaño máximo permitido en este servidor.",
-    "File could not be found" : "El archivo no se ha encontrado",
-    "Show list view" : "Mostrar vista de lista",
-    "Show grid view" : "Mostrar vista de cuadrícula",
-    "Close" : "Cerrar",
-    "Could not create folder \"{dir}\"" : "No se ha podido crear la carpeta \"{dir}\"",
-    "This will stop your current uploads." : "Esto detendrá las subidas en curso.",
-    "Upload cancelled." : "Subida cancelada.",
-    "Processing files …" : "Procesando archivos …",
-    "…" : "…",
-    "Unable to upload {filename} as it is a directory or has 0 bytes" : "No ha sido posible subir {filename} porque es un directorio o tiene 0 bytes",
-    "Not enough free space, you are uploading {size1} but only {size2} is left" : "No hay suficiente espacio libre. Quiere subir {size1} pero solo quedan {size2}",
-    "Target folder \"{dir}\" does not exist any more" : "La carpeta de destino \"{dir}\" ya no existe",
-    "An unknown error has occurred" : "Se ha producido un error desconocido",
-    "File could not be uploaded" : "No se ha podido subir el archivo",
-    "Uploading …" : "Subiendo …",
-    "{remainingTime} ({currentNumber}/{total})" : "{remainingTime} ({currentNumber}/{total})",
-    "Uploading … ({currentNumber}/{total})" : "Cargando… ({currentNumber}/{total})",
-    "{loadedSize} of {totalSize} ({bitrate})" : "{loadedSize} de {totalSize} ({bitrate})",
-    "Uploading that item is not supported" : "Subir este archivo no es compatible",
-    "Error when assembling chunks, status code {status}" : "Error al reunir los trozos, código de estado {status}",
-    "Choose target folder" : "Elegir carpeta de destino",
-    "Set reminder" : "Establecer recordatorio",
-    "Edit locally" : "Editar localmente",
-    "Open" : "Abrir",
-    "Could not load info for file \"{file}\"" : "No se ha podido cargar información para el archivo \"{file}\"",
-    "Please select tag(s) to add to the selection" : "Seleccione la(s) etiqueta(s) para añadir a la selección",
-    "Apply tag(s) to selection" : "Aplicar etiqueta(s) a la selección",
-    "Select directory \"{dirName}\"" : "Seleccione la carpeta \"{dirName}\"",
-    "Select file \"{fileName}\"" : "Seleccione el archivo \"{fileName}\"",
-    "Unable to determine date" : "No se ha podido determinar la fecha",
-    "This directory is unavailable, please check the logs or contact the administrator" : "Esta carpeta no está disponible, por favor verifique los registros o contacte con el administrador",
-    "Could not move \"{file}\", target exists" : "No se ha podido mover \"{file}\", ya existe",
-    "Could not move \"{file}\"" : "No se ha podido mover \"{file}\"",
-    "copy" : "copiar",
-    "Could not copy \"{file}\", target exists" : "No se ha podido copiar \"{file}\", ya existe el destino",
-    "Could not copy \"{file}\"" : "No se ha podido copiar \"{file}\"",
-    "Copied {origin} inside {destination}" : "Se ha copiado {origin} dentro de {destination}",
-    "Copied {origin} and {nbfiles} other files inside {destination}" : "Se han copiado {origin} y {nbfiles} otros archivos dentro de {destination}",
-    "{newName} already exists" : "{newName} ya existe",
-    "Could not create file \"{file}\"" : "No se ha podido crear el archivo \"{file}\"",
-    "Could not create file \"{file}\" because it already exists" : "No se pudo crear archivo \"{file}\" porque ya existe",
-    "Could not create folder \"{dir}\" because it already exists" : "No se ha podido crear la carpeta \"{dir}\" porque ya existe",
-    "Could not fetch file details \"{file}\"" : "No se han podido obtener los detalles de \"{file}\"",
-    "Error deleting file \"{fileName}\"." : "Error al borrar el archivo \"{fileName}\".",
-    "No search results in other folders for {tag}{filter}{endtag}" : "No hay resultados de búsqueda en otras carpetas para  {tag}{filter}{endtag}",
-    "Enter more than two characters to search in other folders" : "Escriba más de dos caracteres para buscar en otras carpetas",
-    "{dirs} and {files}" : "{dirs} y {files}",
-    "_including %n hidden_::_including %n hidden_" : ["incluyendo %n oculto","incluyendo %n ocultos","incluyendo %n ocultos"],
-    "You do not have permission to upload or create files here" : "No tiene permiso para subir o crear archivos aquí",
-    "_Uploading %n file_::_Uploading %n files_" : ["Subiendo %n archivo","Subiendo %n archivos","Subiendo %n archivos"],
-    "New" : "Nuevo",
-    "New file/folder menu" : "Menú de carpeta/archivo nuevo",
-    "Select file range" : "Seleccionar el rango de archivos",
-    "{used}%" : "{used}%",
-    "{used} used" : "{used} usados",
-    "\"{name}\" is an invalid file name." : "\"{name}\" es un nombre de archivo no válido.",
-    "File name cannot be empty." : "El nombre de archivo no puede estar vacío.",
-    "\"/\" is not allowed inside a file name." : "\"/\" no se permite en un nombre de archivo.",
-    "\"{name}\" is not an allowed filetype" : "\"{name}\" no es un tipo de archivo permitido",
-    "Storage of {owner} is full, files cannot be updated or synced anymore!" : "El almacenamiento de {owner} está lleno. ¡No se puede actualizar o sincronizar ningún archivo más!",
-    "Group folder \"{mountPoint}\" is full, files cannot be updated or synced anymore!" : "La carpeta de grupo \"{mountPoint}\" está llena. ¡No se puede actualizar o sincronizar ningún archivo más!",
-    "External storage \"{mountPoint}\" is full, files cannot be updated or synced anymore!" : "El almacenamiento externo \"{mountPoint}\" está lleno. ¡No se puede actualizar o sincronizar ningún archivo más!",
-    "Your storage is full, files cannot be updated or synced anymore!" : "Tu almacenamiento está lleno. ¡No se puede actualizar o sincronizar ningún archivo más!",
-    "Storage of {owner} is almost full ({usedSpacePercent}%)." : "El almacenamiento de {owner} está casi lleno ({usedSpacePercent}%).",
-    "Group folder \"{mountPoint}\" is almost full ({usedSpacePercent}%)." : "La carpeta de grupo \"{mountPoint}\" está casi llena ({usedSpacePercent}%).",
-    "External storage \"{mountPoint}\" is almost full ({usedSpacePercent}%)." : "El almacenamiento externo \"{mountPoint}\" está casi lleno ({usedSpacePercent}%).",
-    "Your storage is almost full ({usedSpacePercent}%)." : "Tu almacenamiento está casi lleno ({usedSpacePercent}%).",
-    "_matches \"{filter}\"_::_match \"{filter}\"_" : ["coinciden \"{filter}\"","coincide \"{filter}\"","coincide \"{filter}\""],
-    "Direct link was copied (only works for people who have access to this file/folder)" : "Se ha copiado el enlace directo (sólo funciona para usuarios que tengan acceso a este archivo/carpeta)",
-    "Path" : "Ruta",
-    "_%n byte_::_%n bytes_" : ["%n byte","%n bytes","%n bytes"],
-    "Favored" : "Favorecido",
-    "Favor" : "Favorecer",
-    "Copy direct link (only works for people who have access to this file/folder)" : "Copiar enlace directo (solo funciona para usuarios que tienen acceso a este archivo/carpeta)",
-    "Upload file" : "Subir archivo",
-    "Not favored" : "No favorecido",
-    "An error occurred while trying to update the tags" : "Se ha producido un error al tratar de actualizar las etiquetas",
+    "%1$s (renamed)" : "%1$s (renombrado)",
+    "renamed file" : "archivo renombrado",
     "Upload (max. %s)" : "Subida (máx. %s)",
-    "\"{displayName}\" action executed successfully" : "la acción \"{displayName}\" se ejecutó exitosamente",
-    "\"{displayName}\" action failed" : "la acción \"{displayName}\" falló",
+    "After enabling the windows compatible filenames, existing files cannot be modified anymore but can be renamed to valid new names by their owner." : "Una vez habilitados los nombres de archivo compatibles con Windows, los archivos existentes ya no se podrán modificar, pero su propietario podrá renombrarlos a otros nombres válidos de archivo.",
+    "It is also possible to migrate files automatically after enabling this setting, please refer to the documentation about the occ command." : "También es posible migrar los archivos automáticamente luego de habilitar este ajuste. Por favor, refiérase a la documentación sobre el comando occ.",
+    "Renamed \"{oldName}\" to \"{newName}\"" : "Renombrado \"{oldName}\" a \"{newName}\"",
+    "Clear filter" : "Borrar filtro",
     "\"{displayName}\" failed on some elements" : "\"{displayName}\" falló en algunos elementos",
     "\"{displayName}\" batch action executed successfully" : "la acción en lotes \"{displayName}\" se ejecutó exitosamente",
-    "Submitting fields…" : "Enviando campos…",
-    "Filter filenames…" : "Filtrar nombres de archivo…",
+    "\"{displayName}\" action failed" : "la acción \"{displayName}\" falló",
+    "Submitting fields …" : "Enviando campos …",
+    "Shared by link" : "Compartido por enlace",
+    "Shared" : "Compartido",
+    "\"{displayName}\" action executed successfully" : "la acción \"{displayName}\" se ejecutó exitosamente",
+    "Filter file names …" : "Filtrar nombres de archivo …",
+    "Clipboard is not available" : "El portapapeles no está disponible",
     "WebDAV URL copied to clipboard" : "URL de WebDAV copiado al portapapeles",
     "Enable the grid view" : "Habilitar vista de cuadrícula",
     "Enable folder tree" : "Habilitar el árbol de carpetas",
+    "WebDAV" : "WebDAV",
     "Copy to clipboard" : "Copiar al portapapeles",
     "Use this address to access your Files via WebDAV" : "Use esta dirección para acceder a sus archivos vía WebDAV",
     "If you have enabled 2FA, you must create and use a new app password by clicking here." : "Si ha habilitado 2FA, debe crear y utilizar una nueva contraseña de aplicación haciendo clic aquí.",
-    "Deletion cancelled" : "Eliminación cancelada",
-    "Move cancelled" : "Se canceló la movida",
-    "Cancelled move or copy of \"{filename}\"." : "Se canceló la operación de mover o copiar de \"{filename}\".",
-    "Cancelled move or copy operation" : "Se canceló la operación de mover o copiar",
-    "Open details" : "Abrir detalles",
-    "Photos and images" : "Fotos e imágenes",
-    "New folder creation cancelled" : "Se canceló la creación de la carpeta nueva",
-    "_{folderCount} folder_::_{folderCount} folders_" : ["{folderCount} carpeta","{folderCount} carpetas","{folderCount} carpetas"],
-    "_{fileCount} file_::_{fileCount} files_" : ["{fileCount} archivo","{fileCount} archivos","{fileCount} archivos"],
-    "_1 file and {folderCount} folder_::_1 file and {folderCount} folders_" : ["1 archivo y {folderCount} carpeta","1 archivo y {folderCount} carpetas","1 archivo y {folderCount} carpetas"],
-    "_{fileCount} file and 1 folder_::_{fileCount} files and 1 folder_" : ["{fileCount} archivo y 1 carpeta","{fileCount} archivos y 1 carpeta","{fileCount} archivos y 1 carpeta"],
-    "{fileCount} files and {folderCount} folders" : "{fileCount} archivos y {folderCount} carpetas",
-    "All folders" : "Todas las carpetas",
-    "Personal Files" : "Archivos Personales",
-    "Text file" : "Archivo de texto",
-    "New text file.txt" : "Nuevo archivo.txt",
-    "%1$s (renamed)" : "%1$s (renombrado)",
-    "renamed file" : "archivo renombrado",
-    "After enabling the windows compatible filenames, existing files cannot be modified anymore but can be renamed to valid new names by their owner." : "Una vez habilitados los nombres de archivo compatibles con Windows, los archivos existentes ya no se podrán modificar, pero su propietario podrá renombrarlos a otros nombres válidos de archivo.",
-    "It is also possible to migrate files automatically after enabling this setting, please refer to the documentation about the occ command." : "También es posible migrar los archivos automáticamente luego de habilitar este ajuste. Por favor, refiérase a la documentación sobre el comando occ.",
-    "Filter file names …" : "Filtrar nombres de archivo …",
     "Prevent warning dialogs from open or reenable them." : "Evitar que se abran los diálogos de advertencia o volver a habilitarlos.",
     "Show a warning dialog when changing a file extension." : "Mostrar un diálogo de advertencia cuando se cambia la extensión de un archivo.",
+    "Keyboard shortcuts" : "Atajos de teclado",
     "Speed up your Files experience with these quick shortcuts." : "Acelere su experiencia con Archivos con estos rápidos atajos de teclado.",
     "Open the actions menu for a file" : "Abrir el menú de acciones para un archivo",
     "Rename a file" : "Renombrar un archivo",
@@ -522,6 +436,32 @@ OC.L10N.register(
     "Navigate to the file on the left (in grid mode)" : "Navegar al archivo de la izquierda (en modo cuadrícula)",
     "Navigate to the file on the right (in grid mode)" : "Navegar al archivo de la derecha (en modo cuadrícula)",
     "Toggle the grid view" : "Alternar vista en cuadrícula",
-    "Open the sidebar for a file" : "Abrir la barra lateral para un archivo"
+    "Open the sidebar for a file" : "Abrir la barra lateral para un archivo",
+    "You" : "Tú",
+    "Shared multiple times with different people" : "Compartido múltiples veces con diferentes personas",
+    "Unable to change the favorite state of the file" : "No fue posible cambiar el estado de favorito del archivo",
+    "Error while loading the file data" : "Error al cargar los datos del archivo",
+    "Tags" : "Etiquetas",
+    "Save as …" : "Guardar como …",
+    "Converting files …" : "Convirtiendo archivos …",
+    "Converting file …" : "Convirtiendo archivo …",
+    "Deletion cancelled" : "Eliminación cancelada",
+    "Edit locally" : "Editar localmente",
+    "Moving \"{source}\" to \"{destination}\" …" : "Moviendo \"{source}\" a \"{destination}\" …",
+    "Copying \"{source}\" to \"{destination}\" …" : "Copiando \"{source}\" a \"{destination}\" …",
+    "(copy)" : "(copiar)",
+    "(copy %n)" : "(copiar %n)",
+    "Move cancelled" : "Se canceló la movida",
+    "Cancelled move or copy of \"{filename}\"." : "Se canceló la operación de mover o copiar de \"{filename}\".",
+    "Cancelled move or copy operation" : "Se canceló la operación de mover o copiar",
+    "Open details" : "Abrir detalles",
+    "Photos and images" : "Fotos e imágenes",
+    "New folder creation cancelled" : "Se canceló la creación de la carpeta nueva",
+    "This directory is unavailable, please check the logs or contact the administrator" : "Esta carpeta no está disponible, por favor verifique los registros o contacte con el administrador",
+    "All folders" : "Todas las carpetas",
+    "Open file sidebar" : "Abrir la barra lateral de archivo",
+    "Search everywhere …" : "Buscar en todas partes …",
+    "Search here …" : "Buscar aquí …",
+    "Preparing …" : "Preparando …"
 },
 "nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
