@@ -67,6 +67,7 @@ OC.L10N.register(
     "Reload current directory" : "Recargar el directorio actual",
     "Go to the \"{dir}\" directory" : "Ir al directorio \"{dir}\"",
     "Current directory path" : "Dirección del directorio actual",
+    "Share" : "Compartir",
     "Your have used your space quota and cannot upload files anymore" : "Ha utilizado su cuota de espacio y ya no puede subir más archivos",
     "Drag and drop files here to upload" : "Arrastre y suelte los archivos aquí para subirlos",
     "Favorite" : "Favorito",
@@ -80,27 +81,55 @@ OC.L10N.register(
     "This node is unavailable" : "Este nodo no está disponible",
     "Another entry with the same name already exists." : "Ya existe otra entrada con el mismo nombre.",
     "Invalid filename." : "Nombre de archivo inválido",
-    "Renamed \"{oldName}\" to \"{newName}\"" : "Renombrado \"{oldName}\" a \"{newName}\"",
     "Rename file" : "Renombrar archivo",
     "Folder" : "Carpeta",
     "Pending" : "Pendiente",
     "Unknown date" : "Fecha desconocida",
-    "Clear filter" : "Limpiar filtro",
-    "Modified" : "Modificado",
-    "Search everywhere" : "Buscar en todas partes",
-    "Type" : "Tipo",
     "Active filters" : "Filtros activos",
     "Remove filter" : "Quitar filtro",
+    "Today" : "Hoy",
+    "Last 7 days" : "Últimos 7 días",
+    "Last 30 days" : "Últimos 30 días",
+    "This year ({year})" : "Este año ({year})",
+    "Last year ({year})" : "El año pasado ({year})",
+    "Custom date range" : "Rango de fechas personalizado",
+    "Search everywhere" : "Buscar en todas partes",
+    "Documents" : "Documentos",
+    "Spreadsheets" : "Hojas de cálculo",
+    "Presentations" : "Presentaciones",
+    "PDFs" : "PDFs",
+    "Folders" : "Carpetas",
+    "Audio" : "Audio",
+    "Images" : "Imágenes",
+    "Videos" : "Videos",
+    "Filters" : "Filtros",
+    "Appearance" : "Apariencia",
+    "Show hidden files" : "Mostrar archivos ocultos",
+    "Crop image previews" : "Recortar la previsualización de las imágenes",
+    "General" : "General",
+    "Sort favorites first" : "Ordenar los favoritos primero",
+    "Sort folders before files" : "Ordenar carpetas antes que archivos",
+    "All files" : "Todos los archivos",
+    "Personal files" : "Archivos personales",
+    "Additional settings" : "Configuraciones adicionales",
+    "Actions" : "Acciones",
+    "Selection" : "Selección",
+    "Deselect all" : "Deseleccionar todo",
+    "Navigation" : "Navegación",
+    "View" : "Ver",
+    "Toggle grid view" : "Vista de cuadrícula",
+    "WebDAV URL" : "WebDAV URL",
     "Total rows summary" : "Resumen de filas totales",
     "Toggle selection for all files and folders" : "Alternar selección para todos los archivos y carpetas",
     "Name" : "Nombre",
     "Size" : "Tamaño",
-    "Actions" : "Acciones",
+    "Modified" : "Modificado",
     "(selected)" : "(seleccionado)",
     "List of files and folders." : "Lista de archivos y carpetas.",
     "Column headers with buttons are sortable." : "Las columnas con botones en la cabecera son ordenables.",
     "This list is not fully rendered for performance reasons. The files will be rendered as you navigate through the list." : "Esta lista no se muestra completamente por motivos de rendimiento. Los archivos se mostrarán a medida que navega por la lista.",
     "File not found" : "Archivo no encontrado",
+    "Owner" : "Propietario",
     "{usedQuotaByte} used" : "{usedQuotaByte} utilizados",
     "{used} of {quota} used" : "{used} de {quota} usados",
     "{relative}% used" : "{relative}% utilizado",
@@ -132,34 +161,11 @@ OC.L10N.register(
     "Changing the file extension from \"{old}\" to \"{new}\" may render the file unreadable." : "Cambiar la extensión del archivo de \"{old}\" a \"{new}\" podría volver al archivo inaccesible.",
     "Removing the file extension \"{old}\" may render the file unreadable." : "Remover la extensión \"{old}\" podría volver al archivo inaccesible.",
     "Adding the file extension \"{new}\" may render the file unreadable." : "Añadir la extensión de archivo \"{new}\" podría volver al archivo inaccesible.",
+    "Cancel" : "Cancelar",
+    "Rename" : "Renombrar",
     "Select file or folder to link to" : "Seleccionar archivo o carpeta para enlazar.",
     "Choose {file}" : "Elegir {file}",
-    "Clipboard is not available" : "El portapapeles no está disponible",
     "Files settings" : "Configuración de archivos",
-    "General" : "General",
-    "All files" : "Todos los archivos",
-    "Personal files" : "Archivos personales",
-    "Sort favorites first" : "Ordenar los favoritos primero",
-    "Sort folders before files" : "Ordenar carpetas antes que archivos",
-    "Appearance" : "Apariencia",
-    "Show hidden files" : "Mostrar archivos ocultos",
-    "Crop image previews" : "Recortar la previsualización de las imágenes",
-    "Additional settings" : "Configuraciones adicionales",
-    "WebDAV" : "WebDAV",
-    "WebDAV URL" : "WebDAV URL",
-    "Copy" : "Copiar",
-    "Keyboard shortcuts" : "Atajos del teclado",
-    "Rename" : "Renombrar",
-    "Delete" : "Borrar",
-    "Manage tags" : "Administrar etiquetas",
-    "Selection" : "Selección",
-    "Deselect all" : "Deseleccionar todo",
-    "Navigation" : "Navegación",
-    "View" : "Ver",
-    "Toggle grid view" : "Vista de cuadrícula",
-    "Share" : "Compartir",
-    "Shared by link" : "Compartido por liga",
-    "Shared" : "Compartido",
     "Switch to list view" : "Cambiar a la vista de lista",
     "Switch to grid view" : "Cambiar a la vista de cuadrícula",
     "Upload was cancelled by user" : "La subida fue cancelada por el usuario",
@@ -174,13 +180,6 @@ OC.L10N.register(
     "Upload some content or sync with your devices!" : "¡Carga algún contenido o sincroniza con tus dispositivos!",
     "Go back" : "Regresar",
     "Views" : "Vistas",
-    "You" : "Usted",
-    "Shared multiple times with different people" : "Compartido múltiples veces con diferentes personas",
-    "Error while loading the file data" : "Error al cargar los datos del archivo",
-    "Owner" : "Propietario",
-    "Remove from favorites" : "Eliminar de favoritos",
-    "Add to favorites" : "Agregar a favoritos",
-    "Tags" : "Etiquetas",
     "Your files" : "Sus archivos",
     "Open in files" : "Abrir en archivos",
     "File cannot be accessed" : "No se puede acceder al archivo",
@@ -194,6 +193,7 @@ OC.L10N.register(
     "Pick a template for {name}" : "Elija una plantilla para {name}",
     "Create a new file with the selected template" : "Crear un nuevo archivo con la plantilla seleccionada",
     "Creating file" : "Creando el archivo",
+    "Delete" : "Borrar",
     "Leave this share" : "Dejar este recurso compartido",
     "Leave these shares" : "Dejar estos recursos compartidos",
     "Disconnect storage" : "Desconectar almacenamiento",
@@ -207,22 +207,22 @@ OC.L10N.register(
     "_You are about to permanently delete {count} item_::_You are about to permanently delete {count} items_" : ["Está a punto de eliminar {count} elemento permanentemente.","Está a punto de eliminar {count} elementos permanentemente.","Está a punto de eliminar {count} elementos permanentemente."],
     "_You are about to delete {count} item_::_You are about to delete {count} items_" : ["Está a punto de eliminar {count} elemento.","Está a punto de eliminar {count} elementos.","Está a punto de eliminar {count} elementos."],
     "Confirm deletion" : "Confirmar eliminación",
-    "Cancel" : "Cancelar",
     "Download" : "Descargar",
+    "Add to favorites" : "Agregar a favoritos",
+    "Remove from favorites" : "Eliminar de favoritos",
+    "Move" : "Mover",
+    "Copy" : "Copiar",
+    "Move or copy" : "Mover o copiar",
     "Destination is not a folder" : "El destino no es una carpeta",
     "This file/folder is already in that directory" : "Este archivo/carpeta ya está en ese directorio",
     "You cannot move a file/folder onto itself or into a subfolder of itself" : "No puede mover un archivo/carpeta a sí mismo o a una subcarpeta de sí mismo",
-    "(copy)" : "(copiar)",
-    "(copy %n)" : "(copiar %n)",
     "A file or folder with that name already exists in this folder" : "Un archivo o carpeta con ese nombre ya existe en esta carpeta",
     "The files are locked" : "Los archivos están bloqueados",
     "The file does not exist anymore" : "El archivo ya no existe",
     "Choose destination" : "Elegir destino",
     "Copy to {target}" : "Copiar a {target}",
     "Move to {target}" : "Mover a {target}",
-    "Move" : "Mover",
     "Move or copy operation failed" : "La operación de mover o copiar falló",
-    "Move or copy" : "Mover o copiar",
     "Open folder {displayName}" : "Abrir carpeta {displayName}",
     "Open in Files" : "Abrir en Archivos",
     "Failed to redirect to client" : "Fallo al redirigir al cliente",
@@ -230,19 +230,7 @@ OC.L10N.register(
     "Retry and close" : "Reintentar y cerrar",
     "Details" : "Detalles",
     "View in folder" : "Ver en la carpeta",
-    "Today" : "Hoy",
-    "Last 7 days" : "Últimos 7 días",
-    "Last 30 days" : "Últimos 30 días",
-    "This year ({year})" : "Este año ({year})",
-    "Last year ({year})" : "El año pasado ({year})",
-    "Documents" : "Documentos",
-    "Spreadsheets" : "Hojas de cálculo",
-    "Presentations" : "Presentaciones",
-    "PDFs" : "PDFs",
-    "Folders" : "Carpetas",
-    "Audio" : "Audio",
-    "Images" : "Imágenes",
-    "Videos" : "Videos",
+    "Type" : "Tipo",
     "Created new folder \"{name}\"" : "Nueva carpeta \"{name}\" creada",
     "Unable to initialize the templates directory" : "No se ha podido iniciar la carpeta de plantillas",
     "Create templates folder" : "Crear la carpeta de plantillas",
@@ -257,10 +245,10 @@ OC.L10N.register(
     "Some files could not be uploaded" : "No se pudieron subir algunos archivos",
     "Files uploaded successfully" : "Archivo subido exitosamente",
     "No files to process" : "No hay archivos a procesar",
-    "Some files could not be copied" : "Algunos archivos no se pudieron copiar",
-    "Some files could not be moved" : "Algunos archivos no se pudieron mover",
     "Files copied successfully" : "Archivos copiados exitosamente",
     "Files moved successfully" : "Archivos movidos exitosamente",
+    "Some files could not be copied" : "Algunos archivos no se pudieron copiar",
+    "Some files could not be moved" : "Algunos archivos no se pudieron mover",
     "Conflicts resolution skipped" : "Resolución de conflictos omitida",
     "Upload cancelled" : "Subida cancelada",
     "Could not rename \"{oldName}\", it does not exist any more" : "No se pudo renombrar \"{oldName}\", ya no existe.",
@@ -293,19 +281,32 @@ OC.L10N.register(
     "Upload too large" : "La carga es demasido grande",
     "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Los archivos que estás intentando cargar sobrepasan el tamaño máximo permitido para la carga de archivos en este servidor.",
     "Upload (max. %s)" : "Cargar (max. %s)",
+    "Renamed \"{oldName}\" to \"{newName}\"" : "Renombrado \"{oldName}\" a \"{newName}\"",
+    "Clear filter" : "Limpiar filtro",
     "\"{displayName}\" batch action executed successfully" : "La acción en lote \"{displayName}\" se ejecutó exitosamente",
     "\"{displayName}\" action failed" : "La acción \"{displayName}\" falló",
+    "Shared by link" : "Compartido por liga",
+    "Shared" : "Compartido",
     "\"{displayName}\" action executed successfully" : "La acción \"{displayName}\" se ejecutó correctamente",
+    "Clipboard is not available" : "El portapapeles no está disponible",
     "WebDAV URL copied to clipboard" : "WebDAV URL copiada al portapapeles",
     "Enable the grid view" : "Habilitar la vista de cuadrícula",
     "Enable folder tree" : "Habilitar el árbol de carpetas",
+    "WebDAV" : "WebDAV",
     "Copy to clipboard" : "Copiar al portapapeles",
     "Use this address to access your Files via WebDAV" : "Use esta dirección para acceder a tus archivos vía WebDAV",
     "If you have enabled 2FA, you must create and use a new app password by clicking here." : "Si ha habilitado 2FA, debe crear y utilizar una nueva contraseña de aplicación haciendo clic aquí.",
+    "Keyboard shortcuts" : "Atajos del teclado",
+    "You" : "Usted",
+    "Shared multiple times with different people" : "Compartido múltiples veces con diferentes personas",
+    "Error while loading the file data" : "Error al cargar los datos del archivo",
+    "Tags" : "Etiquetas",
     "Deletion cancelled" : "Eliminación cancelada",
     "Edit locally" : "Editar localmente",
     "Moving \"{source}\" to \"{destination}\" …" : "Moviendo \"{source}\" a \"{destination}\" …",
     "Copying \"{source}\" to \"{destination}\" …" : "Copiando \"{source}\" a \"{destination}\" …",
+    "(copy)" : "(copiar)",
+    "(copy %n)" : "(copiar %n)",
     "Move cancelled" : "Movimiento cancelado",
     "Cancelled move or copy of \"{filename}\"." : "Se canceló la operación de mover o copiar de \"{filename}\".",
     "Cancelled move or copy operation" : "Se canceló la operación de mover o copiar",
