@@ -78,6 +78,8 @@ OC.L10N.register(
     "Reload current directory" : "Laadi see kaust uuesti",
     "Go to the \"{dir}\" directory" : "Mine kausta „{dir}“",
     "Current directory path" : "Praeguse kausta asukoht",
+    "Share" : "Jaga",
+    "Reload content" : "Laadi sisu uuesti",
     "Your have used your space quota and cannot upload files anymore" : "Sa oled kasutanud ära kogu oma andmeruumi kvoodi ega saa rohkem faile üles laadida.",
     "You do not have permission to upload or create files here." : "Sul puuduvad õigused siia failide üleslaadimiseks või loomiseks.",
     "Drag and drop files here to upload" : "Üleslaadimiseks lohista failid siia",
@@ -92,7 +94,6 @@ OC.L10N.register(
     "This node is unavailable" : "See sõlm pole saadaval",
     "Another entry with the same name already exists." : "Selle nimega kirje on juba olemas.",
     "Invalid filename." : "Vigane failinimi.",
-    "Renamed \"{oldName}\" to \"{newName}\"" : "Failinimi on muutunud „{oldName}“ ⇨ „{newName}“",
     "Rename file" : "Muuda failinime",
     "Folder" : "Kaust",
     "Unknown file type" : "Tundmatu failitüüp",
@@ -102,12 +103,26 @@ OC.L10N.register(
     "{ext} text" : "{ext} tekst",
     "Pending" : "Ootel",
     "Unknown date" : "Tundmatu kuupäev",
-    "Clear filter" : "Tühjenda filter",
-    "Modified" : "Muudetud",
-    "Search everywhere" : "Otsi kõikjalt",
-    "Type" : "Tüüp",
     "Active filters" : "Aktiivsed filtrid",
     "Remove filter" : "Eemalda filter",
+    "Today" : "Täna",
+    "Last 7 days" : "Viimase 7 päeva jooksul",
+    "Last 30 days" : "Viimase 30 päeva jooksul",
+    "This year ({year})" : "Sel aastal ({year})",
+    "Last year ({year})" : "Eelmisel aastal ({year})",
+    "Custom range" : "Valitud vahemik",
+    "Custom date range" : "Sinu valitud kuupäevavahemik",
+    "Search everywhere" : "Otsi kõikjalt",
+    "Documents" : "Dokumendid",
+    "Spreadsheets" : "Arvutustabelid",
+    "Presentations" : "Esitlused",
+    "PDFs" : "PDF-failid",
+    "Folders" : "Kaustad",
+    "Audio" : "Helifailid",
+    "Images" : "Pildid",
+    "Videos" : "Videod",
+    "Filters" : "Filtrid",
+    "Back to filters" : "Tagasi filtrite juurde",
     "Appearance" : "Välimus",
     "Show hidden files" : "Näita peidetud faile",
     "Show file type column" : "Näita failitüübi veergu",
@@ -136,7 +151,6 @@ OC.L10N.register(
     "Go right in grid" : "Mine ruudustikus paremale",
     "View" : "Vaata",
     "Toggle grid view" : "Lülita ruudustikuvaade sisse/välja",
-    "Open file sidebar" : "Ava failide külgriba",
     "Show those shortcuts" : "Näita neid otseteid",
     "Warnings" : "Hoiatused",
     "Warn before changing a file extension" : "Hoiata enne faililaiendi muutmist",
@@ -150,6 +164,7 @@ OC.L10N.register(
     "Name" : "Nimi",
     "File type" : "Failitüüp",
     "Size" : "Suurus",
+    "Modified" : "Muudetud",
     "{displayName}: failed on some elements" : "{displayName}: ei toiminud mõne objekti puhul",
     "{displayName}: done" : "{displayName}: valmis",
     "{displayName}: failed" : "{displayName}: ei õnnestunud",
@@ -164,6 +179,7 @@ OC.L10N.register(
     "Search here …" : "Otsi siin…",
     "Search scope options" : "Otsinguulatuse valikud",
     "Search here" : "Otsi siin",
+    "Owner" : "Omanik",
     "{usedQuotaByte} used" : "{usedQuotaByte} kasutusel",
     "{used} of {quota} used" : "{used} / {quota} kasutusel",
     "{relative}% used" : "{relative}% kasutusel",
@@ -217,12 +233,14 @@ OC.L10N.register(
     "Removing the file extension \"{old}\" may render the file unreadable." : "„{old}“ faililaiendi eemaldamine võib muuta faili loetamatuks.",
     "Adding the file extension \"{new}\" may render the file unreadable." : "„{new}“ faililaiendi lisamine võib muuta faili loetamatuks.",
     "Do not show this dialog again." : "Ära näita seda vaadet enam uuesti.",
+    "Rename file to hidden" : "Oled muutmas faili peidetuks",
+    "Prefixing a filename with a dot may render the file hidden." : "Kui lisad faili algusesse punkt, siis ta võib muutuda peidetuks.",
+    "Are you sure you want to rename the file to \"{filename}\"?" : "Kas sa tahad uueks faillinimeks muuta „{filename}“?",
+    "Cancel" : "Loobu",
+    "Rename" : "Muuda nime",
     "Select file or folder to link to" : "Vali lingitav fail või kaust",
     "Choose {file}" : "Vali „{file}“",
     "Files settings" : "Failide seadistused",
-    "Share" : "Jaga",
-    "Shared by link" : "Jagatud lingiga",
-    "Shared" : "Jagatud",
     "Switch to list view" : "Kasuta loendivaadet",
     "Switch to grid view" : "Kasuta ruudustikuvaadet",
     "The file could not be found" : "Seda faili ei õnnestu leida",
@@ -232,20 +250,14 @@ OC.L10N.register(
     "Error during upload: {message}" : "Viga üleslaadimisel: {message}",
     "Error during upload, status code {status}" : "Viga üleslaadimisel, olekukood {status} ",
     "Unknown error during upload" : "Tundmatu viga üleslaadimisel",
+    "File list is reloading" : "Faililoend on laadimisel",
     "Loading current folder" : "Laadin käesolevat kausta",
     "Retry" : "Proovi uuesti",
     "No files in here" : "Siin ei ole faile",
     "Upload some content or sync with your devices!" : "Laadi sisu üles või süngi oma seadmetega!",
     "Go back" : "Mine tagasi",
     "Views" : "Vaated",
-    "You" : "Sina",
-    "Shared multiple times with different people" : "Jagatud mitu korda eri kasutajate poolt",
-    "Unable to change the favorite state of the file" : "Faili olekut lemmikuna ei õnnestu muuta",
-    "Error while loading the file data" : "Viga faili andmete laadimisel",
-    "Owner" : "Omanik",
-    "Remove from favorites" : "Eemalda lemmikutest",
-    "Add to favorites" : "Lisa lemmikutesse",
-    "Tags" : "Sildid",
+    "Loading …" : "Andmed on laadimisel…",
     "Your files" : "Sinu failid",
     "Open in files" : "Ava failirakenduses",
     "File cannot be accessed" : "Failile ligipääs puudub",
@@ -273,7 +285,7 @@ OC.L10N.register(
     "_%n file converted_::_%n files converted_" : ["%n fail on teisendatud","%n faili on teisendatud"],
     "Files converted" : "Failid on teisendatud",
     "Failed to convert files" : "Failide teisendamine ei õnnestunud",
-    "Converting file …" : "Teisendan faile…",
+    "Converting file …" : "Teisendan faili…",
     "File successfully converted" : "Faili teisendamine õnnestus",
     "Failed to convert file: {message}" : "Faili teisendamine ei õnnestunud: {message}",
     "Failed to convert file" : "Faili teisendamine ei õnnestunud",
@@ -291,28 +303,30 @@ OC.L10N.register(
     "_You are about to permanently delete {count} item_::_You are about to permanently delete {count} items_" : ["Sa oled jäädavalt kustutamas {count} objekti","Sa oled jäädavalt kustutamas {count} objekti"],
     "_You are about to delete {count} item_::_You are about to delete {count} items_" : ["Sa oled kustutamas {count} objekti","Sa oled kustutamas {count} objekti"],
     "Confirm deletion" : "Kinnita kustutamine",
-    "Cancel" : "Loobu",
     "Download" : "Laadi alla",
     "The requested file is not available." : "Soovitud fail pole saadaval.",
     "The requested files are not available." : "Soovitud failid pole saadaval.",
+    "Add to favorites" : "Lisa lemmikutesse",
+    "Remove from favorites" : "Eemalda lemmikutest",
     "Add or remove favorite" : "Lisa või eemalda lemmik",
-    "Moving \"{source}\" to \"{destination}\" …" : "Teisaldan „{source}“ → „{destination}“…",
-    "Copying \"{source}\" to \"{destination}\" …" : "Kopeerin „{source}“ → „{destination}“…",
+    "Move" : "Teisalda",
+    "Copy" : "Kopeeri",
+    "Move or copy" : "Liiguta või kopeeri",
     "Destination is not a folder" : "Sihtasukoht pole kaust",
     "This file/folder is already in that directory" : "See fail või kaust juba asub selles kaustas",
     "You cannot move a file/folder onto itself or into a subfolder of itself" : "Sa ei saa faili või kausta iseendaks teisaldada ega teisaldada kausta iseenda alamkausta",
-    "(copy)" : "(koopia)",
-    "(copy %n)" : "(%n koopia)",
     "A file or folder with that name already exists in this folder" : "Selles kaustas juba on olemas sama nimega fail või kaust",
     "The files are locked" : "Need failid on lukustatud",
     "The file does not exist anymore" : "Neid faile pole enam olemas",
+    "Moving \"{source}\" to \"{destination}\" …" : "Teisaldan „{source}“ → „{destination}“…",
+    "Moving {count} files to \"{destination}\" …" : "Tõstan {count} faili „{destination}“ kausta…",
+    "Copying \"{source}\" to \"{destination}\" …" : "Kopeerin „{source}“ → „{destination}“…",
+    "Copying {count} files to \"{destination}\" …" : "Kopeerin {count} faili „{destination}“ kausta…",
     "Choose destination" : "Vali sihtkaust",
     "Copy to {target}" : "Kopeeri kausta {target}",
-    "Copy" : "Kopeeri",
     "Move to {target}" : "Teisalda kausta {target}",
-    "Move" : "Teisalda",
     "Move or copy operation failed" : "Teisaldamine või kopeerimine ei õnnestunud",
-    "Move or copy" : "Liiguta või kopeeri",
+    "Open folder" : "Ava kaust",
     "Open folder {displayName}" : "Ava kaust {displayName}",
     "Open in Files" : "Ava failirakenduses",
     "Open locally" : "Ava kohalikust andmeruumist",
@@ -321,28 +335,18 @@ OC.L10N.register(
     "The file should now open on your device. If it doesn't, please check that you have the desktop app installed." : "Fail peaks nüüd sinu seadmes või arvutis olema avatud. Kui see nii pole, siis palun kontrolli, et töölauarakendus on paigaldatud.",
     "Retry and close" : "Proovi uuesti ja sulge",
     "Open online" : "Ava võrgust",
-    "Rename" : "Muuda nime",
     "Details" : "Üksikasjad",
+    "Open the details sidebar" : "Ava üksikasjade külgpaan",
+    "Unfavorite" : "Eemalda lemmikute seast",
     "View in folder" : "Vaata kaustas",
-    "Today" : "Täna",
-    "Last 7 days" : "Viimase 7 päeva jooksul",
-    "Last 30 days" : "Viimase 30 päeva jooksul",
-    "This year ({year})" : "Sel aastal ({year})",
-    "Last year ({year})" : "Eelmisel aastal ({year})",
-    "Documents" : "Dokumendid",
-    "Spreadsheets" : "Arvutustabelid",
-    "Presentations" : "Esitlused",
-    "PDFs" : "PDF-failid",
-    "Folders" : "Kaustad",
-    "Audio" : "Helifailid",
-    "Images" : "Pildid",
-    "Videos" : "Videod",
+    "Type" : "Tüüp",
     "Created new folder \"{name}\"" : "Uus „{name}“ kaust on loodud",
     "Unable to initialize the templates directory" : "Mallide kausta loomine ebaõnnestus",
     "Create templates folder" : "Loo mallide kaust",
     "Templates" : "Mallid",
     "New template folder" : "Uus kaustamall",
     "In folder" : "Kaustas",
+    "Pick folder to search in" : "Vali kaust, kus soovid otsida",
     "Search in all files" : "Otsi kõikide failide seast",
     "Search in folder: {folder}" : "Otsi kaustast: {folder}",
     "One of the dropped files could not be processed" : "Ühte siia lisatud failidest ei õnnestunud töödelda",
@@ -352,10 +356,10 @@ OC.L10N.register(
     "Some files could not be uploaded" : "Mõnda faili ei saanud üles laadida",
     "Files uploaded successfully" : "Failide üleslaadimine õnnestus",
     "No files to process" : "Töödeldavaid faile pole",
-    "Some files could not be copied" : "Mõnda faili ei saanud kopeerida",
-    "Some files could not be moved" : "Mõnda faili ei saanud teisaldada",
     "Files copied successfully" : "Failide kopeerimine õnnestus",
     "Files moved successfully" : "Failide teisaldamine õnnestus",
+    "Some files could not be copied" : "Mõnda faili ei saanud kopeerida",
+    "Some files could not be moved" : "Mõnda faili ei saanud teisaldada",
     "Conflicts resolution skipped" : "Andmekonfilkti lahendamine jäi vahele",
     "Upload cancelled" : "Üleslaadimine on katkestatud",
     "Could not rename \"{oldName}\", it does not exist any more" : "„{oldName}“ faili nime muutmine ei õnnestunud, seda pole enam olemas",
@@ -396,10 +400,14 @@ OC.L10N.register(
     "Upload (max. %s)" : "Üleslaadimine (max. %s)",
     "After enabling the windows compatible filenames, existing files cannot be modified anymore but can be renamed to valid new names by their owner." : "Kui võtad kasutusele Windowsiga ühilduvad failinimed, siis olemasolevad mitteühilduvaid faile ei saa enam muuta, aga faili omanik saab failinime muuta ühilduvaks.",
     "It is also possible to migrate files automatically after enabling this setting, please refer to the documentation about the occ command." : "Lisaks on peale selle seadistuse kasutuselevõtmist võimalik kõik mitteühilduvad failid automaatselt ära muuta. Asjakohast teavet leiad kasutusjuhendist occ-käsku kirjeldavast peatükist.",
+    "Renamed \"{oldName}\" to \"{newName}\"" : "Failinimi on muutunud „{oldName}“ ⇨ „{newName}“",
+    "Clear filter" : "Tühjenda filter",
     "\"{displayName}\" failed on some elements" : "„{displayName}“ ei toiminud mõne objekti puhul",
     "\"{displayName}\" batch action executed successfully" : "Pakktöötlus õnnestus: „{displayName}“",
     "\"{displayName}\" action failed" : "Tegevus ei õnnestunud: „{displayName}“",
     "Submitting fields …" : "Saadan välju…",
+    "Shared by link" : "Jagatud lingiga",
+    "Shared" : "Jagatud",
     "\"{displayName}\" action executed successfully" : "Toiming õnnestus: „{displayName}“",
     "Filter file names …" : "Otsi failinimesid…",
     "Clipboard is not available" : "Lõikelaud ei ole saadaval",
@@ -429,6 +437,11 @@ OC.L10N.register(
     "Navigate to the file on the right (in grid mode)" : "Liigu parempoolse faili juurde (ruudustikuvaates)",
     "Toggle the grid view" : "Lülita ruudustikuvaade sisse/välja",
     "Open the sidebar for a file" : "Ava faili külgriba",
+    "You" : "Sina",
+    "Shared multiple times with different people" : "Jagatud mitu korda eri kasutajate poolt",
+    "Unable to change the favorite state of the file" : "Faili olekut lemmikuna ei õnnestu muuta",
+    "Error while loading the file data" : "Viga faili andmete laadimisel",
+    "Tags" : "Sildid",
     "Save as …" : "Salvesta kui…",
     "Converting files …" : "Teisendan faile…",
     "Converting file …" : "Teisendan faili…",
@@ -436,6 +449,8 @@ OC.L10N.register(
     "Edit locally" : "Muuda lokaalselt",
     "Moving \"{source}\" to \"{destination}\" …" : "Teisaldan „{source}“ → „{destination}“…",
     "Copying \"{source}\" to \"{destination}\" …" : "Kopeerin „{source}“ → „{destination}“…",
+    "(copy)" : "(koopia)",
+    "(copy %n)" : "(%n koopia)",
     "Move cancelled" : "Teisaldamine on katkestatud",
     "Cancelled move or copy of \"{filename}\"." : "„{filename}“ faili teisaldamine või kopeerimine on katkestatud.",
     "Cancelled move or copy operation" : "Teisaldamine või kopeerimine on katkestatud",
@@ -444,6 +459,7 @@ OC.L10N.register(
     "New folder creation cancelled" : "Uue kausta loomine on katkestatud",
     "This directory is unavailable, please check the logs or contact the administrator" : "See kaust pole saadaval, palun kontrolli logifaile või võta ühendust administraatoriga",
     "All folders" : "Kõik kaustad",
+    "Open file sidebar" : "Ava failide külgriba",
     "Search everywhere …" : "Otsi kõikjalt…",
     "Search here …" : "Otsi siin…",
     "Preparing …" : "Ettevalmistamisel…"
