@@ -75,6 +75,8 @@ OC.L10N.register(
     "Reload current directory" : "Lataa nykyinen kansio uudelleen",
     "Go to the \"{dir}\" directory" : "Siirry kansioon \"{dir}\"",
     "Current directory path" : "Nykyisen kansion polku",
+    "Share" : "Jaa",
+    "Reload content" : "Lataa sisältö uudelleen",
     "Your have used your space quota and cannot upload files anymore" : "Olet käyttänyt tilakiintiösi, joten et voi lähettää enempää tiedostoja",
     "You do not have permission to upload or create files here." : "Käyttöoikeutesi eivät riitä tiedostojen lähettämiseen tai luomiseen tänne.",
     "Drag and drop files here to upload" : "Vedä ja pudota tiedostot tähän lähettääksesi",
@@ -85,7 +87,6 @@ OC.L10N.register(
     "Filename" : "Tiedostonimi",
     "Folder name" : "Kansion nimi",
     "Invalid filename." : "Epäkelpo tiedostonimi.",
-    "Renamed \"{oldName}\" to \"{newName}\"" : "Kohteen \"{oldName}\" uudeksi nimeksi asetettiin \"{newName}\"",
     "Rename file" : "Nimeä tiedosto uudelleen",
     "Folder" : "Kansio",
     "Unknown file type" : "Tuntematon tiedostotyyppi",
@@ -95,12 +96,24 @@ OC.L10N.register(
     "{ext} text" : "{ext} teksti",
     "Pending" : "Odottaa",
     "Unknown date" : "Tuntematon päivämäärä",
-    "Clear filter" : "Tyhjennä suodatin",
-    "Modified" : "Muokattu",
-    "Search everywhere" : "Etsi kaikkialta",
-    "Type" : "Tyyppi",
     "Active filters" : "Aktiiviset suodattimet",
     "Remove filter" : "Poista suodatin",
+    "Today" : "Tänään",
+    "Last 7 days" : "Edelliset 7 päivää",
+    "Last 30 days" : "Edelliset 30 päivää",
+    "This year ({year})" : "Tämä vuosi ({year})",
+    "Last year ({year})" : "Viime vuosi ({year})",
+    "Custom date range" : "Mukautettu päivämääräväli",
+    "Search everywhere" : "Etsi kaikkialta",
+    "Documents" : "Asiakirjat",
+    "Spreadsheets" : "Laskentataulukot",
+    "Presentations" : "Esitykset",
+    "PDFs" : "PDF-tiedostot",
+    "Folders" : "Kansiot",
+    "Audio" : "Ääni",
+    "Images" : "Kuvat",
+    "Videos" : "Videot",
+    "Filters" : "Suodattimet",
     "Appearance" : "Ulkoasu",
     "Show hidden files" : "Näytä piilotetut tiedostot",
     "Show file type column" : "Näytä tiedostotyypin sarake",
@@ -126,14 +139,15 @@ OC.L10N.register(
     "Go right in grid" : "Siirry oikealle ruudukossa",
     "View" : "Näytä",
     "Toggle grid view" : "Ruudukkonäkymä päälle/pois",
-    "Open file sidebar" : "Avaa tiedoston sivupalkki",
     "Warnings" : "Varoitukset",
     "Warn before changing a file extension" : "Varoita ennen tiedostopäätteen muuttamista",
+    "Warn before deleting a file" : "Varoita ennen tiedoston poistamista",
     "WebDAV URL" : "WebDAV:in URL-osoite",
     "Create an app password" : "Luo sovellussalasana",
     "Name" : "Nimi",
     "File type" : "Tiedoston tyyppi",
     "Size" : "Koko",
+    "Modified" : "Muokattu",
     "{displayName}: done" : "{displayName}: valmis",
     "{displayName}: failed" : "{displayName}: epäonnistui",
     "(selected)" : "(valittu)",
@@ -143,7 +157,10 @@ OC.L10N.register(
     "This list is not fully rendered for performance reasons. The files will be rendered as you navigate through the list." : "Tätä luetteloa ei ole esitetty täysin suorituskykyyn liittyvistä syistä. Tiedostot esitetään sitä mukaa, kun selaat luetteloa.",
     "File not found" : "Tiedostoa ei löytynyt",
     "_{count} selected_::_{count} selected_" : ["{count} valittu","{count} valittu"],
+    "Search everywhere …" : "Etsi kaikkialta …",
+    "Search here …" : "Etsi täältä …",
     "Search here" : "Etsi tästä",
+    "Owner" : "Omistaja",
     "{usedQuotaByte} used" : "{usedQuotaByte} käytetty",
     "{used} of {quota} used" : "{used}/{quota} käytetty",
     "{relative}% used" : "{relative} % käytetty",
@@ -158,6 +175,7 @@ OC.L10N.register(
     "Files starting with a dot are hidden by default" : "Pisteellä alkavat tiedostot ovat oletusarvoisesti piilotettuja",
     "Failed to start filename sanitization." : "Tiedostonimien siistimisen käynnistäminen epäonnistui.",
     "Filename sanitization in progress." : "Tiedostonimien siistiminen käynnissä.",
+    "Preparing …" : "Valmistellaan …",
     "Refresh" : "Päivitä",
     "Sanitization errors" : "Siistimisvirheet",
     "Windows filename support has been enabled." : "Windows-tiedostonimien tuki on otettu käyttöön.",
@@ -184,12 +202,11 @@ OC.L10N.register(
     "Removing the file extension \"{old}\" may render the file unreadable." : "Tiedostopäätteen \"{old}\" poistaminen saattaa tehdä tiedostosta lukukelvottoman.",
     "Adding the file extension \"{new}\" may render the file unreadable." : "Tiedostopäätteen \"{new}\" lisääminen saattaa tehdä tiedostosta lukukelvottoman.",
     "Do not show this dialog again." : "Älä näytä uudelleen",
+    "Cancel" : "Peruuta",
+    "Rename" : "Nimeä uudelleen",
     "Select file or folder to link to" : "Valitse tiedosto tai kansio, johon linkitetään",
     "Choose {file}" : "Valitse {file}",
     "Files settings" : "Tiedostojen asetukset",
-    "Share" : "Jaa",
-    "Shared by link" : "Jaettu linkillä",
-    "Shared" : "Jaettu",
     "Switch to list view" : "Vaihda taulukkonäkymään",
     "Switch to grid view" : "Vaihda ruudukkonäkymään",
     "The file could not be found" : "Tiedostoa ei löytynyt",
@@ -205,13 +222,7 @@ OC.L10N.register(
     "Upload some content or sync with your devices!" : "Lähetä tiedostoja tai synkronoi sisältö laitteidesi kanssa!",
     "Go back" : "Mene takaisin",
     "Views" : "Näkymät",
-    "You" : "Sinä",
-    "Shared multiple times with different people" : "Jaettu useita kertoja eri ihmisten kanssa",
-    "Error while loading the file data" : "Virhe tiedostoa ladatessa",
-    "Owner" : "Omistaja",
-    "Remove from favorites" : "Poista suosikeista",
-    "Add to favorites" : "Lisää suosikkeihin",
-    "Tags" : "Tunnisteet",
+    "Loading …" : "Ladataan …",
     "Your files" : "Tiedostot",
     "Open in files" : "Avaa tiedostosovelluksessa",
     "File cannot be accessed" : "Tiedostoa ei voi käyttää",
@@ -226,10 +237,15 @@ OC.L10N.register(
     "Create a new file with the selected template" : "Luo uusi tiedosto valitulla mallipohjalla",
     "Creating file" : "Luodaan tiedostoa",
     "Save as {displayName}" : "Tallenna nimellä {displayName}",
+    "Save as …" : "Tallenna nimellä …",
+    "Converting files …" : "Muunnetaan tiedostoja …",
     "Failed to convert files: {message}" : "Tiedostojen muuntaminen epäonnistui: {message}",
     "All files failed to be converted" : "Mitään tiedostoista ei voitu muuntaa",
     "One file could not be converted: {message}" : "Yhtä tiedostoa ei voitu muuntaa: {message}",
+    "_%n file could not be converted_::_%n files could not be converted_" : ["%n tiedostoa ei voitu muuntaa","%n tiedostoa ei voitu muuntaa"],
+    "_%n file converted_::_%n files converted_" : ["%n tiedosto muunnettu","%n tiedostoa muunnettu"],
     "Failed to convert files" : "Tiedostojen muuntaminen epäonnistui",
+    "Converting file …" : "Muunnetaan tiedosto …",
     "File successfully converted" : "Tiedosto muunnettu onnistuneesti",
     "Failed to convert file: {message}" : "Tiedoston muuntaminen epäonnistui: {message}",
     "Failed to convert file" : "Tiedoston muuntaminen epäonnistui",
@@ -246,47 +262,38 @@ OC.L10N.register(
     "_You are about to permanently delete {count} item_::_You are about to permanently delete {count} items_" : ["Olet poistamassa {count} kohteen lopullisesti","Olet poistamassa {count} kohdetta lopullisesti"],
     "_You are about to delete {count} item_::_You are about to delete {count} items_" : ["Olet poistamassa {count} kohteen","Olet poistamassa {count} kohdetta"],
     "Confirm deletion" : "Vahvista poistaminen",
-    "Cancel" : "Peruuta",
     "Download" : "Lataa",
     "The requested file is not available." : "Pyydetty tiedosto ei ole saatavilla.",
     "The requested files are not available." : "Pyydetyt tiedostot eivät ole saatavilla.",
-    "Moving \"{source}\" to \"{destination}\" …" : "Siirretään \"{source}\" kohteeseen \"{destination}\" …",
-    "Copying \"{source}\" to \"{destination}\" …" : "Kopioidaan \"{source}\" kohteeseen \"{destination}\" …",
+    "Add to favorites" : "Lisää suosikkeihin",
+    "Remove from favorites" : "Poista suosikeista",
+    "Add or remove favorite" : "Lisää tai poista suosikki",
+    "Move" : "Siirrä",
+    "Copy" : "Kopioi",
+    "Move or copy" : "Siirrä tai kopioi",
     "Destination is not a folder" : "Kohde ei ole kansio",
     "This file/folder is already in that directory" : "Tämä tiedosto/kansio on jo kyseisessä kansiossa",
-    "(copy)" : "(kopioi)",
     "A file or folder with that name already exists in this folder" : "Tiedosto tai kansio tällä nimellä on jo olemassa tässä kansiossa",
     "The files are locked" : "Tiedostot on lukittu",
     "The file does not exist anymore" : "Tiedostoa ei ole enää olemassa",
+    "Moving \"{source}\" to \"{destination}\" …" : "Siirretään \"{source}\" kohteeseen \"{destination}\" …",
+    "Copying \"{source}\" to \"{destination}\" …" : "Kopioidaan \"{source}\" kohteeseen \"{destination}\" …",
     "Choose destination" : "Valitse kohde",
     "Copy to {target}" : "Kopioi kohteeseen {target}",
-    "Copy" : "Kopioi",
     "Move to {target}" : "Siirrä kohteeseen {target}",
-    "Move" : "Siirrä",
     "Move or copy operation failed" : "Siirto- tai kopiointitoiminto epäonnistui",
-    "Move or copy" : "Siirrä tai kopioi",
+    "Open folder" : "Avaa kansio",
     "Open folder {displayName}" : "Avaa kansio {displayName}",
     "Open in Files" : "Avaa tiedostosovelluksessa",
     "Open locally" : "Avaa paikallisesti",
     "Failed to redirect to client" : "Uudelleenohjaus asiakkaaseen epäonnistui",
     "Open file locally" : "Avaa tiedosto paikallisesti",
+    "The file should now open on your device. If it doesn't, please check that you have the desktop app installed." : "Tiedoston pitäisi nyt avautua laitteellasi. Jos se ei avaudu, varmista että sinulla työpöytäsovellus asennettuna.",
     "Retry and close" : "Yritä uudelleen ja sulje",
-    "Rename" : "Nimeä uudelleen",
     "Details" : "Tiedot",
+    "Unfavorite" : "Poista suosikeista",
     "View in folder" : "Näe kansiossa",
-    "Today" : "Tänään",
-    "Last 7 days" : "Edelliset 7 päivää",
-    "Last 30 days" : "Edelliset 30 päivää",
-    "This year ({year})" : "Tämä vuosi ({year})",
-    "Last year ({year})" : "Viime vuosi ({year})",
-    "Documents" : "Asiakirjat",
-    "Spreadsheets" : "Laskentataulukot",
-    "Presentations" : "Esitykset",
-    "PDFs" : "PDF-tiedostot",
-    "Folders" : "Kansiot",
-    "Audio" : "Ääni",
-    "Images" : "Kuvat",
-    "Videos" : "Videot",
+    "Type" : "Tyyppi",
     "Created new folder \"{name}\"" : "Luotu uusi kansio \"{name}\"",
     "Unable to initialize the templates directory" : "Mallipohjien kansiota ei voitu alustaa",
     "Create templates folder" : "Luo mallipohjien kansio",
@@ -302,10 +309,10 @@ OC.L10N.register(
     "Some files could not be uploaded" : "Joitain tiedostoja ei voitu lähettää",
     "Files uploaded successfully" : "Tiedostot lähetetty onnistuneesti",
     "No files to process" : "Ei tiedostoja käsiteltäväksi",
-    "Some files could not be copied" : "Joitain tiedostoja ei voitu kopioida",
-    "Some files could not be moved" : "Joitain tiedostoja ei voitu siirtää",
     "Files copied successfully" : "Tiedostot kopioitu onnistuneesti",
     "Files moved successfully" : "Tiedostot siirretty onnistuneesti",
+    "Some files could not be copied" : "Joitain tiedostoja ei voitu kopioida",
+    "Some files could not be moved" : "Joitain tiedostoja ei voitu siirtää",
     "Upload cancelled" : "Lataus peruutettu",
     "Could not rename \"{oldName}\", it does not exist any more" : "Kohdetta \"{oldName}\" ei voitu nimetä uudelleen, koska sitä ei ole enää olemassa",
     "The name \"{newName}\" is already used in the folder \"{dir}\". Please choose a different name." : "Nimi \"{newName}\" on jo käytössä kansiossa \"{dir}\". Valitse toinen nimi.",
@@ -342,7 +349,11 @@ OC.L10N.register(
     "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Lähetettäväksi valitsemasi tiedostot ylittävät palvelimen salliman tiedostokoon rajan.",
     "%1$s (renamed)" : "%1$s (nimetty uudelleen)",
     "Upload (max. %s)" : "Lähetys (enintään %s)",
+    "Renamed \"{oldName}\" to \"{newName}\"" : "Kohteen \"{oldName}\" uudeksi nimeksi asetettiin \"{newName}\"",
+    "Clear filter" : "Tyhjennä suodatin",
     "\"{displayName}\" batch action executed successfully" : "\"{displayName}\" massatoiminto suoritettu",
+    "Shared by link" : "Jaettu linkillä",
+    "Shared" : "Jaettu",
     "Filter file names …" : "Suodata tiedostonimiä…",
     "Clipboard is not available" : "Leikepöytä ei ole käytettävissä",
     "WebDAV URL copied to clipboard" : "WebDAV-osoite kopioitu leikepöydälle",
@@ -369,6 +380,10 @@ OC.L10N.register(
     "Navigate to the file on the right (in grid mode)" : "Siirry oikealla olevaan tiedostoon (ruudukkotilassa)",
     "Toggle the grid view" : "Ruudukkonäkymä päälle/pois",
     "Open the sidebar for a file" : "Avaa tiedoston sivupalkki",
+    "You" : "Sinä",
+    "Shared multiple times with different people" : "Jaettu useita kertoja eri ihmisten kanssa",
+    "Error while loading the file data" : "Virhe tiedostoa ladatessa",
+    "Tags" : "Tunnisteet",
     "Save as …" : "Tallenna nimellä",
     "Converting files …" : "Muunnetaan tiedostoja…",
     "Converting file …" : "Muunnetaan tiedostoa…",
@@ -376,6 +391,7 @@ OC.L10N.register(
     "Edit locally" : "Muokkaa paikallisesti",
     "Moving \"{source}\" to \"{destination}\" …" : "Siirretään \"{source}\" kohteeseen \"{destination}\" …",
     "Copying \"{source}\" to \"{destination}\" …" : "Kopioidaan \"{source}\" kohteeseen \"{destination}\" …",
+    "(copy)" : "(kopioi)",
     "Move cancelled" : "Siirtäminen peruttu",
     "Cancelled move or copy operation" : "Siirto- tai kopiointitoiminto peruttu",
     "Open details" : "Avaa yksityiskohdat",
@@ -383,6 +399,7 @@ OC.L10N.register(
     "New folder creation cancelled" : "Kansion luominen peruttu",
     "This directory is unavailable, please check the logs or contact the administrator" : "Hakemisto ei ole käytettävissä. Tarkista lokit tai ole yhteydessä ylläpitoon.",
     "All folders" : "Kaikki kansiot",
+    "Open file sidebar" : "Avaa tiedoston sivupalkki",
     "Search everywhere …" : "Etsi kaikkialta…",
     "Search here …" : "Etsi tästä…",
     "Preparing …" : "Valmistellaan…"
