@@ -78,6 +78,8 @@ OC.L10N.register(
     "Reload current directory" : "Rafraîchir le dossier courant",
     "Go to the \"{dir}\" directory" : "Aller au dossier \"{dir}\"",
     "Current directory path" : "Chemin du répertoire courant",
+    "Share" : "Partager",
+    "Reload content" : "Recharger le contenu",
     "Your have used your space quota and cannot upload files anymore" : "Vous avez utilisé votre quota d'espace et vous ne pouvez plus téléverser de fichiers",
     "You do not have permission to upload or create files here." : "Vous n'avez pas la permission de téléverser ou créer des fichiers ici.",
     "Drag and drop files here to upload" : "Glissez-déposez les fichiers ici pour les téléverser",
@@ -92,7 +94,6 @@ OC.L10N.register(
     "This node is unavailable" : "Ce nœud est indisponible ",
     "Another entry with the same name already exists." : "Une autre entrée avec le même nom existe déjà.",
     "Invalid filename." : "Nom de fichier invalide.",
-    "Renamed \"{oldName}\" to \"{newName}\"" : "\"{oldName}\" renommé en \"{newName}\"",
     "Rename file" : "Renommer le fichier",
     "Folder" : "Dossier",
     "Unknown file type" : "Type de fichier inconnu",
@@ -102,12 +103,26 @@ OC.L10N.register(
     "{ext} text" : "{ext} texte",
     "Pending" : "En attente",
     "Unknown date" : "Date inconnue",
-    "Clear filter" : "Supprimer le filtre",
-    "Modified" : "Modifié",
-    "Search everywhere" : "Rechercher partout",
-    "Type" : "Type",
     "Active filters" : "Filtres actifs",
     "Remove filter" : "Retirer le filtre",
+    "Today" : "Aujourd’hui",
+    "Last 7 days" : "7 derniers jours",
+    "Last 30 days" : "30 derniers jours",
+    "This year ({year})" : "Cette année ({year})",
+    "Last year ({year})" : "L'année dernière ({year})",
+    "Custom range" : "Plage personnalisée",
+    "Custom date range" : "Plage de dates personnalisée",
+    "Search everywhere" : "Rechercher partout",
+    "Documents" : "Documents",
+    "Spreadsheets" : "Feuilles de calcul",
+    "Presentations" : "Présentations",
+    "PDFs" : "PDFs",
+    "Folders" : "Dossiers",
+    "Audio" : "Audio",
+    "Images" : "Images",
+    "Videos" : "Vidéos",
+    "Filters" : "Filtres",
+    "Back to filters" : "Retour aux filtres",
     "Appearance" : "Apparence",
     "Show hidden files" : "Montrer les fichiers masqués",
     "Show file type column" : "Afficher la colonne du type de fichier",
@@ -136,7 +151,6 @@ OC.L10N.register(
     "Go right in grid" : "Aller à droite dans la grille",
     "View" : "Voir",
     "Toggle grid view" : "Activer/Désactiver l'affichage mosaïque",
-    "Open file sidebar" : "Ouvrir le panneau latéral du fichier",
     "Show those shortcuts" : "Montrer ces raccourcis",
     "Warnings" : "Avertissements",
     "Warn before changing a file extension" : "Avertir avant de modifier l'extension d'un fichier",
@@ -150,6 +164,7 @@ OC.L10N.register(
     "Name" : "Nom",
     "File type" : "Type de fichier",
     "Size" : "Taille",
+    "Modified" : "Modifié",
     "{displayName}: failed on some elements" : "{displayName} : a échoué pour certains éléments",
     "{displayName}: done" : "{displayName} : terminé",
     "{displayName}: failed" : "{displayName} : échec",
@@ -218,12 +233,14 @@ OC.L10N.register(
     "Removing the file extension \"{old}\" may render the file unreadable." : "Retirer l'extension de fichier \"{old}\" peut rendre le fichier illisible.",
     "Adding the file extension \"{new}\" may render the file unreadable." : "Ajouter l'extension de fichier \"{new}\" peut rendre le fichier illisible.",
     "Do not show this dialog again." : "Ne plus montrer cette boite de dialogue.",
+    "Rename file to hidden" : "Renommer le fichier en caché",
+    "Prefixing a filename with a dot may render the file hidden." : "Le fait de préfixer un nom de fichier avec un point peut rendre le fichier caché.",
+    "Are you sure you want to rename the file to \"{filename}\"?" : "Voulez-vous vraiment renommer le fichier en \"{filename}\" ?",
+    "Cancel" : "Annuler",
+    "Rename" : "Renommer",
     "Select file or folder to link to" : "Sélection d'un fichier ou d'un dossier à lier",
     "Choose {file}" : "Choisir {file}",
     "Files settings" : "Paramètres de Fichiers",
-    "Share" : "Partager",
-    "Shared by link" : "Partagés par lien",
-    "Shared" : "Partagé",
     "Switch to list view" : "Passer à la vue en liste",
     "Switch to grid view" : "Basculer en vue en grille",
     "The file could not be found" : "Le fichier n'a pas pu être trouvé",
@@ -233,6 +250,7 @@ OC.L10N.register(
     "Error during upload: {message}" : "Erreur lors du téléversement : {message}",
     "Error during upload, status code {status}" : "Erreur lors du téléversement, code de statut {status}",
     "Unknown error during upload" : "Erreur inconnue lors du téléversement",
+    "File list is reloading" : "La liste des fichiers est en cours de rechargement",
     "Loading current folder" : "Chargement du dossier courant",
     "Retry" : "Réessayer",
     "No files in here" : "Aucun fichier",
@@ -248,7 +266,7 @@ OC.L10N.register(
     "Search for files" : "Rechercher des fichiers",
     "Allow to restrict filenames to ensure files can be synced with all clients. By default all filenames valid on POSIX (e.g. Linux or macOS) are allowed." : "Permet de restreindre les noms de fichiers pour s'assurer que les fichiers peuvent être synchronisés avec tous les clients. Par défaut, tous les noms de fichier valides sur POSIX (c'est à dire sur Linux ou MacOS) sont acceptés.",
     "After enabling the Windows compatible filenames, existing files cannot be modified anymore but can be renamed to valid new names by their owner." : "Après avoir activé les noms de fichiers compatibles Windows, les fichiers existants ne peuvent plus être modifiés mais peuvent être renommés avec de nouveaux noms valides par leur propriétaire.",
-    "Failed to toggle Windows filename support" : "Échec de l'activation de la prise en charge des noms de fichiers compatibles Windows",
+    "Failed to toggle Windows filename support" : "Échec d'activation/désactivation de la prise en charge des noms de fichiers compatibles Windows",
     "Files compatibility" : "Compatibilité des fichiers",
     "Enforce Windows compatibility" : "Forcer la compatibilité Windows",
     "This will block filenames not valid on Windows systems, like using reserved names or special characters. But this will not enforce compatibility of case sensitivity." : "Cela va bloquer les noms de fichier non valides sur les systèmes Windows, comme utiliser des noms réservés ou des caractères spéciaux. Mais cela ne renforcera pas la compatibilité de la sensibilité à la casse.",
@@ -285,30 +303,29 @@ OC.L10N.register(
     "_You are about to permanently delete {count} item_::_You are about to permanently delete {count} items_" : ["Vous êtes sur le point de supprimer définitivement {count} élément","Vous êtes sur le point de supprimer définitivement {count} éléments","Vous êtes sur le point de supprimer définitivement {count} éléments"],
     "_You are about to delete {count} item_::_You are about to delete {count} items_" : ["Vous êtes sur le point de supprimer {count} élément","Vous êtes sur le point de supprimer {count} éléments","Vous êtes sur le point de supprimer {count} éléments"],
     "Confirm deletion" : "Confirmer la suppression",
-    "Cancel" : "Annuler",
     "Download" : "Télécharger",
     "The requested file is not available." : "Le fichier demandé n'est pas disponible.",
     "The requested files are not available." : "Les fichiers demandés ne sont pas disponibles.",
     "Add to favorites" : "Ajouter aux favoris",
     "Remove from favorites" : "Retirer des favoris",
     "Add or remove favorite" : "Ajouter ou supprimer un favoris",
-    "Moving \"{source}\" to \"{destination}\" …" : "Déplacement de \"{source}\" vers \"{destination}\" …",
-    "Copying \"{source}\" to \"{destination}\" …" : "Copie de \"{source}\" vers \"{destination}\" …",
+    "Move" : "Déplacer",
+    "Copy" : "Copier",
+    "Move or copy" : "Déplacer ou copier",
     "Destination is not a folder" : "La destination n'est pas un dossier",
     "This file/folder is already in that directory" : "Ce fichier/dossier se trouve déjà dans ce dossier",
     "You cannot move a file/folder onto itself or into a subfolder of itself" : "Vous ne pouvez pas déplacer un fichier/dossier sur lui-même ou dans un sous-dossier de celui-ci",
-    "(copy)" : "(copie)",
-    "(copy %n)" : "(copier %n)",
     "A file or folder with that name already exists in this folder" : "Un fichier ou un dossier portant ce nom existe déjà dans ce dossier",
     "The files are locked" : "Les fichiers sont verrouillés",
     "The file does not exist anymore" : "Le fichier n'existe plus",
+    "Moving \"{source}\" to \"{destination}\" …" : "Déplacement de \"{source}\" vers \"{destination}\" …",
+    "Moving {count} files to \"{destination}\" …" : "Déplacement de {count} fichiers vers \"{destination}\" …",
+    "Copying \"{source}\" to \"{destination}\" …" : "Copie de \"{source}\" vers \"{destination}\" …",
+    "Copying {count} files to \"{destination}\" …" : "Copie de {count} fichiers vers \"{destination}\" …",
     "Choose destination" : "Choisir la destination",
     "Copy to {target}" : "Copier vers {target}",
-    "Copy" : "Copier",
     "Move to {target}" : "Déplacer vers {target}",
-    "Move" : "Déplacer",
     "Move or copy operation failed" : "L'opération de copie ou de déplacement a échoué",
-    "Move or copy" : "Déplacer ou copier",
     "Open folder" : "Ouvrir le dossier",
     "Open folder {displayName}" : "Ouvrir le dossier {displayName}",
     "Open in Files" : "Ouvrir dans Fichiers",
@@ -318,29 +335,18 @@ OC.L10N.register(
     "The file should now open on your device. If it doesn't, please check that you have the desktop app installed." : "Le fichier devrait maintenant s'ouvrir sur votre appareil. Si ce n'est pas le cas, vérifiez que vous avez installé l'application de bureau.",
     "Retry and close" : "Réessayer et fermer",
     "Open online" : "Ouvrir en ligne",
-    "Rename" : "Renommer",
     "Details" : "Détails",
+    "Open the details sidebar" : "Ouvrir la barre latéral des détails",
     "Unfavorite" : "Retirer des favoris",
     "View in folder" : "Afficher dans le dossier",
-    "Today" : "Aujourd’hui",
-    "Last 7 days" : "7 derniers jours",
-    "Last 30 days" : "30 derniers jours",
-    "This year ({year})" : "Cette année ({year})",
-    "Last year ({year})" : "L'année dernière ({year})",
-    "Documents" : "Documents",
-    "Spreadsheets" : "Feuilles de calcul",
-    "Presentations" : "Présentations",
-    "PDFs" : "PDFs",
-    "Folders" : "Dossiers",
-    "Audio" : "Audio",
-    "Images" : "Images",
-    "Videos" : "Vidéos",
+    "Type" : "Type",
     "Created new folder \"{name}\"" : "Nouveau dossier \"{name}\" créé",
     "Unable to initialize the templates directory" : "Impossible d'initialiser le dossier des modèles",
     "Create templates folder" : "Créer le dossier des modèles",
     "Templates" : "Modèles",
     "New template folder" : "Nouveau modèle de dossier",
     "In folder" : "Dans le dossier",
+    "Pick folder to search in" : "Choisir le dossier pour la recherche",
     "Search in all files" : "Rechercher dans tous les fichiers",
     "Search in folder: {folder}" : "Rechercher dans le dossier : {folder}",
     "One of the dropped files could not be processed" : "L'un des fichiers déposés n'a pas pu être traité",
@@ -350,10 +356,10 @@ OC.L10N.register(
     "Some files could not be uploaded" : "Certains fichiers n'ont pu être téléversés",
     "Files uploaded successfully" : "Fichiers téléversés avec succès",
     "No files to process" : "Aucun fichier à traiter",
-    "Some files could not be copied" : "Certains des fichiers n’ont pas pu être copiés",
-    "Some files could not be moved" : "Certains fichiers n’ont pu être déplacés",
     "Files copied successfully" : "Fichiers copiés avec succès",
     "Files moved successfully" : "Fichiers déplacés avec succès",
+    "Some files could not be copied" : "Certains des fichiers n’ont pas pu être copiés",
+    "Some files could not be moved" : "Certains fichiers n’ont pu être déplacés",
     "Conflicts resolution skipped" : "Résolution des conflits ignorée",
     "Upload cancelled" : "Téléversement annulé",
     "Could not rename \"{oldName}\", it does not exist any more" : "Impossible de renommer \"{oldName}\", il n'existe plus.",
@@ -394,10 +400,14 @@ OC.L10N.register(
     "Upload (max. %s)" : "Envoi (max. %s)",
     "After enabling the windows compatible filenames, existing files cannot be modified anymore but can be renamed to valid new names by their owner." : "Après avoir activé les noms de fichiers compatibles Windows, les fichiers existants ne peuvent plus être modifiés, mais peuvent être renommés avec des noms valides par leur propriétaire.",
     "It is also possible to migrate files automatically after enabling this setting, please refer to the documentation about the occ command." : "Il est également possible de migrer les fichiers automatiquement après avoir activé ce paramètre, veuillez vous référer à la documentation sur la commande occ.",
+    "Renamed \"{oldName}\" to \"{newName}\"" : "\"{oldName}\" renommé en \"{newName}\"",
+    "Clear filter" : "Supprimer le filtre",
     "\"{displayName}\" failed on some elements" : "\"{displayName}\" a échoué pour certains éléments",
     "\"{displayName}\" batch action executed successfully" : "L’action « {displayName} » par lot a été exécutée avec succès",
     "\"{displayName}\" action failed" : "Échec de l'action \"{displayName}\"",
     "Submitting fields …" : "Soumission des champs...",
+    "Shared by link" : "Partagés par lien",
+    "Shared" : "Partagé",
     "\"{displayName}\" action executed successfully" : "Action \"{displayName}\" exécutée avec succès",
     "Filter file names …" : "Filtrer les noms de fichier…",
     "Clipboard is not available" : "Le presse-papiers n'est pas disponible",
@@ -426,7 +436,7 @@ OC.L10N.register(
     "Navigate to the file on the left (in grid mode)" : "Naviguer vers le fichier à gauche (en mode grille)",
     "Navigate to the file on the right (in grid mode)" : "Naviguer vers le fichier à droite (en mode grille)",
     "Toggle the grid view" : "Activer/Désactiver la vue grille",
-    "Open the sidebar for a file" : "Ouvrir la barre latérale pour un fichier",
+    "Open the sidebar for a file" : "Ouvrir le panneau latéral pour un fichier",
     "You" : "Vous",
     "Shared multiple times with different people" : "Partagé plusieurs fois avec plusieurs personnes",
     "Unable to change the favorite state of the file" : "Impossible de modifier l'état de mise en favori du fichier",
@@ -439,6 +449,8 @@ OC.L10N.register(
     "Edit locally" : "Éditer localement",
     "Moving \"{source}\" to \"{destination}\" …" : "Déplacement de \"{source}\" vers \"{destination}\" …",
     "Copying \"{source}\" to \"{destination}\" …" : "Copie de \"{source}\" vers \"{destination}\" …",
+    "(copy)" : "(copie)",
+    "(copy %n)" : "(copier %n)",
     "Move cancelled" : "Déplacement annulé",
     "Cancelled move or copy of \"{filename}\"." : "Déplacement ou copie de \"{filename}\" annulé.",
     "Cancelled move or copy operation" : "Opération de déplacement ou de copie annulée",
@@ -447,6 +459,7 @@ OC.L10N.register(
     "New folder creation cancelled" : "La création du nouveau dossier est annulée",
     "This directory is unavailable, please check the logs or contact the administrator" : "Ce répertoire est indisponible, merci de consulter les journaux ou de contacter votre administrateur",
     "All folders" : "Tous les dossiers",
+    "Open file sidebar" : "Ouvrir le panneau latéral du fichier",
     "Search everywhere …" : "Rechercher partout...",
     "Search here …" : "Rechercher ici...",
     "Preparing …" : "Préparation..."
