@@ -78,6 +78,8 @@ OC.L10N.register(
     "Reload current directory" : "Athlódáil an eolaire reatha",
     "Go to the \"{dir}\" directory" : "Téigh go dtí an eolaire \"{dir}\".",
     "Current directory path" : "An cosán eolaire reatha",
+    "Share" : "Comhroinn",
+    "Reload content" : "Athlódáil an t-ábhar",
     "Your have used your space quota and cannot upload files anymore" : "D'úsáid tú do chuóta spáis agus ní féidir leat comhaid a uaslódáil a thuilleadh",
     "You do not have permission to upload or create files here." : "Níl cead agat comhaid a uaslódáil nó a chruthú anseo.",
     "Drag and drop files here to upload" : "Tarraing agus scaoil comhaid anseo le huaslódáil",
@@ -92,7 +94,6 @@ OC.L10N.register(
     "This node is unavailable" : "Níl an nód seo ar fáil",
     "Another entry with the same name already exists." : "Tá iontráil eile leis an ainm céanna ann cheana féin.",
     "Invalid filename." : "Ainm comhaid neamhbhailí.",
-    "Renamed \"{oldName}\" to \"{newName}\"" : "Athainmnithe \"{oldName}\" go \"{newName}\"",
     "Rename file" : "Athainmnigh an comhad",
     "Folder" : "Fillteán",
     "Unknown file type" : "Cineál comhaid anaithnid",
@@ -102,21 +103,71 @@ OC.L10N.register(
     "{ext} text" : "téacs {ext}",
     "Pending" : "Ar feitheamh",
     "Unknown date" : "Dáta anaithnid",
-    "Clear filter" : "Glan an scagaire",
-    "Modified" : "Athraithe",
-    "Search everywhere" : "Cuardaigh i ngach áit",
-    "Type" : "Cineál",
     "Active filters" : "Scagairí gníomhacha",
     "Remove filter" : "Bain an scagaire",
+    "Today" : "Inniu",
+    "Last 7 days" : "7 lá seo caite",
+    "Last 30 days" : "30 lá anuas",
+    "This year ({year})" : "i mbliana ({year})",
+    "Last year ({year})" : "An bhliain seo caite {year}",
+    "Custom range" : "Raon saincheaptha",
+    "Custom date range" : "Raon dáta saincheaptha",
+    "Search everywhere" : "Cuardaigh i ngach áit",
+    "Documents" : "Doiciméid",
+    "Spreadsheets" : "Scarbhileoga",
+    "Presentations" : "Cur i láthair",
+    "PDFs" : "PDFs",
+    "Folders" : "Fillteáin",
+    "Audio" : "Fuaime",
+    "Images" : "Íomhánna",
+    "Videos" : "Físeáin",
+    "Filters" : "Scagairí",
+    "Back to filters" : "Ar ais chuig na scagairí",
+    "Appearance" : "Dealramh",
+    "Show hidden files" : "Taispeáin comhaid i bhfolach",
+    "Show file type column" : "Taispeáin colún cineál comhaid",
+    "Show file extensions" : "Taispeáin síntí comhaid",
+    "Crop image previews" : "Réamhamhairc íomhá barr",
+    "General" : "Ginearálta",
+    "Sort favorites first" : "Sórtáil na cinn is ansa leat ar dtús",
+    "Sort folders before files" : "Sórtáil fillteáin roimh chomhaid",
+    "Enable folder tree view" : "Cumasaigh radharc crann fillteán",
+    "Default view" : "Amharc réamhshocraithe",
+    "All files" : "Gach comhad",
+    "Personal files" : "Comhaid phearsanta",
+    "Additional settings" : "Socruithe breise",
+    "Actions" : "Gníomhartha",
+    "File actions" : "Gníomhartha comhaid",
+    "Selection" : "Roghnú",
+    "Select all files" : "Roghnaigh gach comhad",
+    "Deselect all" : "Díroghnaigh go léir",
+    "Select or deselect" : "Roghnaigh nó díroghnaigh",
+    "Select a range" : "Roghnaigh raon",
+    "Navigation" : "Loingseoireacht",
+    "Go to parent folder" : "Téigh go dtí an fillteán tuismitheora",
+    "Go to file above" : "Téigh go dtí an comhad thuas",
+    "Go to file below" : "Téigh go dtí an comhad thíos",
+    "Go left in grid" : "Téigh ar chlé sa ghreille",
+    "Go right in grid" : "Téigh ar dheis sa ghreille",
+    "View" : "Amharc",
+    "Toggle grid view" : "Scoránaigh amharc greille",
+    "Show those shortcuts" : "Taispeáin na haicearraí sin",
+    "Warnings" : "Rabhaidh",
+    "Warn before changing a file extension" : "Tabhair rabhadh sula n-athraítear síneadh comhaid",
+    "Warn before deleting a file" : "Rabhadh roimh chomhad a scriosadh",
+    "WebDAV URL" : "URL WebDAV",
+    "Create an app password" : "Cruthaigh pasfhocal aip",
+    "Required for WebDAV authentication because Two-Factor Authentication is enabled for this account." : "Riachtanach le haghaidh fíordheimhniú WebDAV mar go bhfuil Fíordheimhniú Dhá Fhachtóir cumasaithe don chuntas seo.",
+    "How to access files using WebDAV" : "Conas rochtain a fháil ar chomhaid ag baint úsáide as WebDAV",
     "Total rows summary" : "Achoimre ar na sraitheanna iomlána",
     "Toggle selection for all files and folders" : "Scoránaigh an roghnúchán do gach comhad agus fillteán",
     "Name" : "Ainm",
     "File type" : "Cineál comhaid",
     "Size" : "Méid",
+    "Modified" : "Athraithe",
     "{displayName}: failed on some elements" : "{displayName}: theip ar roinnt eilimintí",
     "{displayName}: done" : "{displayName}: déanta",
     "{displayName}: failed" : "{displayName}: theip air",
-    "Actions" : "Gníomhartha",
     "(selected)" : "(roghnaithe)",
     "List of files and folders." : "Liosta de chomhaid agus fillteáin.",
     "You have used your space quota and cannot upload files anymore." : "D'úsáid tú do chuóta spáis agus ní féidir leat comhaid a uaslódáil a thuilleadh.",
@@ -124,10 +175,11 @@ OC.L10N.register(
     "This list is not fully rendered for performance reasons. The files will be rendered as you navigate through the list." : "Níl an liosta seo le fáil go hiomlán ar chúiseanna feidhmíochta. Déanfar na comhaid a rindreáil agus tú ag dul tríd an liosta.",
     "File not found" : "Comhad gan aimsiú",
     "_{count} selected_::_{count} selected_" : ["{count} roghnaithe","{count} roghnaithe","{count} roghnaithe","{count} roghnaithe","{count} roghnaithe"],
-    "Search everywhere …" : "Cuardaigh i ngach áit…",
-    "Search here …" : "Cuardaigh anseo…",
+    "Search everywhere …" : "Cuardaigh i ngach áit …",
+    "Search here …" : "Cuardaigh anseo …",
     "Search scope options" : "Roghanna raon feidhme cuardaigh",
     "Search here" : "Cuardaigh anseo",
+    "Owner" : "Úinéir",
     "{usedQuotaByte} used" : "{usedQuotaByte} úsáidte",
     "{used} of {quota} used" : "{used} de {quota} in úsáid",
     "{relative}% used" : "{relative}% in úsáid",
@@ -144,7 +196,7 @@ OC.L10N.register(
     "Failed to refresh filename sanitization status." : "Theip ar stádas sláintíochta ainm comhaid a athnuachan.",
     "Filename sanitization in progress." : "Glanadh ainm comhaid ar siúl.",
     "Currently {processedUsers} of {totalUsers} accounts are already processed." : "Tá {processedUsers} de {totalUsers} cuntas próiseáilte cheana féin faoi láthair.",
-    "Preparing …" : "Ag ullmhú …",
+    "Preparing …" : "Ag ullmhú …",
     "Refresh" : "Athnuaigh",
     "All files have been santized for Windows filename support." : "Tá gach comhad glanta chun tacú le hainmneacha comhad Windows.",
     "Some files could not be sanitized, please check your logs." : "Níorbh fhéidir roinnt comhad a shláintiú, seiceáil do logaí le do thoil.",
@@ -159,7 +211,7 @@ OC.L10N.register(
     "Sanitize filenames" : "Glanadh ainmneacha comhad",
     "(starting)" : "(ag tosú)",
     "Fill template fields" : "Líon réimsí teimpléid",
-    "Submitting fields …" : "Réimsí á gcur isteach…",
+    "Submitting fields …" : "Réimsí á gcur isteach …",
     "Submit" : "Cuir isteach",
     "Choose a file or folder to transfer" : "Roghnaigh comhad nó fillteán le haistriú",
     "Transfer" : "Aistriú",
@@ -181,11 +233,14 @@ OC.L10N.register(
     "Removing the file extension \"{old}\" may render the file unreadable." : "Má bhaintear an iarmhír chomhaid \"{old}\" seans go mbeidh an comhad do-léite.",
     "Adding the file extension \"{new}\" may render the file unreadable." : "Má chuirtear an síneadh comhad \"{new}\" leis, seans go mbeidh an comhad do-léite.",
     "Do not show this dialog again." : "Ná taispeáin an dialóg seo arís.",
+    "Rename file to hidden" : "Athainmnigh an comhad go hiomlaithe",
+    "Prefixing a filename with a dot may render the file hidden." : "D’fhéadfadh sé go mbeadh an comhad i bhfolach má chuireann tú ponc roimh ainm comhaid.",
+    "Are you sure you want to rename the file to \"{filename}\"?" : "An bhfuil tú cinnte gur mian leat an comhad a athainmniú go \"{filename}\"?",
+    "Cancel" : "Cealaigh",
+    "Rename" : "Athainmnigh",
     "Select file or folder to link to" : "Roghnaigh comhad nó fillteán le nascadh leis",
     "Choose {file}" : "Roghnaigh {file}",
-    "Share" : "Comhroinn",
-    "Shared by link" : "Roinnte ag nasc",
-    "Shared" : "Roinnte",
+    "Files settings" : "Socruithe comhaid",
     "Switch to list view" : "Athraigh go dtí an amharc liosta",
     "Switch to grid view" : "Téigh go dtí an radharc greille",
     "The file could not be found" : "Níorbh fhéidir an comhad a aimsiú",
@@ -195,96 +250,46 @@ OC.L10N.register(
     "Error during upload: {message}" : "Earráid le linn uaslódála: {message}",
     "Error during upload, status code {status}" : "Earráid le linn uaslódála, cód stádais {status}",
     "Unknown error during upload" : "Earráid anaithnid le linn uaslódála",
+    "File list is reloading" : "Tá an liosta comhad á athlódáil",
     "Loading current folder" : "An fillteán reatha á lódáil",
     "Retry" : "Bain triail eile as",
     "No files in here" : "Níl aon chomhaid istigh anseo",
     "Upload some content or sync with your devices!" : "Uaslódáil roinnt inneachair nó sioncronaigh le do ghléasanna!",
     "Go back" : "Dul ar ais",
     "Views" : "Radhairc",
-    "Files settings" : "Socruithe comhaid",
+    "Loading …" : "Ag luchtú …",
     "Your files" : "Do chuid comhad",
     "Open in files" : "Oscail i gcomhaid",
     "File cannot be accessed" : "Ní féidir an comhad a rochtain",
     "The file could not be found or you do not have permissions to view it. Ask the sender to share it." : "Níorbh fhéidir an comhad a aimsiú nó níl cead agat féachaint air. Iarr ar an seoltóir é a roinnt.",
     "No search results for “{query}”" : "Gan aon torthaí cuardaigh le haghaidh ”{query}”",
     "Search for files" : "Cuardaigh comhaid",
-    "Clipboard is not available" : "Níl fáil ar an ngearrthaisce",
-    "WebDAV URL copied" : "URL WebDAV cóipeáilte",
-    "General" : "Ginearálta",
-    "Default view" : "Amharc réamhshocraithe",
-    "All files" : "Gach comhad",
-    "Personal files" : "Comhaid phearsanta",
-    "Sort favorites first" : "Sórtáil na cinn is ansa leat ar dtús",
-    "Sort folders before files" : "Sórtáil fillteáin roimh chomhaid",
-    "Folder tree" : "Crann fillteán",
-    "Appearance" : "Dealramh",
-    "Show hidden files" : "Taispeáin comhaid i bhfolach",
-    "Show file type column" : "Taispeáin colún cineál comhaid",
-    "Show file extensions" : "Taispeáin síntí comhaid",
-    "Crop image previews" : "Réamhamhairc íomhá barr",
-    "Additional settings" : "Socruithe breise",
-    "WebDAV" : "WebDAV",
-    "WebDAV URL" : "URL WebDAV",
-    "Copy" : "Cóipeáil",
-    "How to access files using WebDAV" : "Conas rochtain a fháil ar chomhaid ag baint úsáide as WebDAV",
-    "Two-Factor Authentication is enabled for your account, and therefore you need to use an app password to connect an external WebDAV client." : "Tá Fíordheimhniú Dhá Fhachtóir cumasaithe do do chuntas, agus dá bhrí sin ní mór duit pasfhocal aipe a úsáid chun cliant seachtrach WebDAV a nascadh.",
-    "Warnings" : "Rabhaidh",
-    "Warn before changing a file extension" : "Tabhair rabhadh sula n-athraítear síneadh comhaid",
-    "Warn before deleting files" : "Rabhadh roimh scriosadh comhad",
-    "Keyboard shortcuts" : "Aicearraí méarchláir",
-    "File actions" : "Gníomhartha comhaid",
-    "Rename" : "Athainmnigh",
-    "Delete" : "Scrios",
-    "Add or remove favorite" : "Cuir leis nó bain an rogha is fearr leat",
-    "Manage tags" : "Bainistigh clibeanna",
-    "Selection" : "Roghnú",
-    "Select all files" : "Roghnaigh gach comhad",
-    "Deselect all" : "Díroghnaigh go léir",
-    "Select or deselect" : "Roghnaigh nó díroghnaigh",
-    "Select a range" : "Roghnaigh raon",
-    "Navigation" : "Loingseoireacht",
-    "Go to parent folder" : "Téigh go dtí an fillteán tuismitheora",
-    "Go to file above" : "Téigh go dtí an comhad thuas",
-    "Go to file below" : "Téigh go dtí an comhad thíos",
-    "Go left in grid" : "Téigh ar chlé sa ghreille",
-    "Go right in grid" : "Téigh ar dheis sa ghreille",
-    "View" : "Amharc",
-    "Toggle grid view" : "Scoránaigh amharc greille",
-    "Open file sidebar" : "Oscail barra taoibh an chomhaid",
-    "Show those shortcuts" : "Taispeáin na haicearraí sin",
     "Allow to restrict filenames to ensure files can be synced with all clients. By default all filenames valid on POSIX (e.g. Linux or macOS) are allowed." : "Ceadaigh comhaid a shrianadh lena chinntiú gur féidir comhaid a shioncronú le gach cliant. De réir réamhshocraithe ceadaítear gach comhadainm atá bailí ar POSIX (m.sh. Linux nó macOS).",
     "After enabling the Windows compatible filenames, existing files cannot be modified anymore but can be renamed to valid new names by their owner." : "Tar éis na hainmneacha comhad atá comhoiriúnach le Windows a chumasú, ní féidir comhaid atá ann cheana a mhodhnú a thuilleadh ach is féidir lena n-úinéir iad a athainmniú go hainmneacha nua bailí.",
     "Failed to toggle Windows filename support" : "Theip ar thacaíocht d'ainmneacha comhaid Windows a athrú",
     "Files compatibility" : "Comhoiriúnacht comhaid",
     "Enforce Windows compatibility" : "Comhoiriúnacht Windows a fhorfheidhmiú",
     "This will block filenames not valid on Windows systems, like using reserved names or special characters. But this will not enforce compatibility of case sensitivity." : "Cuirfidh sé seo bac ar ainmneacha comhaid nach bhfuil bailí ar chórais Windows, ar nós ainmneacha forchoimeádta nó carachtair speisialta a úsáid. Ach ní chuirfidh sé seo i bhfeidhm comhoiriúnacht íogaireacht cáis.",
-    "You" : "tú",
-    "Shared multiple times with different people" : "Roinnte go minic le daoine éagsúla",
-    "Unable to change the favorite state of the file" : "Ní féidir staid an chomhaid is fearr leat a athrú",
-    "Error while loading the file data" : "Earráid agus sonraí an chomhaid á lódáil",
-    "Owner" : "Úinéir",
-    "Remove from favorites" : "Bain ó cheanáin",
-    "Add to favorites" : "Cuir le ceanáin",
-    "Tags" : "Clibeanna",
     "Blank" : "Bán",
     "Unable to create new file from template" : "Ní féidir comhad nua a chruthú ón teimpléad",
     "Pick a template for {name}" : "Roghnaigh teimpléad le haghaidh {name}",
     "Create a new file with the selected template" : "Cruthaigh comhad nua leis an teimpléad roghnaithe",
     "Creating file" : "Comhad a chruthú",
     "Save as {displayName}" : "Sábháil mar {displayName}",
-    "Save as …" : "Sábháil mar…",
-    "Converting files …" : "Comhaid á thiontú…",
+    "Save as …" : "Sábháil mar …",
+    "Converting files …" : "Ag tiontú comhad …",
     "Failed to convert files: {message}" : "Theip ar thiontú comhaid: {message}",
     "All files failed to be converted" : "Theip ar gach comhad a thiontú",
     "One file could not be converted: {message}" : "Níorbh fhéidir comhad amháin a thiontú:{message}",
-    "_One file could not be converted_::_%n files could not be converted_" : ["Níorbh fhéidir comhad amháin a thiontú","Níorbh fhéidir %n comhad a thiontú","Níorbh fhéidir %n comhad a thiontú","Níorbh fhéidir %n comhad a thiontú","Níorbh fhéidir %n comhad a thiontú"],
-    "_One file successfully converted_::_%n files successfully converted_" : ["D'éirigh le comhad amháin a thiontú","D'éirigh le %n comhad a thiontú","D'éirigh le %n comhad a thiontú","D'éirigh le %n comhad a thiontú","D'éirigh le %n comhad a thiontú"],
-    "Files successfully converted" : "Comhaid a thiontú go rathúil",
+    "_%n file could not be converted_::_%n files could not be converted_" : ["Níorbh fhéidir %n comhad a thiontú","Níorbh fhéidir %n comhaid a thiontú","Níorbh fhéidir %n comhaid a thiontú","Níorbh fhéidir %n comhaid a thiontú","Níorbh fhéidir %n comhaid a thiontú"],
+    "_%n file converted_::_%n files converted_" : ["%n comhad tiontaithe","%n comhaid tiontaithe","%n comhaid tiontaithe","%n comhaid tiontaithe","%n comhaid tiontaithe"],
+    "Files converted" : "Comhaid a tiontaíodh",
     "Failed to convert files" : "Theip ar thiontú comhaid",
-    "Converting file …" : "Comhad á thiontú…",
+    "Converting file …" : "Ag tiontú comhaid …",
     "File successfully converted" : "D'éirigh leis an gcomhad a thiontú",
     "Failed to convert file: {message}" : "Theip ar an gcomhad a thiontú: {message}",
     "Failed to convert file" : "Theip ar thiontú an chomhaid",
+    "Delete" : "Scrios",
     "Leave this share" : "Fág an sciar seo",
     "Leave these shares" : "Fág na scaireanna seo",
     "Disconnect storage" : "Déan stóráil a dhícheangal",
@@ -298,26 +303,30 @@ OC.L10N.register(
     "_You are about to permanently delete {count} item_::_You are about to permanently delete {count} items_" : ["Tá tú ar tí {count} mír a scriosadh go buan","Tá tú ar tí {count} mír a scriosadh go buan","Tá tú ar tí {count} mír a scriosadh go buan","Tá tú ar tí {count} mír a scriosadh go buan","Tá tú ar tí {count} mír a scriosadh go buan"],
     "_You are about to delete {count} item_::_You are about to delete {count} items_" : ["Tá tú ar tí {count} mír a scriosadh","Tá tú ar tí {count} mír a scriosadh","Tá tú ar tí {count} mír a scriosadh","Tá tú ar tí {count} mír a scriosadh","Tá tú ar tí {count} mír a scriosadh"],
     "Confirm deletion" : "Deimhnigh scriosadh",
-    "Cancel" : "Cealaigh",
     "Download" : "Íoslódáil",
     "The requested file is not available." : "Níl an comhad iarrtha ar fáil.",
     "The requested files are not available." : "Níl na comhaid iarrtha ar fáil.",
-    "Moving \"{source}\" to \"{destination}\" …" : "Ag bogadh \"{source}\" go \"{destination}\" ...",
-    "Copying \"{source}\" to \"{destination}\" …" : "“{source}” á chóipeáil go “{destination}”…",
+    "Add to favorites" : "Cuir le ceanáin",
+    "Remove from favorites" : "Bain ó cheanáin",
+    "Add or remove favorite" : "Cuir leis nó bain an rogha is fearr leat",
+    "Move" : "Bog",
+    "Copy" : "Cóipeáil",
+    "Move or copy" : "Bog nó cóipeáil",
     "Destination is not a folder" : "Ní fillteán é ceann scríbe",
     "This file/folder is already in that directory" : "Tá an comhad/fillteán seo san eolaire sin cheana féin",
     "You cannot move a file/folder onto itself or into a subfolder of itself" : "Ní féidir leat comhad/fillteán a bhogadh isteach ann féin nó isteach i bhfofhillteán de féin",
-    "(copy)" : "(cóip)",
-    "(copy %n)" : "(cóip %n)",
     "A file or folder with that name already exists in this folder" : "Tá comhad nó fillteán leis an ainm sin san fhillteán seo cheana",
     "The files are locked" : "Tá na comhaid faoi ghlas",
     "The file does not exist anymore" : "Níl an comhad ann a thuilleadh",
+    "Moving \"{source}\" to \"{destination}\" …" : "Ag bogadh \"{source}\" go \"{destination}\" …",
+    "Moving {count} files to \"{destination}\" …" : "Ag bogadh {count} comhad go \"{destination}\" …",
+    "Copying \"{source}\" to \"{destination}\" …" : "Ag cóipeáil \"{source}\" go \"{destination}\" …",
+    "Copying {count} files to \"{destination}\" …" : "Ag cóipeáil {count} comhad chuig \"{destination}\" …",
     "Choose destination" : "Roghnaigh ceann scríbe",
     "Copy to {target}" : "Cóipeáil chuig {target}",
     "Move to {target}" : "Bog go {target}",
-    "Move" : "Bog",
     "Move or copy operation failed" : "Theip ar an oibríocht a bhogadh nó a chóipeáil",
-    "Move or copy" : "Bog nó cóipeáil",
+    "Open folder" : "Oscail fillteán",
     "Open folder {displayName}" : "Oscail fillteán {displayName}",
     "Open in Files" : "Oscail i Comhaid",
     "Open locally" : "Oscail go háitiúil",
@@ -327,26 +336,17 @@ OC.L10N.register(
     "Retry and close" : "Bain triail eile as agus dún",
     "Open online" : "Oscail ar líne",
     "Details" : "Sonraí",
+    "Open the details sidebar" : "Oscail an barra taoibh sonraí",
+    "Unfavorite" : "Mí-mheas",
     "View in folder" : "Amharc san fhillteán",
-    "Today" : "Inniu",
-    "Last 7 days" : "7 lá seo caite",
-    "Last 30 days" : "30 lá anuas",
-    "This year ({year})" : "i mbliana ({year})",
-    "Last year ({year})" : "An bhliain seo caite {year}",
-    "Documents" : "Doiciméid",
-    "Spreadsheets" : "Scarbhileoga",
-    "Presentations" : "Cur i láthair",
-    "PDFs" : "PDFs",
-    "Folders" : "Fillteáin",
-    "Audio" : "Fuaime",
-    "Images" : "Íomhánna",
-    "Videos" : "Físeáin",
+    "Type" : "Cineál",
     "Created new folder \"{name}\"" : "Cruthaíodh fillteán nua \"{name}\"",
     "Unable to initialize the templates directory" : "Ní féidir eolaire na dteimpléad a thúsú",
     "Create templates folder" : "Cruthaigh fillteán teimpléid",
     "Templates" : "Teimpléid",
     "New template folder" : "Fillteán teimpléid nua",
     "In folder" : "I bhfillteán",
+    "Pick folder to search in" : "Roghnaigh fillteán le cuardach a dhéanamh ann",
     "Search in all files" : "Cuardaigh i ngach comhad",
     "Search in folder: {folder}" : "Cuardaigh i bhfillteán: {folder}",
     "One of the dropped files could not be processed" : "Níorbh fhéidir ceann de na comhaid a thit a phróiseáil",
@@ -356,10 +356,10 @@ OC.L10N.register(
     "Some files could not be uploaded" : "Níorbh fhéidir roinnt comhad a uaslódáil",
     "Files uploaded successfully" : "D'éirigh le huaslódáil comhaid",
     "No files to process" : "Níl aon chomhaid le próiseáil",
-    "Some files could not be copied" : "Níorbh fhéidir roinnt comhad a chóipeáil",
-    "Some files could not be moved" : "Níorbh fhéidir roinnt comhad a bhogadh",
     "Files copied successfully" : "D'éirigh le cóipeáil na gcomhaid",
     "Files moved successfully" : "Bogadh na comhaid go rathúil",
+    "Some files could not be copied" : "Níorbh fhéidir roinnt comhad a chóipeáil",
+    "Some files could not be moved" : "Níorbh fhéidir roinnt comhad a bhogadh",
     "Conflicts resolution skipped" : "Léiríodh réiteach coinbhleachta",
     "Upload cancelled" : "Cuireadh an t-uaslódáil ar ceal",
     "Could not rename \"{oldName}\", it does not exist any more" : "Níorbh fhéidir \"{oldName}\" a athainmniú, níl sé ann a thuilleadh",
@@ -381,6 +381,7 @@ OC.L10N.register(
     "No favorites yet" : "Níl aon cheanáin go fóill",
     "Files and folders you mark as favorite will show up here" : "Taispeánfar comhaid agus fillteáin a mharcálann tú mar is fearr leat anseo",
     "List of your files and folders." : "Liosta de do chuid comhad agus fillteáin.",
+    "Folder tree" : "Crann fillteán",
     "List of your files and folders that are not shared." : "Liosta de do chuid comhad agus fillteáin nach bhfuil roinnte.",
     "No personal files found" : "Níor aimsíodh aon chomhaid phearsanta",
     "Files that are not shared will show up here." : "Taispeánfar comhaid nach bhfuil roinnte anseo.",
@@ -394,119 +395,32 @@ OC.L10N.register(
     "Select all" : "Roghnú go léir",
     "Upload too large" : "Íoslódáil ró-mhór",
     "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Sáraíonn na comhaid atá tú ag iarraidh a uaslódáil an t-uasmhéid le haghaidh uaslódáil comhad ar an bhfreastalaí seo.",
-    "File could not be found" : "Níorbh fhéidir an comhad a aimsiú",
-    "Show list view" : "Taispeáin amharc liosta",
-    "Show grid view" : "Taispeáin radharc greille",
-    "Close" : "Dún",
-    "Could not create folder \"{dir}\"" : "Níorbh fhéidir fillteán \"{dir}\" a chruthú",
-    "This will stop your current uploads." : "Cuirfidh sé seo stop le d'uaslódálacha reatha.",
-    "Upload cancelled." : "Cuireadh an t-uaslódáil ar ceal.",
-    "Processing files …" : "Comhaid á bpróiseáil…",
-    "…" : "…",
-    "Unable to upload {filename} as it is a directory or has 0 bytes" : "Ní féidir {filename} a uaslódáil mar gur eolaire é nó go bhfuil 0 beart ann",
-    "Not enough free space, you are uploading {size1} but only {size2} is left" : "Níl go leor spáis saor in aisce, tá {size1} á uaslódáil agat ach níl ach {size2} fágtha",
-    "Target folder \"{dir}\" does not exist any more" : "Níl an spriocfhillteán \"{dir}\" ann a thuilleadh",
-    "An unknown error has occurred" : "Tharla earráid anaithnid",
-    "File could not be uploaded" : "Níorbh fhéidir an comhad a uaslódáil",
-    "Uploading …" : "Á uaslódáil…",
-    "{remainingTime} ({currentNumber}/{total})" : "{remainingTime} ({currentNumber}/{total})",
-    "Uploading … ({currentNumber}/{total})" : "Á uaslódáil … ({currentNumber}/{total})",
-    "{loadedSize} of {totalSize} ({bitrate})" : "{loadedSize} di {totalSize} ({bitrate})",
-    "Uploading that item is not supported" : "Ní thacaítear le huaslódáil an mhír sin",
-    "Error when assembling chunks, status code {status}" : "Earráid agus smután á chur le chéile, cód stádais {status}",
-    "Choose target folder" : "Roghnaigh fillteán sprice",
-    "Set reminder" : "Socraigh meabhrúchán",
-    "Edit locally" : "Cuir in eagar go háitiúil",
-    "Open" : "Oscail",
-    "Could not load info for file \"{file}\"" : "Níorbh fhéidir faisnéis don chomhad \"{file}\" a lódáil",
-    "Please select tag(s) to add to the selection" : "Roghnaigh clib(í) le cur leis an rogha le do thoil",
-    "Apply tag(s) to selection" : "Cuir clib(í) i bhfeidhm ar an roghnúchán",
-    "Select directory \"{dirName}\"" : "Roghnaigh eolaire \"{dirName}\"",
-    "Select file \"{fileName}\"" : "Roghnaigh comhad \"{fileName}\"",
-    "Unable to determine date" : "Ní féidir an dáta a chinneadh",
-    "This directory is unavailable, please check the logs or contact the administrator" : "Níl an t-eolaire seo ar fáil, seiceáil na logaí nó déan teagmháil leis an riarthóir le do thoil",
-    "Could not move \"{file}\", target exists" : "Níorbh fhéidir \"{file}\" a bhogadh, tá an sprioc ann",
-    "Could not move \"{file}\"" : "Níorbh fhéidir \"{file}\" a bhogadh",
-    "copy" : "cóip",
-    "Could not copy \"{file}\", target exists" : "Níorbh fhéidir \"{file}\" a chóipeáil, tá an sprioc ann",
-    "Could not copy \"{file}\"" : "Níorbh fhéidir \"{file}\" a chóipeáil",
-    "Copied {origin} inside {destination}" : "Cóipeáladh {origin} taobh istigh de {destination}",
-    "Copied {origin} and {nbfiles} other files inside {destination}" : "Cóipeáladh {origin} agus {nbfiles} comhaid eile laistigh de {destination}",
-    "{newName} already exists" : "Tá {newName} ann cheana",
-    "Could not create file \"{file}\"" : "Níorbh fhéidir comhad \"{file}\" a chruthú",
-    "Could not create file \"{file}\" because it already exists" : "Níorbh fhéidir an comhad \"{file}\" a chruthú toisc go bhfuil sé ann cheana",
-    "Could not create folder \"{dir}\" because it already exists" : "Níorbh fhéidir fillteán \"{dir}\" a chruthú toisc go bhfuil sé ann cheana",
-    "Could not fetch file details \"{file}\"" : "Níorbh fhéidir sonraí an chomhaid \"{file}\" a fháil",
-    "Error deleting file \"{fileName}\"." : "Earráid agus comhad \"{fileName}\" á scriosadh.",
-    "No search results in other folders for {tag}{filter}{endtag}" : "Níl aon toradh cuardaigh i bhfillteáin eile le haghaidh {tag}{filter}{endtag}",
-    "Enter more than two characters to search in other folders" : "Cuir isteach níos mó ná dhá charachtar chun cuardach a dhéanamh i bhfillteáin eile",
-    "{dirs} and {files}" : "{dirs} agus {files}",
-    "_including %n hidden_::_including %n hidden_" : ["lena n-áirítear %n i bhfolach","lena n-áirítear %n i bhfolach","lena n-áirítear %n i bhfolach","lena n-áirítear %n i bhfolach","lena n-áirítear %n i bhfolach"],
-    "You do not have permission to upload or create files here" : "Níl cead agat comhaid a uaslódáil nó a chruthú anseo",
-    "_Uploading %n file_::_Uploading %n files_" : ["%n comhad á uaslódáil","%n comhaid á uaslódáil","%n comhaid á uaslódáil","%n comhaid á uaslódáil","%n comhaid á uaslódáil"],
-    "New" : "Nua",
-    "New file/folder menu" : "New file/folder menu",
-    "Select file range" : "Roghnaigh raon comhaid",
-    "{used}%" : "{used}%",
-    "{used} used" : "{used} in úsáid",
-    "\"{name}\" is an invalid file name." : "Is ainm comhaid neamhbhailí é \"{name}\".",
-    "File name cannot be empty." : "Ní féidir leis an ainm comhaid a bheith folamh.",
-    "\"/\" is not allowed inside a file name." : "Ní cheadaítear \"/\" taobh istigh d'ainm comhaid.",
-    "\"{name}\" is not an allowed filetype" : "Ní cineál comhaid ceadaithe é \"{name}\".",
-    "Storage of {owner} is full, files cannot be updated or synced anymore!" : "Tá stóráil {owner} lán, ní féidir comhaid a nuashonrú ná a shioncronú a thuilleadh!",
-    "Group folder \"{mountPoint}\" is full, files cannot be updated or synced anymore!" : "Tá fillteán grúpa \"{mountPoint}\" lán, ní féidir comhaid a nuashonrú nó a shioncronú a thuilleadh!",
-    "External storage \"{mountPoint}\" is full, files cannot be updated or synced anymore!" : "Tá an stóras seachtrach \"{mountPoint}\" lán, ní féidir comhaid a nuashonrú ná a shioncronú a thuilleadh!",
-    "Your storage is full, files cannot be updated or synced anymore!" : "Tá do stóras lán, ní féidir comhaid a nuashonrú ná a shioncronú a thuilleadh!",
-    "Storage of {owner} is almost full ({usedSpacePercent}%)." : "Tá stóráil {owner} beagnach lán ({usedSpacePercent}%).",
-    "Group folder \"{mountPoint}\" is almost full ({usedSpacePercent}%)." : "Tá fillteán grúpa \"{mountPoint}\" beagnach lán ({usedSpacePercent}%).",
-    "External storage \"{mountPoint}\" is almost full ({usedSpacePercent}%)." : "Tá an stóras seachtrach \"{mountPoint}\" beagnach lán ({usedSpacePercent}%).",
-    "Your storage is almost full ({usedSpacePercent}%)." : "Tá do stóras beagnach lán ({usedSpacePercent}%).",
-    "_matches \"{filter}\"_::_match \"{filter}\"_" : ["meaitseálann \"{filter}\"","mheaitseáil \"{filter}\"","mheaitseáil \"{filter}\"","mheaitseáil \"{filter}\"","mheaitseáil \"{filter}\""],
-    "Direct link was copied (only works for people who have access to this file/folder)" : "Cóipeáladh nasc díreach (oibreacha do dhaoine a bhfuil rochtain acu ar an gcomhad/fillteán seo amháin)",
-    "Path" : "Cosán",
-    "_%n byte_::_%n bytes_" : ["%n beart ","%n bearta ","%n bearta","%n bearta","%n bearta"],
-    "Favored" : "B'fhearr leis",
-    "Favor" : "Fabhar",
-    "Copy direct link (only works for people who have access to this file/folder)" : "Cóipeáil nasc díreach (ní oibríonn ach do dhaoine a bhfuil rochtain acu ar an gcomhad/fillteán seo)",
-    "Upload file" : "Uaslódáil comhad",
-    "Not favored" : "Ní bail ar fónamh orthu",
-    "An error occurred while trying to update the tags" : "Tharla earráid agus iarracht á déanamh na clibeanna a nuashonrú",
+    "%1$s (renamed)" : "%1$s (athainmnithe)",
+    "renamed file" : "comhad athainmnithe",
     "Upload (max. %s)" : "Uaslódáil (%s ar a mhéad)",
-    "\"{displayName}\" action executed successfully" : "Cuireadh an gníomh \"{displayName}\" i gcrích go rathúil",
-    "\"{displayName}\" action failed" : "Theip ar an ngníomh \"{displayName}\".",
+    "After enabling the windows compatible filenames, existing files cannot be modified anymore but can be renamed to valid new names by their owner." : "Tar éis na hainmneacha comhad atá comhoiriúnach le Windows a chumasú, ní féidir comhaid atá ann cheana a mhodhnú a thuilleadh ach is féidir lena n-úinéir iad a athainmniú go hainmneacha nua bailí.",
+    "It is also possible to migrate files automatically after enabling this setting, please refer to the documentation about the occ command." : "Is féidir comhaid a aistriú go huathoibríoch freisin tar éis an socrú seo a chumasú, féach ar an doiciméadú faoin ordú occ.",
+    "Renamed \"{oldName}\" to \"{newName}\"" : "Athainmnithe \"{oldName}\" go \"{newName}\"",
+    "Clear filter" : "Glan an scagaire",
     "\"{displayName}\" failed on some elements" : "\"{displayName}\" theip ar roinnt gnéithe",
     "\"{displayName}\" batch action executed successfully" : "D'éirigh le beart baisce \"{displayName}\" a rith",
-    "Submitting fields…" : "Réimsí á gcur isteach…",
-    "Filter filenames…" : "Scag ainmneacha comhaid…",
+    "\"{displayName}\" action failed" : "Theip ar an ngníomh \"{displayName}\".",
+    "Submitting fields …" : "Réimsí á gcur isteach…",
+    "Shared by link" : "Roinnte ag nasc",
+    "Shared" : "Roinnte",
+    "\"{displayName}\" action executed successfully" : "Cuireadh an gníomh \"{displayName}\" i gcrích go rathúil",
+    "Filter file names …" : "Scag ainmneacha na gcomhad…",
+    "Clipboard is not available" : "Níl fáil ar an ngearrthaisce",
     "WebDAV URL copied to clipboard" : "URL WebDAV cóipeáilte chuig an ngearrthaisce",
     "Enable the grid view" : "Cumasaigh an radharc greille",
     "Enable folder tree" : "Cumasaigh crann fillteáin",
+    "WebDAV" : "WebDAV",
     "Copy to clipboard" : "Cóipeáil chuig an ngearrthaisce",
     "Use this address to access your Files via WebDAV" : "Úsáid an seoladh seo chun do Chomhaid a rochtain trí WebDAV",
     "If you have enabled 2FA, you must create and use a new app password by clicking here." : "Má tá 2FA cumasaithe agat, ní mór duit pasfhocal aip nua a chruthú agus a úsáid trí chliceáil anseo.",
-    "Deletion cancelled" : "Scriosadh cealaithe",
-    "Move cancelled" : "Bogadh ar ceal",
-    "Cancelled move or copy of \"{filename}\"." : "Cealaíodh bogadh nó cóip de \"{filename}\".",
-    "Cancelled move or copy operation" : "Oibríocht aistrithe nó cóipeála curtha ar ceal",
-    "Open details" : "Sonraí oscailte",
-    "Photos and images" : "Grianghraif agus íomhánna",
-    "New folder creation cancelled" : "Cruthú fillteán nua curtha ar ceal",
-    "_{folderCount} folder_::_{folderCount} folders_" : ["{folderCount} fillteán","{folderCount} fillteáin","{folderCount} fillteáin","{folderCount} fillteáin","{folderCount} fillteáin"],
-    "_{fileCount} file_::_{fileCount} files_" : ["{fileCount} comhad","{fileCount} comhaid","{fileCount} comhaid","{fileCount} comhaid","{fileCount} comhaid"],
-    "_1 file and {folderCount} folder_::_1 file and {folderCount} folders_" : ["1 chomhad agus {folderCount} fillteán","1 chomhad agus {folderCount} fillteáin","1 chomhad agus {folderCount} fillteáin","1 chomhad agus {folderCount} fillteáin","1 chomhad agus {folderCount} fillteáin"],
-    "_{fileCount} file and 1 folder_::_{fileCount} files and 1 folder_" : ["{fileCount} comhad agus 1 fillteán","{fileCount} comhaid agus 1 fillteán","{fileCount} comhaid agus 1 fillteán","{fileCount} comhaid agus 1 fillteán","{fileCount} comhaid agus 1 fillteán"],
-    "{fileCount} files and {folderCount} folders" : "comhaid {fileCount} agus fillteáin {folderCount}",
-    "All folders" : "Gach fillteáin",
-    "Personal Files" : "Comhaid Phearsanta",
-    "Text file" : "Comhad téacs",
-    "New text file.txt" : "Comhad téacs nua.txt",
-    "%1$s (renamed)" : "%1$s (athainmnithe)",
-    "renamed file" : "comhad athainmnithe",
-    "After enabling the windows compatible filenames, existing files cannot be modified anymore but can be renamed to valid new names by their owner." : "Tar éis na hainmneacha comhad atá comhoiriúnach le Windows a chumasú, ní féidir comhaid atá ann cheana a mhodhnú a thuilleadh ach is féidir lena n-úinéir iad a athainmniú go hainmneacha nua bailí.",
-    "It is also possible to migrate files automatically after enabling this setting, please refer to the documentation about the occ command." : "Is féidir comhaid a aistriú go huathoibríoch freisin tar éis an socrú seo a chumasú, féach ar an doiciméadú faoin ordú occ.",
-    "Filter file names …" : "Scag ainmneacha na gcomhad…",
     "Prevent warning dialogs from open or reenable them." : "Cosc a chur ar dialóga rabhaidh ó iad a oscailt nó iad a athchumasú.",
     "Show a warning dialog when changing a file extension." : "Taispeáin dialóg rabhaidh nuair a athraítear síneadh comhad.",
+    "Keyboard shortcuts" : "Aicearraí méarchláir",
     "Speed up your Files experience with these quick shortcuts." : "Déan do thaithí Comhaid a bhrostú leis na haicearraí tapa seo.",
     "Open the actions menu for a file" : "Oscail an roghchlár gníomhartha le haghaidh comhad",
     "Rename a file" : "Athainmnigh comhad",
@@ -522,6 +436,32 @@ OC.L10N.register(
     "Navigate to the file on the left (in grid mode)" : "Déan nascleanúint go dtí an comhad ar chlé (i mód greille)",
     "Navigate to the file on the right (in grid mode)" : "Déan nascleanúint go dtí an comhad ar dheis (i mód greille)",
     "Toggle the grid view" : "Scoránaigh an radharc greille",
-    "Open the sidebar for a file" : "Oscail an barra taoibh le haghaidh comhad"
+    "Open the sidebar for a file" : "Oscail an barra taoibh le haghaidh comhad",
+    "You" : "tú",
+    "Shared multiple times with different people" : "Roinnte go minic le daoine éagsúla",
+    "Unable to change the favorite state of the file" : "Ní féidir staid an chomhaid is fearr leat a athrú",
+    "Error while loading the file data" : "Earráid agus sonraí an chomhaid á lódáil",
+    "Tags" : "Clibeanna",
+    "Save as …" : "Sábháil mar…",
+    "Converting files …" : "Comhaid á thiontú…",
+    "Converting file …" : "Comhad á thiontú…",
+    "Deletion cancelled" : "Scriosadh cealaithe",
+    "Edit locally" : "Cuir in eagar go háitiúil",
+    "Moving \"{source}\" to \"{destination}\" …" : "Ag bogadh \"{source}\" go \"{destination}\" ...",
+    "Copying \"{source}\" to \"{destination}\" …" : "“{source}” á chóipeáil go “{destination}”…",
+    "(copy)" : "(cóip)",
+    "(copy %n)" : "(cóip %n)",
+    "Move cancelled" : "Bogadh ar ceal",
+    "Cancelled move or copy of \"{filename}\"." : "Cealaíodh bogadh nó cóip de \"{filename}\".",
+    "Cancelled move or copy operation" : "Oibríocht aistrithe nó cóipeála curtha ar ceal",
+    "Open details" : "Sonraí oscailte",
+    "Photos and images" : "Grianghraif agus íomhánna",
+    "New folder creation cancelled" : "Cruthú fillteán nua curtha ar ceal",
+    "This directory is unavailable, please check the logs or contact the administrator" : "Níl an t-eolaire seo ar fáil, seiceáil na logaí nó déan teagmháil leis an riarthóir le do thoil",
+    "All folders" : "Gach fillteáin",
+    "Open file sidebar" : "Oscail barra taoibh an chomhaid",
+    "Search everywhere …" : "Cuardaigh i ngach áit…",
+    "Search here …" : "Cuardaigh anseo…",
+    "Preparing …" : "Ag ullmhú …"
 },
 "nplurals=5; plural=(n==1 ? 0 : n==2 ? 1 : n<7 ? 2 : n<11 ? 3 : 4);");
