@@ -45,7 +45,7 @@ OC.L10N.register(
     "A favorite file or folder has been <strong>changed</strong>" : "<strong>Cambiouse</strong> un ficheiro ou cartafol favorito",
     "Failed to authorize" : "Produciuse un fallo ao autorizar",
     "Invalid folder path" : "A ruta ao cartafol non é correcta.",
-    "Folder not found" : "Non se atopou o cartafolNon se atopou o cartafol",
+    "Folder not found" : "Non se atopou o cartafol",
     "The file cannot be found" : "Non é posíbel atopar o ficheiro",
     "The destination path does not exist: %1$s" : "Non existe a ruta de destino: %1$s",
     "You do not have permission to create a file at the specified location" : "Vde. non ten permiso para crear un ficheiro na localización especificada",
@@ -54,7 +54,7 @@ OC.L10N.register(
     "Limit must be a positive integer." : "O límite debe ser un número enteiro positivo.",
     "The replacement character may only be a single character." : "O carácter de substitución só poderá ser un carácter único.",
     "Filename sanitization already started." : "Xa foi iniciado o saneamento dos nomes do ficheiro.",
-    "No filename sanitization inprogress." : "O saneamento dos nomes de ficheiro non está en proceso.",
+    "No filename sanitization in progress." : "O saneamento dos nomes de ficheiro non está en proceso.",
     "Favorite files" : "Ficheiros favoritos",
     "No favorites" : "Non hai favoritos",
     "More favorites" : "Máis favoritos",
@@ -78,6 +78,8 @@ OC.L10N.register(
     "Reload current directory" : "Recargar o directorio actual",
     "Go to the \"{dir}\" directory" : "Vaia ao directorio «{dir}».",
     "Current directory path" : "Ruta do directorio actual",
+    "Share" : "Compartir",
+    "Reload content" : "Recargar o contido",
     "Your have used your space quota and cannot upload files anymore" : "Vde. usou a súa cota de espazo e xa non pode enviar ningún ficheiro más",
     "You do not have permission to upload or create files here." : "Non ten permiso para enviar ou crear ficheiros aquí.",
     "Drag and drop files here to upload" : "Arrastre e solte os ficheiros aquí para envialos",
@@ -92,7 +94,6 @@ OC.L10N.register(
     "This node is unavailable" : "Este nodo non está dispoñíbel",
     "Another entry with the same name already exists." : "Xa existe outra entrada co mesmo nome.",
     "Invalid filename." : "Nome de ficheiro incorrecto.",
-    "Renamed \"{oldName}\" to \"{newName}\"" : "Cambiouse o nome de «{oldName}» a «{newName}»",
     "Rename file" : "Cambiar o nome do ficheiro",
     "Folder" : "Cartafol",
     "Unknown file type" : "Tipo de ficheiro descoñecido",
@@ -102,21 +103,71 @@ OC.L10N.register(
     "{ext} text" : "Texto {ext}",
     "Pending" : "Pendentes",
     "Unknown date" : "Data descoñecida",
-    "Clear filter" : "Limpar o filtro",
-    "Modified" : "Modificado",
-    "Search everywhere" : "Buscar en todos os sitios",
-    "Type" : "Escribir",
     "Active filters" : "Filtros activos",
     "Remove filter" : "Retirar o filtro",
+    "Today" : "Hoxe",
+    "Last 7 days" : "Últimos 7 días",
+    "Last 30 days" : "Últimos 30 días",
+    "This year ({year})" : "Este ano ({year})",
+    "Last year ({year})" : "O ano pasado ({year})",
+    "Custom range" : "Intervalo personalizado",
+    "Custom date range" : "Intervalo de datas personalizado",
+    "Search everywhere" : "Buscar en todos os sitios",
+    "Documents" : "Documentos",
+    "Spreadsheets" : "Follas de cálculo",
+    "Presentations" : "Presentacións",
+    "PDFs" : "PDF",
+    "Folders" : "Cartafoles",
+    "Audio" : "Son",
+    "Images" : "Imaxes",
+    "Videos" : "Vídeos",
+    "Filters" : "Filtros",
+    "Back to filters" : "Volver aos filtros",
+    "Appearance" : "Aparencia",
+    "Show hidden files" : "Amosar os ficheiros agochados",
+    "Show file type column" : "Amosar a columna de tipo de ficheiro",
+    "Show file extensions" : "Amosar as extensións de ficheiro",
+    "Crop image previews" : "Recortar a vista previa das imaxes",
+    "General" : "Xeral",
+    "Sort favorites first" : "Ordenar primeiro os favoritos",
+    "Sort folders before files" : "Ordenar os cartafoles antes que os ficheiros",
+    "Enable folder tree view" : "Activar a vista en árbore de cartafoles",
+    "Default view" : "Vista predeterminada",
+    "All files" : "Todos os ficheiros",
+    "Personal files" : "Ficheiros persoais",
+    "Additional settings" : "Axustes adicionais",
+    "Actions" : "Accións",
+    "File actions" : "Accións de ficheiro",
+    "Selection" : "Selección",
+    "Select all files" : "Seleccionar todos os ficheiros",
+    "Deselect all" : "Deseleccionar todo",
+    "Select or deselect" : "Seleccionar ou deseleccionar",
+    "Select a range" : "Seleccionar un intervalo",
+    "Navigation" : "Navegación",
+    "Go to parent folder" : "Ir ao cartafol superior",
+    "Go to file above" : "Ir ao ficheiro de arriba",
+    "Go to file below" : "Ir ao ficheiro de abaixo",
+    "Go left in grid" : "Ir á esquerda na grella",
+    "Go right in grid" : "Ir á dereita na grella",
+    "View" : "Ver",
+    "Toggle grid view" : "Alternar a vista como grade",
+    "Show those shortcuts" : "Amosar eses atallos",
+    "Warnings" : "Advertencias",
+    "Warn before changing a file extension" : "Advertir antes de cambiar unha extensión de ficheiro",
+    "Warn before deleting a file" : "Advertir antes de borrar un ficheiro",
+    "WebDAV URL" : "URL de WebDAV",
+    "Create an app password" : "Crear un contrasinal de aplicación",
+    "Required for WebDAV authentication because Two-Factor Authentication is enabled for this account." : "É necesario para a autenticación WebDAV porque a autenticación de dous factores está activada para esta conta.",
+    "How to access files using WebDAV" : "Como acceder aos ficheiros empregando WebDAV",
     "Total rows summary" : "Resumo total de filas",
     "Toggle selection for all files and folders" : "Conmutar a selección para todos os ficheiros e cartafoles",
     "Name" : "Nome",
     "File type" : "Tipo do ficheiro",
     "Size" : "Tamaño",
+    "Modified" : "Modificado",
     "{displayName}: failed on some elements" : "Produciuse un fallo nalgúns elementos de {displayName}",
     "{displayName}: done" : "{displayName}: feito",
     "{displayName}: failed" : "{displayName}: produciuse un fallo",
-    "Actions" : "Accións",
     "(selected)" : "(seleccionado)",
     "List of files and folders." : "Lista de ficheiros e cartafoles",
     "You have used your space quota and cannot upload files anymore." : "Vde. usou a súa cota de espazo e xa non pode enviar ningún ficheiro más",
@@ -124,10 +175,11 @@ OC.L10N.register(
     "This list is not fully rendered for performance reasons. The files will be rendered as you navigate through the list." : "Esta lista non se representa de xeito completo por mor do rendemento. Os ficheiros represéntanse mentres se despraza pola lista.",
     "File not found" : "Non se atopou o ficheiro",
     "_{count} selected_::_{count} selected_" : ["{count} seleccionado","{count} seleccionados"],
-    "Search everywhere …" : "Buscar en todos os sitios…",
-    "Search here …" : "Buscar aquí…",
+    "Search everywhere …" : "Buscar en todos os sitios…",
+    "Search here …" : "Buscar aquí…",
     "Search scope options" : "Opcións do alcance da busca",
     "Search here" : "Buscar aquí",
+    "Owner" : "Propietario",
     "{usedQuotaByte} used" : "{usedQuotaByte} usado",
     "{used} of {quota} used" : "Usados {used} de {quota}",
     "{relative}% used" : "{relative}% usado",
@@ -144,7 +196,7 @@ OC.L10N.register(
     "Failed to refresh filename sanitization status." : "Produciuse un fallo ao actualizar o estado de saneamento dos nomes de ficheiro.",
     "Filename sanitization in progress." : "O saneamento dos nomes de ficheiro está en proceso.",
     "Currently {processedUsers} of {totalUsers} accounts are already processed." : "Xa foron procesadas {processedUsers} de {totalUsers} contas.",
-    "Preparing …" : "Preparando…",
+    "Preparing …" : "Preparando…",
     "Refresh" : "Actualizar",
     "All files have been santized for Windows filename support." : "Todos os ficheiros foron saneados para que sexan compatíbeis cos nomes de ficheiro de Windows.",
     "Some files could not be sanitized, please check your logs." : "Non foi posíbel sanear algúns ficheiros, revise os rexistros.",
@@ -159,7 +211,7 @@ OC.L10N.register(
     "Sanitize filenames" : "Sanear os nomes dos ficheiros",
     "(starting)" : "(iniciando)",
     "Fill template fields" : "Encher os campos do modelo",
-    "Submitting fields …" : "Enviando os campos...",
+    "Submitting fields …" : "Enviando os campos...",
     "Submit" : "Enviar",
     "Choose a file or folder to transfer" : "Escolla un ficheiro ou cartafol para transferir",
     "Transfer" : "Transferencia",
@@ -181,11 +233,14 @@ OC.L10N.register(
     "Removing the file extension \"{old}\" may render the file unreadable." : "Retirar a extensión de ficheiro «{old}» pode facer que o ficheiro sexa ilexíbel.",
     "Adding the file extension \"{new}\" may render the file unreadable." : "Engadir a extensión de ficheiro «{new}» pode facer que o ficheiro sexa ilexíbel.",
     "Do not show this dialog again." : "Non volver amosar este diálogo",
+    "Rename file to hidden" : "Renomear o ficheiro a agochado",
+    "Prefixing a filename with a dot may render the file hidden." : "Antepor un punto a un nome de ficheiro pode agochalo.",
+    "Are you sure you want to rename the file to \"{filename}\"?" : "Confirma que quere renomear o ficheiro a «{filename}»?",
+    "Cancel" : "Cancelar",
+    "Rename" : "Cambiar o nome",
     "Select file or folder to link to" : "Seleccione o ficheiro ou cartafol ao que ligar",
     "Choose {file}" : "Escoller {file}",
-    "Share" : "Compartir",
-    "Shared by link" : "Compartido por ligazón",
-    "Shared" : "Compartido",
+    "Files settings" : "Axustes de Ficheiros",
     "Switch to list view" : "Cambiar á vista de lista",
     "Switch to grid view" : "Cambiar á vista de grade",
     "The file could not be found" : "Non foi posíbel atopar o ficheiro",
@@ -195,96 +250,46 @@ OC.L10N.register(
     "Error during upload: {message}" : "Produciuse un erro durante o envío: {message}",
     "Error during upload, status code {status}" : "Produciuse un erro durante o envío, código de estado {status}",
     "Unknown error during upload" : "Produciuse un erro descoñecido durante o envío",
+    "File list is reloading" : "Estase a cargar de novo o ficheiro",
     "Loading current folder" : "Cargando o cartafol actual",
     "Retry" : "Volver tentar",
     "No files in here" : "Aquí non hai ficheiros",
     "Upload some content or sync with your devices!" : "Envíe algún contido ou sincronice cos seus dispositivos!",
     "Go back" : "Volver",
     "Views" : "Vistas",
-    "Files settings" : "Axustes de Ficheiros",
+    "Loading …" : "Cargando…",
     "Your files" : "Os seus ficheiros",
     "Open in files" : "Abrir en ficheiros",
     "File cannot be accessed" : "Non é posíbel acceder ao ficheiro",
     "The file could not be found or you do not have permissions to view it. Ask the sender to share it." : "Non foi posíbel atopar o ficheiro ou non ten permiso para velo. Pídalle ao remitente que o comparta.",
     "No search results for “{query}”" : "Sen resultados de busca para «{query}»",
     "Search for files" : "Buscar ficheiros",
-    "Clipboard is not available" : "O portapapeis non está dispoñíbel",
-    "WebDAV URL copied" : "URL de WebDAV copiado",
-    "General" : "Xeral",
-    "Default view" : "Vista predeterminada",
-    "All files" : "Todos os ficheiros",
-    "Personal files" : "Ficheiros persoais",
-    "Sort favorites first" : "Ordene antes os favoritos",
-    "Sort folders before files" : "Ordenar os cartafoles diante dos ficheiros",
-    "Folder tree" : "Árbore de cartafoles",
-    "Appearance" : "Aparencia",
-    "Show hidden files" : "Amosar os ficheiros agochados",
-    "Show file type column" : "Amosar a columna de tipo de ficheiro",
-    "Show file extensions" : "Amosar as extensións de ficheiro",
-    "Crop image previews" : "Recortar a vista previa das imaxes",
-    "Additional settings" : "Axustes adicionais",
-    "WebDAV" : "WebDAV",
-    "WebDAV URL" : "URL de WebDAV",
-    "Copy" : "Copiar",
-    "How to access files using WebDAV" : "Como acceder aos ficheiros empregando WebDAV",
-    "Two-Factor Authentication is enabled for your account, and therefore you need to use an app password to connect an external WebDAV client." : "A autenticación de dous factores está activada para a súa conta e, polo tanto, necesita usar un contrasinal de aplicación para conectar un cliente WebDAV externo.",
-    "Warnings" : "Advertencias",
-    "Warn before changing a file extension" : "Advertir antes de cambiar unha extensión de ficheiro",
-    "Warn before deleting files" : "Advertir antes de borrar ficheiros",
-    "Keyboard shortcuts" : "Atallos de teclado",
-    "File actions" : "Accións de ficheiro",
-    "Rename" : "Cambiar o nome",
-    "Delete" : "Eliminar",
-    "Add or remove favorite" : "Engadir ou retirar favoritos",
-    "Manage tags" : "Xestionar as etiquetas",
-    "Selection" : "Selección",
-    "Select all files" : "Seleccionar todos os ficheiros",
-    "Deselect all" : "Deseleccionar todo",
-    "Select or deselect" : "Seleccionar ou deseleccionar",
-    "Select a range" : "Seleccionar un intervalo",
-    "Navigation" : "Navegación",
-    "Go to parent folder" : "Ir ao cartafol superior",
-    "Go to file above" : "Ir ao ficheiro de arriba",
-    "Go to file below" : "Ir ao ficheiro de abaixo",
-    "Go left in grid" : "Ir á esquerda na grella",
-    "Go right in grid" : "Ir á dereita na grella",
-    "View" : "Ver",
-    "Toggle grid view" : "Alternar a vista como grade",
-    "Open file sidebar" : "Abrir a barra lateral do ficheiro",
-    "Show those shortcuts" : "Amosar eses atallos",
     "Allow to restrict filenames to ensure files can be synced with all clients. By default all filenames valid on POSIX (e.g. Linux or macOS) are allowed." : "Permitir restrinxir os nomes de ficheiros para garantir que os ficheiros se poidan sincronizar con todos os clientes. De xeito predeterminado, permítense todos os nomes de ficheiro válidos en POSIX (p. ex., Linux ou macOS).",
     "After enabling the Windows compatible filenames, existing files cannot be modified anymore but can be renamed to valid new names by their owner." : "Após activar os nomes de ficheiro compatíbeis con Windows, os ficheiros existentes xa non poden ser modificados, mais poden ser renomeados con novos nomes válidos polo seu propietario.",
     "Failed to toggle Windows filename support" : "Poduciuse un fallo ao activar a compatibilidade cos nomes de ficheiro de Windows",
     "Files compatibility" : "Compatibilidade de ficheiros",
     "Enforce Windows compatibility" : "Forzar a compatibilidade con Windows",
     "This will block filenames not valid on Windows systems, like using reserved names or special characters. But this will not enforce compatibility of case sensitivity." : "Isto bloqueará os nomes de ficheiros non válidos en sistemas Windows, coma o uso de nomes reservados ou caracteres especiais. Porén, isto non forzará á compatibilidade da distinción entre maiúsculas e minúsculas.",
-    "You" : "Vde.",
-    "Shared multiple times with different people" : "Compartido varias veces con diferentes persoas",
-    "Unable to change the favorite state of the file" : "Non é posíbel cambiar o estado de favorito do ficheiro",
-    "Error while loading the file data" : "Produciuse un erro ao cargar os datos do ficheiro",
-    "Owner" : "Propietario",
-    "Remove from favorites" : "Retirar de favoritos",
-    "Add to favorites" : "Engadir a favoritos",
-    "Tags" : "Etiquetas",
     "Blank" : "Baleiro",
     "Unable to create new file from template" : "Non é posíbel crear un novo ficheiro a partir do modelo",
     "Pick a template for {name}" : "Escolla un modelo para {name}",
     "Create a new file with the selected template" : "Crear un novo ficheiro co modelo seleccionado",
     "Creating file" : "Creando o ficheiro",
     "Save as {displayName}" : "Gardar como {displayName}",
-    "Save as …" : "Gardar como…",
-    "Converting files …" : "Convertendo ficheiros…",
+    "Save as …" : "Gardar como…",
+    "Converting files …" : "Convertendo ficheiros…",
     "Failed to convert files: {message}" : "Produciuse un fallo ao converter os ficheiros: {message}",
     "All files failed to be converted" : "Non foi posíbel converter ningún ficheiro",
     "One file could not be converted: {message}" : "Non foi posíbel converter un ficheiro: {message}",
-    "_One file could not be converted_::_%n files could not be converted_" : ["Non foi posíbel converter un ficheiro","Non foi posíbel converter %n ficheiros"],
-    "_One file successfully converted_::_%n files successfully converted_" : ["Foi convertido correctamente un ficheiro","%n ficheiros foron convertidos correctamente"],
-    "Files successfully converted" : "Os ficheiros foron convertidos correctamente",
+    "_%n file could not be converted_::_%n files could not be converted_" : ["Non foi posíbel converter %n ficheiro","Non foi posíbel converter %n ficheiros"],
+    "_%n file converted_::_%n files converted_" : ["%n ficheiro convertido","%n ficheiros convertidos"],
+    "Files converted" : "Ficheiros convertidos",
     "Failed to convert files" : "Produciuse un fallo ao converter os ficheiros",
-    "Converting file …" : "Convertendo o ficheiro…",
+    "Converting file …" : "Convertendo o ficheiro…",
     "File successfully converted" : "O ficheiro foi convertido correctamente",
     "Failed to convert file: {message}" : "Produciuse un fallo ao converter o ficheiro: {message}",
     "Failed to convert file" : "Produciuse un fallo ao converter o ficheiro",
+    "Delete" : "Eliminar",
     "Leave this share" : "Deixar esta compartición",
     "Leave these shares" : "Deixar estas comparticións",
     "Disconnect storage" : "Desconectar o almacenamento",
@@ -298,26 +303,30 @@ OC.L10N.register(
     "_You are about to permanently delete {count} item_::_You are about to permanently delete {count} items_" : ["Está a piques de eliminar definitivamente {count} elemento","Está a piques de eliminar definitivamente {count} elementos"],
     "_You are about to delete {count} item_::_You are about to delete {count} items_" : ["Está a piques de eliminar {count} elemento","Está a piques de eliminar {count} elementos"],
     "Confirm deletion" : "Confirmar a eliminación",
-    "Cancel" : "Cancelar",
     "Download" : "Descargar",
-    "The requested file is not available." : "O ficheiro solicitado non está dispoñible.",
+    "The requested file is not available." : "O ficheiro solicitado non está dispoñíbel.",
     "The requested files are not available." : "Os ficheiros solicitados non están dispoñíbeis",
-    "Moving \"{source}\" to \"{destination}\" …" : "Movendo «{source}» a «{destination}»…",
-    "Copying \"{source}\" to \"{destination}\" …" : "Copiando «{source}» en «{destination}»…",
+    "Add to favorites" : "Engadir a favoritos",
+    "Remove from favorites" : "Retirar de favoritos",
+    "Add or remove favorite" : "Engadir ou retirar favoritos",
+    "Move" : "Mover",
+    "Copy" : "Copiar",
+    "Move or copy" : "Mover ou copiar",
     "Destination is not a folder" : "O destino non é un cartafol",
     "This file/folder is already in that directory" : "Este ficheiro/cartafol xa está nese directorio",
     "You cannot move a file/folder onto itself or into a subfolder of itself" : "Non é posíbel mover un ficheiro/cartafol sobre si mesmo ou a un subcartafol de si mesmo",
-    "(copy)" : "(copiar)",
-    "(copy %n)" : "(copiar %n)",
     "A file or folder with that name already exists in this folder" : "Neste cartafol xa existe un ficheiro ou cartafol con ese nome",
     "The files are locked" : "Os ficheiros están bloqueados",
     "The file does not exist anymore" : "O ficheiro xa non existe",
+    "Moving \"{source}\" to \"{destination}\" …" : "Movendo «{source}» a «{destination}»…",
+    "Moving {count} files to \"{destination}\" …" : "Movendo {count} ficheiros a «{destination}»…",
+    "Copying \"{source}\" to \"{destination}\" …" : "Copiando «{source}» en «{destination}»…",
+    "Copying {count} files to \"{destination}\" …" : "Copiando {count} ficheiros en «{destination}»…",
     "Choose destination" : "Escoller o destino",
     "Copy to {target}" : "Copiar en {target}",
     "Move to {target}" : "Mover a {target}",
-    "Move" : "Mover",
     "Move or copy operation failed" : "Produciuse un erro na operación de copia ou de movemento",
-    "Move or copy" : "Mover ou copiar",
+    "Open folder" : "Abrir o cartafol",
     "Open folder {displayName}" : "Abrir o cartafol  {displayName}",
     "Open in Files" : "Abrir en Ficheiros",
     "Open locally" : "Abrir localmente",
@@ -327,39 +336,30 @@ OC.L10N.register(
     "Retry and close" : "Tentar de novo e pechar",
     "Open online" : "Abrir en liña",
     "Details" : "Detalles",
+    "Open the details sidebar" : "Abrir a barra lateral de detalles",
+    "Unfavorite" : "Retirar de favoritos",
     "View in folder" : "Ver no cartafol",
-    "Today" : "Hoxe",
-    "Last 7 days" : "Últimos 7 días",
-    "Last 30 days" : "Últimos 30 días",
-    "This year ({year})" : "Este ano ({year})",
-    "Last year ({year})" : "O ano pasado ({year})",
-    "Documents" : "Documentos",
-    "Spreadsheets" : "Follas de cálculo",
-    "Presentations" : "Presentacións",
-    "PDFs" : "PDF",
-    "Folders" : "Cartafoles",
-    "Audio" : "Son",
-    "Images" : "Imaxes",
-    "Videos" : "Vídeos",
+    "Type" : "Escribir",
     "Created new folder \"{name}\"" : "Creouse un novo cartafol «{name}»",
-    "Unable to initialize the templates directory" : "Non é posíbel iniciar o directorio de modelos",
+    "Unable to initialize the templates directory" : "Non é posíbel preparar o directorio de modelos",
     "Create templates folder" : "Crear o cartafol de modelos",
     "Templates" : "Modelos",
     "New template folder" : "Novo cartafol de modelos",
     "In folder" : "No cartafol",
+    "Pick folder to search in" : "Escolla o cartafol no que buscar",
     "Search in all files" : "Buscar en todos os ficheiros",
     "Search in folder: {folder}" : "Buscar no cartafol: {folder}",
     "One of the dropped files could not be processed" : "Non foi posíbel procesar un dos ficheiros arrastrados",
     "Your browser does not support the Filesystem API. Directories will not be uploaded" : "O seu navegador non é compatíbel coa API do sistema de ficheiros. Os directorios non van ser enviados",
     "No files to upload" : "Non hai ficheiros que enviar",
-    "Unable to create the directory {directory}" : "Non foi posíbel crear o directorio {directory}",
+    "Unable to create the directory {directory}" : "Non é posíbel crear o directorio {directory}",
     "Some files could not be uploaded" : "Non foi posíbel enviar algúns ficheiros",
     "Files uploaded successfully" : "Ficheiros enviados satisfactoriamente",
     "No files to process" : "Non hai ficheiros para procesar",
-    "Some files could not be copied" : "Non foi posíbel copiar algúns ficheiros",
-    "Some files could not be moved" : "Non foi posíbel mover algúns ficheiros",
     "Files copied successfully" : "Ficheiros copiados correctamente",
     "Files moved successfully" : "Ficheiros movidos correctamente",
+    "Some files could not be copied" : "Non foi posíbel copiar algúns ficheiros",
+    "Some files could not be moved" : "Non foi posíbel mover algúns ficheiros",
     "Conflicts resolution skipped" : "Omitiuse a resolución dos conflitos",
     "Upload cancelled" : "Envío cancelado",
     "Could not rename \"{oldName}\", it does not exist any more" : "Non foi posíbel cambiarlle o nome a «{oldName}», xa non existe",
@@ -381,6 +381,7 @@ OC.L10N.register(
     "No favorites yet" : "Aínda non hai favoritos",
     "Files and folders you mark as favorite will show up here" : "Os ficheiros e cartafoles que marque como favoritos amosaranse aquí",
     "List of your files and folders." : "Lista dos seus ficheiros e cartafoles",
+    "Folder tree" : "Árbore de cartafoles",
     "List of your files and folders that are not shared." : "Lista dos seus ficheiros e cartafoles que non están a seren compartidos.",
     "No personal files found" : "Non se atopou ningún ficheiro persoal",
     "Files that are not shared will show up here." : "Os ficheiros que non se comparten amosaranse aquí.",
@@ -394,119 +395,32 @@ OC.L10N.register(
     "Select all" : "Seleccionar todo",
     "Upload too large" : "Envío grande de máis",
     "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Os ficheiros que tenta enviar exceden do tamaño máximo permitido neste servidor",
-    "File could not be found" : "Non foi posíbel atopar o ficheiro",
-    "Show list view" : "Amosar a vista de lista",
-    "Show grid view" : "Amosar a vista de grade",
-    "Close" : "Pechar",
-    "Could not create folder \"{dir}\"" : "Non foi posíbel crear o cartafol «{dir}»",
-    "This will stop your current uploads." : "Isto deterá os envíos actuais.",
-    "Upload cancelled." : "Envío cancelado.",
-    "Processing files …" : "Procesando ficheiros…",
-    "…" : "…",
-    "Unable to upload {filename} as it is a directory or has 0 bytes" : "Non é posíbel enviar {filename}, xa que ou é un directorio ou ten 0 bytes",
-    "Not enough free space, you are uploading {size1} but only {size2} is left" : "Non hai espazo libre abondo, o seu envío é de {size1} mais só dispón de {size2}",
-    "Target folder \"{dir}\" does not exist any more" : "O cartafol de destino «{dir}» xa non existe",
-    "An unknown error has occurred" : "Produciuse un erro descoñecido",
-    "File could not be uploaded" : "Non foi posíbel enviar o ficheiro",
-    "Uploading …" : "Enviando…",
-    "{remainingTime} ({currentNumber}/{total})" : "{remainingTime} ({currentNumber}/{total})",
-    "Uploading … ({currentNumber}/{total})" : "Enviando… ({currentNumber}/{total})",
-    "{loadedSize} of {totalSize} ({bitrate})" : "{loadedSize} de {totalSize} ({bitrate})",
-    "Uploading that item is not supported" : "Non se admite o envío deste elemento",
-    "Error when assembling chunks, status code {status}" : "Produciuse un erro ao ensamblar os bloques, código de estado {status}",
-    "Choose target folder" : "Escoller o cartafol de destino",
-    "Set reminder" : "Definir un lembrete",
-    "Edit locally" : "Editar localmente",
-    "Open" : "Abrir",
-    "Could not load info for file \"{file}\"" : "Non foi posíbel cargar información para o ficheiro «{file}»",
-    "Please select tag(s) to add to the selection" : "Escolla a etiqueta(s) para engadir á selección",
-    "Apply tag(s) to selection" : "Aplicar etiqueta(s) á selección",
-    "Select directory \"{dirName}\"" : "Seleccione o directorio «{dirName}»",
-    "Select file \"{fileName}\"" : "Seleccione o ficheiro «{fileName}»",
-    "Unable to determine date" : "Non é posíbel determinar a data",
-    "This directory is unavailable, please check the logs or contact the administrator" : "Este directorio non está dispoñíbel, consulte os ficheiros de rexistro ou póñase en contacto coa administración desta instancia.",
-    "Could not move \"{file}\", target exists" : "Non foi posíbel mover «{file}», o destino xa existe",
-    "Could not move \"{file}\"" : "Non foi posíbel mover «{file}»",
-    "copy" : "copiar",
-    "Could not copy \"{file}\", target exists" : "Non foi posíbel copiar «{file}», o destino xa existe",
-    "Could not copy \"{file}\"" : "Non foi posíbel copiar «{file}",
-    "Copied {origin} inside {destination}" : "Copiado {origin} en {destination}",
-    "Copied {origin} and {nbfiles} other files inside {destination}" : "Copiado {origin} e outros {nbfiles} ficheiros en {destination} ",
-    "{newName} already exists" : "Xa existe {newName}",
-    "Could not create file \"{file}\"" : "Non foi posíbel crear o ficheiro «{file}»",
-    "Could not create file \"{file}\" because it already exists" : "Non foi posíbel crear o ficheiro «{file}» por mor de que xa existe",
-    "Could not create folder \"{dir}\" because it already exists" : "Non foi posíbel crear o cartafol «{dir}» por mor de que xa existe",
-    "Could not fetch file details \"{file}\"" : "Non foi posíbel recuperar os detalles do ficheiro «{file}»",
-    "Error deleting file \"{fileName}\"." : "Produciuse un erro ao eliminar o ficheiro «{fileName}».",
-    "No search results in other folders for {tag}{filter}{endtag}" : "Non foi posíbel atopar resultados de busca noutros cartafoles para {tag}{filter}{endtag}",
-    "Enter more than two characters to search in other folders" : "Introduza máis de dous caracteres para buscar noutros cartafoles",
-    "{dirs} and {files}" : "{dirs} e {files}",
-    "_including %n hidden_::_including %n hidden_" : ["incluíndo %n agachado","incluíndo %n agochados"],
-    "You do not have permission to upload or create files here" : "Non ten permiso para enviar ou crear ficheiros aquí",
-    "_Uploading %n file_::_Uploading %n files_" : ["Enviando %n ficheiro","Enviando %n ficheiros"],
-    "New" : "Novo",
-    "New file/folder menu" : "Novo menú ficheiro/cartafol",
-    "Select file range" : "Seleccionar o intervalo de ficheiros ",
-    "{used}%" : "{used}%",
-    "{used} used" : "{used} usados",
-    "\"{name}\" is an invalid file name." : "«{name}» é un nome incorrecto de ficheiro.",
-    "File name cannot be empty." : "O nome de ficheiro non pode estar baleiro",
-    "\"/\" is not allowed inside a file name." : "«/» non está permitido nun nome de ficheiro",
-    "\"{name}\" is not an allowed filetype" : "«{name}» non é un tipo de ficheiro permitido",
-    "Storage of {owner} is full, files cannot be updated or synced anymore!" : "O espazo de almacenamento de {owner} está cheo, xa é posíbel actualizar nin sincronizar os ficheiros!",
-    "Group folder \"{mountPoint}\" is full, files cannot be updated or synced anymore!" : "O cartafol «{mountPoint}» do grupo está completo, non se poderán actualizar nin sincronizar ficheiros!",
-    "External storage \"{mountPoint}\" is full, files cannot be updated or synced anymore!" : "O almacenamento externo «{mountPoint}» está cheo, xa non é posíbel actualizar nin sincronizar os ficheiros.",
-    "Your storage is full, files cannot be updated or synced anymore!" : "O seu espazo de almacenamento está cheo, xa non é posíbel actualizar nin sincronizar os ficheiros!",
-    "Storage of {owner} is almost full ({usedSpacePercent}%)." : "O espazo de almacenamento de {owner} está case cheo ({usedSpacePercent}%).",
-    "Group folder \"{mountPoint}\" is almost full ({usedSpacePercent}%)." : "O cartafol de grupo «{mountPoint}» está case cheo ({usedSpacePercent}%).",
-    "External storage \"{mountPoint}\" is almost full ({usedSpacePercent}%)." : "O almacenamento externo «{mountPoint}» está case cheo ({usedSpacePercent}%)",
-    "Your storage is almost full ({usedSpacePercent}%)." : "O seu espazo de almacenamento está case cheo ({usedSpacePercent}%).",
-    "_matches \"{filter}\"_::_match \"{filter}\"_" : ["coincide con «{filter}»","coinciden con «{filter}»"],
-    "Direct link was copied (only works for people who have access to this file/folder)" : "Foi copiada a ligazón directa (só funciona para as persoas que teñen acceso a este ficheiro/cartafol)",
-    "Path" : "Ruta",
-    "_%n byte_::_%n bytes_" : ["%n byte","%n bytes"],
-    "Favored" : "Favorecido",
-    "Favor" : "Favorecer",
-    "Copy direct link (only works for people who have access to this file/folder)" : "Copiar a ligazón directa (só funciona para persoas con acceso a este ficheiro/cartafol)",
-    "Upload file" : "Enviar ficheiro",
-    "Not favored" : "Non favorecido",
-    "An error occurred while trying to update the tags" : "Produciuse un erro ao tentar actualizar as etiquetas",
+    "%1$s (renamed)" : "%1$s (renomeado)",
+    "renamed file" : "ficheiro renomeado",
     "Upload (max. %s)" : "Envío (máx. %s)",
-    "\"{displayName}\" action executed successfully" : "A acción «{displayName}» executouse correctamente",
-    "\"{displayName}\" action failed" : "Produciuse un fallo na acción «{displayName}»",
+    "After enabling the windows compatible filenames, existing files cannot be modified anymore but can be renamed to valid new names by their owner." : "Após activar os nomes de ficheiro compatíbeis con Windows, os ficheiros existentes xa non poden ser modificados, mais poden ser renomeados con novos nomes válidos polo seu propietario.",
+    "It is also possible to migrate files automatically after enabling this setting, please refer to the documentation about the occ command." : "Tamén é posíbel migrar os ficheiros automaticamente após activar esta configuración, consulte a documentación sobre a orde occ.",
+    "Renamed \"{oldName}\" to \"{newName}\"" : "Cambiouse o nome de «{oldName}» a «{newName}»",
+    "Clear filter" : "Limpar o filtro",
     "\"{displayName}\" failed on some elements" : "Produciuse un fallo nalgúns elementos de «{displayName}»",
     "\"{displayName}\" batch action executed successfully" : "A acción por lotes «{displayName}» executouse correctamente",
-    "Submitting fields…" : "Enviando os campos...",
-    "Filter filenames…" : "Filtrar os nomes de ficheiro…",
+    "\"{displayName}\" action failed" : "Produciuse un fallo na acción «{displayName}»",
+    "Submitting fields …" : "Enviando os campos...",
+    "Shared by link" : "Compartido por ligazón",
+    "Shared" : "Compartido",
+    "\"{displayName}\" action executed successfully" : "A acción «{displayName}» executouse correctamente",
+    "Filter file names …" : "Filtrar os nomes de ficheiro…",
+    "Clipboard is not available" : "O portapapeis non está dispoñíbel",
     "WebDAV URL copied to clipboard" : "O URL de WebDAV foi copiado no portapapeis",
-    "Enable the grid view" : "Activar á vista de grade",
+    "Enable the grid view" : "Activar a vista de grade",
     "Enable folder tree" : "Activar a árbore de cartafoles",
+    "WebDAV" : "WebDAV",
     "Copy to clipboard" : "Copiar no portapapeis.",
     "Use this address to access your Files via WebDAV" : "Empregue este enderezo para acceder ao seu Ficheiros mediante WebDAV",
     "If you have enabled 2FA, you must create and use a new app password by clicking here." : "Se activou 2FA, cree e utilice un novo contrasinal de aplicación premendo aquí.",
-    "Deletion cancelled" : "Foi cancelada a eliminación",
-    "Move cancelled" : "Cancelouse o movemento",
-    "Cancelled move or copy of \"{filename}\"." : "Foi cancelado o movemento ou copia de «{filename}»",
-    "Cancelled move or copy operation" : "Foi cancelada a operación de movemento ou copia",
-    "Open details" : "Abrir detalles",
-    "Photos and images" : "Fotos e imaxes",
-    "New folder creation cancelled" : "Cancelouse a creación dun novo cartafol",
-    "_{folderCount} folder_::_{folderCount} folders_" : ["{folderCount} cartafol","{folderCount} cartafoles"],
-    "_{fileCount} file_::_{fileCount} files_" : ["{fileCount} ficheiro","{fileCount} ficheiros"],
-    "_1 file and {folderCount} folder_::_1 file and {folderCount} folders_" : ["1 ficheiro e {folderCount} cartafol","1 ficheiro e {folderCount} cartafoles"],
-    "_{fileCount} file and 1 folder_::_{fileCount} files and 1 folder_" : ["{fileCount} ficheiro e 1 cartafol","{fileCount} ficheiros e 1 cartafol"],
-    "{fileCount} files and {folderCount} folders" : "{fileCount} ficheiros e {folderCount} cartafoles",
-    "All folders" : "Todos os cartafoles",
-    "Personal Files" : "Ficheiros persoais",
-    "Text file" : "Ficheiro de texto",
-    "New text file.txt" : "Novo ficheiro de texto.txt",
-    "%1$s (renamed)" : "%1$s (renomeado)",
-    "renamed file" : "ficheiro renomeado",
-    "After enabling the windows compatible filenames, existing files cannot be modified anymore but can be renamed to valid new names by their owner." : "Após activar os nomes de ficheiro compatíbeis con Windows, os ficheiros existentes xa non poden ser modificados, mais poden ser renomeados con novos nomes válidos polo seu propietario.",
-    "It is also possible to migrate files automatically after enabling this setting, please refer to the documentation about the occ command." : "Tamén é posíbel migrar os ficheiros automaticamente após activar esta configuración, consulte a documentación sobre a orde occ.",
-    "Filter file names …" : "Filtrar os nomes de ficheiro…",
     "Prevent warning dialogs from open or reenable them." : "Impedir abrir ou reactivar os diálogos de advertencia",
     "Show a warning dialog when changing a file extension." : "Amosar un diálogo de advertencia ao cambiar unha extensión de ficheiro.",
+    "Keyboard shortcuts" : "Atallos de teclado",
     "Speed up your Files experience with these quick shortcuts." : "Acelere a súa experiencia con Ficheiros con estes atallos rápidos.",
     "Open the actions menu for a file" : "Abrir o menú de accións dun ficheiro",
     "Rename a file" : "Cambiar o nome dun ficheiro",
@@ -522,6 +436,32 @@ OC.L10N.register(
     "Navigate to the file on the left (in grid mode)" : "Navegar ata o ficheiro da esquerda (en modo de grade)",
     "Navigate to the file on the right (in grid mode)" : "Navegar ata o ficheiro da dereita (en modo de grade)",
     "Toggle the grid view" : "Cambiar á vista de grade",
-    "Open the sidebar for a file" : "Abrir a barra lateral dun ficheiro"
+    "Open the sidebar for a file" : "Abrir a barra lateral dun ficheiro",
+    "You" : "Vde.",
+    "Shared multiple times with different people" : "Compartido varias veces con diferentes persoas",
+    "Unable to change the favorite state of the file" : "Non é posíbel cambiar o estado de favorito do ficheiro",
+    "Error while loading the file data" : "Produciuse un erro ao cargar os datos do ficheiro",
+    "Tags" : "Etiquetas",
+    "Save as …" : "Gardar como…",
+    "Converting files …" : "Convertendo ficheiros…",
+    "Converting file …" : "Convertendo o ficheiro…",
+    "Deletion cancelled" : "Foi cancelada a eliminación",
+    "Edit locally" : "Editar localmente",
+    "Moving \"{source}\" to \"{destination}\" …" : "Movendo «{source}» a «{destination}»…",
+    "Copying \"{source}\" to \"{destination}\" …" : "Copiando «{source}» en «{destination}»…",
+    "(copy)" : "(copiar)",
+    "(copy %n)" : "(copiar %n)",
+    "Move cancelled" : "Cancelouse o movemento",
+    "Cancelled move or copy of \"{filename}\"." : "Foi cancelado o movemento ou copia de «{filename}»",
+    "Cancelled move or copy operation" : "Foi cancelada a operación de movemento ou copia",
+    "Open details" : "Abrir detalles",
+    "Photos and images" : "Fotos e imaxes",
+    "New folder creation cancelled" : "Cancelouse a creación dun novo cartafol",
+    "This directory is unavailable, please check the logs or contact the administrator" : "Este directorio non está dispoñíbel, consulte os ficheiros de rexistro ou póñase en contacto coa administración desta instancia.",
+    "All folders" : "Todos os cartafoles",
+    "Open file sidebar" : "Abrir a barra lateral do ficheiro",
+    "Search everywhere …" : "Buscar en todos os sitios…",
+    "Search here …" : "Buscar aquí…",
+    "Preparing …" : "Preparando…"
 },
 "nplurals=2; plural=(n != 1);");
