@@ -78,6 +78,7 @@ OC.L10N.register(
     "Reload current directory" : "Jelenlegi könyvtár újratöltése",
     "Go to the \"{dir}\" directory" : "Ugrás a(z) „{dir}” könyvtárhoz",
     "Current directory path" : "Jelenlegi könyvtár útvonala",
+    "Share" : "Megosztás",
     "Your have used your space quota and cannot upload files anymore" : "Már felhasználta a tárhelykvótáját, így már nem tölthet fel fájlokat",
     "You do not have permission to upload or create files here." : "Nincs jogosultsága, hogy fájlokat töltsön fel és hozzon létre itt.",
     "Drag and drop files here to upload" : "Húzza ide a fájlokat a feltöltéshez",
@@ -92,7 +93,6 @@ OC.L10N.register(
     "This node is unavailable" : "Ez az elem nem érhető el",
     "Another entry with the same name already exists." : "Már létezik ilyen nevű bejegyzés.",
     "Invalid filename." : "Érvénytelen fájlnév.",
-    "Renamed \"{oldName}\" to \"{newName}\"" : "A(z) „{oldName}” átnevezve erre: „{newName}”",
     "Rename file" : "Fájl átnevezése",
     "Folder" : "Mappa",
     "Unknown file type" : "Ismeretlen fájltípus",
@@ -102,12 +102,24 @@ OC.L10N.register(
     "{ext} text" : "{ext}-szöveg",
     "Pending" : "Függőben",
     "Unknown date" : "Ismeretlen dátum",
-    "Clear filter" : "Szűrő törlése",
-    "Modified" : "Módosítva",
-    "Search everywhere" : "Keresés mindenhol",
-    "Type" : "Típus",
     "Active filters" : "Aktív szűrők",
     "Remove filter" : "Szűrő eltávolítása",
+    "Today" : "Ma",
+    "Last 7 days" : "Előző 7 nap",
+    "Last 30 days" : "Előző 30 nap",
+    "This year ({year})" : "Idén ({year})",
+    "Last year ({year})" : "Tavaly ({year})",
+    "Custom date range" : "Egyéni dátumtartomány",
+    "Search everywhere" : "Keresés mindenhol",
+    "Documents" : "Dokumentumok",
+    "Spreadsheets" : "Munkafüzetek",
+    "Presentations" : "Bemutatók",
+    "PDFs" : "PDF-ek",
+    "Folders" : "Mappák",
+    "Audio" : "Hangok",
+    "Images" : "Képek",
+    "Videos" : "Videók",
+    "Filters" : "Szűrők",
     "Appearance" : "Megjelenés",
     "Show hidden files" : "Rejtett fájlok megjelenítése",
     "Show file type column" : "Fájltípus oszlop megjelenítése",
@@ -136,7 +148,6 @@ OC.L10N.register(
     "Go right in grid" : "Jobbra ugrás a rácsban",
     "View" : "Nézet",
     "Toggle grid view" : "Rácsnézet be/ki",
-    "Open file sidebar" : "Fájl oldalsáv megnyitása",
     "Show those shortcuts" : "Gyorsbillentyűk megjelenítése",
     "Warnings" : "Figyelmeztetések",
     "Warn before changing a file extension" : "Figyelmeztetés a fájlkiterjesztés módosítása előtt",
@@ -150,6 +161,7 @@ OC.L10N.register(
     "Name" : "Név",
     "File type" : "Fájltípus",
     "Size" : "Méret",
+    "Modified" : "Módosítva",
     "{displayName}: failed on some elements" : "{displayName}: egyes elemeken sikertelen",
     "{displayName}: done" : "{displayName}: kész",
     "{displayName}: failed" : "{displayName}: sikertelen",
@@ -218,12 +230,11 @@ OC.L10N.register(
     "Removing the file extension \"{old}\" may render the file unreadable." : "A fájl „{old}” kiterjesztésének eltávolítása olvashatatlanná teheti azt.",
     "Adding the file extension \"{new}\" may render the file unreadable." : "A fájl „{new}” kiterjesztésének hozzáadása olvashatatlanná teheti azt.",
     "Do not show this dialog again." : "Ne jelenítse meg újra ezt a párbeszédablakot.",
+    "Cancel" : "Mégse",
+    "Rename" : "Átnevezés",
     "Select file or folder to link to" : "Válassza ki a hivatkozandó fájlt vagy mappát",
     "Choose {file}" : "{file} kiválasztása",
     "Files settings" : "Fájlok beállításai",
-    "Share" : "Megosztás",
-    "Shared by link" : "Megosztva hivatkozással",
-    "Shared" : "Megosztva",
     "Switch to list view" : "Váltás listanézetre",
     "Switch to grid view" : "Váltás rácsnézetre",
     "The file could not be found" : "A fájl nem található",
@@ -285,30 +296,27 @@ OC.L10N.register(
     "_You are about to permanently delete {count} item_::_You are about to permanently delete {count} items_" : ["{count} elem végleges törlésére készül","{count} elem végleges törlésére készül"],
     "_You are about to delete {count} item_::_You are about to delete {count} items_" : ["{count} elem törlésére készül","{count} elem törlésére készül"],
     "Confirm deletion" : "Törlés megerősítése",
-    "Cancel" : "Mégse",
     "Download" : "Letöltés",
     "The requested file is not available." : "A kért fájl nem érhető el.",
     "The requested files are not available." : "A kért fájlok nem érhetőek el.",
     "Add to favorites" : "Hozzáadás a kedvencekhez",
     "Remove from favorites" : "Eltávolítás a kedvencekből",
     "Add or remove favorite" : "Kedvenc hozzáadása vagy eltávolítása",
-    "Moving \"{source}\" to \"{destination}\" …" : "A(z) „{source}” áthelyezése ide: „{destination}”…",
-    "Copying \"{source}\" to \"{destination}\" …" : "A(z) „{source}” másolása ide: „{destination}”…",
+    "Move" : "Áthelyezés",
+    "Copy" : "Másolás",
+    "Move or copy" : "Áthelyezés vagy másolás",
     "Destination is not a folder" : "A cél nem mappa",
     "This file/folder is already in that directory" : "Ez a fájl/mappa már létezik a mappában",
     "You cannot move a file/folder onto itself or into a subfolder of itself" : "A fájl/mappa önmagába, vagy saját almappájába áthelyezése nem lehetséges",
-    "(copy)" : "(másolat)",
-    "(copy %n)" : "(%n. másolat)",
     "A file or folder with that name already exists in this folder" : "Már létezik ilyen nevű fájl vagy mappa ebben a mappában",
     "The files are locked" : "A fájlok zárolva vannak",
     "The file does not exist anymore" : "Ez a fájl már nem létezik",
+    "Moving \"{source}\" to \"{destination}\" …" : "A(z) „{source}” áthelyezése ide: „{destination}”…",
+    "Copying \"{source}\" to \"{destination}\" …" : "A(z) „{source}” másolása ide: „{destination}”…",
     "Choose destination" : "Válasszon célt",
     "Copy to {target}" : "Másolás ide: {target}",
-    "Copy" : "Másolás",
     "Move to {target}" : "Áthelyezés ide: {target}",
-    "Move" : "Áthelyezés",
     "Move or copy operation failed" : "Nem sikerült az áthelyezés vagy a másolás",
-    "Move or copy" : "Áthelyezés vagy másolás",
     "Open folder" : "Mappa megnyitása",
     "Open folder {displayName}" : "A(z) {displayName} mappa megnyitása",
     "Open in Files" : "Megnyitás a Fájlokban",
@@ -318,23 +326,10 @@ OC.L10N.register(
     "The file should now open on your device. If it doesn't, please check that you have the desktop app installed." : "A fájlnak most már meg kellene nyílni az eszközén. Ha mégsem, ellenőrizze, hogy telepítve van-e az asztali alkalmazás.",
     "Retry and close" : "Újrapróbálás és bezárás",
     "Open online" : "Megnyitás online",
-    "Rename" : "Átnevezés",
     "Details" : "Részletek",
     "Unfavorite" : "Nem kedvenc",
     "View in folder" : "Megtekintés mappában",
-    "Today" : "Ma",
-    "Last 7 days" : "Előző 7 nap",
-    "Last 30 days" : "Előző 30 nap",
-    "This year ({year})" : "Idén ({year})",
-    "Last year ({year})" : "Tavaly ({year})",
-    "Documents" : "Dokumentumok",
-    "Spreadsheets" : "Munkafüzetek",
-    "Presentations" : "Bemutatók",
-    "PDFs" : "PDF-ek",
-    "Folders" : "Mappák",
-    "Audio" : "Hangok",
-    "Images" : "Képek",
-    "Videos" : "Videók",
+    "Type" : "Típus",
     "Created new folder \"{name}\"" : "Új „{name}” mappa létrehozva",
     "Unable to initialize the templates directory" : "A sablonkönyvtár előkészítése sikertelen",
     "Create templates folder" : "Sablonmappa létrehozása",
@@ -350,10 +345,10 @@ OC.L10N.register(
     "Some files could not be uploaded" : "Néhány fájlt nem lehet feltölteni",
     "Files uploaded successfully" : "Fájlok sikeresen feltöltve",
     "No files to process" : "Nincsenek feldolgozandó fájlok",
-    "Some files could not be copied" : "Néhány fájlt nem lehetett másolni",
-    "Some files could not be moved" : "Néhány fájlt nem lehetett áthelyezni",
     "Files copied successfully" : "A fájlok másolása sikeres",
     "Files moved successfully" : "A fájlok áthelyezése sikeres",
+    "Some files could not be copied" : "Néhány fájlt nem lehetett másolni",
+    "Some files could not be moved" : "Néhány fájlt nem lehetett áthelyezni",
     "Conflicts resolution skipped" : "Konfliktusfeloldás kihagyva",
     "Upload cancelled" : "Feltöltés megszakítva",
     "Could not rename \"{oldName}\", it does not exist any more" : "A(z) „{oldName}” nem nevezhető át, mert már nem létezik",
@@ -394,10 +389,14 @@ OC.L10N.register(
     "Upload (max. %s)" : "Feltöltés (legfeljebb %s)",
     "After enabling the windows compatible filenames, existing files cannot be modified anymore but can be renamed to valid new names by their owner." : "A Windows-kompatibilis fájlnevek engedélyezése után a meglévő fájlok már nem módosíthatóak, de a tulajdonosaik átnevezhetik őket érvényes új nevekre.",
     "It is also possible to migrate files automatically after enabling this setting, please refer to the documentation about the occ command." : "Továbbá lehetséges a fájlok automatikus átköltöztetése is a beállítás engedélyezése után, kövesse az occ parancs dokumentációját.",
+    "Renamed \"{oldName}\" to \"{newName}\"" : "A(z) „{oldName}” átnevezve erre: „{newName}”",
+    "Clear filter" : "Szűrő törlése",
     "\"{displayName}\" failed on some elements" : "A(z) „{displayName}” művelet egyes elemeken nem sikerült",
     "\"{displayName}\" batch action executed successfully" : "A(z) „{displayName}” tömeges művelet sikeresen végrehajtva",
     "\"{displayName}\" action failed" : "A(z) „{displayName}” művelet nem sikerült",
     "Submitting fields …" : "Mezők beküldése…",
+    "Shared by link" : "Megosztva hivatkozással",
+    "Shared" : "Megosztva",
     "\"{displayName}\" action executed successfully" : "A(z) „{displayName}” művelet sikeresen végrehajtva",
     "Filter file names …" : "Fájlnevek szűrése…",
     "Clipboard is not available" : "A vágólap nem érhető el",
@@ -439,6 +438,8 @@ OC.L10N.register(
     "Edit locally" : "Szerkesztés helyileg",
     "Moving \"{source}\" to \"{destination}\" …" : "„{source}” áthelyezése ide: „{destination}” …",
     "Copying \"{source}\" to \"{destination}\" …" : "„{source}” másolása ide: „{destination}” …",
+    "(copy)" : "(másolat)",
+    "(copy %n)" : "(%n. másolat)",
     "Move cancelled" : "Áthelyezés megszakítva",
     "Cancelled move or copy of \"{filename}\"." : "A(z) „{filename}” áthelyezése vagy másolása megszakítva.",
     "Cancelled move or copy operation" : "Az áthelyezés vagy másolás művelet megszakítva",
@@ -447,6 +448,7 @@ OC.L10N.register(
     "New folder creation cancelled" : "Az új mappa létrehozása megszakítva",
     "This directory is unavailable, please check the logs or contact the administrator" : "Ez a könyvtár nem érhető el, nézze meg a naplófájlokat vagy lépjen kapcsolatba az adminisztrátorral",
     "All folders" : "Összes mappa",
+    "Open file sidebar" : "Fájl oldalsáv megnyitása",
     "Search everywhere …" : "Keresés mindenhol…",
     "Search here …" : "Keresés itt…",
     "Preparing …" : "Előkészítés…"
