@@ -78,6 +78,7 @@ OC.L10N.register(
     "Reload current directory" : "Muat ulang direktori saat ini",
     "Go to the \"{dir}\" directory" : "Buka direktori \"{dir}\"",
     "Current directory path" : "Jalur direktori saat ini",
+    "Share" : "Bagikan",
     "Your have used your space quota and cannot upload files anymore" : "Anda telah menggunakan kuota ruang Anda dan tidak dapat mengunggah file lagi",
     "You do not have permission to upload or create files here." : "Anda tidak memiliki izin untuk mengunggah atau membuat file di sini.",
     "Drag and drop files here to upload" : "Seret dan lepaskan file di sini untuk mengunggah",
@@ -92,7 +93,6 @@ OC.L10N.register(
     "This node is unavailable" : "Node ini tidak tersedia",
     "Another entry with the same name already exists." : "Entri lain dengan nama yang sama sudah ada.",
     "Invalid filename." : "Nama file tidak valid.",
-    "Renamed \"{oldName}\" to \"{newName}\"" : "Mengganti nama \"{oldName}\" menjadi \"{newName}\"",
     "Rename file" : "Ganti nama file",
     "Folder" : "Folder",
     "Unknown file type" : "Jenis file tidak dikenal",
@@ -102,12 +102,24 @@ OC.L10N.register(
     "{ext} text" : "Teks {ext}",
     "Pending" : "Tertunda",
     "Unknown date" : "Tanggal tidak diketahui",
-    "Clear filter" : "Bersihkan filter",
-    "Modified" : "Dimodifikasi",
-    "Search everywhere" : "Cari di mana saja",
-    "Type" : "tipe",
     "Active filters" : "Filter aktif",
     "Remove filter" : "Hapus filter",
+    "Today" : "Hari ini",
+    "Last 7 days" : "7 hari terakhir",
+    "Last 30 days" : "30 hari terakhir",
+    "This year ({year})" : "Tahun ini ({year})",
+    "Last year ({year})" : "Tahun lalu ({year})",
+    "Custom date range" : "Rentang tanggal kustom",
+    "Search everywhere" : "Cari di mana saja",
+    "Documents" : "Dokumen",
+    "Spreadsheets" : "Spreadsheet",
+    "Presentations" : "Presentasi",
+    "PDFs" : "PDF",
+    "Folders" : "Folder",
+    "Audio" : "Audio",
+    "Images" : "Gambar",
+    "Videos" : "Video",
+    "Filters" : "Filter",
     "Appearance" : "Tampilan",
     "Show hidden files" : "Lihat berkas tersembunyi",
     "Show file type column" : "Tampilkan kolom jenis file",
@@ -136,7 +148,6 @@ OC.L10N.register(
     "Go right in grid" : "Pergi ke kanan dalam grid",
     "View" : "Tampilan",
     "Toggle grid view" : "Alihkan tampilan jala-jala",
-    "Open file sidebar" : "Buka bilah samping file",
     "Show those shortcuts" : "Tampilkan pintasan tersebut",
     "Warnings" : "Peringatan",
     "Warn before changing a file extension" : "Peringatkan sebelum mengubah ekstensi file",
@@ -150,6 +161,7 @@ OC.L10N.register(
     "Name" : "Nama",
     "File type" : "Jenis file",
     "Size" : "Ukuran",
+    "Modified" : "Dimodifikasi",
     "{displayName}: failed on some elements" : "{displayName}: gagal pada beberapa elemen",
     "{displayName}: done" : "{displayName}: selesai",
     "{displayName}: failed" : "{displayName}: gagal",
@@ -218,12 +230,11 @@ OC.L10N.register(
     "Removing the file extension \"{old}\" may render the file unreadable." : "Menghapus ekstensi file \"{old}\" dapat membuat file tidak dapat dibaca.",
     "Adding the file extension \"{new}\" may render the file unreadable." : "Menambahkan ekstensi file \"{new}\" dapat membuat file tidak dapat dibaca.",
     "Do not show this dialog again." : "Jangan tampilkan dialog ini lagi.",
+    "Cancel" : "Membatalkan",
+    "Rename" : "Ubah nama",
     "Select file or folder to link to" : "Pilih berkas atau folder untuk ditautkan",
     "Choose {file}" : "Pilih {file}",
     "Files settings" : "Setelan berkas",
-    "Share" : "Bagikan",
-    "Shared by link" : "Dibagikan dengan tautan",
-    "Shared" : "Dibagikan",
     "Switch to list view" : "Beralih ke tampilan daftar",
     "Switch to grid view" : "Beralih ke tampilan grid",
     "The file could not be found" : "File tidak dapat ditemukan",
@@ -263,6 +274,8 @@ OC.L10N.register(
     "Failed to convert files: {message}" : "Gagal mengonversi file: {message}",
     "All files failed to be converted" : "Semua file gagal dikonversi",
     "One file could not be converted: {message}" : "Satu file tidak dapat dikonversi: {message}",
+    "_%n file could not be converted_::_%n files could not be converted_" : ["%n file tidak dapat dikonversi"],
+    "_%n file converted_::_%n files converted_" : ["%n file dikonversi"],
     "Files converted" : "File dikonversi",
     "Failed to convert files" : "Gagal mengonversi file",
     "Converting file …" : "Mengonversi file …",
@@ -280,31 +293,30 @@ OC.L10N.register(
     "Delete files" : "Hapus file",
     "Delete folder" : "Hapus folder",
     "Delete folders" : "Hapus folder",
+    "_You are about to permanently delete {count} item_::_You are about to permanently delete {count} items_" : ["Anda akan menghapus {count} item secara permanen"],
+    "_You are about to delete {count} item_::_You are about to delete {count} items_" : ["Anda akan menghapus {count} item"],
     "Confirm deletion" : "Konfirmasi penghapusan",
-    "Cancel" : "Membatalkan",
     "Download" : "Unduh",
     "The requested file is not available." : "File yang diminta tidak tersedia.",
     "The requested files are not available." : "File yang diminta tidak tersedia.",
     "Add to favorites" : "Tambah ke favorit",
     "Remove from favorites" : "Remove from favorites",
     "Add or remove favorite" : "Tambahkan atau hapus favorit",
-    "Moving \"{source}\" to \"{destination}\" …" : "Memindahkan \"{source}\" ke \"{destination}\" …",
-    "Copying \"{source}\" to \"{destination}\" …" : "Menyalin \"{source}\" ke \"{destination}\" …",
+    "Move" : "Pindah",
+    "Copy" : "Salin",
+    "Move or copy" : "Pindah atau salin",
     "Destination is not a folder" : "Tujuan bukan folder",
     "This file/folder is already in that directory" : "File/folder ini sudah ada di direktori tersebut",
     "You cannot move a file/folder onto itself or into a subfolder of itself" : "Anda tidak dapat memindahkan file/folder ke dirinya sendiri atau ke subfolder dari dirinya sendiri",
-    "(copy)" : "(salinan)",
-    "(copy %n)" : "(salinan %n)",
     "A file or folder with that name already exists in this folder" : "File atau folder dengan nama tersebut sudah ada di folder ini",
     "The files are locked" : "File terkunci",
     "The file does not exist anymore" : "File tersebut sudah tidak ada",
+    "Moving \"{source}\" to \"{destination}\" …" : "Memindahkan \"{source}\" ke \"{destination}\" …",
+    "Copying \"{source}\" to \"{destination}\" …" : "Menyalin \"{source}\" ke \"{destination}\" …",
     "Choose destination" : "Pilih tujuan",
     "Copy to {target}" : "Salin ke {target}",
-    "Copy" : "Salin",
     "Move to {target}" : "Pindahkan ke {target}",
-    "Move" : "Pindah",
     "Move or copy operation failed" : "Operasi pemindahan atau penyalinan gagal",
-    "Move or copy" : "Pindah atau salin",
     "Open folder" : "Buka folder",
     "Open folder {displayName}" : "Buka folder {displayName}",
     "Open in Files" : "Buka di File",
@@ -314,23 +326,11 @@ OC.L10N.register(
     "The file should now open on your device. If it doesn't, please check that you have the desktop app installed." : "File seharusnya sekarang terbuka di perangkat Anda. Jika tidak, silakan periksa bahwa Anda telah menginstal aplikasi desktop.",
     "Retry and close" : "Coba lagi dan tutup",
     "Open online" : "Buka online",
-    "Rename" : "Ubah nama",
     "Details" : "Rincian",
+    "Open the details sidebar" : "Buka bilah sisi detail",
     "Unfavorite" : "Hapus dari favorit",
     "View in folder" : "Lihat dalam folder",
-    "Today" : "Hari ini",
-    "Last 7 days" : "7 hari terakhir",
-    "Last 30 days" : "30 hari terakhir",
-    "This year ({year})" : "Tahun ini ({year})",
-    "Last year ({year})" : "Tahun lalu ({year})",
-    "Documents" : "Dokumen",
-    "Spreadsheets" : "Spreadsheet",
-    "Presentations" : "Presentasi",
-    "PDFs" : "PDF",
-    "Folders" : "Folder",
-    "Audio" : "Audio",
-    "Images" : "Gambar",
-    "Videos" : "Video",
+    "Type" : "tipe",
     "Created new folder \"{name}\"" : "Membuat folder baru \"{name}\"",
     "Unable to initialize the templates directory" : "Tidak dapat membuat direktori templat",
     "Create templates folder" : "Buat folder templat",
@@ -346,10 +346,10 @@ OC.L10N.register(
     "Some files could not be uploaded" : "Beberapa file tidak dapat diunggah",
     "Files uploaded successfully" : "File berhasil diunggah",
     "No files to process" : "Tidak ada file untuk diproses",
-    "Some files could not be copied" : "Beberapa file tidak dapat disalin",
-    "Some files could not be moved" : "Beberapa berkas tidak dapat dipindahkan",
     "Files copied successfully" : "File berhasil disalin",
     "Files moved successfully" : "File berhasil dipindahkan",
+    "Some files could not be copied" : "Beberapa file tidak dapat disalin",
+    "Some files could not be moved" : "Beberapa berkas tidak dapat dipindahkan",
     "Conflicts resolution skipped" : "Penyelesaian konflik dilewati",
     "Upload cancelled" : "Unggahan dibatalkan",
     "Could not rename \"{oldName}\", it does not exist any more" : "Tidak dapat mengganti \"{oldName}\", tidak ada lagi",
@@ -361,6 +361,7 @@ OC.L10N.register(
     "Unexpected error: {error}" : "Kesalahan tak terduga: {error}",
     "_%n file_::_%n files_" : ["%n berkas"],
     "_%n folder_::_%n folders_" : ["%n folder"],
+    "_%n hidden_::_%n hidden_" : ["%n disembunyikan"],
     "Filename must not be empty." : "Nama file tidak boleh kosong.",
     "\"{char}\" is not allowed inside a filename." : "\"{char}\" tidak diperbolehkan di dalam nama file.",
     "\"{segment}\" is a reserved name and not allowed for filenames." : "\"{segment}\" adalah nama yang dicadangkan dan tidak diizinkan untuk nama file.",
@@ -389,10 +390,14 @@ OC.L10N.register(
     "Upload (max. %s)" : "Unggah (maks. %s)",
     "After enabling the windows compatible filenames, existing files cannot be modified anymore but can be renamed to valid new names by their owner." : "Setelah mengaktifkan nama file yang kompatibel dengan Windows, file yang sudah ada tidak dapat dimodifikasi lagi, tetapi dapat diganti nama menjadi nama baru yang valid oleh pemiliknya.",
     "It is also possible to migrate files automatically after enabling this setting, please refer to the documentation about the occ command." : "File juga dapat dimigrasikan secara otomatis setelah mengaktifkan pengaturan ini, silakan merujuk ke dokumentasi tentang perintah occ.",
+    "Renamed \"{oldName}\" to \"{newName}\"" : "Mengganti nama \"{oldName}\" menjadi \"{newName}\"",
+    "Clear filter" : "Bersihkan filter",
     "\"{displayName}\" failed on some elements" : "\"{displayName}\" gagal pada beberapa elemen",
     "\"{displayName}\" batch action executed successfully" : "Tindakan batch \"{displayName}\" berhasil dijalankan",
     "\"{displayName}\" action failed" : "Tindakan \"{displayName}\" gagal",
     "Submitting fields …" : "Mengirim kolom …",
+    "Shared by link" : "Dibagikan dengan tautan",
+    "Shared" : "Dibagikan",
     "\"{displayName}\" action executed successfully" : "Tindakan \"{displayName}\" berhasil dijalankan",
     "Filter file names …" : "Filter nama file …",
     "Clipboard is not available" : "Papan klip tidak tersedia",
@@ -434,6 +439,8 @@ OC.L10N.register(
     "Edit locally" : "Sunting secara lokal",
     "Moving \"{source}\" to \"{destination}\" …" : "Memindahkan \"{source}\" ke \"{destination}\" …",
     "Copying \"{source}\" to \"{destination}\" …" : "Menyalin \"{source}\" ke \"{destination}\" …",
+    "(copy)" : "(salinan)",
+    "(copy %n)" : "(salinan %n)",
     "Move cancelled" : "Pemindahan dibatalkan",
     "Cancelled move or copy of \"{filename}\"." : "Pemindahan atau penyalinan \"{filename}\" dibatalkan.",
     "Cancelled move or copy operation" : "Operasi pemindahan atau penyalinan dibatalkan",
@@ -442,6 +449,7 @@ OC.L10N.register(
     "New folder creation cancelled" : "Pembuatan folder baru dibatalkan",
     "This directory is unavailable, please check the logs or contact the administrator" : "Direktori ini tidak tersedia, silakan periksa log atau hubungi kontak",
     "All folders" : "Semua folder",
+    "Open file sidebar" : "Buka bilah samping file",
     "Search everywhere …" : "Cari di mana saja …",
     "Search here …" : "Cari di sini …",
     "Preparing …" : "Menyiapkan …"
