@@ -51,6 +51,10 @@ OC.L10N.register(
     "You do not have permission to create a file at the specified location" : "Þú hefur ekki heimild til að búa til skrá á umbeðnu staðsetningunni",
     "The file could not be converted." : "Ekki var hægt að umbreyta skránni.",
     "Could not get relative path to converted file" : "Ekki tókst að fá afstæða slóð að umbreyttu skránni",
+    "Limit must be a positive integer." : "Takmörk verða að vera jákvæð heiltala.",
+    "The replacement character may only be a single character." : "Útskiptistafurinn verður að vera eitt staftákn.",
+    "Filename sanitization already started." : "Lagfæring skráaheita er þegar hafin.",
+    "No filename sanitization in progress." : "Engin lagfæring skráaheita í gangi.",
     "Favorite files" : "Eftirlætisskrár",
     "No favorites" : "Engin eftirlæti",
     "More favorites" : "Fleiri eftirlæti",
@@ -74,7 +78,9 @@ OC.L10N.register(
     "Reload current directory" : "Endurhlaða núverandi möppu",
     "Go to the \"{dir}\" directory" : "Fara í heimamöppu",
     "Current directory path" : "Fyrirliggjandi slóð að möppu",
+    "Share" : "Deila",
     "Your have used your space quota and cannot upload files anymore" : "Þú hefur fullnýtt geymslukvótann þinn og getur ekki lengur sent inn skrár",
+    "You do not have permission to upload or create files here." : "Þú hefur ekki heimild til að senda inn eða búa til skrár hér.",
     "Drag and drop files here to upload" : "Dragðu og slepptu hér skrám til að senda inn",
     "Favorite" : "Eftirlæti",
     "Back" : "Til baka",
@@ -87,28 +93,86 @@ OC.L10N.register(
     "This node is unavailable" : "Þessi hnútur er ekki tiltækur",
     "Another entry with the same name already exists." : "Önnur færsla með sama heiti er þegar til staðar.",
     "Invalid filename." : "Ógilt skráarheiti.",
-    "Renamed \"{oldName}\" to \"{newName}\"" : "Endurnefndi \"{oldName}\" sem \"{newName}\"",
     "Rename file" : "Endurnefna skrá",
     "Folder" : "Mappa",
+    "Unknown file type" : "Óþekkt skráartegund",
+    "{ext} image" : "{ext} mynd",
+    "{ext} video" : "{ext} myndskeið",
+    "{ext} audio" : "{ext} hljóðskrá",
+    "{ext} text" : "{ext} textaskrá",
     "Pending" : "Í bið",
     "Unknown date" : "Óþekkt dagsetning",
-    "Clear filter" : "Hreinsa síu",
-    "Modified" : "Breytt",
-    "Search everywhere" : "Leita allsstaðar",
-    "Type" : "Tegund",
     "Active filters" : "Virkar síur",
     "Remove filter" : "Fjarlægja síu",
+    "Today" : "Í dag",
+    "Last 7 days" : "Síðustu 7 daga",
+    "Last 30 days" : "Síðustu 30 daga",
+    "This year ({year})" : "Þetta ár ({year})",
+    "Last year ({year})" : "Síðasta ár ({year})",
+    "Custom date range" : "Sérsniðið dagsetningabil",
+    "Search everywhere" : "Leita allsstaðar",
+    "Documents" : "Skjöl",
+    "Spreadsheets" : "Töflureiknar",
+    "Presentations" : "Kynningar",
+    "PDFs" : "PDF-skrár",
+    "Folders" : "Möppur",
+    "Audio" : "Hljóð",
+    "Images" : "Myndir",
+    "Videos" : "Myndskeið",
+    "Filters" : "Síur",
+    "Appearance" : "Útlit",
+    "Show hidden files" : "Sýna faldar skrár",
+    "Show file type column" : "Sýna dálk fyrir skráategund",
+    "Show file extensions" : "Birta skráaendingar",
+    "Crop image previews" : "Skera utan af forskoðun mynda",
+    "General" : "Almennt",
+    "Sort favorites first" : "Raða eftirlætum fremst",
+    "Sort folders before files" : "Raða möppum á undan skrám",
+    "Default view" : "Sjálfgefin sýn",
+    "All files" : "Allar skrár",
+    "Personal files" : "Einkaskrár",
+    "Additional settings" : "Valfrjálsar stillingar",
+    "Actions" : "Aðgerðir",
+    "File actions" : "Skráaaðgerðir",
+    "Selection" : "Val",
+    "Select all files" : "Velja allar skrár",
+    "Deselect all" : "Afvelja allt",
+    "Select or deselect" : "Velja eða afvelja",
+    "Select a range" : "Veldu svið",
+    "Navigation" : "Yfirsýn",
+    "Go to parent folder" : "Fara í yfirmöppu",
+    "Go to file above" : "Fara í skrá fyrir ofan",
+    "Go to file below" : "Fara í skrá fyrir neðan",
+    "Go left in grid" : "Fara til vinstri í reitum",
+    "Go right in grid" : "Fara til hægri í reitum",
+    "View" : "Skoða",
+    "Toggle grid view" : "Víxla reitasýn af/á",
+    "Show those shortcuts" : "Sýna þessa flýtilykla",
+    "Warnings" : "Aðvaranir",
+    "Warn before changing a file extension" : "Aðvara áður en skráarendingu er breytt",
+    "WebDAV URL" : "WebDAV-slóð",
+    "How to access files using WebDAV" : "Hvernig á að nálgast skrár í gegnum WebDAV",
     "Total rows summary" : "Samantek á fjölda raða",
     "Toggle selection for all files and folders" : "Víxla vali af/á fyrir allar skrár og möppur",
     "Name" : "Heiti",
+    "File type" : "Skráartegund",
     "Size" : "Stærð",
-    "Actions" : "Aðgerðir",
+    "Modified" : "Breytt",
+    "{displayName}: failed on some elements" : "{displayName}: mistókst á einhverjum atriðum",
+    "{displayName}: done" : "{displayName}: lokið",
+    "{displayName}: failed" : "{displayName}: mistókst",
     "(selected)" : "(valið)",
     "List of files and folders." : "Listi yfir skrár og möppur.",
     "You have used your space quota and cannot upload files anymore." : "Þú hefur fullnýtt geymslukvótann þinn og getur ekki lengur sent inn skrár.",
     "Column headers with buttons are sortable." : "Dálkfyrirsagnir með hnöppum eru raðanlegar",
     "This list is not fully rendered for performance reasons. The files will be rendered as you navigate through the list." : "Til að halda sem bestum afköstum er þessi listi ekki myndgerður að fullu. Skrárnar munu birtast eftir því sem farið er í gegnum listann.",
     "File not found" : "Skrá finnst ekki",
+    "_{count} selected_::_{count} selected_" : ["{count} valið","{count} valið"],
+    "Search everywhere …" : "Leita allsstaðar …",
+    "Search here …" : "Leita hér …",
+    "Search scope options" : "Valkostir leitarsviðs",
+    "Search here" : "Leita hér",
+    "Owner" : "Eigandi",
     "{usedQuotaByte} used" : "{usedQuotaByte} notað",
     "{used} of {quota} used" : "{used} af {quota} notað",
     "{relative}% used" : "{relative}% notað",
@@ -120,8 +184,27 @@ OC.L10N.register(
     "Create new folder" : "Búa til nýja möppu",
     "This name is already in use." : "Þetta nafn er nú þegar í notkun.",
     "Create" : "Búa til",
+    "Files starting with a dot are hidden by default" : "Skrár með heiti sem byrjar á punkti, eru sjálfgefið faldar",
+    "Failed to start filename sanitization." : "Mistókst að ræsa lagfæringu skráaheita.",
+    "Failed to refresh filename sanitization status." : "Mistókst að endurlesa stöðu á lagfæringum skráaheita.",
+    "Filename sanitization in progress." : "Lagfæring skráaheita í gangi.",
+    "Currently {processedUsers} of {totalUsers} accounts are already processed." : "Núna eru {processedUsers} af {totalUsers} aðgöngum þegar meðhöndlaðir.",
+    "Preparing …" : "Undirbý …",
     "Refresh" : "Endurnýja",
+    "All files have been santized for Windows filename support." : "Allar skrár hafa verið lagfærðar með tilliti til stuðnings við Windows-skráaheiti.",
+    "Some files could not be sanitized, please check your logs." : "Ekki var hægt að lagfæra sum skráaheiti, skoðaðu atvikaskrárnar þínar.",
+    "Sanitization errors" : "Villur við lagfæringu",
+    "Not sanitized filenames" : "Ekki lagfærð skráaheiti",
+    "Windows filename support has been enabled." : "Stuðningur við Windows-skráaheiti hefur verið virkjaður.",
+    "While this blocks users from creating new files with unsupported filenames, existing files are not yet renamed and thus still may break sync on Windows." : "Á meðan þetta kemur í veg fyrir að notendur búi til nýjar skrár með óstuddum skráaheitum, þá eru fyrirliggjandi skrár ekki ennþá endurnefndar og gætu þannig skemmt fyrir samstillingu á Windows.",
+    "You can trigger a rename of files with invalid filenames, this will be done in the background and may take some time." : "Þú getur sett í gang endurnefningu á skrám með ógild skráaheiti, það verður framkvæmt í bakgrunnsferli og gæti tekið nokkra stund.",
+    "Please note that this may cause high workload on the sync clients." : "Athugaðu að þetta getur valdið miklu álagi á samstillt biðlaraforrit.",
+    "Limit" : "Takmörk",
+    "This allows to configure how many users should be processed in one background job run." : "Þetta gerir kleift að stilla hve marga notendur eigi að meðhöndla í einu bakgrunnsferli.",
+    "Sanitize filenames" : "Lagfæra skráaheiti",
+    "(starting)" : "(byrja)",
     "Fill template fields" : "Fylla inn reiti sniðmáts",
+    "Submitting fields …" : "Sendi inn gagnasvið…",
     "Submit" : "Senda inn",
     "Choose a file or folder to transfer" : "Veldu skrá eða möppu til að millifæra",
     "Transfer" : "Færa",
@@ -134,18 +217,23 @@ OC.L10N.register(
     "Choose file or folder to transfer" : "Veldu skrá eða möppu til að millifæra",
     "Change" : "Breyta",
     "New owner" : "Nýr eigandi",
+    "Keep {old}" : "Halda {old}",
+    "Keep without extension" : "Halda án skráarendingar",
+    "Use {new}" : "Nota {new}",
     "Remove extension" : "Fjarlægja skráarendingu",
     "Change file extension" : "Breyta skráarendingu",
     "Changing the file extension from \"{old}\" to \"{new}\" may render the file unreadable." : "Sé skráaendingunni breytt úr \"{old}\" yfir í \"{new}\", gæti skráin orðið ólæsileg.",
     "Removing the file extension \"{old}\" may render the file unreadable." : "Sé skráaendingin \"{old}\" fjarlægð, gæti skráin orðið ólæsileg.",
     "Adding the file extension \"{new}\" may render the file unreadable." : "Sé skráaendingunni \"{new}\" bætt við, gæti skráin orðið ólæsileg.",
+    "Do not show this dialog again." : "Ekki sýna þennan glugga aftur.",
+    "Cancel" : "Hætta við",
+    "Rename" : "Endurnefna",
     "Select file or folder to link to" : "Veldu skrá eða möppu til að tengja í",
     "Choose {file}" : "Veldu {file}",
-    "Share" : "Deila",
-    "Shared by link" : "Deilt með tengli",
-    "Shared" : "Sameiginlegt",
+    "Files settings" : "Stillingar skráaforritsins",
     "Switch to list view" : "Skipta yfir í listasýn",
     "Switch to grid view" : "Skipta yfir í reitasýn",
+    "The file could not be found" : "Skráin fannst ekki",
     "Upload was cancelled by user" : "Notandi hætti við innsendingu",
     "Not enough free space" : "Ekki nægilegt pláss",
     "Operation is blocked by access control" : "Aðgerðin er hindruð af aðgangsstýringu",
@@ -158,62 +246,35 @@ OC.L10N.register(
     "Upload some content or sync with your devices!" : "Sendu inn eitthvað efni eða samstilltu við tækin þín!",
     "Go back" : "Fara til baka",
     "Views" : "Skoðun",
-    "Files settings" : "Stillingar skráaforritsins",
     "Your files" : "Skrárnar þínar",
     "Open in files" : "Opna í skráaforritinu",
     "File cannot be accessed" : "Skráin er ekki aðgengileg",
     "The file could not be found or you do not have permissions to view it. Ask the sender to share it." : "Skráin fannst ekki eða að þú hefur ekki heimildir til að skoða hana. Biddu sendandann um að deila henni.",
-    "Clipboard is not available" : "Klippispjald er ekki tiltækt",
-    "General" : "Almennt",
-    "All files" : "Allar skrár",
-    "Personal files" : "Einkaskrár",
-    "Sort favorites first" : "Raða eftirlætum fremst",
-    "Sort folders before files" : "Raða möppum á undan skrám",
-    "Appearance" : "Útlit",
-    "Show hidden files" : "Sýna faldar skrár",
-    "Crop image previews" : "Skera utan af forskoðun mynda",
-    "Additional settings" : "Valfrjálsar stillingar",
-    "WebDAV" : "WebDAV",
-    "WebDAV URL" : "WebDAV-slóð",
-    "Copy" : "Afrita",
-    "Keyboard shortcuts" : "Flýtileiðir á lyklaborði",
-    "Rename" : "Endurnefna",
-    "Delete" : "Eyða",
-    "Manage tags" : "Sýsla með merki",
-    "Selection" : "Val",
-    "Select all files" : "Velja allar skrár",
-    "Deselect all" : "Afvelja allt",
-    "Navigation" : "Yfirsýn",
-    "View" : "Skoða",
-    "Toggle grid view" : "Víxla reitasýn af/á",
-    "Show those shortcuts" : "Sýna þessa flýtilykla",
+    "No search results for “{query}”" : "Engar leitarniðurstöður fyrir “{query}”",
+    "Search for files" : "Leita að skrám",
     "Allow to restrict filenames to ensure files can be synced with all clients. By default all filenames valid on POSIX (e.g. Linux or macOS) are allowed." : "Leyfa að takmarka skráaheiti til að tryggja að hægt sé að samstilla skrár við öll biðlaraforrit. Sjálfgefið eru leyfð öll skráaheiti sem gilda á POSIX (þ.e.a.s. Linux eða macOS).",
+    "After enabling the Windows compatible filenames, existing files cannot be modified anymore but can be renamed to valid new names by their owner." : "Eftir að Windows-samhæfð skráaheiti hafa verið virkjuð, er ekki lengur hægt að breyta fyrirliggjandi skrám, en þær getur eigandi þeirra samt endurnefnt með gildu skráaheiti.",
+    "Failed to toggle Windows filename support" : "Tókst ekki að víxla stuðningi við Windows-skráaheiti af/á",
     "Files compatibility" : "Samhæfni skráa",
     "Enforce Windows compatibility" : "Þvinga fram samhæfni við Windows",
     "This will block filenames not valid on Windows systems, like using reserved names or special characters. But this will not enforce compatibility of case sensitivity." : "Þetta mun útiloka skráaheiti sem ekki gilda á Windows-kerfum, eins og þau sem innihalda frátekin heiti og sérstafi. En þetta mun hinsvegar ekki þvinga fram samhæfni í stafstöðu (há-/lágstafir).",
-    "You" : "Þú",
-    "Shared multiple times with different people" : "Deilt mörgum sinnum með mismunandi fólki",
-    "Unable to change the favorite state of the file" : "Get ekki breytt stöðu sem eftirlæti á skránni",
-    "Error while loading the file data" : "Villa við að hlaða inn skráagögnum",
-    "Owner" : "Eigandi",
-    "Remove from favorites" : "Fjarlægja úr eftirlætum",
-    "Add to favorites" : "Bæta í eftirlæti",
-    "Tags" : "Merki",
     "Blank" : "Tóm",
     "Unable to create new file from template" : "Tekst ekki að búa til nýja skrá út frá sniðmáti",
     "Pick a template for {name}" : "Veldu sniðmát fyrir {name}",
     "Create a new file with the selected template" : "Búa til nýja skrá úr völdu sniðmáti",
     "Creating file" : "Bý til skrá",
     "Save as {displayName}" : "Vista sem {displayName}",
-    "Save as …" : "Vista sem …",
+    "Save as …" : "Vista sem …",
+    "Converting files …" : "Umbreyti skrám …",
     "Failed to convert files: {message}" : "Mistókst að umbreyta skrám: {message}",
     "All files failed to be converted" : "Mistókst að umbreyta öllum skrám",
     "One file could not be converted: {message}" : "Ekki var hægt að umbreyta einni skrá: {message}",
-    "Files successfully converted" : "Tókst að umbreyta skrám",
     "Failed to convert files" : "Mistókst að umbreyta skrám",
+    "Converting file …" : "Umbreyti skrá…",
     "File successfully converted" : "Tókst að umbreyta skrá",
     "Failed to convert file: {message}" : "Mistókst að umbreyta skrá: {message}",
     "Failed to convert file" : "Mistókst að umbreyta skrá",
+    "Delete" : "Eyða",
     "Leave this share" : "Yfirgefa þessa sameign",
     "Leave these shares" : "Yfirgefa þessar sameignir",
     "Disconnect storage" : "Aftengja geymslu",
@@ -227,50 +288,46 @@ OC.L10N.register(
     "_You are about to permanently delete {count} item_::_You are about to permanently delete {count} items_" : ["Þú ert við það að eyða endanlega {count} atriði","Þú ert við það að eyða endanlega {count} atriðum"],
     "_You are about to delete {count} item_::_You are about to delete {count} items_" : ["Þú ert við það að eyða {count} atriði","Þú ert við það að eyða {count} atriðum"],
     "Confirm deletion" : "Staðfesta eyðingu",
-    "Cancel" : "Hætta við",
     "Download" : "Niðurhal",
-    "Moving \"{source}\" to \"{destination}\" …" : "Færi \"{source}\" í \"{destination}\" …",
-    "Copying \"{source}\" to \"{destination}\" …" : "Afrita \"{source}\" í \"{destination}\" …",
+    "The requested file is not available." : "Umbeðin skrá er ekki tiltæk.",
+    "The requested files are not available." : "Umbeðnar skrár eru ekki tiltækar.",
+    "Add to favorites" : "Bæta í eftirlæti",
+    "Remove from favorites" : "Fjarlægja úr eftirlætum",
+    "Add or remove favorite" : "Bæta við eða fjarlægja eftirlæti",
+    "Move" : "Færa",
+    "Copy" : "Afrita",
+    "Move or copy" : "Færa eða afrita",
     "Destination is not a folder" : "Áfangastaðurinn er ekki mappa",
     "This file/folder is already in that directory" : "Þessi skrá/mappa er þegar í þessari möppu",
     "You cannot move a file/folder onto itself or into a subfolder of itself" : "Þú getur ekki flutt skrá/möppu inn í sjálfa sig eða inni í undirmöppu af sjálfri sér",
-    "(copy)" : "(afrita)",
-    "(copy %n)" : "(afrita %n)",
     "A file or folder with that name already exists in this folder" : "Skrá eða mappa með þessu heiti er þegar til staðar í þessari möppu",
     "The files are locked" : "Skrárnar eru læstar",
     "The file does not exist anymore" : "Skráin  er ekki lengur til",
+    "Moving \"{source}\" to \"{destination}\" …" : "Færi \"{source}\" í \"{destination}\" …",
+    "Copying \"{source}\" to \"{destination}\" …" : "Afrita \"{source}\" í \"{destination}\" …",
     "Choose destination" : "Veldu áfangastað",
     "Copy to {target}" : "Afrita í {target}",
     "Move to {target}" : "Færa í {target}",
-    "Move" : "Færa",
     "Move or copy operation failed" : "Aðgerð við að færa eða afrita mistókst",
-    "Move or copy" : "Færa eða afrita",
+    "Open folder" : "Opna möppu",
     "Open folder {displayName}" : "Opna möppu {displayName}",
     "Open in Files" : "Opna í skráaforritinu",
+    "Open locally" : "Opna staðvært",
     "Failed to redirect to client" : "Mistókst að endurbeina til biðlara",
+    "Open file locally" : "Opna skrá staðvært",
     "The file should now open on your device. If it doesn't, please check that you have the desktop app installed." : "Skráin ætti núna að opnast á tækinu þínu. Ef það gerist ekki, ættirðu að ganga úr skugga um að þú sért með vinnutölvuforritið uppsett.",
     "Retry and close" : "Prófa aftur og loka",
+    "Open online" : "Opna á netinu",
     "Details" : "Nánar",
     "View in folder" : "Skoða í möppu",
-    "Today" : "Í dag",
-    "Last 7 days" : "Síðustu 7 daga",
-    "Last 30 days" : "Síðustu 30 daga",
-    "This year ({year})" : "Þetta ár ({year})",
-    "Last year ({year})" : "Síðasta ár ({year})",
-    "Documents" : "Skjöl",
-    "Spreadsheets" : "Töflureiknar",
-    "Presentations" : "Kynningar",
-    "PDFs" : "PDF-skrár",
-    "Folders" : "Möppur",
-    "Audio" : "Hljóð",
-    "Images" : "Myndir",
-    "Videos" : "Myndskeið",
+    "Type" : "Tegund",
     "Created new folder \"{name}\"" : "Bjó til nýja möppu \"{name}\"",
     "Unable to initialize the templates directory" : "Tókst ekki að frumstilla sniðmátamöppuna",
     "Create templates folder" : "Búa til sniðmátamöppu",
     "Templates" : "Sniðmát",
     "New template folder" : "Ný mappa fyrir sniðmát",
     "In folder" : "Í möppunni",
+    "Search in all files" : "Leita í öllum skrám",
     "Search in folder: {folder}" : "Leita í möppunni: {folder}",
     "One of the dropped files could not be processed" : "Ekki var hægt að vinna með eina af slepptu skránum",
     "Your browser does not support the Filesystem API. Directories will not be uploaded" : "Vafrinn þinn styður ekki API skráakerfis. Möppur verða ekki sendar inn",
@@ -279,20 +336,22 @@ OC.L10N.register(
     "Some files could not be uploaded" : "Ekki tókst að senda inn sumar skrár",
     "Files uploaded successfully" : "Tókst að senda inn skrár",
     "No files to process" : "Engar skrár til að vinna úr",
-    "Some files could not be copied" : "Ekki tókst að afrita sumar skrár",
-    "Some files could not be moved" : "Ekki tókst að færa sumar skrár",
     "Files copied successfully" : "Tókst að afrita skrár",
     "Files moved successfully" : "Tókst að færa skrár",
+    "Some files could not be copied" : "Ekki tókst að afrita sumar skrár",
+    "Some files could not be moved" : "Ekki tókst að færa sumar skrár",
     "Conflicts resolution skipped" : "Sleppti lausn árekstra",
     "Upload cancelled" : "Hætt við innsendingu",
     "Could not rename \"{oldName}\", it does not exist any more" : "Gat ekki endurnefnt \"{oldName}\", það er ekki lengur til staðar",
     "The name \"{newName}\" is already used in the folder \"{dir}\". Please choose a different name." : "Heitið \"{newName}\" er nú þegar notað í \"{dir}\" möppunni. Veldu eitthvað annað nafn.",
     "Could not rename \"{oldName}\"" : "Tókst ekki að endurnefna \"{oldName}\"",
     "This operation is forbidden" : "Þessi aðgerð er bönnuð",
+    "This folder is unavailable, please try again later or contact the administration" : "Þessi mappa er ekki aðgengileg, reyndu aftur síðar eða hafðu samband við kerfisstjórnendur",
     "Storage is temporarily not available" : "Gagnageymsla ekki tiltæk í augnablikinu",
     "Unexpected error: {error}" : "Óvænt villa: {error}",
     "_%n file_::_%n files_" : ["%n skrá","%n skrár"],
     "_%n folder_::_%n folders_" : ["%n mappa","%n möppur"],
+    "_%n hidden_::_%n hidden_" : ["%n falin","%n faldar"],
     "Filename must not be empty." : "Skráarheiti má ekki vera tómt.",
     "\"{char}\" is not allowed inside a filename." : "\"{char}\" er er ekki leyfilegt innan í skráarheiti.",
     "\"{segment}\" is a reserved name and not allowed for filenames." : "\"{segment}\" er frátekið heiti og er ekki leyft í skráaheitum.",
@@ -302,6 +361,7 @@ OC.L10N.register(
     "No favorites yet" : "Engin eftirlæti ennþá",
     "Files and folders you mark as favorite will show up here" : "Skrár og möppur sem þú merkir sem eftirlæti birtast hér",
     "List of your files and folders." : "Listi yfir skrárnar þínar og möppur.",
+    "Folder tree" : "Möppugreinar",
     "List of your files and folders that are not shared." : "Listi yfir skrárnar þínar og möppur sem ekki er deilt.",
     "No personal files found" : "Engar einkaskrár fundust",
     "Files that are not shared will show up here." : "Skrár sem ekki er deilt birtast hér.",
@@ -310,115 +370,35 @@ OC.L10N.register(
     "No recently modified files" : "Engar nýlega breyttar skrár",
     "Files and folders you recently modified will show up here." : "Skrár og möppur sem þú breyttir nýlega birtast hér.",
     "Search" : "Search",
+    "Search results within your files." : "Leitarniðurstöður úr skránum þínum.",
     "No entries found in this folder" : "Engar skrár fundust í þessari möppu",
     "Select all" : "Velja allt",
     "Upload too large" : "Innsend skrá er of stór",
     "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Skrárnar sem þú ert að senda inn eru stærri en hámarks innsendingarstærð á þessum netþjóni.",
-    "File could not be found" : "Skrá finnst ekki",
-    "Show list view" : "Birta listasýn",
-    "Show grid view" : "Birta reitasýn",
-    "Close" : "Loka",
-    "Could not create folder \"{dir}\"" : "Gat ekki búið til möppuna \"{dir}\"",
-    "This will stop your current uploads." : "Þetta mun stöðva núverandi innsendingar þínar.",
-    "Upload cancelled." : "Hætt við innsendingu.",
-    "Processing files …" : "Vinn með skrár …",
-    "…" : "…",
-    "Unable to upload {filename} as it is a directory or has 0 bytes" : "Tókst ekki að hlaða inn {filename} þar sem þetta er mappa eða er 0 bæti",
-    "Not enough free space, you are uploading {size1} but only {size2} is left" : "Ekki nægilegt laust pláss, þú ert að senda inn {size1} en einungis {size2} eru eftir",
-    "Target folder \"{dir}\" does not exist any more" : "Markmappan \"{dir}\" er ekki lengur til",
-    "An unknown error has occurred" : "Óþekkt villa kom upp",
-    "File could not be uploaded" : "Gat ekki sent inn skrána",
-    "Uploading …" : "Sendi inn …",
-    "{remainingTime} ({currentNumber}/{total})" : "{remainingTime} ({currentNumber}/{total})",
-    "Uploading … ({currentNumber}/{total})" : "Sendi inn … ({currentNumber}/{total})",
-    "{loadedSize} of {totalSize} ({bitrate})" : "{loadedSize} af {totalSize} ({bitrate})",
-    "Uploading that item is not supported" : "Innsending á þessu atriði er ekki studd",
-    "Error when assembling chunks, status code {status}" : "Villa við að setja búta saman, stöðukóði {status}",
-    "Choose target folder" : "Veldu úttaksmöppu",
-    "Set reminder" : "Setja áminningu",
-    "Edit locally" : "Breyta staðvært",
-    "Open" : "Opna",
-    "Could not load info for file \"{file}\"" : "Gat ekki lesið upplýsingar um skrána \"{file}\"",
-    "Please select tag(s) to add to the selection" : "Veldu merki til að bæta á valið",
-    "Apply tag(s) to selection" : "Beita merki/merkjum á valið",
-    "Select directory \"{dirName}\"" : "Veldu möppuna \"{dirName}\"",
-    "Select file \"{fileName}\"" : "Veldu skrána \"{fileName}\"",
-    "Unable to determine date" : "Tókst ekki að ákvarða dagsetningu",
-    "This directory is unavailable, please check the logs or contact the administrator" : "Þessi mappa er ekki tiltæk, athugaðu atvikaskrár eða hafðu samband við kerfissjóra",
-    "Could not move \"{file}\", target exists" : "Gat ekki fært \"{file}\", markskrá er til",
-    "Could not move \"{file}\"" : "Gat ekki fært \"{file}\"",
-    "copy" : "afrit",
-    "Could not copy \"{file}\", target exists" : "Gat ekki afritað \"{file}\", markskrá er til",
-    "Could not copy \"{file}\"" : "Gat ekki afritað \"{file}\"",
-    "Copied {origin} inside {destination}" : "Afritaði {origin} inn í {destination}",
-    "Copied {origin} and {nbfiles} other files inside {destination}" : "Afritaði {origin} og {nbfiles} aðrar skrár inn í {destination}",
-    "{newName} already exists" : "{newName} er þegar til",
-    "Could not create file \"{file}\"" : "Gat ekki búið til skrána \"{file}\"",
-    "Could not create file \"{file}\" because it already exists" : "Gat ekki búið til skrána \"{file}\" vegna þess að hún er þegar til",
-    "Could not create folder \"{dir}\" because it already exists" : "Gat ekki búið til möppuna \"{dir}\" vegna þess að hún er þegar til",
-    "Could not fetch file details \"{file}\"" : "Gat ekki sótt nánari upplýsingar um skrána \"{file}\"",
-    "Error deleting file \"{fileName}\"." : "Villa við að eyða skránni \"{fileName}\".",
-    "No search results in other folders for {tag}{filter}{endtag}" : "Engar leitarniðurstöður í öðrum möppum fyrir {tag}{filter}{endtag}",
-    "Enter more than two characters to search in other folders" : "Settu inn fleiri en tvo stafi til að leita í öðrum möppum",
-    "{dirs} and {files}" : "{dirs} og {files}",
-    "_including %n hidden_::_including %n hidden_" : ["þar á meðal %n falin","þar á meðal %n faldar"],
-    "You do not have permission to upload or create files here" : "Þú hefur ekki heimild til að senda inn eða búa til skrár hér",
-    "_Uploading %n file_::_Uploading %n files_" : ["Sendi inn %n skrá","Sendi inn %n skrár"],
-    "New" : "Nýtt",
-    "New file/folder menu" : "Valmynd fyrir nýja skrá/möppu",
-    "Select file range" : "Veldu skráasvið",
-    "{used}%" : "{used}%",
-    "{used} used" : "{used} notað",
-    "\"{name}\" is an invalid file name." : "\"{name}\" er ógilt skráarheiti.",
-    "File name cannot be empty." : "Heiti skráar má ekki vera tómt",
-    "\"/\" is not allowed inside a file name." : "\"/\" er er ekki leyfilegt innan í skráarheiti.",
-    "\"{name}\" is not an allowed filetype" : "\"{name}\" er ógild skráartegund",
-    "Storage of {owner} is full, files cannot be updated or synced anymore!" : "Geymslupláss {owner} er fullt, ekki er lengur hægt að uppfæra eða samstilla skrár!",
-    "Group folder \"{mountPoint}\" is full, files cannot be updated or synced anymore!" : "Hópmappa {mountPoint} er full, ekki er lengur hægt að uppfæra eða samstilla skrár!",
-    "External storage \"{mountPoint}\" is full, files cannot be updated or synced anymore!" : "Ytra geymslupláss {mountPoint} er fullt, ekki er lengur hægt að uppfæra eða samstilla skrár!",
-    "Your storage is full, files cannot be updated or synced anymore!" : "Geymsluplássið þitt er fullt, ekki er lengur hægt að uppfæra eða samstilla skrár!",
-    "Storage of {owner} is almost full ({usedSpacePercent}%)." : "Geymslupláss {owner} er næstum fullt ({usedSpacePercent}%).",
-    "Group folder \"{mountPoint}\" is almost full ({usedSpacePercent}%)." : "Hópmappan \"{mountPoint}\" er næstum full ({usedSpacePercent}%).",
-    "External storage \"{mountPoint}\" is almost full ({usedSpacePercent}%)." : "Ytra geymsluplássið \"{mountPoint}\" er næstum fullt ({usedSpacePercent}%).",
-    "Your storage is almost full ({usedSpacePercent}%)." : "Geymsluplássið þitt er næstum fullt ({usedSpacePercent}%).",
-    "_matches \"{filter}\"_::_match \"{filter}\"_" : ["samsvarar \"{filter}\"","samsvara \"{filter}\""],
-    "Direct link was copied (only works for people who have access to this file/folder)" : "Beinn tengill var afritaður (virkar bara fyrir fólk sem hefur aðgang að þessari skrá/möppu)",
-    "Path" : "Slóð",
-    "_%n byte_::_%n bytes_" : ["%n bæti","%n bæti"],
-    "Favored" : "Eftirlæti",
-    "Favor" : "Eftirl",
-    "Copy direct link (only works for people who have access to this file/folder)" : "Afrita beinan tengil (virkar bara fyrir fólk sem hefur aðgang að þessari skrá/möppu)",
-    "Upload file" : "Senda inn skrá",
-    "Not favored" : "Ekki eftirlæti",
-    "An error occurred while trying to update the tags" : "Villa kom upp við að reyna að uppfæra merkin",
+    "%1$s (renamed)" : "%1$s (endurnefnd)",
+    "renamed file" : "endurnefndi skrá",
     "Upload (max. %s)" : "Senda inn (hám. %s)",
-    "\"{displayName}\" action executed successfully" : "Tókst að framkvæma \"{displayName}\" aðgerð",
-    "\"{displayName}\" action failed" : "\"{displayName}\" aðgerð mistókst",
+    "After enabling the windows compatible filenames, existing files cannot be modified anymore but can be renamed to valid new names by their owner." : "Eftir að Windows-samhæfð skráaheiti hafa verið virkjuð, er ekki lengur hægt að breyta fyrirliggjandi skrám, en þær getur eigandi þeirra samt endurnefnt með gildu skráaheiti.",
+    "Renamed \"{oldName}\" to \"{newName}\"" : "Endurnefndi \"{oldName}\" sem \"{newName}\"",
+    "Clear filter" : "Hreinsa síu",
+    "\"{displayName}\" failed on some elements" : "\"{displayName}\" mistókst á einhverjum atriðum",
     "\"{displayName}\" batch action executed successfully" : "Tókst að framkvæma \"{displayName}\" magnvinnsluaðgerð",
-    "Submitting fields…" : "Sendi inn gögn úr reitum…",
-    "Filter filenames…" : "Sía skráaheiti…",
+    "\"{displayName}\" action failed" : "\"{displayName}\" aðgerð mistókst",
+    "Submitting fields …" : "Sendi inn gagnasvið…",
+    "Shared by link" : "Deilt með tengli",
+    "Shared" : "Sameiginlegt",
+    "\"{displayName}\" action executed successfully" : "Tókst að framkvæma \"{displayName}\" aðgerð",
+    "Filter file names …" : "Sía skráaheiti …",
+    "Clipboard is not available" : "Klippispjald er ekki tiltækt",
     "WebDAV URL copied to clipboard" : "WebDAV-slóð afrituð á klippispjaldið",
     "Enable the grid view" : "Virkja reitasýnina",
     "Enable folder tree" : "Virkja möppugreinar",
+    "WebDAV" : "WebDAV",
     "Copy to clipboard" : "Afrita á klippispjald",
     "Use this address to access your Files via WebDAV" : "Notaðu þetta vistfang til að nálgast skráaforritið þitt með WebDAV",
     "If you have enabled 2FA, you must create and use a new app password by clicking here." : "Ef þú hefur virkjað 2FA tveggja-þrepa-auðkenningu, þarftu að útbúa nýtt lykilorð forrits og nota það með því að smella hér.",
-    "Deletion cancelled" : "Hætt við eyðingu",
-    "Move cancelled" : "Hætt við tilfærslu",
-    "Cancelled move or copy of \"{filename}\"." : "Hætti við aðgerð við að færa eða afrita \"{filename}\".",
-    "Cancelled move or copy operation" : "Hætti við aðgerð við að færa eða afrita",
-    "Open details" : "Opna nánari upplýsingar",
-    "Photos and images" : "Myndefni",
-    "New folder creation cancelled" : "Hætti við gerð nýrrar möppu",
-    "_{folderCount} folder_::_{folderCount} folders_" : ["{folderCount} mappa","{folderCount} möppur"],
-    "_{fileCount} file_::_{fileCount} files_" : ["{fileCount} skrá","{fileCount} skrár"],
-    "_1 file and {folderCount} folder_::_1 file and {folderCount} folders_" : ["1 skrá og {folderCount} mappa","1 skrá og {folderCount} möppur"],
-    "_{fileCount} file and 1 folder_::_{fileCount} files and 1 folder_" : ["{fileCount} skrá og 1 mappa","{fileCount} skrár og 1 mappa"],
-    "{fileCount} files and {folderCount} folders" : "{fileCount} skrár og {folderCount} möppur",
-    "All folders" : "Allar möppur",
-    "Personal Files" : "Einkaskrár",
-    "Text file" : "Textaskrá",
-    "New text file.txt" : "Ný textaskrá.txt",
+    "Show a warning dialog when changing a file extension." : "Birta aðvörunarglugga þegar skráarendingu er breytt.",
+    "Keyboard shortcuts" : "Flýtileiðir á lyklaborði",
     "Speed up your Files experience with these quick shortcuts." : "Flýttu fyrir vinnu þinni með skrár með þessum flýtilyklum.",
     "Open the actions menu for a file" : "Opna aðgerðavalmynd fyrir skrá",
     "Rename a file" : "Endurnefna skrá",
@@ -434,6 +414,32 @@ OC.L10N.register(
     "Navigate to the file on the left (in grid mode)" : "Fara á skrána til vinstri (í reitayfirliti)",
     "Navigate to the file on the right (in grid mode)" : "Fara á skrána til hægri (í reitayfirliti)",
     "Toggle the grid view" : "Víxla reitayfirliti af/á",
-    "Open the sidebar for a file" : "Opna hliðarspjald fyrir skrá"
+    "Open the sidebar for a file" : "Opna hliðarspjald fyrir skrá",
+    "You" : "Þú",
+    "Shared multiple times with different people" : "Deilt mörgum sinnum með mismunandi fólki",
+    "Unable to change the favorite state of the file" : "Get ekki breytt stöðu sem eftirlæti á skránni",
+    "Error while loading the file data" : "Villa við að hlaða inn skráagögnum",
+    "Tags" : "Merki",
+    "Save as …" : "Vista sem …",
+    "Converting files …" : "Umbreyti skrám …",
+    "Converting file …" : "Umbreyti skrá…",
+    "Deletion cancelled" : "Hætt við eyðingu",
+    "Edit locally" : "Breyta staðvært",
+    "Moving \"{source}\" to \"{destination}\" …" : "Færi \"{source}\" í \"{destination}\" …",
+    "Copying \"{source}\" to \"{destination}\" …" : "Afrita \"{source}\" í \"{destination}\" …",
+    "(copy)" : "(afrita)",
+    "(copy %n)" : "(afrita %n)",
+    "Move cancelled" : "Hætt við tilfærslu",
+    "Cancelled move or copy of \"{filename}\"." : "Hætti við aðgerð við að færa eða afrita \"{filename}\".",
+    "Cancelled move or copy operation" : "Hætti við aðgerð við að færa eða afrita",
+    "Open details" : "Opna nánari upplýsingar",
+    "Photos and images" : "Myndefni",
+    "New folder creation cancelled" : "Hætti við gerð nýrrar möppu",
+    "This directory is unavailable, please check the logs or contact the administrator" : "Þessi mappa er ekki tiltæk, athugaðu atvikaskrár eða hafðu samband við kerfissjóra",
+    "All folders" : "Allar möppur",
+    "Open file sidebar" : "Opna hliðarspjald skráa",
+    "Search everywhere …" : "Leita allsstaðar …",
+    "Search here …" : "Leita hér …",
+    "Preparing …" : "Undirbý …"
 },
 "nplurals=2; plural=(n % 10 != 1 || n % 100 == 11);");
