@@ -78,6 +78,8 @@ OC.L10N.register(
     "Reload current directory" : "Ricarica la cartella corrente",
     "Go to the \"{dir}\" directory" : "Vai alla cartella \"{dir}\"",
     "Current directory path" : "Percorso della cartella corrente",
+    "Share" : "Condividi",
+    "Reload content" : "Ricarica il contenuto",
     "Your have used your space quota and cannot upload files anymore" : "Hai esaurito la tua quota di spazio e non puoi più caricare file",
     "You do not have permission to upload or create files here." : "Non hai l'autorizzazione per caricare o creare file qui.",
     "Drag and drop files here to upload" : "Trascina e rilascia i file qui per caricarli",
@@ -92,7 +94,6 @@ OC.L10N.register(
     "This node is unavailable" : "Questa nodo non è disponibile",
     "Another entry with the same name already exists." : "Esiste già un'altra voce con lo stesso nome.",
     "Invalid filename." : "Nome di file non valido.",
-    "Renamed \"{oldName}\" to \"{newName}\"" : "Rinominato \"{oldName}\" in \"{newName}\"",
     "Rename file" : "Rinomina file",
     "Folder" : "Cartella",
     "Unknown file type" : "Tipo di file sconosciuto",
@@ -102,12 +103,26 @@ OC.L10N.register(
     "{ext} text" : "{ext} text",
     "Pending" : "In corso",
     "Unknown date" : "Data sconosciuta",
-    "Clear filter" : "Pulisci il filtro",
-    "Modified" : "Modificato",
-    "Search everywhere" : "Cerca ovunque",
-    "Type" : "Tipo",
     "Active filters" : "Filtri attivi",
     "Remove filter" : "Rimuovi filtro",
+    "Today" : "Oggi",
+    "Last 7 days" : "Ultimi 7 giorni",
+    "Last 30 days" : "Ultimi 30 giorni",
+    "This year ({year})" : "Quest'anno ({year})",
+    "Last year ({year})" : "L'anno scorso ({year})",
+    "Custom range" : "Intervallo personalizzato",
+    "Custom date range" : "Intervallo di date personalizzato",
+    "Search everywhere" : "Cerca ovunque",
+    "Documents" : "Documenti",
+    "Spreadsheets" : "Fogli elettronici",
+    "Presentations" : "Presentazioni",
+    "PDFs" : "PDF",
+    "Folders" : "Cartelle",
+    "Audio" : "Audio",
+    "Images" : "Immagini",
+    "Videos" : "Video",
+    "Filters" : "Filtri",
+    "Back to filters" : "Torna ai filtri",
     "Appearance" : "Aspetto",
     "Show hidden files" : "Mostra i file nascosti",
     "Show file type column" : "Mostra colonna tipo di file",
@@ -116,6 +131,7 @@ OC.L10N.register(
     "General" : "Generale",
     "Sort favorites first" : "Ordina prima i preferiti",
     "Sort folders before files" : "Ordina cartelle prima dei files",
+    "Enable folder tree view" : "Abilita visuale ad albero delle cartelle",
     "Default view" : "Vista predefinita",
     "All files" : "Tutti i file",
     "Personal files" : "File personali",
@@ -135,17 +151,20 @@ OC.L10N.register(
     "Go right in grid" : "Vai a destra nella griglia",
     "View" : "Visualizza",
     "Toggle grid view" : "Commuta la vista a griglia",
-    "Open file sidebar" : "Apri la barra laterale del file",
     "Show those shortcuts" : "Mostra quelle scorciatoie",
     "Warnings" : "Avvertenze",
     "Warn before changing a file extension" : "Avvisa prima di modificare l'estensione di un file",
+    "Warn before deleting a file" : "Avvisa prima di eliminare un file",
     "WebDAV URL" : "URL WebDAV",
+    "Create an app password" : "Crea una nuova password di applicazione",
+    "Required for WebDAV authentication because Two-Factor Authentication is enabled for this account." : "Richiesto per l'autenticazione WebDAV perché l'autenticazione a due fattori è abilitata per questo account.",
     "How to access files using WebDAV" : "Come accedere ai file tramite WebDAV",
     "Total rows summary" : "Riepilogo totale delle righe",
     "Toggle selection for all files and folders" : "Attiva/disattiva la selezione per tutti i file e le cartelle",
     "Name" : "Nome",
     "File type" : "Tipo di file",
     "Size" : "Dimensione",
+    "Modified" : "Modificato",
     "{displayName}: failed on some elements" : "{displayName}: non riuscito su alcuni elementi",
     "{displayName}: done" : "{displayName}: fatto",
     "{displayName}: failed" : "{displayName}: non riuscito",
@@ -160,6 +179,7 @@ OC.L10N.register(
     "Search here …" : "Cerca qui …",
     "Search scope options" : "Opzioni nell'ambito di ricerca",
     "Search here" : "Cerca qui",
+    "Owner" : "Proprietario",
     "{usedQuotaByte} used" : "{usedQuotaByte} usato",
     "{used} of {quota} used" : "{used} di {quota} utilizzati",
     "{relative}% used" : "{relative}% usato",
@@ -184,7 +204,7 @@ OC.L10N.register(
     "Not sanitized filenames" : "Nomi di file non sanificati",
     "Windows filename support has been enabled." : "È stato abilitato il supporto per i nomi file di Windows.",
     "While this blocks users from creating new files with unsupported filenames, existing files are not yet renamed and thus still may break sync on Windows." : "Sebbene ciò impedisca agli utenti di creare nuovi file con nomi non supportati, i file esistenti non sono ancora stati rinominati e pertanto potrebbero comunque interrompere la sincronizzazione su Windows.",
-    "You can trigger a rename of files with invalid filenames, this will be done in the background and may take some time." : "È possibile attivare la ridenominazione dei file con nomi non validi; questa operazione verrà eseguita in background e potrebbe richiedere del tempo.",
+    "You can trigger a rename of files with invalid filenames, this will be done in the background and may take some time." : "È possibile attivare la rinomina dei file con nomi non validi; questa operazione verrà eseguita in background e potrebbe richiedere del tempo.",
     "Please note that this may cause high workload on the sync clients." : "Si prega di notare che ciò potrebbe causare un carico di lavoro elevato sui client di sincronizzazione.",
     "Limit" : "Limite",
     "This allows to configure how many users should be processed in one background job run." : "Ciò consente di configurare quanti utenti devono essere elaborati in un'esecuzione di un processo in background.",
@@ -213,12 +233,11 @@ OC.L10N.register(
     "Removing the file extension \"{old}\" may render the file unreadable." : "Rimuovendo dell'estensione del file \"{old}\" potrebbe rendere il file illeggibile.",
     "Adding the file extension \"{new}\" may render the file unreadable." : "Aggiungere l'estensione del file \"{new}\" potrebbe rendere il file illeggibile.",
     "Do not show this dialog again." : "Non visualizzare più questa finestra di dialogo.",
+    "Cancel" : "Annulla",
+    "Rename" : "Rinomina",
     "Select file or folder to link to" : "Seleziona un file o una cartella da collegare",
     "Choose {file}" : "Scegli {file}",
     "Files settings" : "Impostazioni File",
-    "Share" : "Condividi",
-    "Shared by link" : "Condivisi tramite collegamento",
-    "Shared" : "Condiviso",
     "Switch to list view" : "Passa alla vista elenco",
     "Switch to grid view" : "Passa alla vista griglia",
     "The file could not be found" : "Il file non è stato trovato",
@@ -234,14 +253,7 @@ OC.L10N.register(
     "Upload some content or sync with your devices!" : "Carica dei contenuti o sincronizza con i tuoi dispositivi!",
     "Go back" : "Indietro",
     "Views" : "Viste",
-    "You" : "Tu",
-    "Shared multiple times with different people" : "Condiviso più volte con diverse persone",
-    "Unable to change the favorite state of the file" : "Impossibile modificare lo stato preferito del file",
-    "Error while loading the file data" : "Errore durante il caricamento del file di dati",
-    "Owner" : "Proprietario",
-    "Remove from favorites" : "Rimuovi dai preferiti",
-    "Add to favorites" : "Aggiungi ai preferiti",
-    "Tags" : "Etichette",
+    "Loading …" : "Caricamento in corso...",
     "Your files" : "I tuoi files",
     "Open in files" : "Apri in file",
     "File cannot be accessed" : "Il file non possono essere acceduti",
@@ -259,7 +271,7 @@ OC.L10N.register(
     "Pick a template for {name}" : "Scegli un modello per {name}",
     "Create a new file with the selected template" : "Crea un nuovo file con il modello selezionato",
     "Creating file" : "Creazione del file",
-    "Save as {displayName}" : "Savlva come {displayName}",
+    "Save as {displayName}" : "Salva come {displayName}",
     "Save as …" : "Salva come …",
     "Converting files …" : "Conversione dei file …",
     "Failed to convert files: {message}" : "Impossibile convertire i file: {message}",
@@ -287,71 +299,61 @@ OC.L10N.register(
     "_You are about to permanently delete {count} item_::_You are about to permanently delete {count} items_" : ["Stai per eliminare permanentemente {count} elemento","Stai per eliminare permanentemente {count} elementi","Stai per eliminare permanentemente {count} elementi"],
     "_You are about to delete {count} item_::_You are about to delete {count} items_" : ["Stai per eliminare {count} elemento","Stai per eliminare {count} elementi","Stai per eliminare {count} elementi"],
     "Confirm deletion" : "Conferma l'eliminazione",
-    "Cancel" : "Annulla",
     "Download" : "Scarica",
     "The requested file is not available." : "Il file richiesto non è disponibile.",
     "The requested files are not available." : "I file richiesti non sono disponibili.",
+    "Add to favorites" : "Aggiungi ai preferiti",
+    "Remove from favorites" : "Rimuovi dai preferiti",
     "Add or remove favorite" : "Aggiungi o rimuovi preferito",
-    "Moving \"{source}\" to \"{destination}\" …" : "Spostare \"{source}\" in \"{destination}\" …",
-    "Copying \"{source}\" to \"{destination}\" …" : "Copiare \"{source}\" in \"{destination}\" …",
+    "Move" : "Sposta",
+    "Copy" : "Copia",
+    "Move or copy" : "Sposta o copia",
     "Destination is not a folder" : "La destinazione non è una cartella",
     "This file/folder is already in that directory" : "Questo file/cartella è già in quella cartella",
     "You cannot move a file/folder onto itself or into a subfolder of itself" : "Non puoi spostare un file/cartella in se stesso o in una sottocartella di se stesso",
-    "(copy)" : "(copia)",
-    "(copy %n)" : "(copia %n)",
     "A file or folder with that name already exists in this folder" : "Esiste già un file o una cartella con quel nome in questa cartella",
     "The files are locked" : "I files sono bloccati",
     "The file does not exist anymore" : "Il file non esiste più",
+    "Moving \"{source}\" to \"{destination}\" …" : "Spostare \"{source}\" in \"{destination}\" …",
+    "Copying \"{source}\" to \"{destination}\" …" : "Copiare \"{source}\" in \"{destination}\" …",
     "Choose destination" : "Scegli la destinazione",
     "Copy to {target}" : "Copia in {target}",
-    "Copy" : "Copia",
     "Move to {target}" : "Sposta in {target}",
-    "Move" : "Sposta",
     "Move or copy operation failed" : "Operazione di spostamento o copia fallita",
-    "Move or copy" : "Sposta o copia",
+    "Open folder" : "Apri cartella",
     "Open folder {displayName}" : "Apri la cartella {displayName}",
     "Open in Files" : "Apri in File",
     "Open locally" : "Aprire localmente",
     "Failed to redirect to client" : "Reindirizzamento al client non riuscito",
     "Open file locally" : "Apri file localmente",
-    "The file should now open on your device. If it doesn't, please check that you have the desktop app installed." : "Il file dovrebbe ora aprirsi sul tuo dispositivo. In caso contrario, controlla di aver installato l'app desktop.",
+    "The file should now open on your device. If it doesn't, please check that you have the desktop app installed." : "Il file dovrebbe ora aprirsi sul tuo dispositivo. In caso contrario, controlla di aver installato l'applicazione desktop.",
     "Retry and close" : "Riprova e chiudi",
     "Open online" : "Apri online",
-    "Rename" : "Rinomina",
     "Details" : "Dettagli",
+    "Open the details sidebar" : "Apri la barra laterale dei dettagli",
+    "Unfavorite" : "Rimuovi preferito",
     "View in folder" : "Visualizza nella cartella",
-    "Today" : "Ogg",
-    "Last 7 days" : "Ultimi 7 giorni",
-    "Last 30 days" : "Ultimi 30 giorni",
-    "This year ({year})" : "Quest'anno ({year})",
-    "Last year ({year})" : "L'anno scorso ({year})",
-    "Documents" : "Documenti",
-    "Spreadsheets" : "Fogli elettronici",
-    "Presentations" : "Presentazioni",
-    "PDFs" : "PDF",
-    "Folders" : "Cartelle",
-    "Audio" : "Audio",
-    "Images" : "Immagini",
-    "Videos" : "Video",
+    "Type" : "Tipo",
     "Created new folder \"{name}\"" : "Crea una nuova cartella \"{name}\"",
     "Unable to initialize the templates directory" : "Impossibile inizializzare la cartella dei modelli",
     "Create templates folder" : "Crea cartella dei modelli",
     "Templates" : "Modelli",
     "New template folder" : "Nuova cartella dei modelli",
     "In folder" : "Nella cartella",
+    "Pick folder to search in" : "Seleziona la cartella in cui cercare",
     "Search in all files" : "Cerca in tutti i file",
     "Search in folder: {folder}" : "Cerca nella cartella: {folder}",
     "One of the dropped files could not be processed" : "Impossibile elaborare uno dei file depositati",
     "Your browser does not support the Filesystem API. Directories will not be uploaded" : "Il tuo browser non supporta l'API del file system. Le directory non verranno caricate",
     "No files to upload" : "Nessun file da caricare",
-    "Unable to create the directory {directory}" : "Impossibile creare la directory {directory}",
+    "Unable to create the directory {directory}" : "Impossibile creare la cartella {directory}",
     "Some files could not be uploaded" : "Alcuni file non possono essere caricati",
     "Files uploaded successfully" : "Files caricati correttamente",
     "No files to process" : "Nessun file da elaborare",
-    "Some files could not be copied" : "Alcuni file non possono essere copiati",
-    "Some files could not be moved" : "Alcuni file non possono essere spostati",
     "Files copied successfully" : "File copiati correttamente",
     "Files moved successfully" : "File spostati correttamente",
+    "Some files could not be copied" : "Alcuni file non possono essere copiati",
+    "Some files could not be moved" : "Alcuni file non possono essere spostati",
     "Conflicts resolution skipped" : "Risoluzione dei conflitti saltata",
     "Upload cancelled" : "Caricamento annullato",
     "Could not rename \"{oldName}\", it does not exist any more" : "Impossibile rinominare \"{oldName}\", non esiste più",
@@ -392,10 +394,14 @@ OC.L10N.register(
     "Upload (max. %s)" : "Carica (massimo %s)",
     "After enabling the windows compatible filenames, existing files cannot be modified anymore but can be renamed to valid new names by their owner." : "Dopo aver abilitato i nomi file compatibili con Windows, i file esistenti non potranno più essere modificati, ma potranno essere rinominati con nuovi nomi validi dal rispettivo proprietario.",
     "It is also possible to migrate files automatically after enabling this setting, please refer to the documentation about the occ command." : "È anche possibile migrare i file automaticamente dopo aver abilitato questa impostazione; fare riferimento alla documentazione relativa al comando occ.",
+    "Renamed \"{oldName}\" to \"{newName}\"" : "Rinominato \"{oldName}\" in \"{newName}\"",
+    "Clear filter" : "Pulisci il filtro",
     "\"{displayName}\" failed on some elements" : "\"{displayName}\" non riuscito su alcuni elementi",
     "\"{displayName}\" batch action executed successfully" : "L'azione batch \"{displayName}\" è stata eseguita correttamente",
     "\"{displayName}\" action failed" : "L'azione \"{displayName}\" non è riuscita",
     "Submitting fields …" : "Invio dei campi …",
+    "Shared by link" : "Condivisi tramite collegamento",
+    "Shared" : "Condiviso",
     "\"{displayName}\" action executed successfully" : "L'azione \"{displayName}\" è stata eseguita correttamente",
     "Filter file names …" : "Filtra i nomi dei file …",
     "Clipboard is not available" : "Appunti non disponibili",
@@ -425,6 +431,11 @@ OC.L10N.register(
     "Navigate to the file on the right (in grid mode)" : "Navigare nel file a destra (in modalità griglia)",
     "Toggle the grid view" : "Attiva la vista a griglia",
     "Open the sidebar for a file" : "Aprire la barra laterale per un file",
+    "You" : "Tu",
+    "Shared multiple times with different people" : "Condiviso più volte con diverse persone",
+    "Unable to change the favorite state of the file" : "Impossibile modificare lo stato preferito del file",
+    "Error while loading the file data" : "Errore durante il caricamento del file di dati",
+    "Tags" : "Etichette",
     "Save as …" : "Salva come …",
     "Converting files …" : "Conversione dei file …",
     "Converting file …" : "Conversione del file …",
@@ -432,7 +443,9 @@ OC.L10N.register(
     "Edit locally" : "Modifica localmente",
     "Moving \"{source}\" to \"{destination}\" …" : "Sposta \"{source}\" in \"{destination}\" …",
     "Copying \"{source}\" to \"{destination}\" …" : "Copia \"{source}\" in \"{destination}\" …",
-    "Move cancelled" : "Spostamento cancellato",
+    "(copy)" : "(copia)",
+    "(copy %n)" : "(copia %n)",
+    "Move cancelled" : "Spostamento annullato",
     "Cancelled move or copy of \"{filename}\"." : "Spostamento o copia di \"{filename}\" annullato.",
     "Cancelled move or copy operation" : "Operazione di spostamento o copia annullata",
     "Open details" : "Apri i dettagli",
@@ -440,6 +453,7 @@ OC.L10N.register(
     "New folder creation cancelled" : "Creazione nuova cartella annullata",
     "This directory is unavailable, please check the logs or contact the administrator" : "Questa cartella non è disponibile, controlla i log o contatta l'amministratore",
     "All folders" : "Tutte le cartelle",
+    "Open file sidebar" : "Apri la barra laterale del file",
     "Search everywhere …" : "Cerca ovunque…",
     "Search here …" : "Cerca qui…",
     "Preparing …" : "In preparazione …"
