@@ -74,6 +74,7 @@ OC.L10N.register(
     "Reload current directory" : "이 경로를 새로고침",
     "Go to the \"{dir}\" directory" : "\"{dir}\" 경로로 이동",
     "Current directory path" : "현재 디렉토리 경로",
+    "Share" : "공유하기",
     "Your have used your space quota and cannot upload files anymore" : "저장소 할당량을 모두 사용하여 더 이상 파일을 업로드할 수 없습니다",
     "You do not have permission to upload or create files here." : "여기에 업로드하거나 파일을 생성할 권한이 없습니다.",
     "Drag and drop files here to upload" : "이곳에 파일을 드래그 앤 드롭해 업로드",
@@ -88,17 +89,28 @@ OC.L10N.register(
     "This node is unavailable" : "이 노드를 사용할 수 없습니다",
     "Another entry with the same name already exists." : "같은 이름의 항목이 이미 있습니다.",
     "Invalid filename." : "잘못된 파일 이름",
-    "Renamed \"{oldName}\" to \"{newName}\"" : "\"{oldName}\" 에서 \"{newName}\"(으)로 이름 변경함",
     "Rename file" : "파일 이름 바꾸기",
     "Folder" : "폴더",
     "Pending" : "대기 중",
     "Unknown date" : "알 수 없는 날짜",
-    "Clear filter" : "필터 지우기",
-    "Modified" : "수정됨",
-    "Search everywhere" : "모든 곳에서 찾기",
-    "Type" : "종류",
     "Active filters" : "활성 필터",
     "Remove filter" : "필터 삭제",
+    "Today" : "오늘",
+    "Last 7 days" : "지난 7일",
+    "Last 30 days" : "지난 30일",
+    "This year ({year})" : "올해 ({year})",
+    "Last year ({year})" : "작년 ({year})",
+    "Custom date range" : "맞춤 날짜 범위",
+    "Search everywhere" : "모든 곳에서 찾기",
+    "Documents" : "문서",
+    "Spreadsheets" : "스프레드시트",
+    "Presentations" : "프레젠테이션",
+    "PDFs" : "PDF",
+    "Folders" : "폴더",
+    "Audio" : "오디오",
+    "Images" : "이미지",
+    "Videos" : "동영상",
+    "Filters" : "필터",
     "Appearance" : "외형",
     "Show hidden files" : "숨김 파일 보이기",
     "Show file type column" : "파일 형식 열 보이기",
@@ -126,7 +138,6 @@ OC.L10N.register(
     "Go right in grid" : "그리드에서 오른쪽으로 이동",
     "View" : "보기",
     "Toggle grid view" : "그리드뷰 전환",
-    "Open file sidebar" : "파일 사이드바 열기",
     "Show those shortcuts" : "다음 단축키 표시",
     "Warnings" : "경고",
     "Warn before changing a file extension" : "파일 확장자 변경 시 경고",
@@ -136,6 +147,7 @@ OC.L10N.register(
     "Toggle selection for all files and folders" : "모든 파일 선택/선택해제",
     "Name" : "이름",
     "Size" : "크기",
+    "Modified" : "수정됨",
     "(selected)" : "(선택됨)",
     "List of files and folders." : "파일과 폴더의 목록",
     "You have used your space quota and cannot upload files anymore." : "저장소 할당량을 모두 사용하여 더 이상 파일을 업로드할 수 없습니다.",
@@ -180,12 +192,11 @@ OC.L10N.register(
     "Removing the file extension \"{old}\" may render the file unreadable." : "\"{old}\" 파일 확장자를 제거하면 파일을 읽지 못할 수 있습니다.",
     "Adding the file extension \"{new}\" may render the file unreadable." : "\"{new}\" 파일 확장자를 추가하면 파일을 읽지 못할 수 있습니다.",
     "Do not show this dialog again." : "이 알림을 다시 보여주지 마세요.",
+    "Cancel" : "취소",
+    "Rename" : "이름 바꾸기",
     "Select file or folder to link to" : "링크할 파일이나 폴더 선택",
     "Choose {file}" : "{file} 선택",
     "Files settings" : "파일 설정",
-    "Share" : "공유하기",
-    "Shared by link" : "링크로 공유됨",
-    "Shared" : "공유됨",
     "Switch to list view" : "목록 보기로 전환",
     "Switch to grid view" : "바둑판식 보기로 전환",
     "The file could not be found" : "파일을 찾을 수 없음",
@@ -233,26 +244,23 @@ OC.L10N.register(
     "_You are about to permanently delete {count} item_::_You are about to permanently delete {count} items_" : ["{count}개 항목을 영구적으로 삭제하려 합니다."],
     "_You are about to delete {count} item_::_You are about to delete {count} items_" : ["{count}개 항목을 삭제하려 합니다."],
     "Confirm deletion" : "삭제 확인",
-    "Cancel" : "취소",
     "Download" : "다운로드",
     "Add to favorites" : "즐겨찾기에 추가",
     "Remove from favorites" : "즐겨찾기에서 삭제",
     "Add or remove favorite" : "즐겨찾기 추가 또는 삭제",
+    "Move" : "이동",
+    "Copy" : "복사",
+    "Move or copy" : "이동이나 복사",
     "Destination is not a folder" : "대상이 폴더가 아닙니다.",
     "This file/folder is already in that directory" : "이 파일/폴더가 이미 그 경로에 있습니다.",
     "You cannot move a file/folder onto itself or into a subfolder of itself" : "파일/폴더를 그 안이나 그 안의 폴더로 이동할 수 없습니다.",
-    "(copy)" : "(복사)",
-    "(copy %n)" : "(%n 복사)",
     "A file or folder with that name already exists in this folder" : "같은 이름을 사용하는 파일 또는 폴더가 이미 이 폴더에 있습니다.",
     "The files are locked" : "이 파일은 잠겼습니다",
     "The file does not exist anymore" : "파일이 더이상 존재하지 않습니다.",
     "Choose destination" : "목적지 선택",
     "Copy to {target}" : "{target}에 복사",
-    "Copy" : "복사",
     "Move to {target}" : "{target}에 이동",
-    "Move" : "이동",
     "Move or copy operation failed" : "이동 또는 복사 작업에 실패함",
-    "Move or copy" : "이동이나 복사",
     "Open folder" : "폴더를 열 수 없음",
     "Open folder {displayName}" : "{displayName} 폴더 열기",
     "Open in Files" : "파일에서 열기",
@@ -261,22 +269,9 @@ OC.L10N.register(
     "Open file locally" : "로컬에서 파일 열기",
     "The file should now open on your device. If it doesn't, please check that you have the desktop app installed." : "이제 이 파일이 당신의 기기에서 열려야 합니다. 그렇지 않다면, 데스크톱 앱이 설치되어 있는지 확인하세요.",
     "Retry and close" : "재시도 후 닫기",
-    "Rename" : "이름 바꾸기",
     "Details" : "자세한 정보",
     "View in folder" : "폴더에서 보기",
-    "Today" : "오늘",
-    "Last 7 days" : "지난 7일",
-    "Last 30 days" : "지난 30일",
-    "This year ({year})" : "올해 ({year})",
-    "Last year ({year})" : "작년 ({year})",
-    "Documents" : "문서",
-    "Spreadsheets" : "스프레드시트",
-    "Presentations" : "프레젠테이션",
-    "PDFs" : "PDF",
-    "Folders" : "폴더",
-    "Audio" : "오디오",
-    "Images" : "이미지",
-    "Videos" : "동영상",
+    "Type" : "종류",
     "Created new folder \"{name}\"" : "\"{name}\" 폴더를 새로 만듦",
     "Unable to initialize the templates directory" : "템플릿 디렉터리를 설정할 수 없음",
     "Create templates folder" : "템플릿 폴더 만들기",
@@ -291,10 +286,10 @@ OC.L10N.register(
     "Some files could not be uploaded" : "일부 파일을 업로드할 수 없었습니다.",
     "Files uploaded successfully" : "파일을 성공적으로 업로드했습니다.",
     "No files to process" : "처리할 파일이 없음",
-    "Some files could not be copied" : "일부 파일을 복사할 수 없음",
-    "Some files could not be moved" : "일부 파일을 이동할 수 없음",
     "Files copied successfully" : "파일을 성공적으로 복사함",
     "Files moved successfully" : "파일을 성공적으로 이동함",
+    "Some files could not be copied" : "일부 파일을 복사할 수 없음",
+    "Some files could not be moved" : "일부 파일을 이동할 수 없음",
     "Conflicts resolution skipped" : "충돌 해결 건너뜀",
     "Upload cancelled" : "업로드가 취소됨",
     "Could not rename \"{oldName}\", it does not exist any more" : "\"{oldName}\"(이)가 더이상 존재하지 않아 이름을 바꿀 수 없습니다.",
@@ -328,10 +323,14 @@ OC.L10N.register(
     "Upload too large" : "업로드한 파일이 너무 큼",
     "The files you are trying to upload exceed the maximum size for file uploads on this server." : "이 파일이 서버에서 허용하는 최대 업로드 가능 용량보다 큽니다.",
     "Upload (max. %s)" : "업로드(최대 %s)",
+    "Renamed \"{oldName}\" to \"{newName}\"" : "\"{oldName}\" 에서 \"{newName}\"(으)로 이름 변경함",
+    "Clear filter" : "필터 지우기",
     "\"{displayName}\" failed on some elements" : "\"{displayName}\" 일부 요소로 실패",
     "\"{displayName}\" batch action executed successfully" : "\"{displayName}\" 일괄 작업을 성공적으로 실행함",
     "\"{displayName}\" action failed" : "\"{displayName}\" 작업을 실패함",
     "Submitting fields …" : "항목 제출 중 ...",
+    "Shared by link" : "링크로 공유됨",
+    "Shared" : "공유됨",
     "\"{displayName}\" action executed successfully" : "\"{displayName}\" 작업을 성공적으로 실행함",
     "Clipboard is not available" : "클립보드를 사용할 수 없습니다.",
     "WebDAV URL copied to clipboard" : "WebDAV URL이 클립보드에 복사됨",
@@ -368,6 +367,8 @@ OC.L10N.register(
     "Edit locally" : "로컬에서 편집",
     "Moving \"{source}\" to \"{destination}\" …" : "\"{source}\"을(를) \"{destination}\"(으)로 이동...",
     "Copying \"{source}\" to \"{destination}\" …" : "\"{source}\"을(를) \"{destination}\"(으)로 복사...",
+    "(copy)" : "(복사)",
+    "(copy %n)" : "(%n 복사)",
     "Move cancelled" : "이동이 취소됨",
     "Cancelled move or copy of \"{filename}\"." : "\"{filename}\"의 이동 또는 복사를 취소했습니다.",
     "Cancelled move or copy operation" : "이동 또는 복사 작업을 취소함",
@@ -376,6 +377,7 @@ OC.L10N.register(
     "New folder creation cancelled" : "새 폴더 생성 취소됨",
     "This directory is unavailable, please check the logs or contact the administrator" : "디렉터리를 사용할 수 없습니다. 로그를 확인하거나 관리자에게 연락하십시오",
     "All folders" : "모든 폴더",
+    "Open file sidebar" : "파일 사이드바 열기",
     "Search everywhere …" : "모든 곳에서 검색 ...",
     "Search here …" : "여기서 검색 ..."
 },
