@@ -78,6 +78,7 @@ OC.L10N.register(
     "Reload current directory" : "Reload current directory",
     "Go to the \"{dir}\" directory" : "Go to the \"{dir}\" directory",
     "Current directory path" : "Current directory path",
+    "Share" : "ແບ່ງປັນ",
     "Your have used your space quota and cannot upload files anymore" : "Your have used your space quota and cannot upload files anymore",
     "You do not have permission to upload or create files here." : "You do not have permission to upload or create files here.",
     "Drag and drop files here to upload" : "Drag and drop files here to upload",
@@ -92,7 +93,6 @@ OC.L10N.register(
     "This node is unavailable" : "This node is unavailable",
     "Another entry with the same name already exists." : "Another entry with the same name already exists.",
     "Invalid filename." : "Invalid filename.",
-    "Renamed \"{oldName}\" to \"{newName}\"" : "Renamed \"{oldName}\" to \"{newName}\"",
     "Rename file" : "Rename file",
     "Folder" : "Folder",
     "Unknown file type" : "Unknown file type",
@@ -102,12 +102,24 @@ OC.L10N.register(
     "{ext} text" : "{ext} text",
     "Pending" : "ທີ່ກໍາລັງລໍຖ້າ",
     "Unknown date" : "Unknown date",
-    "Clear filter" : "Clear filter",
-    "Modified" : "\"{name}\" ແມ່ນຊື່ໄຟລ໌ທີ່ບໍ່ຖືກຕ້ອງ.",
-    "Search everywhere" : "ຄົ້ນຫາທຸກບ່ອນ",
-    "Type" : "ພິມ",
     "Active filters" : "Active filters",
     "Remove filter" : "ລຶບໂຕກອງ",
+    "Today" : "ມື້ນີ້",
+    "Last 7 days" : "Last 7 days",
+    "Last 30 days" : "Last 30 days",
+    "This year ({year})" : "This year ({year})",
+    "Last year ({year})" : "Last year ({year})",
+    "Custom date range" : "Custom date range",
+    "Search everywhere" : "ຄົ້ນຫາທຸກບ່ອນ",
+    "Documents" : "ເອກະສານ",
+    "Spreadsheets" : "Spreadsheets",
+    "Presentations" : "Presentations",
+    "PDFs" : "PDFs",
+    "Folders" : "Folders",
+    "Audio" : "ສຽງ",
+    "Images" : "ຮູບພາບ",
+    "Videos" : "ວິດີໂອ",
+    "Filters" : "ຟິວເຕີ",
     "Appearance" : "Appearance",
     "Show hidden files" : "ສະແດງຟາຍທີ່ເຊື່ອງໄວ້",
     "Show file type column" : "Show file type column",
@@ -136,7 +148,6 @@ OC.L10N.register(
     "Go right in grid" : "Go right in grid",
     "View" : "ເບິ່ງ",
     "Toggle grid view" : "Toggle grid view",
-    "Open file sidebar" : "Open file sidebar",
     "Show those shortcuts" : "Show those shortcuts",
     "Warnings" : "Warnings",
     "Warn before changing a file extension" : "Warn before changing a file extension",
@@ -150,6 +161,7 @@ OC.L10N.register(
     "Name" : "ຊື່",
     "File type" : "File type",
     "Size" : "ຂະຫນາດ",
+    "Modified" : "\"{name}\" ແມ່ນຊື່ໄຟລ໌ທີ່ບໍ່ຖືກຕ້ອງ.",
     "{displayName}: failed on some elements" : "{displayName}: failed on some elements",
     "{displayName}: done" : "{displayName}: done",
     "{displayName}: failed" : "{displayName}: failed",
@@ -218,12 +230,11 @@ OC.L10N.register(
     "Removing the file extension \"{old}\" may render the file unreadable." : "Removing the file extension \"{old}\" may render the file unreadable.",
     "Adding the file extension \"{new}\" may render the file unreadable." : "Adding the file extension \"{new}\" may render the file unreadable.",
     "Do not show this dialog again." : "Do not show this dialog again.",
+    "Cancel" : "ຍົກເລີກ",
+    "Rename" : "ປ່ຽນຊື່",
     "Select file or folder to link to" : "Select file or folder to link to",
     "Choose {file}" : "Choose {file}",
     "Files settings" : "Files settings",
-    "Share" : "ແບ່ງປັນ",
-    "Shared by link" : "ແບ່ງປັນດ້ວຍລິ້ງ",
-    "Shared" : "ແບ່ງປັນ",
     "Switch to list view" : "ປ່ຽນເປັນມຸມມອງລາຍການ",
     "Switch to grid view" : "Switch to grid view",
     "The file could not be found" : "The file could not be found",
@@ -285,30 +296,27 @@ OC.L10N.register(
     "_You are about to permanently delete {count} item_::_You are about to permanently delete {count} items_" : ["You are about to permanently delete {count} items"],
     "_You are about to delete {count} item_::_You are about to delete {count} items_" : ["You are about to delete {count} item"],
     "Confirm deletion" : "Confirm deletion",
-    "Cancel" : "ຍົກເລີກ",
     "Download" : "ດາວໂຫລດ",
     "The requested file is not available." : "The requested file is not available.",
     "The requested files are not available." : "The requested files are not available.",
     "Add to favorites" : "ເພີ່ມລາຍການທີ່ມັກ",
     "Remove from favorites" : "ຍ້າຍຈາກລາຍການທີ່ມັກ",
     "Add or remove favorite" : "Add or remove favorite",
-    "Moving \"{source}\" to \"{destination}\" …" : "Moving \"{source}\" to \"{destination}\" …",
-    "Copying \"{source}\" to \"{destination}\" …" : "Copying \"{source}\" to \"{destination}\" …",
+    "Move" : "ຍ້າຍ",
+    "Copy" : "ສຳເນົາ",
+    "Move or copy" : "ຍ້າຍ ຫຼື ສຳເນົາ",
     "Destination is not a folder" : "Destination is not a folder",
     "This file/folder is already in that directory" : "This file/folder is already in that directory",
     "You cannot move a file/folder onto itself or into a subfolder of itself" : "You cannot move a file/folder onto itself or into a subfolder of itself",
-    "(copy)" : "(copy)",
-    "(copy %n)" : "(copy %n)",
     "A file or folder with that name already exists in this folder" : "A file or folder with that name already exists in this folder",
     "The files are locked" : "The files are locked",
     "The file does not exist anymore" : "The file does not exist anymore",
+    "Moving \"{source}\" to \"{destination}\" …" : "Moving \"{source}\" to \"{destination}\" …",
+    "Copying \"{source}\" to \"{destination}\" …" : "Copying \"{source}\" to \"{destination}\" …",
     "Choose destination" : "Choose destination",
     "Copy to {target}" : "ສຳເນົາໄປທີ່ {target}",
-    "Copy" : "ສຳເນົາ",
     "Move to {target}" : "ຍ້າຍໄປທີ່ {target}",
-    "Move" : "ຍ້າຍ",
     "Move or copy operation failed" : "Move or copy operation failed",
-    "Move or copy" : "ຍ້າຍ ຫຼື ສຳເນົາ",
     "Open folder" : "Open folder",
     "Open folder {displayName}" : "Open folder {displayName}",
     "Open in Files" : "ເປີດໃນ Files",
@@ -318,22 +326,9 @@ OC.L10N.register(
     "The file should now open on your device. If it doesn't, please check that you have the desktop app installed." : "The file should now open on your device. If it doesn't, please check that you have the desktop app installed.",
     "Retry and close" : "Retry and close",
     "Open online" : "Open online",
-    "Rename" : "ປ່ຽນຊື່",
     "Details" : "ລາຍລະອຽດ",
     "View in folder" : "ເບິ່ງໃນໂຟນເດີ",
-    "Today" : "ມື້ນີ້",
-    "Last 7 days" : "Last 7 days",
-    "Last 30 days" : "Last 30 days",
-    "This year ({year})" : "This year ({year})",
-    "Last year ({year})" : "Last year ({year})",
-    "Documents" : "ເອກະສານ",
-    "Spreadsheets" : "Spreadsheets",
-    "Presentations" : "Presentations",
-    "PDFs" : "PDFs",
-    "Folders" : "Folders",
-    "Audio" : "ສຽງ",
-    "Images" : "ຮູບພາບ",
-    "Videos" : "ວິດີໂອ",
+    "Type" : "ພິມ",
     "Created new folder \"{name}\"" : "Created new folder \"{name}\"",
     "Unable to initialize the templates directory" : "Unable to initialize the templates directory",
     "Create templates folder" : "Create templates folder",
@@ -349,10 +344,10 @@ OC.L10N.register(
     "Some files could not be uploaded" : "Some files could not be uploaded",
     "Files uploaded successfully" : "Files uploaded successfully",
     "No files to process" : "No files to process",
-    "Some files could not be copied" : "Some files could not be copied",
-    "Some files could not be moved" : "ບາງຟາຍບໍ່ສາມາດເຄື່ອນຍ້າຍໄດ້",
     "Files copied successfully" : "Files copied successfully",
     "Files moved successfully" : "Files moved successfully",
+    "Some files could not be copied" : "Some files could not be copied",
+    "Some files could not be moved" : "ບາງຟາຍບໍ່ສາມາດເຄື່ອນຍ້າຍໄດ້",
     "Conflicts resolution skipped" : "Conflicts resolution skipped",
     "Upload cancelled" : "Upload cancelled",
     "Could not rename \"{oldName}\", it does not exist any more" : "Could not rename \"{oldName}\", it does not exist any more",
@@ -393,10 +388,14 @@ OC.L10N.register(
     "Upload (max. %s)" : "Upload (max. %s)",
     "After enabling the windows compatible filenames, existing files cannot be modified anymore but can be renamed to valid new names by their owner." : "After enabling the windows compatible filenames, existing files cannot be modified anymore but can be renamed to valid new names by their owner.",
     "It is also possible to migrate files automatically after enabling this setting, please refer to the documentation about the occ command." : "It is also possible to migrate files automatically after enabling this setting, please refer to the documentation about the occ command.",
+    "Renamed \"{oldName}\" to \"{newName}\"" : "Renamed \"{oldName}\" to \"{newName}\"",
+    "Clear filter" : "Clear filter",
     "\"{displayName}\" failed on some elements" : "\"{displayName}\" failed on some elements",
     "\"{displayName}\" batch action executed successfully" : "\"{displayName}\" batch action executed successfully",
     "\"{displayName}\" action failed" : "\"{displayName}\" action failed",
     "Submitting fields …" : "Submitting fields …",
+    "Shared by link" : "ແບ່ງປັນດ້ວຍລິ້ງ",
+    "Shared" : "ແບ່ງປັນ",
     "\"{displayName}\" action executed successfully" : "\"{displayName}\" action executed successfully",
     "Filter file names …" : "Filter file names …",
     "Clipboard is not available" : "Clipboard is not available",
@@ -438,6 +437,8 @@ OC.L10N.register(
     "Edit locally" : "Edit locally",
     "Moving \"{source}\" to \"{destination}\" …" : "Moving \"{source}\" to \"{destination}\" …",
     "Copying \"{source}\" to \"{destination}\" …" : "Copying \"{source}\" to \"{destination}\" …",
+    "(copy)" : "(copy)",
+    "(copy %n)" : "(copy %n)",
     "Move cancelled" : "Move cancelled",
     "Cancelled move or copy of \"{filename}\"." : "Cancelled move or copy of \"{filename}\".",
     "Cancelled move or copy operation" : "Cancelled move or copy operation",
@@ -446,6 +447,7 @@ OC.L10N.register(
     "New folder creation cancelled" : "New folder creation cancelled",
     "This directory is unavailable, please check the logs or contact the administrator" : "This directory is unavailable, please check the logs or contact the administrator",
     "All folders" : "All folders",
+    "Open file sidebar" : "Open file sidebar",
     "Search everywhere …" : "Search everywhere …",
     "Search here …" : "Search here …",
     "Preparing …" : "Preparing …"
