@@ -60,11 +60,11 @@ OC.L10N.register(
     "Your ownership transfer of {path} to {user} has completed." : "Jūsų {path} nuosavybės perdavimas naudotojui {user} užbaigtas.",
     "The ownership transfer of {path} from {user} has completed." : "{path} nuosavybės perdavimas iš naudotojo {user} užbaigtas.",
     "in %s" : "per %s",
-    "Files compatibility" : "Failų suderinamumas",
     "File Management" : "Failų tvarkymas",
     "Home" : "Pagrindinis",
     "Target folder does not exist any more" : "Paskirties aplanko daugiau nebėra",
     "Reload current directory" : "Įkelti dabartinį katalogą iš naujo",
+    "Share" : "Bendrinti",
     "Drag and drop files here to upload" : "Tempkite failus čia norėdami išsiųsti",
     "Favorite" : "Mėgstamas",
     "Back" : "Atgal",
@@ -73,22 +73,44 @@ OC.L10N.register(
     "Filename" : "Failo pavadinimas",
     "Folder name" : "Aplanko pavadinimas",
     "Invalid filename." : "Neteisingas failo pavadinimas.",
-    "Renamed \"{oldName}\" to \"{newName}\"" : "„{oldName}“ pervadintas į „{newName}“",
     "Rename file" : "Pervadinti failą",
     "Folder" : "Aplankas",
     "Pending" : "Laukiantis",
     "Unknown date" : "Nežinoma data",
-    "Clear filter" : "Išvalyti filtrą",
-    "Modified" : "Pakeistas",
-    "Type" : "Tipas",
     "Active filters" : "Aktyvūs filtrai",
     "Remove filter" : "Šalinti filtrą",
+    "Today" : "Šiandien",
+    "Last 7 days" : "Paskutinės 7 dienos",
+    "Last 30 days" : "Paskutinės 30 dienų",
+    "Documents" : "Dokumentai",
+    "Spreadsheets" : "Skaičiuoklės",
+    "Presentations" : "Pateiktys",
+    "PDFs" : "PDF dokumentai",
+    "Folders" : "Aplankai",
+    "Audio" : "Garso įrašai",
+    "Images" : "Paveikslai",
+    "Videos" : "Vaizdo įrašai",
+    "Filters" : "Filtrai",
+    "Appearance" : "Išvaizda",
+    "Show hidden files" : "Rodyti paslėptus failus",
+    "Crop image previews" : "Apkirpti paveikslėlių peržiūras",
+    "General" : "Bendra",
+    "All files" : "Visi failai",
+    "Personal files" : "Asmeniniai failai",
+    "Additional settings" : "Papildomi nustatymai",
+    "Actions" : "Veiksmai",
+    "Selection" : "Pasirinkimas",
+    "Deselect all" : "Panaikinti pasirinkimą",
+    "Navigation" : "Navigacija",
+    "View" : "Rodyti",
+    "Toggle grid view" : "Rodyti tinkleliu",
+    "Warnings" : "Įspėjimai",
     "Name" : "Pavadinimas",
     "Size" : "Dydis",
-    "Actions" : "Veiksmai",
+    "Modified" : "Pakeistas",
     "List of files and folders." : "Failų ir aplankų sąrašas.",
     "File not found" : "Failas nerastas",
-    "{count} selected" : "Pažymėta {count}",
+    "Owner" : "Savininkas",
     "{usedQuotaByte} used" : "Naudojama {usedQuotaByte}",
     "{used} of {quota} used" : "panaudota {used} iš {quota}",
     "{relative}% used" : "Naudojama {relative}",
@@ -99,6 +121,7 @@ OC.L10N.register(
     "Create new folder" : "Sukurti naują aplanką",
     "This name is already in use." : "Šis pavadinimas jau yra naudojamas.",
     "Create" : "Sukurti",
+    "Refresh" : "Įkelti iš naujo",
     "Submit" : "Pateikti",
     "Choose a file or folder to transfer" : "Pasirinkite norimą perduoti failą ar aplanką",
     "Transfer" : "Perduoti",
@@ -110,10 +133,10 @@ OC.L10N.register(
     "Choose file or folder to transfer" : "Pasirinkti norimą perduoti failą ar aplanką",
     "Change" : "Keisti",
     "New owner" : "Naujasis savininkas",
+    "Cancel" : "Atsisakyti",
+    "Rename" : "Pervadinti",
     "Choose {file}" : "Pasirinkti{file}",
-    "Share" : "Bendrinti",
-    "Shared by link" : "Bendrinama pagal nuorodą",
-    "Shared" : "Bendrinama",
+    "Files settings" : "Failų nustatymai",
     "Switch to list view" : "Perjungti į sąrašo rodinį",
     "Switch to grid view" : "Perjungti į tinklelio rodinį",
     "The file could not be found" : "Failas nerastas",
@@ -127,40 +150,17 @@ OC.L10N.register(
     "Upload some content or sync with your devices!" : "Įkelkite failus arba sinchronizuokite su savo įrenginiais!",
     "Go back" : "Grįžti",
     "Views" : "Rodiniai",
-    "Files settings" : "Failų nustatymai",
+    "Loading …" : "Įkeliama …",
     "Your files" : "Jūsų failai",
     "File cannot be accessed" : "Nepavyksta gauti prieigos prie failo",
     "The file could not be found or you do not have permissions to view it. Ask the sender to share it." : "Nepavyko surasti failo arba jūs neturite leidimo jo peržiūrėti. Paprašykite siuntėjo, kad pradėtų jį su jumis bendrinti.",
-    "Clipboard is not available" : "Iškarpinė neprieinama",
-    "WebDAV URL copied to clipboard" : "WebDAV URL nukopijuotas į iškarpinę",
-    "Show hidden files" : "Rodyti paslėptus failus",
-    "Crop image previews" : "Apkirpti paveikslėlių peržiūras",
-    "Enable the grid view" : "Įjungti grid peržiūrą",
-    "Enable folder tree" : "Įjungti direktorijų medį",
-    "Additional settings" : "Papildomi nustatymai",
-    "WebDAV" : "WebDAV",
-    "Copy to clipboard" : "Kopijuoti į iškarpinę",
-    "Use this address to access your Files via WebDAV" : "Naudokite šį adresą norėdami pasiekti failus per WebDAV",
-    "Warnings" : "Įspėjimai",
-    "Keyboard shortcuts" : "Spartieji klavišai",
-    "Rename a file" : "Pervadinti failą",
-    "Delete a file" : "Ištrinti failą",
-    "Selection" : "Pasirinkimas",
-    "Navigation" : "Navigacija",
-    "View" : "Rodyti",
-    "You" : "Jūs",
-    "Error while loading the file data" : "Klaida įkeliant failo duomenis",
-    "Owner" : "Savivinkas",
-    "Remove from favorites" : "Šalinti iš mėgstamų",
-    "Add to favorites" : "Pridėti į mėgstamus",
-    "Tags" : "Žymos",
+    "Files compatibility" : "Failų suderinamumas",
     "Unable to create new file from template" : "Nepavyko sukurti naujo failo iš šablono",
     "Pick a template for {name}" : "Pasirinkite šabloną, skirtą {name}",
     "Create a new file with the selected template" : "Sukurti naują failą naudojant pasirinktą šabloną",
     "Creating file" : "Sukuriamas failas",
     "Save as {displayName}" : "Įrašyti kaip {displayName}",
-    "Save as …" : "Įrašyti kaip…",
-    "Deletion cancelled" : "Ištrynimo atsisakyta",
+    "Delete" : "Ištrinti",
     "Leave this share" : "Palikti bendrinimą",
     "Disconnect storage" : "Atjungti saugyklą",
     "Delete permanently" : "Ištrinti negrįžtamai",
@@ -169,51 +169,39 @@ OC.L10N.register(
     "Delete files" : "Ištrinti failus",
     "Delete folder" : "Ištrinti aplanką",
     "Delete folders" : "Ištrinti aplankus",
-    "Delete" : "Ištrinti",
     "_You are about to delete {count} item_::_You are about to delete {count} items_" : ["Jūs ketinate ištrinti {count} elementą","Jūs ketinate ištrinti {count} elementus","Jūs ketinate ištrinti {count} elementų","Jūs ketinate ištrinti {count} elementą"],
-    "Cancel" : "Atsisakyti",
-    "Moving \"{source}\" to \"{destination}\" …" : "Perkeliama „{source}“ į „{destination}“…",
-    "Copying \"{source}\" to \"{destination}\" …" : "Kopijuojama „{source}“ į „{destination}“…",
-    "(copy)" : "(kopija)",
-    "(copy %n)" : "(kopija %n)",
+    "Download" : "Atsisiųsti",
+    "Add to favorites" : "Pridėti į mėgstamus",
+    "Remove from favorites" : "Šalinti iš mėgstamų",
+    "Move" : "Perkelti",
+    "Copy" : "Kopijuoti",
+    "Move or copy" : "Perkelti ar kopijuoti",
     "The files are locked" : "Failai yra užrakinti",
     "The file does not exist anymore" : "Failo daugiau nebėra",
     "Copy to {target}" : "Kopijuoti į {target}",
-    "Copy" : "Kopijuoti",
     "Move to {target}" : "Perkelti į {target}",
-    "Move" : "Perkelti",
     "Move or copy operation failed" : "Perkėlimo ar kopijavimo operacija patyrė nesėkmę",
-    "Move or copy" : "Perkelti ar kopijuoti",
+    "Open folder" : "Atverti aplanką",
     "Open folder {displayName}" : "Atverti aplanką {displayName}",
     "Failed to redirect to client" : "Nepavyko peradresuoti į klientą",
     "Retry and close" : "Bandyti dar kartą ir užverti",
-    "Rename" : "Pervadinti",
-    "Open details" : "Atverti išsamesnę informaciją",
+    "Details" : "Išsamiau",
     "View in folder" : "Rodyti aplanke",
-    "Today" : "Šiandien",
-    "Last 7 days" : "Paskutinės 7 dienos",
-    "Last 30 days" : "Paskutinės 30 dienų",
-    "Documents" : "Dokumentai",
-    "Spreadsheets" : "Skaičiuoklės",
-    "Presentations" : "Pateiktys",
-    "PDFs" : "PDF dokumentai",
-    "Folders" : "Aplankai",
-    "Audio" : "Garso įrašai",
-    "Photos and images" : "Nuotraukos ir paveikslai",
-    "Videos" : "Vaizdo įrašai",
-    "New folder creation cancelled" : "Naujo aplanko sukūrimo atsisakyta",
+    "Type" : "Tipas",
     "Created new folder \"{name}\"" : "Sukurtas naujas aplankas „{name}“",
     "Unable to initialize the templates directory" : "Nepavyko inicijuoti šablonų katalogo",
     "Create templates folder" : "Sukurti šablonų aplanką",
     "Templates" : "Šablonai",
     "Search in folder: {folder}" : "Ieškoti aplanke: {folder}",
     "Unable to create the directory {directory}" : "Nepavyko sukurti katalogo {directory}",
-    "Some files could not be copied" : "Kai kurių failų nepavyko nukopijuoti",
-    "Some files could not be moved" : "Kai kurių failų nepavyko perkelti",
     "Files copied successfully" : "Failai sėkmingai nukopijuoti",
     "Files moved successfully" : "Failai sėkmingai perkelti",
+    "Some files could not be copied" : "Kai kurių failų nepavyko nukopijuoti",
+    "Some files could not be moved" : "Kai kurių failų nepavyko perkelti",
+    "Could not rename \"{oldName}\", it does not exist any more" : "Nepavyko pervadinti failo „{oldName}“, jo daugiau nebėra",
+    "The name \"{newName}\" is already used in the folder \"{dir}\". Please choose a different name." : "Pavadinimas „{newName}“ jau naudojamas aplanke „{dir}“. Pasirinkite kitokį pavadinimą.",
+    "Could not rename \"{oldName}\"" : "Nepavyko pervadinti „{oldName}“",
     "This operation is forbidden" : "Ši operacija yra uždrausta",
-    "This directory is unavailable, please check the logs or contact the administrator" : "Šis katalogas neprieinamas, peržiūrėkite žurnalo įrašus arba susisiekite su administratoriumi",
     "Storage is temporarily not available" : "Saugykla yra laikinai neprieinama",
     "Unexpected error: {error}" : "Netikėta klaida: {error}",
     "_%n file_::_%n files_" : ["%n failas","%n failai","%n failų","%n failas"],
@@ -223,97 +211,45 @@ OC.L10N.register(
     "\"{extension}\" is not an allowed filetype." : "„{extension}“ nėra leidžiamas failo tipas.",
     "No favorites yet" : "Kol kas nėra mėgstamų",
     "Files and folders you mark as favorite will show up here" : "Čia bus rodomi failai ir aplankai, kuriuos pažymėsite kaip mėgstamus",
-    "All files" : "Visi failai",
     "List of your files and folders." : "Jūsų failų ir aplankų sąrašas.",
-    "All folders" : "Visi aplankai",
-    "Personal files" : "Asmeniniai failai",
     "No personal files found" : "Nerasta jokių asmeninių failų",
     "Recent" : "Paskiausiai naudoti",
     "List of recently modified files and folders." : "Paskiausiai modifikuotų failų ir aplankų sąrašas.",
     "No recently modified files" : "Nėra jokių paskiausiai modifikuotų failų",
+    "Search" : "Paieška",
     "No entries found in this folder" : "Nerasta įrašų šiame aplanke",
     "Select all" : "Pažymėti viską",
     "Upload too large" : "Įkėlimui failas per didelis",
     "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Bandomų įkelti failų dydis viršija maksimalų, šiame serveryje leidžiamų įkelti failų dydį.",
-    "File could not be found" : "Nepavyko rasti failo",
-    "Download" : "Atsisiųsti",
-    "Show list view" : "Rodyti sąrašo rodinį",
-    "Show grid view" : "Rodyti tinklelio rodinį",
-    "Close" : "Užverti",
-    "Could not create folder \"{dir}\"" : "Nepavyko sukurti aplanko „{dir}“",
-    "This will stop your current uploads." : "Tai sustabdys dabartinius įkėlimus.",
-    "Upload cancelled." : "Įkėlimo atsisakyta.",
-    "Processing files …" : "Apdorojami failai…",
-    "…" : "…",
-    "Unable to upload {filename} as it is a directory or has 0 bytes" : "Nepavyksta įkelti {filename}, nes tai yra katalogas arba šio failo dydis yra 0 baitų",
-    "Not enough free space, you are uploading {size1} but only {size2} is left" : "Nepakanka laisvos vietos. Jūs bandote įkelti {size1} dydžio bylą, bet liko tik  {size2} vietos",
-    "Target folder \"{dir}\" does not exist any more" : "Paskirties aplanko „{dir}“ daugiau nebėra",
-    "An unknown error has occurred" : "Įvyko nežinoma klaida",
-    "File could not be uploaded" : "Nepavyko įkelti failo",
-    "Uploading …" : "Įkeliama…",
-    "{remainingTime} ({currentNumber}/{total})" : "{remainingTime} ({currentNumber}/{total})",
-    "{loadedSize} of {totalSize} ({bitrate})" : "{loadedSize} iš {totalSize} ({bitrate})",
-    "Uploading that item is not supported" : "To elemento įkėlimas nėra palaikomas",
-    "Error when assembling chunks, status code {status}" : "Klaida surenkant dalis, klaidos kodas {status}",
-    "Choose target folder" : "Pasirinkite paskirties aplanką",
-    "Set reminder" : "Nustatyti priminimą",
-    "Edit locally" : "Redaguoti lokaliai",
-    "Open" : "Atverti",
-    "Could not load info for file \"{file}\"" : "Nepavyko įkelti informacijos failui „{file}“",
-    "Details" : "Išsamiau",
-    "Please select tag(s) to add to the selection" : "Pasirinkite žymas, kurias pridėsite prie pažymėtų",
-    "Apply tag(s) to selection" : "Pritaikyti žymą(-as) pažymėtiems",
-    "Select directory \"{dirName}\"" : "Pasirinkite direktoriją \"{dirName}\"",
-    "Select file \"{fileName}\"" : "Pasirinkite failą \"{fileName}\"",
-    "Unable to determine date" : "Nepavyksta nustatyti datos",
-    "Could not move \"{file}\", target exists" : "Nepavyko perkelti „{file}“, toks failas jau yra",
-    "Could not move \"{file}\"" : "Nepavyko perkelti „{file}“",
-    "copy" : "kopija",
-    "Could not copy \"{file}\", target exists" : "Nepavyko nukopijuoti \"{file}\", toks jau yra",
-    "Could not copy \"{file}\"" : "Nepavyko nukopijuoti \"{file}\"",
-    "Copied {origin} inside {destination}" : "Nukopijuota {origin} aplanke {destination}",
-    "Copied {origin} and {nbfiles} other files inside {destination}" : "Nukopijuota {origin} ir dar {nbfiles} failus aplanke {destination}",
-    "{newName} already exists" : "{newName} jau yra",
-    "Could not rename \"{fileName}\", it does not exist any more" : "Nepavyko pervadinti failo „{fileName}“, jo daugiau nebėra",
-    "The name \"{targetName}\" is already used in the folder \"{dir}\". Please choose a different name." : "Pavadinimas „{targetName}“ jau naudojamas aplanke „{dir}“. Pasirinkite kitokį pavadinimą.",
-    "Could not rename \"{fileName}\"" : "Nepavyko pervadinti failo „{fileName}“",
-    "Could not create file \"{file}\"" : "Nepavyko sukurti failo „{file}“",
-    "Could not create file \"{file}\" because it already exists" : "Nepavyko sukurti failo „{file}“, nes jis jau yra",
-    "Could not create folder \"{dir}\" because it already exists" : "Nepavyko sukurti aplanko „{dir}“, nes jis jau yra",
-    "Could not fetch file details \"{file}\"" : "Nepavyko gauti išsamesnės failo \"{file}\" informacijos",
-    "Error deleting file \"{fileName}\"." : "Klaida ištrinant failą „{fileName}“.",
-    "No search results in other folders for {tag}{filter}{endtag}" : "Kituose aplankuose nėra paieškos rezultatų, skirtų {tag}{filter}{endtag}",
-    "Enter more than two characters to search in other folders" : "Įveskite daugiau nei du simbolius, jei norite ieškoti kituose aplankuose",
-    "{dirs} and {files}" : "{dirs} ir {files}",
-    "_including %n hidden_::_including %n hidden_" : ["įskaitant %n paslėptą","įskaitant %n paslėptus","įskaitant %n paslėptų","įskaitant %n paslėptą"],
-    "You do not have permission to upload or create files here" : "Neturite teisės įkalti ar kurti failus šioje vietoje",
-    "_Uploading %n file_::_Uploading %n files_" : ["Įkeliamas %n failas","Įkeliami %n failai","Įkeliama %n failų","Įkeliamas %n failas"],
-    "New" : "Nauja",
-    "Select file range" : "Žymėti failų rėžį",
-    "{used}%" : "{used}%",
-    "{used} used" : "{used} naudojama",
-    "\"{name}\" is an invalid file name." : "„{name}“ yra netinkamas bylos pavadinimas.",
-    "File name cannot be empty." : "Failo pavadinimas negali būti tuščias.",
-    "\"/\" is not allowed inside a file name." : "Failo pavadinime simbolis „/“ draudžiamas.",
-    "\"{name}\" is not an allowed filetype" : "„{name}“ nėra leidžiamas failo tipas",
-    "Your storage is full, files cannot be updated or synced anymore!" : "Jūsų saugykla yra pilna, failai daugiau nebegalės būti atnaujinti ar sinchronizuoti!",
-    "Group folder \"{mountPoint}\" is almost full ({usedSpacePercent}%)." : "Grupės aplankas \"{mountPoint}\" yra beveik pilnas ({usedSpacePercent}%).",
-    "External storage \"{mountPoint}\" is almost full ({usedSpacePercent}%)." : "Išorinė saugykla \"{mountPoint}\" yra beveik pilna ({usedSpacePercent}%).",
-    "Your storage is almost full ({usedSpacePercent}%)." : "Jūsų saugykla yra beveik pilna ({usedSpacePercent}%).",
-    "Direct link was copied (only works for people who have access to this file/folder)" : "Tiesioginė nuoroda buvo nukopijuota (veiks tik žmonėms, turintiems prieigą prie šio failo/aplanko)",
-    "Path" : "Kelias",
-    "_%n byte_::_%n bytes_" : ["%n baitas","%n baitai","%n baitų","%n baitų"],
-    "Copy direct link (only works for people who have access to this file/folder)" : "Kopijuoti tiesioginę nuorodą (veiks tik žmonėms, turintiems prieigą prie šio failo/aplanko)",
-    "Upload file" : "Įkelti failą",
-    "An error occurred while trying to update the tags" : "Įvyko klaida bandant atnaujinti žymas",
     "Upload (max. %s)" : "Įkelti (maks. %s)",
-    "Filter filenames…" : "Filtruoti failų pavadinimus…",
-    "_{folderCount} folder_::_{folderCount} folders_" : ["{folderCount} aplankas","{folderCount} aplankai","{folderCount} aplankų","{folderCount} aplankas"],
-    "_{fileCount} file_::_{fileCount} files_" : ["{fileCount} failas","{fileCount} failai","{fileCount} failų","{fileCount} failas"],
-    "_1 file and {folderCount} folder_::_1 file and {folderCount} folders_" : ["1 failas ir {folderCount} aplankas","1 failas ir {folderCount} aplankai","1 failas ir {folderCount} aplankų","1 failas ir {folderCount} aplankas"],
-    "_{fileCount} file and 1 folder_::_{fileCount} files and 1 folder_" : ["{fileCount} failas ir 1 aplankas","{fileCount} failai ir 1 aplankas","{fileCount} failų ir 1 aplankas","{fileCount} failas ir 1 aplankas"],
-    "Personal Files" : "Asmeniniai failai",
-    "Text file" : "Tekstinis failas",
-    "New text file.txt" : "Naujas tekstinis failas.txt"
+    "Renamed \"{oldName}\" to \"{newName}\"" : "„{oldName}“ pervadintas į „{newName}“",
+    "Clear filter" : "Išvalyti filtrą",
+    "Shared by link" : "Bendrinama pagal nuorodą",
+    "Shared" : "Bendrinama",
+    "Clipboard is not available" : "Iškarpinė neprieinama",
+    "WebDAV URL copied to clipboard" : "WebDAV URL nukopijuotas į iškarpinę",
+    "Enable the grid view" : "Įjungti grid peržiūrą",
+    "Enable folder tree" : "Įjungti direktorijų medį",
+    "WebDAV" : "WebDAV",
+    "Copy to clipboard" : "Kopijuoti į iškarpinę",
+    "Use this address to access your Files via WebDAV" : "Naudokite šį adresą norėdami pasiekti failus per WebDAV",
+    "Keyboard shortcuts" : "Spartieji klavišai",
+    "Rename a file" : "Pervadinti failą",
+    "Delete a file" : "Ištrinti failą",
+    "You" : "Jūs",
+    "Error while loading the file data" : "Klaida įkeliant failo duomenis",
+    "Tags" : "Žymos",
+    "Save as …" : "Įrašyti kaip…",
+    "Deletion cancelled" : "Ištrynimo atsisakyta",
+    "Edit locally" : "Redaguoti lokaliai",
+    "Moving \"{source}\" to \"{destination}\" …" : "Perkeliama „{source}“ į „{destination}“…",
+    "Copying \"{source}\" to \"{destination}\" …" : "Kopijuojama „{source}“ į „{destination}“…",
+    "(copy)" : "(kopija)",
+    "(copy %n)" : "(kopija %n)",
+    "Open details" : "Atverti išsamesnę informaciją",
+    "Photos and images" : "Nuotraukos ir paveikslai",
+    "New folder creation cancelled" : "Naujo aplanko sukūrimo atsisakyta",
+    "This directory is unavailable, please check the logs or contact the administrator" : "Šis katalogas neprieinamas, peržiūrėkite žurnalo įrašus arba susisiekite su administratoriumi",
+    "All folders" : "Visi aplankai"
 },
 "nplurals=4; plural=(n % 10 == 1 && (n % 100 > 19 || n % 100 < 11) ? 0 : (n % 10 >= 2 && n % 10 <=9) && (n % 100 > 19 || n % 100 < 11) ? 1 : n % 1 != 0 ? 2: 3);");
