@@ -78,6 +78,7 @@ OC.L10N.register(
     "Reload current directory" : "Last inn gjeldende katalog på nytt",
     "Go to the \"{dir}\" directory" : "Gå til \"{dir}\"-katalogen",
     "Current directory path" : "Gjeldende katalogsti",
+    "Share" : "Del med andre",
     "Your have used your space quota and cannot upload files anymore" : "Du har brukt opp plasskvoten og kan ikke laste opp filer lenger",
     "You do not have permission to upload or create files here." : "Du har ikke tillatelse til å laste opp eller opprette filer her.",
     "Drag and drop files here to upload" : "Dra og slipp filer her for å laste opp",
@@ -92,7 +93,6 @@ OC.L10N.register(
     "This node is unavailable" : "Denne noden er utilgjengelig",
     "Another entry with the same name already exists." : "En annen oppføring med samme navnet finnes allerede.",
     "Invalid filename." : "Ugyldig filnavn.",
-    "Renamed \"{oldName}\" to \"{newName}\"" : "Omdøpte \"{oldName}\" tl \"{newName}\"",
     "Rename file" : "Gi fil nytt navn",
     "Folder" : "Mappe",
     "Unknown file type" : "Ukjent filtype",
@@ -102,12 +102,24 @@ OC.L10N.register(
     "{ext} text" : "{ext}-text",
     "Pending" : "Venter",
     "Unknown date" : "Ukjent dato",
-    "Clear filter" : "Tøm filter",
-    "Modified" : "Endret",
-    "Search everywhere" : "Søk overalt",
-    "Type" : "Type",
     "Active filters" : "Aktivt filter",
     "Remove filter" : "Fjern filter",
+    "Today" : "I dag",
+    "Last 7 days" : "Siste 7 dager",
+    "Last 30 days" : "Siste 30 dager",
+    "This year ({year})" : "I år ({year})",
+    "Last year ({year})" : "I fjor ({year})",
+    "Custom date range" : "Egendefinert datoperiode",
+    "Search everywhere" : "Søk overalt",
+    "Documents" : "Dokumenter",
+    "Spreadsheets" : "Regneark",
+    "Presentations" : "Presentasjoner",
+    "PDFs" : "PDFer",
+    "Folders" : "Mapper",
+    "Audio" : "Lyd",
+    "Images" : "Bilder",
+    "Videos" : "Filmer",
+    "Filters" : "Filtere",
     "Appearance" : "Utseende",
     "Show hidden files" : "Vis skjulte filer",
     "Show file type column" : "Vis kolonne for filtype",
@@ -135,7 +147,6 @@ OC.L10N.register(
     "Go right in grid" : "Gå til høyre i rutenettet",
     "View" : "Vis",
     "Toggle grid view" : "Veksle rutenett-visning",
-    "Open file sidebar" : "Åpne sidepanelet for fil",
     "Show those shortcuts" : "Vis hurtigtastene",
     "Warnings" : "Advarsler",
     "Warn before changing a file extension" : "Varsle før endring av filtype",
@@ -146,6 +157,7 @@ OC.L10N.register(
     "Name" : "Navn",
     "File type" : "Filtype",
     "Size" : "Størrelse",
+    "Modified" : "Endret",
     "{displayName}: failed on some elements" : "{displayName}: feilet på noen elementer",
     "{displayName}: done" : "{displayName}: ferdig",
     "{displayName}: failed" : "{displayName}: feilet",
@@ -210,12 +222,11 @@ OC.L10N.register(
     "Removing the file extension \"{old}\" may render the file unreadable." : "Å fjerne filendelsen «{old}» kan føre til at filen ikke kan leses.",
     "Adding the file extension \"{new}\" may render the file unreadable." : "Å legge til filendelsen «{new}» kan føre til at filen ikke kan leses.",
     "Do not show this dialog again." : "Ikke vis denne dialogen igjen.",
+    "Cancel" : "Avbryt",
+    "Rename" : "Gi nytt navn",
     "Select file or folder to link to" : "Velg fil eller mappe å koble til",
     "Choose {file}" : "Choose {file}",
     "Files settings" : "Filinnstillinger",
-    "Share" : "Del med andre",
-    "Shared by link" : "Delt med lenke",
-    "Shared" : "Delt",
     "Switch to list view" : "Bytt til listevisning",
     "Switch to grid view" : "Bytt til rutevisning",
     "The file could not be found" : "Kunne ikke finne filen",
@@ -268,28 +279,25 @@ OC.L10N.register(
     "_You are about to permanently delete {count} item_::_You are about to permanently delete {count} items_" : ["Du er i ferd med å slette permanent {count} element","Du er i ferd med å slette permanent {count} elementer"],
     "_You are about to delete {count} item_::_You are about to delete {count} items_" : ["Du er i ferd med å slette {count} element","Du er i ferd med å slette {count} elementer"],
     "Confirm deletion" : "Bekreft sletting",
-    "Cancel" : "Avbryt",
     "Download" : "Last ned",
     "The requested file is not available." : "Den forespurte filen er ikke tilgjengelig.",
     "The requested files are not available." : "De forespurte filene er ikke tilgjengelige.",
     "Add to favorites" : "Legg til i favoritter",
     "Remove from favorites" : "Fjern fra favoritter",
     "Add or remove favorite" : "Legg til eller fjern som favoritt",
+    "Move" : "Flytt",
+    "Copy" : "Kopier",
+    "Move or copy" : "Flytt eller kopier",
     "Destination is not a folder" : "Målplassering er ikke en mappe",
     "This file/folder is already in that directory" : "Denne filen/mappen er allerede i den katalogen",
     "You cannot move a file/folder onto itself or into a subfolder of itself" : "Du kan ikke flytte en fil/mappe til seg selv eller til en undermappe av seg selv",
-    "(copy)" : "(kopier)",
-    "(copy %n)" : "(kopier %n)",
     "A file or folder with that name already exists in this folder" : "En fil eller mappe med det navnet finnes allerede i denne mappen",
     "The files are locked" : "Filene er låst",
     "The file does not exist anymore" : "Filen finnes ikke lenger",
     "Choose destination" : "Velg målplassering",
     "Copy to {target}" : "Copy to {target}",
-    "Copy" : "Kopier",
     "Move to {target}" : "Move to {target}",
-    "Move" : "Flytt",
     "Move or copy operation failed" : "Flytte- eller kopieringsoperason feilet",
-    "Move or copy" : "Flytt eller kopier",
     "Open folder" : "Åpne mappe",
     "Open folder {displayName}" : "Åpne mappe {displayName}",
     "Open in Files" : "Åpne i Filer",
@@ -299,22 +307,9 @@ OC.L10N.register(
     "The file should now open on your device. If it doesn't, please check that you have the desktop app installed." : "Filen skal nå åpnes på enheten din. Om ikke, vennligst sjekk at du har skrivebordsprogrammet installert.",
     "Retry and close" : "Prøv igjen og lukk",
     "Open online" : "Åpne på nett",
-    "Rename" : "Gi nytt navn",
     "Details" : "Detaljer",
     "View in folder" : "Vis i mappe",
-    "Today" : "I dag",
-    "Last 7 days" : "Siste 7 dager",
-    "Last 30 days" : "Siste 30 dager",
-    "This year ({year})" : "I år ({year})",
-    "Last year ({year})" : "I fjor ({year})",
-    "Documents" : "Dokumenter",
-    "Spreadsheets" : "Regneark",
-    "Presentations" : "Presentasjoner",
-    "PDFs" : "PDFer",
-    "Folders" : "Mapper",
-    "Audio" : "Lyd",
-    "Images" : "Bilder",
-    "Videos" : "Filmer",
+    "Type" : "Type",
     "Created new folder \"{name}\"" : "Opprettet ny mappe \"{name}\"",
     "Unable to initialize the templates directory" : "Kan ikke initialisere mal-mappen",
     "Create templates folder" : "Opprett malmappe",
@@ -330,10 +325,10 @@ OC.L10N.register(
     "Some files could not be uploaded" : "Noen filer kunne ikke lastes opp",
     "Files uploaded successfully" : "Filer opplastet",
     "No files to process" : "Ingen filer å behandle",
-    "Some files could not be copied" : "Noen filer kunne ikke kopieres",
-    "Some files could not be moved" : "Noen filer kunne ikke flyttes",
     "Files copied successfully" : "Filer ble kopiert",
     "Files moved successfully" : "Filer ble flyttet",
+    "Some files could not be copied" : "Noen filer kunne ikke kopieres",
+    "Some files could not be moved" : "Noen filer kunne ikke flyttes",
     "Conflicts resolution skipped" : "Konfliktløsning hoppet over",
     "Upload cancelled" : "Opplasting avbrutt",
     "Could not rename \"{oldName}\", it does not exist any more" : "Kunne ikke omdøpe \"{oldName}\", den finnes ikke lenger",
@@ -372,10 +367,14 @@ OC.L10N.register(
     "%1$s (renamed)" : "%1$s (har fått nytt navn)",
     "Upload (max. %s)" : "Opplasting (maks %s)",
     "It is also possible to migrate files automatically after enabling this setting, please refer to the documentation about the occ command." : "Det er også mulig å migrere filer automatisk etter at denne innstillingen er aktivert, se dokumentasjonen for occ-kommandoen.",
+    "Renamed \"{oldName}\" to \"{newName}\"" : "Omdøpte \"{oldName}\" tl \"{newName}\"",
+    "Clear filter" : "Tøm filter",
     "\"{displayName}\" failed on some elements" : "\"{displayName}\" feilet på noen elementer",
     "\"{displayName}\" batch action executed successfully" : "\"{displayName}\" massehandling utført",
     "\"{displayName}\" action failed" : "\"{displayName}\"-handling feilet",
     "Submitting fields …" : "Sender inn felt ...",
+    "Shared by link" : "Delt med lenke",
+    "Shared" : "Delt",
     "\"{displayName}\" action executed successfully" : "\"{displayName}\"-handling utført",
     "Filter file names …" : "Filtrer filnavn ...",
     "Clipboard is not available" : "Utklippstavlen er ikke tilgjengelig",
@@ -416,6 +415,8 @@ OC.L10N.register(
     "Edit locally" : "Rediger lokalt",
     "Moving \"{source}\" to \"{destination}\" …" : "Flytter \"{source}\" til \"{destination}\" …",
     "Copying \"{source}\" to \"{destination}\" …" : "Flytter \"{source}\" til \"{destination}\" …",
+    "(copy)" : "(kopier)",
+    "(copy %n)" : "(kopier %n)",
     "Move cancelled" : "Flytt avbrutt",
     "Cancelled move or copy of \"{filename}\"." : "Kansellert flytte- eller kopieroperasjon av \"{filename}\"",
     "Cancelled move or copy operation" : "Kansellert flytte- eller kopieroperasjon",
@@ -424,6 +425,7 @@ OC.L10N.register(
     "New folder creation cancelled" : "Oppretting av ny mappe avbrutt",
     "This directory is unavailable, please check the logs or contact the administrator" : "Denne mappen er utilgjengelig. Sjekk loggene eller kontakt administrator",
     "All folders" : "Alle mapper",
+    "Open file sidebar" : "Åpne sidepanelet for fil",
     "Search everywhere …" : "Søk overalt ...",
     "Search here …" : "Søk her ...",
     "Preparing …" : "Forbereder ..."
