@@ -78,6 +78,7 @@ OC.L10N.register(
     "Reload current directory" : "Huidige map opnieuw laden",
     "Go to the \"{dir}\" directory" : "Ga naar de \"{dir}\" map",
     "Current directory path" : "Huidig directory pad",
+    "Share" : "Delen",
     "Your have used your space quota and cannot upload files anymore" : "Je hebt je ruimtequotum gebruikt en kan geen bestanden meer uploaden",
     "You do not have permission to upload or create files here." : "Je hebt geen toestemming om hier bestanden te uploaden of aan te maken.",
     "Drag and drop files here to upload" : "Drag en drop bestanden hier om te uploaden",
@@ -92,7 +93,6 @@ OC.L10N.register(
     "This node is unavailable" : "Deze node is niet beschikbaar",
     "Another entry with the same name already exists." : "Er bestaat al een ander item met dezelfde naam",
     "Invalid filename." : "Ongeldige bestandsnaam",
-    "Renamed \"{oldName}\" to \"{newName}\"" : "\"{oldName}\" hernoemd naar \"{newName}\"",
     "Rename file" : "Bestand hernoemen",
     "Folder" : "Map",
     "Unknown file type" : "Onbekend bestandstype",
@@ -102,12 +102,24 @@ OC.L10N.register(
     "{ext} text" : "{ext} tekst",
     "Pending" : "In behandeling",
     "Unknown date" : "Onbekende datum",
-    "Clear filter" : "Filter leegmaken",
-    "Modified" : "Aangepast",
-    "Search everywhere" : "Zoek in alles",
-    "Type" : "Type",
     "Active filters" : "Actieve filters",
     "Remove filter" : "Verwijder filter",
+    "Today" : "Vandaag",
+    "Last 7 days" : "Laatste 7 dagen",
+    "Last 30 days" : "Laatste 30 dagen",
+    "This year ({year})" : "Dit jaar ({year})",
+    "Last year ({year})" : "Afgelopen jaar ({year})",
+    "Custom date range" : "Aangepast datumbereik",
+    "Search everywhere" : "Zoek in alles",
+    "Documents" : "Documenten",
+    "Spreadsheets" : "Spreadsheets",
+    "Presentations" : "Presentaties",
+    "PDFs" : "PDFs",
+    "Folders" : "Mappen",
+    "Audio" : "Geluid",
+    "Images" : "Afbeeldingen",
+    "Videos" : "Video's",
+    "Filters" : "Filters",
     "Appearance" : "Uiterlijk",
     "Show hidden files" : "Toon verborgen bestanden",
     "Show file type column" : "Toon bestandstypekolom",
@@ -135,10 +147,10 @@ OC.L10N.register(
     "Go right in grid" : "Ga naar rechts in raster",
     "View" : "Bekijken",
     "Toggle grid view" : "Omschakelen roosterweergave",
-    "Open file sidebar" : "Open bestands zijbalk",
     "Show those shortcuts" : "Toon die snelkoppelingen",
     "Warnings" : "Waarschuwingen",
     "Warn before changing a file extension" : "Waarschuw voordat een bestand extensie wordt gewijzigd",
+    "Warn before deleting a file" : "Waarschuwen voor verwijderen bestand",
     "WebDAV URL" : "WebDAV URL",
     "How to access files using WebDAV" : "Hoe bestanden te benaderen met WebDAV",
     "Total rows summary" : "Aantal rijen samenvatting",
@@ -146,6 +158,7 @@ OC.L10N.register(
     "Name" : "Naam",
     "File type" : "Bestandstype",
     "Size" : "Grootte",
+    "Modified" : "Aangepast",
     "{displayName}: failed on some elements" : "{displayName}: sommige onderdelen zijn mislukt",
     "{displayName}: done" : "{displayName}: compleet",
     "{displayName}: failed" : "{displayName}: mislukt",
@@ -160,6 +173,7 @@ OC.L10N.register(
     "Search here …" : "Zoek hier …",
     "Search scope options" : "Zoek bereikopties",
     "Search here" : "Zoek hier",
+    "Owner" : "Eigenaar",
     "{usedQuotaByte} used" : "{usedQuotaByte} gebruikt",
     "{used} of {quota} used" : "{used} van {quota} gebruikt",
     "{relative}% used" : "{relative}% gebruikt",
@@ -213,12 +227,11 @@ OC.L10N.register(
     "Removing the file extension \"{old}\" may render the file unreadable." : "Verwijderen van de extensie {old} kan ervoor zorgen dat het bestand niet meer gelezen kan worden.",
     "Adding the file extension \"{new}\" may render the file unreadable." : "Toevoegen van de extensie {new} kan ervoor zorgen dat het bestand niet meer gelezen kan worden.",
     "Do not show this dialog again." : "Laat dit dialoogvenster niet meer zien.",
+    "Cancel" : "Annuleren",
+    "Rename" : "Naam wijzigen",
     "Select file or folder to link to" : "Selecteer een bestand of map om naar te linken",
     "Choose {file}" : "Kies {file}",
     "Files settings" : "Instellingen voor bestanden",
-    "Share" : "Delen",
-    "Shared by link" : "Gedeeld via link",
-    "Shared" : "Gedeeld",
     "Switch to list view" : "Omschakelen naar lijstoverzicht",
     "Switch to grid view" : "Omschakelen naar roosterweergave",
     "The file could not be found" : "Het bestand kon niet worden gevonden",
@@ -234,14 +247,7 @@ OC.L10N.register(
     "Upload some content or sync with your devices!" : "Upload je inhoud of synchroniseer met je apparaten!",
     "Go back" : "Ga terug",
     "Views" : "Bekeken",
-    "You" : "Jij",
-    "Shared multiple times with different people" : "Meerdere keren gedeeld met verschillende mensen",
-    "Unable to change the favorite state of the file" : "Kan de favoriete status van het bestand niet wijzigen",
-    "Error while loading the file data" : "Fout bij het lezen van de bestandsgegevens",
-    "Owner" : "Eigenaar",
-    "Remove from favorites" : "Verwijderen uit favorieten",
-    "Add to favorites" : "Aan favorieten toevoegen",
-    "Tags" : "Tags",
+    "Loading …" : "Aan het laden...",
     "Your files" : "Jouw bestanden",
     "Open in files" : "Open in bestanden",
     "File cannot be accessed" : "Bestand kan niet worden benaderd",
@@ -284,28 +290,28 @@ OC.L10N.register(
     "_You are about to permanently delete {count} item_::_You are about to permanently delete {count} items_" : ["Je staat op het punt om {count} item permanent te verwijderen","Je staat op het punt om {count} items permanent te verwijderen"],
     "_You are about to delete {count} item_::_You are about to delete {count} items_" : ["Je staat op het punt om {count} item te verwijderen","Je staat op het punt om {count}items te verwijderen"],
     "Confirm deletion" : "Bevestig verwijderen",
-    "Cancel" : "Annuleren",
     "Download" : "Downloaden",
     "The requested file is not available." : "Het gevraagde bestand is niet beschikbaar.",
     "The requested files are not available." : "De gevraagde bestanden zijn niet beschikbaar.",
+    "Add to favorites" : "Aan favorieten toevoegen",
+    "Remove from favorites" : "Verwijderen uit favorieten",
     "Add or remove favorite" : "Verwijder of voeg een favoriet toe",
-    "Moving \"{source}\" to \"{destination}\" …" : "Verplaatsen \"{source}\" naar \"{destination}\" …",
-    "Copying \"{source}\" to \"{destination}\" …" : "Kopieren \"{source}\" naar \"{destination}\" …",
+    "Move" : "Verplaatsen",
+    "Copy" : "Kopiëren",
+    "Move or copy" : "Verplaats of kopieer",
     "Destination is not a folder" : "Bestemming is geen map",
     "This file/folder is already in that directory" : "Dit bestand/deze map staat al in die map",
     "You cannot move a file/folder onto itself or into a subfolder of itself" : "Je kan een bestand/map niet verplaatsen naar zichzelf of naar een subfolder van zichzelf.",
-    "(copy)" : "(kopieer)",
-    "(copy %n)" : "(kopieer %n)",
     "A file or folder with that name already exists in this folder" : "Een bestand of map met dezelfde naam is al aanwezig in deze map",
     "The files are locked" : "De bestanden zijn vergrendeld",
     "The file does not exist anymore" : "Dit bestand bestaat niet meer",
+    "Moving \"{source}\" to \"{destination}\" …" : "Verplaatsen \"{source}\" naar \"{destination}\" …",
+    "Copying \"{source}\" to \"{destination}\" …" : "Kopieren \"{source}\" naar \"{destination}\" …",
     "Choose destination" : "Kies bestemming",
     "Copy to {target}" : "Kopieer naar {target}",
-    "Copy" : "Kopiëren",
     "Move to {target}" : "Verplaats naar {target}",
-    "Move" : "Verplaatsen",
     "Move or copy operation failed" : "Verplaatsen of kopiëren mislukt",
-    "Move or copy" : "Verplaats of kopieer",
+    "Open folder" : "Open map",
     "Open folder {displayName}" : "Open map {displayName}",
     "Open in Files" : "Open in Bestanden",
     "Open locally" : "Lokaal openen",
@@ -314,22 +320,9 @@ OC.L10N.register(
     "The file should now open on your device. If it doesn't, please check that you have the desktop app installed." : "Het bestand zou nu moeten openen op je apparaat. Als dat niet het geval is, controleer dan of je de desktop app geïnstalleerd hebt.",
     "Retry and close" : "Probeer opnieuw en sluiten",
     "Open online" : "Open online",
-    "Rename" : "Naam wijzigen",
     "Details" : "Details",
     "View in folder" : "Bekijken in map",
-    "Today" : "Vandaag",
-    "Last 7 days" : "Laatste 7 dagen",
-    "Last 30 days" : "Laatste 30 dagen",
-    "This year ({year})" : "Dit jaar ({year})",
-    "Last year ({year})" : "Afgelopen jaar ({year})",
-    "Documents" : "Documenten",
-    "Spreadsheets" : "Spreadsheets",
-    "Presentations" : "Presentaties",
-    "PDFs" : "PDFs",
-    "Folders" : "Mappen",
-    "Audio" : "Geluid",
-    "Images" : "Afbeeldingen",
-    "Videos" : "Video's",
+    "Type" : "Type",
     "Created new folder \"{name}\"" : "Nieuwe map \"¨{name}\" gemaakt.",
     "Unable to initialize the templates directory" : "Kon de sjablonenmap niet instellen",
     "Create templates folder" : "Nieuwe sjablonenmap",
@@ -345,10 +338,10 @@ OC.L10N.register(
     "Some files could not be uploaded" : "Sommige bestanden konden niet worden geüpload",
     "Files uploaded successfully" : "Bestand succesvol geüpload.",
     "No files to process" : "Geen bestanden te verwerken",
-    "Some files could not be copied" : "Sommige bestanden konden niet gekopieerd worden",
-    "Some files could not be moved" : "Een paar bestanden konden niet worden verplaatst",
     "Files copied successfully" : "Bestanden succesvol gekopieerd",
     "Files moved successfully" : "Bestanden succesvol verplaatst",
+    "Some files could not be copied" : "Sommige bestanden konden niet gekopieerd worden",
+    "Some files could not be moved" : "Een paar bestanden konden niet worden verplaatst",
     "Conflicts resolution skipped" : "Conflictoplossing overgeslagen",
     "Upload cancelled" : "Uploaden geannuleerd",
     "Could not rename \"{oldName}\", it does not exist any more" : "Kon \"{oldName}\" niet hernoemen, het bestaat niet meer",
@@ -389,10 +382,14 @@ OC.L10N.register(
     "Upload (max. %s)" : "Upload (max. %s)",
     "After enabling the windows compatible filenames, existing files cannot be modified anymore but can be renamed to valid new names by their owner." : "Na inschakeling van Windows-compatibele bestandsnamen, kunnen bestaande bestanden niet meer worden gewijzigd, maar kunnen ze door de eigenaar worden hernoemd naar geldige nieuwe namen.",
     "It is also possible to migrate files automatically after enabling this setting, please refer to the documentation about the occ command." : "Het is ook mogelijk om bestanden automatisch te migreren nadat deze instelling is ingeschakeld. Raadpleeg de documentatie over het occ-commando.",
+    "Renamed \"{oldName}\" to \"{newName}\"" : "\"{oldName}\" hernoemd naar \"{newName}\"",
+    "Clear filter" : "Filter leegmaken",
     "\"{displayName}\" failed on some elements" : "“{displayName}” mislukt op sommige elementen",
     "\"{displayName}\" batch action executed successfully" : "\"{displayName}\" batchactie succesvol uitgevoerd",
     "\"{displayName}\" action failed" : "\"{displayName}\" actie mislukt",
     "Submitting fields …" : "Velden verwerken ...",
+    "Shared by link" : "Gedeeld via link",
+    "Shared" : "Gedeeld",
     "\"{displayName}\" action executed successfully" : "\"{displayName}\" actie succesvol uitgevoerd",
     "Filter file names …" : "Bestandsnamen filteren ...",
     "Clipboard is not available" : "Klembord niet beschikbaar",
@@ -422,6 +419,11 @@ OC.L10N.register(
     "Navigate to the file on the right (in grid mode)" : "Navigeer naar het bestand aan de rechterkant (in rastermodus)",
     "Toggle the grid view" : "Rasterweergave omschakelen",
     "Open the sidebar for a file" : "Open de zijbalk voor een bestand",
+    "You" : "Jij",
+    "Shared multiple times with different people" : "Meerdere keren gedeeld met verschillende mensen",
+    "Unable to change the favorite state of the file" : "Kan de favoriete status van het bestand niet wijzigen",
+    "Error while loading the file data" : "Fout bij het lezen van de bestandsgegevens",
+    "Tags" : "Tags",
     "Save as …" : "Opslaan als...",
     "Converting files …" : "Bestanden converteren ...",
     "Converting file …" : "Bestand converteren ...",
@@ -429,6 +431,8 @@ OC.L10N.register(
     "Edit locally" : "Lokaal bewerken",
     "Moving \"{source}\" to \"{destination}\" …" : "Verplaatsen \"{source}\" naar \"{destination}\" …",
     "Copying \"{source}\" to \"{destination}\" …" : "Kopiëren \"{source}\" naar \"{destination}\" …",
+    "(copy)" : "(kopieer)",
+    "(copy %n)" : "(kopieer %n)",
     "Move cancelled" : "Verplaatsen geannuleerd",
     "Cancelled move or copy of \"{filename}\"." : "Verplaatsen of kopiëren van \"¨{filename}\" geannuleerd.",
     "Cancelled move or copy operation" : "Verplaatsen of kopiëren geannuleerd.",
@@ -437,6 +441,7 @@ OC.L10N.register(
     "New folder creation cancelled" : "Maken van nieuwe map geannuleerd",
     "This directory is unavailable, please check the logs or contact the administrator" : "Deze map is niet beschikbaar. Verifieer de logs of neem contact op met de beheerder",
     "All folders" : "Alle mappen",
+    "Open file sidebar" : "Open bestands zijbalk",
     "Search everywhere …" : "Zoek in alles...",
     "Search here …" : "Zoek hier ...",
     "Preparing …" : "Voorbereiden ..."
