@@ -78,6 +78,7 @@ OC.L10N.register(
     "Reload current directory" : "Recarregar a pasta atual",
     "Go to the \"{dir}\" directory" : "Ir para a pasta \"{dir}\"",
     "Current directory path" : "Caminho da pasta atual",
+    "Share" : "Partilhar",
     "Your have used your space quota and cannot upload files anymore" : "Utilizou a sua quota de espaço e já não pode carregar mais ficheiros",
     "You do not have permission to upload or create files here." : "Não tem permissões para enviar ou criar ficheiros aqui.",
     "Drag and drop files here to upload" : "Arraste e largue os ficheiros aqui para carregar",
@@ -92,7 +93,6 @@ OC.L10N.register(
     "This node is unavailable" : "Este nó não está disponível",
     "Another entry with the same name already exists." : "Já existe outra entrada com o mesmo nome",
     "Invalid filename." : "Nome de ficheiro inválido",
-    "Renamed \"{oldName}\" to \"{newName}\"" : "Renomeado de \"{oldName}\" para \"{newName}\"",
     "Rename file" : "Renomear ficheiro",
     "Folder" : "Pasta",
     "Unknown file type" : "Tipo de ficheiro desconhecido",
@@ -102,12 +102,18 @@ OC.L10N.register(
     "{ext} text" : "{ext}texto",
     "Pending" : "Pendente",
     "Unknown date" : "Data desconhecida",
-    "Clear filter" : "Limpar filtro",
-    "Modified" : "Modificado",
-    "Search everywhere" : "Pesquisar em todo o lado",
-    "Type" : "Tipo",
     "Active filters" : "Filtros ativos",
     "Remove filter" : "Remover filtro",
+    "Today" : "Hoje",
+    "Last 7 days" : "Últimos 7 dias",
+    "Last 30 days" : "Últimos 30 dias",
+    "Custom date range" : "Intervalo de datas personalizado",
+    "Search everywhere" : "Pesquisar em todo o lado",
+    "Documents" : "Documentos",
+    "Audio" : "Áudio",
+    "Images" : "Imagens",
+    "Videos" : "Vídeos",
+    "Filters" : "Filtros",
     "Appearance" : "Aspeto",
     "Show hidden files" : "Mostrar ficheiros ocultos",
     "Show file type column" : "Mostrar coluna de tipo de ficheiro",
@@ -136,7 +142,6 @@ OC.L10N.register(
     "Go right in grid" : "Ir para a direita na grelha",
     "View" : "Ver",
     "Toggle grid view" : "Alternar visualização em grelha",
-    "Open file sidebar" : "Abrir barra lateral de ficheiro",
     "Show those shortcuts" : "Mostrar esses atalhos",
     "Warnings" : "Avisos",
     "Warn before changing a file extension" : "Avisar antes de alterar uma extensão de ficheiro",
@@ -150,6 +155,7 @@ OC.L10N.register(
     "Name" : "Nome",
     "File type" : "Tipo de Ficheiro",
     "Size" : "Tamanho",
+    "Modified" : "Modificado",
     "{displayName}: failed on some elements" : "{displayName}: falhou em alguns elementos",
     "{displayName}: done" : "{displayName}: concluído",
     "{displayName}: failed" : "{displayName}: falhou",
@@ -164,6 +170,7 @@ OC.L10N.register(
     "Search here …" : "Procure aqui …",
     "Search scope options" : "Opções do escopo da pesquisa",
     "Search here" : "Pesquisar aqui",
+    "Owner" : "Proprietário",
     "{usedQuotaByte} used" : "{usedQuotaByte} usado",
     "{used} of {quota} used" : "utilizado {used} de {quota}",
     "{relative}% used" : "{relative}% usado",
@@ -201,11 +208,10 @@ OC.L10N.register(
     "Choose file or folder to transfer" : "Escolher ficheiro ou pasta para transferir",
     "Change" : "Mudar",
     "New owner" : "Novo proprietário",
+    "Cancel" : "Cancelar",
+    "Rename" : "Renomear",
     "Choose {file}" : "Escolher {file}",
     "Files settings" : "Definições do Ficheiros",
-    "Share" : "Partilhar",
-    "Shared by link" : "Partilhado por hiperligação",
-    "Shared" : "Partilhados",
     "Not enough free space" : "Espaço insuficiente",
     "Operation is blocked by access control" : "A operação está bloqueada pelo controlo de acesso",
     "Retry" : "Repetir",
@@ -213,11 +219,6 @@ OC.L10N.register(
     "Upload some content or sync with your devices!" : "Envie algum conteúdo ou sincronize com os seus dispositivos!",
     "Go back" : "Voltar",
     "Views" : "Vistas",
-    "You" : "Vovê",
-    "Owner" : "Proprietário",
-    "Remove from favorites" : "Remover dos favoritos",
-    "Add to favorites" : "Adicionar aos favoritos",
-    "Tags" : "Etiquetas",
     "Allow to restrict filenames to ensure files can be synced with all clients. By default all filenames valid on POSIX (e.g. Linux or macOS) are allowed." : "Permitir a restrição dos nomes de ficheiro para garantir que possam ser sincronizados com todos os clientes. Por predefinição, todos os nomes de ficheiro válidos em POSIX (por exemplo, Linux ou macOS) são permitidos.",
     "Files compatibility" : "Compatibilidade de ficheiros",
     "Enforce Windows compatibility" : "Forçar a compatibilidade com Windows",
@@ -229,25 +230,19 @@ OC.L10N.register(
     "Delete permanently" : "Eliminar permanentemente",
     "Delete file" : "Apagar ficheiro",
     "Delete folder" : "Apagar pasta",
-    "Cancel" : "Cancelar",
     "Download" : "Transferir",
+    "Add to favorites" : "Adicionar aos favoritos",
+    "Remove from favorites" : "Remover dos favoritos",
     "Add or remove favorite" : "Adicionar ou remover favorito",
-    "Copy to {target}" : "Copiar para {target}",
-    "Copy" : "Copiar",
-    "Move to {target}" : "Mover para {target}",
     "Move" : "Mover",
+    "Copy" : "Copiar",
     "Move or copy" : "Mover ou copiar",
+    "Copy to {target}" : "Copiar para {target}",
+    "Move to {target}" : "Mover para {target}",
     "Failed to redirect to client" : "Erro ao redirecionar para o cliente",
-    "Rename" : "Renomear",
     "Details" : "Detalhes",
     "View in folder" : "Ver na pasta",
-    "Today" : "Hoje",
-    "Last 7 days" : "Últimos 7 dias",
-    "Last 30 days" : "Últimos 30 dias",
-    "Documents" : "Documentos",
-    "Audio" : "Áudio",
-    "Images" : "Imagens",
-    "Videos" : "Vídeos",
+    "Type" : "Tipo",
     "Templates" : "Modelos",
     "Some files could not be moved" : "Não foi possível mover alguns ficheiros",
     "Could not rename \"{oldName}\", it does not exist any more" : "Não foi possível renomear “{oldName}”, já não existe",
@@ -269,8 +264,12 @@ OC.L10N.register(
     "%1$s (renamed)" : "%1$s (renomeado)",
     "renamed file" : "ficheiro renomeado",
     "Upload (max. %s)" : "Envio (máx. %s)",
+    "Renamed \"{oldName}\" to \"{newName}\"" : "Renomeado de \"{oldName}\" para \"{newName}\"",
+    "Clear filter" : "Limpar filtro",
     "\"{displayName}\" batch action executed successfully" : "Ação de lote “{displayName}” executada com sucesso",
     "\"{displayName}\" action failed" : "\"{displayName}\" a ação falhou",
+    "Shared by link" : "Partilhado por hiperligação",
+    "Shared" : "Partilhados",
     "\"{displayName}\" action executed successfully" : "\"{displayName}\" ação executada com sucesso ",
     "Enable folder tree" : "Ativar pastas em árvore",
     "WebDAV" : "WebDAV",
@@ -279,8 +278,11 @@ OC.L10N.register(
     "Manage tags for a file" : "Gerir etiquetas para um ficheiro",
     "Select or deselect a file" : "Selecionar ou desselecionar um ficheiro",
     "Select a range of files" : "Selecionar um intervalo de ficheiros",
+    "You" : "Você",
+    "Tags" : "Etiquetas",
     "Edit locally" : "Editar localmente",
     "This directory is unavailable, please check the logs or contact the administrator" : "Esta diretoria está indisponível, por favor, verifique os registos ou contacte o administrador",
+    "Open file sidebar" : "Abrir barra lateral de ficheiro",
     "Search everywhere …" : "Pesquisar em todo o lado...",
     "Search here …" : "Pesquisar aqui…"
 },
