@@ -74,6 +74,7 @@ OC.L10N.register(
     "Reload current directory" : "Ponovno naloži trenutno mapo",
     "Go to the \"{dir}\" directory" : "Pojdi v mapo »{dir}«",
     "Current directory path" : "Trenutna pot mape",
+    "Share" : "·Souporaba·",
     "Your have used your space quota and cannot upload files anymore" : "Porabili ste svojo količino prostora in datotek več ne morete nalagati",
     "You do not have permission to upload or create files here." : "Nimate pravic za ustvarjanje ali nalaganje datotek na to mesto.",
     "Drag and drop files here to upload" : "Za pošiljanje potegnite in spustite datoteke na to mesto",
@@ -88,17 +89,28 @@ OC.L10N.register(
     "This node is unavailable" : "To vozlišče ni na voljo.",
     "Another entry with the same name already exists." : "Vpis z istim imenom že obstaja.",
     "Invalid filename." : "Neveljavno ime datoteke",
-    "Renamed \"{oldName}\" to \"{newName}\"" : "Preimenuj »{oldName}« to »{newName}«",
     "Rename file" : "Preimenuj datoteke",
     "Folder" : "Mapa",
     "Pending" : "Na čakanju ...",
     "Unknown date" : "Neznani datum",
-    "Clear filter" : "Počisti filter",
-    "Modified" : "Spremenjeno",
-    "Search everywhere" : "Išči povsod",
-    "Type" : "Vrsta",
     "Active filters" : "Dejavni filtri",
     "Remove filter" : "Odstrani filter",
+    "Today" : "Danes",
+    "Last 7 days" : "Zadnjih 7 dni",
+    "Last 30 days" : "Zadnjih 30 dni",
+    "This year ({year})" : "Letos ({year})",
+    "Last year ({year})" : "Lansko leto ({year})",
+    "Custom date range" : "Obseg datuma po meri",
+    "Search everywhere" : "Išči povsod",
+    "Documents" : "Dokumenti",
+    "Spreadsheets" : "Preglednice",
+    "Presentations" : "Predstavitve",
+    "PDFs" : "Dokumenti PDF",
+    "Folders" : "Mape",
+    "Audio" : "Zvočni posnetek",
+    "Images" : "Slike",
+    "Videos" : "Video posnetki",
+    "Filters" : "Filtri",
     "Appearance" : "Videz",
     "Show hidden files" : "Pokaži skrite datoteke",
     "Crop image previews" : "Obreži slike predogleda",
@@ -122,12 +134,14 @@ OC.L10N.register(
     "Toggle selection for all files and folders" : "Preklopi izbor za vse datoteke in mape",
     "Name" : "Ime",
     "Size" : "Velikost",
+    "Modified" : "Spremenjeno",
     "(selected)" : "(izbrano)",
     "List of files and folders." : "Seznam datotek in map",
     "You have used your space quota and cannot upload files anymore." : "Porabili ste dodeljeno količino prostora, zato datotek ni mogoče več pošiljati.",
     "Column headers with buttons are sortable." : "Stolpce z gumbi je mogoče razvrščati.",
     "This list is not fully rendered for performance reasons. The files will be rendered as you navigate through the list." : "Seznam datotek ni v celoti izpisan zaradi zagotavljanja hitrosti in odzivnosti sistema. Predmeti se bodo dopolnjevali med brskanjem.",
     "File not found" : "Datoteke ni mogoče najti",
+    "Owner" : "Lastnik",
     "{usedQuotaByte} used" : "Zasedeno {usedQuotaByte}",
     "{used} of {quota} used" : "V uporabi je {used} od {quota}",
     "{relative}% used" : "Zasedeno {relative} %",
@@ -163,12 +177,11 @@ OC.L10N.register(
     "Removing the file extension \"{old}\" may render the file unreadable." : "Odstranitev končnice datoteke \"{old}\" lahko naredi datoteko neberljivo.",
     "Adding the file extension \"{new}\" may render the file unreadable." : "Dadajanje končnice datoteke \"{new}\" lahko naredi datoteko neberljivo.",
     "Do not show this dialog again." : "Pogovornega okna ne pokaži več.",
+    "Cancel" : "Prekliči",
+    "Rename" : "Preimenuj",
     "Select file or folder to link to" : "Izbor datoteke ali mape za povezavo",
     "Choose {file}" : "Izberite datoteko {file}",
     "Files settings" : "Nastavitve datotek",
-    "Share" : "·Souporaba·",
-    "Shared by link" : "V souporabi sk povezavo",
-    "Shared" : "V souporabi",
     "Switch to list view" : "Preklopi na seznamski pogled",
     "Switch to grid view" : "Preklopi na mrežni pogled",
     "The file could not be found" : "Datoteke ni mogoče najti.",
@@ -184,13 +197,6 @@ OC.L10N.register(
     "Upload some content or sync with your devices!" : "Uvozite vsebino, ali pa omogočite usklajevanje z napravami!",
     "Go back" : "Skoči nazaj",
     "Views" : "Pogledi",
-    "You" : "Jaz",
-    "Shared multiple times with different people" : "V več souporabah z različnimi uporabniki",
-    "Error while loading the file data" : "Prišlo je do napake med nalaganjem podatkov računa",
-    "Owner" : "Lastnik",
-    "Remove from favorites" : "Odstrani iz priljubljenih",
-    "Add to favorites" : "Dodaj med priljubljene",
-    "Tags" : "Oznake",
     "Your files" : "Osebne datoteke",
     "Open in files" : "Odpri datoteko v mapi",
     "File cannot be accessed" : "Do datoteke dostop ni mogoč",
@@ -227,23 +233,23 @@ OC.L10N.register(
     "_You are about to permanently delete {count} item_::_You are about to permanently delete {count} items_" : ["Za stalno boste izbrisali {count} predmet","Za stalno boste izbrisali {count} predmeta","Za stalno boste izbrisali {count} predmete","Za stalno boste izbrisali {count} predmetov"],
     "_You are about to delete {count} item_::_You are about to delete {count} items_" : ["Izbrisali boste {count} predmet","Izbrisali boste {count} predmeta","Izbrisali boste {count} predmete","Izbrisali boste {count} predmetov"],
     "Confirm deletion" : "Potrdi brisanje",
-    "Cancel" : "Prekliči",
     "Download" : "Prejmi",
+    "Add to favorites" : "Dodaj med priljubljene",
+    "Remove from favorites" : "Odstrani iz priljubljenih",
+    "Move" : "Premakni",
+    "Copy" : "Kopiraj",
+    "Move or copy" : "Premakni ali kopiraj",
     "Destination is not a folder" : "Ciljno mesto ni mapa",
     "This file/folder is already in that directory" : "Ta datoteka oziroma mapa je že v določeni mapi",
     "You cannot move a file/folder onto itself or into a subfolder of itself" : "Mape ali datoteke ni mogoče premakniti samo vase oziroma v podmapo same sebe",
-    "(copy)" : "(kopija)",
-    "(copy %n)" : "(kopija %n)",
     "A file or folder with that name already exists in this folder" : "Datoteka oziroma mapa s tem imenom v tej mapi že obstaja",
     "The files are locked" : "Datoteke so zaklenjene",
     "The file does not exist anymore" : "Datoteka ne obstaja več",
     "Choose destination" : "Izbor ciljnega mesta",
     "Copy to {target}" : "Kopiraj na {target}",
-    "Copy" : "Kopiraj",
     "Move to {target}" : "Premakni na {target}",
-    "Move" : "Premakni",
     "Move or copy operation failed" : "Opravilo kopiranja oziroma premikanja je spodletelo",
-    "Move or copy" : "Premakni ali kopiraj",
+    "Open folder" : "Odpri mapo",
     "Open folder {displayName}" : "Odpri mapo {displayName}",
     "Open in Files" : "Open in Files",
     "Open locally" : "Odpri krajevno",
@@ -252,22 +258,9 @@ OC.L10N.register(
     "The file should now open on your device. If it doesn't, please check that you have the desktop app installed." : "Datoteka bi se sedaj morala odpreti z vaše naprave. Če se to ne zgodi, preverite namestitev namizne aplikacije.",
     "Retry and close" : "Ponovno poskusi in zapri",
     "Open online" : "Odpri v brskalniku",
-    "Rename" : "Preimenuj",
     "Details" : "Podrobnosti",
     "View in folder" : "Pokaži v mapi",
-    "Today" : "Danes",
-    "Last 7 days" : "Zadnjih 7 dni",
-    "Last 30 days" : "Zadnjih 30 dni",
-    "This year ({year})" : "Letos ({year})",
-    "Last year ({year})" : "Lansko leto ({year})",
-    "Documents" : "Dokumenti",
-    "Spreadsheets" : "Preglednice",
-    "Presentations" : "Predstavitve",
-    "PDFs" : "Dokumenti PDF",
-    "Folders" : "Mape",
-    "Audio" : "Zvočni posnetek",
-    "Images" : "Slike",
-    "Videos" : "Video posnetki",
+    "Type" : "Vrsta",
     "Created new folder \"{name}\"" : "Ustvarjena je nova mapa »{name}«.",
     "Unable to initialize the templates directory" : "Ni mogoče začeti mape predlog",
     "Create templates folder" : "Ustvari mapo predlog",
@@ -282,10 +275,10 @@ OC.L10N.register(
     "Some files could not be uploaded" : "Nekaterih datotek ni bilo mogoče poslati",
     "Files uploaded successfully" : "Datoteke so uspešno poslane v oblak",
     "No files to process" : "Ni datotek za obdelavo",
-    "Some files could not be copied" : "Nekaterih datotek ni bilo mogoče kopirati",
-    "Some files could not be moved" : "Nekaterih datotek ni mogoče premakniti",
     "Files copied successfully" : "Datoteke so uspešno kopirane",
     "Files moved successfully" : "Datoteke so uspešno premaknjene",
+    "Some files could not be copied" : "Nekaterih datotek ni bilo mogoče kopirati",
+    "Some files could not be moved" : "Nekaterih datotek ni mogoče premakniti",
     "Conflicts resolution skipped" : "Razreševanje sporov je preklicano",
     "Upload cancelled" : "Pošiljanje je bilo preklicano",
     "Could not rename \"{oldName}\", it does not exist any more" : "Datoteke »{oldName}« ni mogoče preimenovati, ker ne obstaja več.",
@@ -320,10 +313,14 @@ OC.L10N.register(
     "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Datoteke, ki jih želite poslati, presegajo največjo dovoljeno velikost na strežniku.",
     "Upload (max. %s)" : "Pošiljanje (omejitev %s)",
     "It is also possible to migrate files automatically after enabling this setting, please refer to the documentation about the occ command." : "Datoteke lahko po vklopu te možnosti tudi same migrirajo. Preverite dokumentacijo o ukazu occ.",
+    "Renamed \"{oldName}\" to \"{newName}\"" : "Preimenuj »{oldName}« to »{newName}«",
+    "Clear filter" : "Počisti filter",
     "\"{displayName}\" failed on some elements" : "\"{displayName}\" ni uspel za nekatere elemente",
     "\"{displayName}\" batch action executed successfully" : "Paketno dejanje »{displayName}« je uspešno izvedeno",
     "\"{displayName}\" action failed" : "Dejanje »{displayName}« je spodletelo",
     "Submitting fields …" : "Pošiljanje polj ...",
+    "Shared by link" : "V souporabi sk povezavo",
+    "Shared" : "V souporabi",
     "\"{displayName}\" action executed successfully" : "Dejanje »{displayName}« je uspešno izvedeno",
     "Filter file names …" : "Filtriraj imena datotek...",
     "Clipboard is not available" : "Odložišče ni na voljo",
@@ -353,6 +350,10 @@ OC.L10N.register(
     "Navigate to the file on the right (in grid mode)" : "Pojdi na datoteko na desni (v mrežnem načinu)",
     "Toggle the grid view" : "Preklopi mrežni način",
     "Open the sidebar for a file" : "Odpri stransko okno za datoteko",
+    "You" : "Jaz",
+    "Shared multiple times with different people" : "V več souporabah z različnimi uporabniki",
+    "Error while loading the file data" : "Prišlo je do napake med nalaganjem podatkov računa",
+    "Tags" : "Oznake",
     "Save as …" : "Shrani kot ...",
     "Converting files …" : "Poteka pretvarjanje datotek ...",
     "Converting file …" : "Poteka pretvarjanje datoteke ...",
@@ -360,6 +361,8 @@ OC.L10N.register(
     "Edit locally" : "Uredi krajevno",
     "Moving \"{source}\" to \"{destination}\" …" : "Premik \"{source}\" v \"{destination}\"...",
     "Copying \"{source}\" to \"{destination}\" …" : "Kopiranje \"{source}\" v \"{destination}\"...",
+    "(copy)" : "(kopija)",
+    "(copy %n)" : "(kopija %n)",
     "Move cancelled" : "Premikanje je bilo preklicano",
     "Cancelled move or copy of \"{filename}\"." : "Prekinjeno premikanje ali kopiranje za \"{filename}\".",
     "Cancelled move or copy operation" : "Opravilo kopiranje in premikanja je preklicano",
