@@ -78,6 +78,7 @@ OC.L10N.register(
     "Reload current directory" : "Pakia upya kitabu cha orodha ya sasa",
     "Go to the \"{dir}\" directory" : "Nenda kwenye {dir}kitabu cha orodha",
     "Current directory path" : "Njia ya kitabu cha orodha ya sasa",
+    "Share" : "Shirikisha",
     "Your have used your space quota and cannot upload files anymore" : "Umetumia nafasi yako kwa upendeleo na huwezi kupakia faili zaidi",
     "You do not have permission to upload or create files here." : "Huna ruhusa kupakia au kutengeneza faili hapa",
     "Drag and drop files here to upload" : "Sogeza na udondoshe faili hapa ili upakie",
@@ -92,7 +93,6 @@ OC.L10N.register(
     "This node is unavailable" : "Nodi hii haipatikani",
     "Another entry with the same name already exists." : "Ingizo lingine lenye jina sawasawa lipo tayari",
     "Invalid filename." : "Majina ya faili si sahihi",
-    "Renamed \"{oldName}\" to \"{newName}\"" : "Imebadili jina \"{oldName}\" mpaka \"{newName}\"",
     "Rename file" : "Badili jina la faili",
     "Folder" : "Kisanduku",
     "Unknown file type" : "Aina ya faili isiyojulikana",
@@ -102,12 +102,24 @@ OC.L10N.register(
     "{ext} text" : "{ext}maandishi",
     "Pending" : "Inasubiri",
     "Unknown date" : "Tarehe isiyojulikana",
-    "Clear filter" : "Futa kichujio",
-    "Modified" : "Iliyoboreshwa",
-    "Search everywhere" : "Tafuta kila mahali",
-    "Type" : "Aina",
     "Active filters" : "Vichujio vinavyotumika",
     "Remove filter" : "Ondoa kichujio",
+    "Today" : "Leo",
+    "Last 7 days" : "Siku 7 zilizopita",
+    "Last 30 days" : "Siku 30 zilizopita",
+    "This year ({year})" : "Mwaka huu ({year})",
+    "Last year ({year})" : "Mwaka uliopita ({year})",
+    "Custom date range" : "Safu ya tarehe maalum",
+    "Search everywhere" : "Tafuta kila mahali",
+    "Documents" : "Nyaraka",
+    "Spreadsheets" : "Lahajedwali",
+    "Presentations" : "Uwasilishaji",
+    "PDFs" : "PDFs",
+    "Folders" : "Visanduku",
+    "Audio" : "Sauti",
+    "Images" : "Picha",
+    "Videos" : "Picha mjongeo",
+    "Filters" : "Vichujio",
     "Appearance" : "Mwonekano",
     "Show hidden files" : "Onesha mafaili yaliyofichwa",
     "Show file type column" : "Onyesha safu wima ya aina ya faili",
@@ -136,7 +148,6 @@ OC.L10N.register(
     "Go right in grid" : "Nenda kulia katika grid",
     "View" : "Angalia",
     "Toggle grid view" : "Badilisha mwonekano wa gridi",
-    "Open file sidebar" : "Fungua upau wa pembeni wa faili",
     "Show those shortcuts" : "Onesha mikato hiyo",
     "Warnings" : "Maonyo",
     "Warn before changing a file extension" : "Onya kabla ya kubadilisha kiendelezi cha faili",
@@ -150,6 +161,7 @@ OC.L10N.register(
     "Name" : "Jina",
     "File type" : "Aina ya faili",
     "Size" : "Ukubwa",
+    "Modified" : "Iliyoboreshwa",
     "{displayName}: failed on some elements" : "{displayName}: Ilifeli kwenye vipengele vingine",
     "{displayName}: done" : "{displayName}: imefanyika",
     "{displayName}: failed" : "{displayName}: imeshindwa",
@@ -164,6 +176,7 @@ OC.L10N.register(
     "Search here …" : "Tafuta hapa ...",
     "Search scope options" : "Chaguo za upeo wa utafutaji",
     "Search here" : "Tafuta hapa",
+    "Owner" : "Mmiliki",
     "{usedQuotaByte} used" : "{usedQuotaByte}imetumika",
     "{used} of {quota} used" : "{used} ya {quota}imetumika",
     "{relative}% used" : "{relative}% imetumika",
@@ -217,12 +230,11 @@ OC.L10N.register(
     "Removing the file extension \"{old}\" may render the file unreadable." : "Kuondoa kiendelezi cha faili \"{old}\" kunaweza kufanya faili isisomeke.",
     "Adding the file extension \"{new}\" may render the file unreadable." : "Kuongeza kiendelezi cha faili \"{new}\" kunaweza kufanya faili isisomeke.",
     "Do not show this dialog again." : "Usioneshe mazungumzo haya tena",
+    "Cancel" : "Sitisha",
+    "Rename" : "Ipe jina jipya",
     "Select file or folder to link to" : "Chagua faili au kisanduku cha kuunga kwa",
     "Choose {file}" : "Chagua {file}",
     "Files settings" : "Mipangilio ya faili",
-    "Share" : "Shirikisha",
-    "Shared by link" : "Imeshirikishwa na kiungio",
-    "Shared" : "Shirikisha",
     "Switch to list view" : "Badili hadi mwonekano wa orodha",
     "Switch to grid view" : "Badili hadi mwonekano wa gridi",
     "The file could not be found" : "Faili halikupatikana",
@@ -238,14 +250,7 @@ OC.L10N.register(
     "Upload some content or sync with your devices!" : "Pakia baadhi ya maudhui au usawazishe na vifaa vyako!",
     "Go back" : "Rudi nyuma",
     "Views" : "Mionekano",
-    "You" : "Wewe",
-    "Shared multiple times with different people" : "Imeshirikiwa mara nyingi na watu tofauti",
-    "Unable to change the favorite state of the file" : "Haiwezi kubadilisha hali ya faili inayopendwa",
-    "Error while loading the file data" : "Hitilafu wakati wa kupakia data za faili",
-    "Owner" : "Mmiliki",
-    "Remove from favorites" : "Ondoa kutoka katika pendwa",
-    "Add to favorites" : "Ongeza kwenye pendwa",
-    "Tags" : "Maoni",
+    "Loading …" : "Inapakia  …",
     "Your files" : "Mafaili yako",
     "Open in files" : "Fungua ndani ya faili",
     "File cannot be accessed" : "Faili haliwezi kufikika",
@@ -291,28 +296,28 @@ OC.L10N.register(
     "_You are about to permanently delete {count} item_::_You are about to permanently delete {count} items_" : ["You are about to permanently delete {count} item","Unakaribia kufuta vipengee {count}kabisa"],
     "_You are about to delete {count} item_::_You are about to delete {count} items_" : ["You are about to delete {count} item","Unakaribia kufuta vipengee{count}"],
     "Confirm deletion" : "Thibitisha ufutaji",
-    "Cancel" : "Sitisha",
     "Download" : "Pakua",
     "The requested file is not available." : "Faili iliyoombwa haipatikani.",
     "The requested files are not available." : "Faili zilizoombwa hazipatikani.",
+    "Add to favorites" : "Ongeza kwenye pendwa",
+    "Remove from favorites" : "Ondoa kutoka katika pendwa",
     "Add or remove favorite" : "Ongeza au ondoa vipendwa",
-    "Moving \"{source}\" to \"{destination}\" …" : "Inahamisha \"{source}\" hadi \"{destination}\" …",
-    "Copying \"{source}\" to \"{destination}\" …" : "Inanakili \"{source}\" hadi \"{destination}\" …",
+    "Move" : "Hamisha",
+    "Copy" : "Nakili",
+    "Move or copy" : "Hamisha au nakili",
     "Destination is not a folder" : " Lengwa si folda",
     "This file/folder is already in that directory" : "Faili/folda hii tayari iko kwenye saraka hiyo",
     "You cannot move a file/folder onto itself or into a subfolder of itself" : "Huwezi kuhamisha faili/folda kwenye yenyewe au kwenye folda yenyewe",
-    "(copy)" : "(nakili)",
-    "(copy %n)" : "(nakili %n)",
     "A file or folder with that name already exists in this folder" : "Faili au kisanduku chenye jina hilo tayari kipo katika kisanduku hiki",
     "The files are locked" : "Faili zimezuiliwa",
     "The file does not exist anymore" : "Faili halipo tena",
+    "Moving \"{source}\" to \"{destination}\" …" : "Inahamisha \"{source}\" hadi \"{destination}\" …",
+    "Copying \"{source}\" to \"{destination}\" …" : "Inanakili \"{source}\" hadi \"{destination}\" …",
     "Choose destination" : "Chagua eneo lengwa",
     "Copy to {target}" : "Nakili kwenda {target}",
-    "Copy" : "Nakili",
     "Move to {target}" : "Hamishia {target}",
-    "Move" : "Hamisha",
     "Move or copy operation failed" : "Operesheni ya kuhamisha au kunakili imeshindikana",
-    "Move or copy" : "Hamisha au nakili",
+    "Open folder" : "Fungua folda",
     "Open folder {displayName}" : "Fungua kisanduku {displayName}",
     "Open in Files" : "Fungua ndani ya faili",
     "Open locally" : "Fungua kikawaida",
@@ -321,22 +326,9 @@ OC.L10N.register(
     "The file should now open on your device. If it doesn't, please check that you have the desktop app installed." : "Sasa faili inapaswa kufunguliwa kwenye kifaa chako. Ikiwa sivyo, tafadhali hakikisha kuwa umesakinisha programu ya eneo-kazi.",
     "Retry and close" : "Jaribu upya kisha funga",
     "Open online" : "Fungua mtandaoni",
-    "Rename" : "Ipe jina jipya",
     "Details" : "Maelezo ya kina",
     "View in folder" : "Angalia ndani ya kisanduku",
-    "Today" : "Leo",
-    "Last 7 days" : "Siku 7 zilizopita",
-    "Last 30 days" : "Siku 30 zilizopita",
-    "This year ({year})" : "Mwaka huu ({year})",
-    "Last year ({year})" : "Mwaka uliopita ({year})",
-    "Documents" : "Nyaraka",
-    "Spreadsheets" : "Lahajedwali",
-    "Presentations" : "Uwasilishaji",
-    "PDFs" : "PDFs",
-    "Folders" : "Visanduku",
-    "Audio" : "Sauti",
-    "Images" : "Picha",
-    "Videos" : "Picha mjongeo",
+    "Type" : "Aina",
     "Created new folder \"{name}\"" : "Imetengeneza kisanduku kipya \"{name}\"",
     "Unable to initialize the templates directory" : "Haikuweza kuanzisha saraka ya violezo",
     "Create templates folder" : "Imetengeneza kisanduku cha violezo",
@@ -352,10 +344,10 @@ OC.L10N.register(
     "Some files could not be uploaded" : "Faili kadhaa zisingeweza kupakiwa",
     "Files uploaded successfully" : "Faili zimepakiwa kikamilifu",
     "No files to process" : "Hakuna faili la kuchakata",
-    "Some files could not be copied" : "Faili baadhi zisingeweza kunakiliwa",
-    "Some files could not be moved" : "Faili baadhi zisingeweza kuhamishwa",
     "Files copied successfully" : "Faili limenakiliwa kikamilifu",
     "Files moved successfully" : "Faili limeondolewa kikamilifu",
+    "Some files could not be copied" : "Faili baadhi zisingeweza kunakiliwa",
+    "Some files could not be moved" : "Faili baadhi zisingeweza kuhamishwa",
     "Conflicts resolution skipped" : "Utatuzi wa migogoro ulirukwa",
     "Upload cancelled" : "Upakiaji umesitishwa",
     "Could not rename \"{oldName}\", it does not exist any more" : "Haikuweza kuita jina jipya \"{oldName}\", halipo tena",
@@ -396,10 +388,14 @@ OC.L10N.register(
     "Upload (max. %s)" : "Pakia (kiwango cha juu. %s)",
     "After enabling the windows compatible filenames, existing files cannot be modified anymore but can be renamed to valid new names by their owner." : "Baada ya kuwezesha majina ya windows ya faili yanayooana, faili zilizopo haziwezi kurekebishwa tena lakini zinaweza kubadilishwa kuwa majina mapya halali na mmiliki wao.",
     "It is also possible to migrate files automatically after enabling this setting, please refer to the documentation about the occ command." : "Pia inawezekana kuhamisha faili kiotomatiki baada ya kuwezesha mpangilio huu, tafadhali rejelea hati kuhusu amri ya occ.",
+    "Renamed \"{oldName}\" to \"{newName}\"" : "Imebadili jina \"{oldName}\" mpaka \"{newName}\"",
+    "Clear filter" : "Futa kichujio",
     "\"{displayName}\" failed on some elements" : "\"{displayName} imeshindwa katika vipengele kadhaa",
     "\"{displayName}\" batch action executed successfully" : "\"{displayName}\" kitendo cha kundi kimetekelezwa kwa mafanikio",
     "\"{displayName}\" action failed" : "\"{displayName}\" matendo yameshindwa",
     "Submitting fields …" : "Inawasilisha violezo",
+    "Shared by link" : "Imeshirikishwa na kiungio",
+    "Shared" : "Shirikisha",
     "\"{displayName}\" action executed successfully" : "\"{displayName}\" kitendo kimetekelezwa kwa mafanikio",
     "Filter file names …" : "Chuja majina ya faili...",
     "Clipboard is not available" : "Ubao wa kunakili haupatikani",
@@ -429,6 +425,11 @@ OC.L10N.register(
     "Navigate to the file on the right (in grid mode)" : "Sogea kwenye faili la kulia ( in grid mode)",
     "Toggle the grid view" : "Geuza mwonekano wa gridi",
     "Open the sidebar for a file" : "Fungua utepe kwa faili",
+    "You" : "Wewe",
+    "Shared multiple times with different people" : "Imeshirikiwa mara nyingi na watu tofauti",
+    "Unable to change the favorite state of the file" : "Haiwezi kubadilisha hali ya faili inayopendwa",
+    "Error while loading the file data" : "Hitilafu wakati wa kupakia data za faili",
+    "Tags" : "Maoni",
     "Save as …" : "Hifadhi kama",
     "Converting files …" : "Inageuza mafaili",
     "Converting file …" : "Inageuza faili",
@@ -436,6 +437,8 @@ OC.L10N.register(
     "Edit locally" : "Hariri kikawaida",
     "Moving \"{source}\" to \"{destination}\" …" : "Sogeza \"{source}\" mpaka \"{destination}\"",
     "Copying \"{source}\" to \"{destination}\" …" : "Inanakili \"{source}\" hadi \"{destination}\" ...",
+    "(copy)" : "(nakili)",
+    "(copy %n)" : "(nakili %n)",
     "Move cancelled" : "Uhamishaji umeghairishwa",
     "Cancelled move or copy of \"{filename}\"." : "Imesitisha uhamishaji au unakili wa \"{filename}\"",
     "Cancelled move or copy operation" : "Imesitisha operesheni ya uhamishaji au unakili",
@@ -444,6 +447,7 @@ OC.L10N.register(
     "New folder creation cancelled" : "Utengenezaji wa kisanduku kipya umesitishwa",
     "This directory is unavailable, please check the logs or contact the administrator" : "Orodha haipatikani, tafadhali angalia uingiaji au wasiliana na msimamizi",
     "All folders" : "Vikasha vyote",
+    "Open file sidebar" : "Fungua upau wa pembeni wa faili",
     "Search everywhere …" : "Tafuta kila mahali...",
     "Search here …" : "Tafuta hapa...",
     "Preparing …" : "Inaandaa..."
