@@ -47,7 +47,6 @@ OC.L10N.register(
     "Invalid folder path" : "Đường dẫn tới thư mục không hợp lệ",
     "Folder not found" : "Không thể tìm thấy thư mục",
     "No favorites" : "Không có mục ưa thích nào",
-    "Upload (max. %s)" : "Tải lên (tối đa %s)",
     "Accept" : "Đồng ý",
     "Reject" : "Từ chối",
     "Incoming ownership transfer from {user}" : "Có yêu cầu chuyển quyền sở hữu từ {user} ",
@@ -62,16 +61,13 @@ OC.L10N.register(
     "The ownership transfer of {path} from {user} has completed." : "Việc chuyển quyền sở hữu {path} từ {user} đã hoàn tất.",
     "in %s" : "trong %s",
     "Transferred from %1$s on %2$s" : "Chuyển từ %1$s tại %2$s",
-    "Files compatibility" : "Khả năng tương thích của tập tin",
-    "Allow to restrict filenames to ensure files can be synced with all clients. By default all filenames valid on POSIX (e.g. Linux or macOS) are allowed." : "Giới hạn tên tệp để đảm bảo tệp có thể đáp ứng với toàn bộ người dùng. Mặc định hệ thống sẽ cho phép các tập tin có tên hợp lệ trên hệ POSIX (vd. Linux hoặc macOS).",
-    "Enforce Windows compatibility" : "Bắt buộc tên tệp phải tương thích với Windows",
-    "This will block filenames not valid on Windows systems, like using reserved names or special characters. But this will not enforce compatibility of case sensitivity." : "Tính năng này sẽ chặn tên tệp không hợp lệ trên hệ thống Windows, như sử dụng tên dành riêng hoặc ký tự đặc biệt. Tuy nhiên, tính năng này sẽ không bắt buộc với chữ in hoa và in thường.",
     "File Management" : "Quản lý tệp tin",
     "Home" : "Trang nhà",
     "Target folder does not exist any more" : "Thư mục đích không còn tồn tại",
     "Reload current directory" : "Tải lại thư mục hiện tại",
     "Go to the \"{dir}\" directory" : "Đi đến thư mục \"{dir}\"",
     "Current directory path" : "Đường dẫn hiện tại",
+    "Share" : "Chia sẻ",
     "Your have used your space quota and cannot upload files anymore" : "Bạn đã sử dụng hết hạn mức dung lượng và không thể tải tệp lên nữa",
     "Drag and drop files here to upload" : "Kéo thả file vào đây để tải lên",
     "Favorite" : "Ưa thích",
@@ -85,27 +81,46 @@ OC.L10N.register(
     "This node is unavailable" : "Node này không có sẵn",
     "Another entry with the same name already exists." : "Đã tồn tại mục cùng tên",
     "Invalid filename." : "Tên tập tin không hợp lệ.",
-    "Renamed \"{oldName}\" to \"{newName}\"" : "Đã đổi tên \"{oldName}\" thành \"{newName}\"",
     "Rename file" : "Đổi tên tệp tin",
+    "Folder" : "Thư mục",
     "Pending" : "Đang chờ",
-    "Clear filter" : "Xóa bộ lọc",
-    "Modified" : "Đã thay đổi vào:",
-    "Type" : "Loại",
     "Active filters" : "Bộ lọc đang hoạt động",
     "Remove filter" : "Xoá bộ lọc",
+    "Today" : "Hôm nay",
+    "Last 7 days" : "7 ngày trước",
+    "Last 30 days" : "30 ngày trước",
+    "Search everywhere" : "Tìm ở bất kì đâu",
+    "Documents" : "Tài liệu",
+    "Spreadsheets" : "Bảng tính",
+    "Presentations" : "Bản trình chiếu",
+    "Folders" : "Thư mục",
+    "Audio" : "Âm thanh",
+    "Images" : "Hình ảnh",
+    "Videos" : "Phim",
+    "Appearance" : "Giao diện",
+    "Show hidden files" : "Hiển thị các tệp ẩn",
+    "Crop image previews" : "Xén ảnh xem trước",
+    "General" : "Cài đặt chung",
+    "Sort favorites first" : "Sắp xếp mục yêu thích trước",
+    "Sort folders before files" : "Sắp xếp thư mục trước tập tin",
+    "All files" : "Tất cả tệp tin",
+    "Additional settings" : "Cài đặt bổ sung",
+    "Actions" : "Hành động",
+    "Selection" : "Lựa chọn",
+    "Deselect all" : "Bỏ chọn tất cả",
+    "Navigation" : "Điều hướng",
+    "View" : "Xem",
     "Total rows summary" : "Tổng số hàng",
     "Toggle selection for all files and folders" : "Lựa chọn toàn bộ tập tin và thư mục",
     "Name" : "Tên",
     "Size" : "Kích cỡ",
-    "\"{displayName}\" batch action executed successfully" : "Chỉnh sửa hàng loạt \"{displayName}\" được thực hiện thành công",
-    "\"{displayName}\" action failed" : "Hành động \"{displayName}\" đã thực thi thất bại",
-    "Actions" : "Hành động",
+    "Modified" : "Đã thay đổi vào:",
     "(selected)" : "(đã chọn)",
     "List of files and folders." : "Danh sách các tập tin và thư mục.",
     "Column headers with buttons are sortable." : "Tiêu đề cột có thể sắp xếp được.",
     "This list is not fully rendered for performance reasons. The files will be rendered as you navigate through the list." : "Danh sách này không được hiển thị đầy đủ để tăng hiệu năng. Các tập tin sẽ được hiển thị khi bạn điều hướng qua danh sách.",
     "File not found" : "Không tìm thấy tập tin",
-    "{count} selected" : "đã chọn {count} ",
+    "Owner" : "Chủ sở hữu",
     "{usedQuotaByte} used" : "{usedQuotaByte} đã được sử dụng",
     "{used} of {quota} used" : "{used} trong {quota} đã được sử dụng",
     "{relative}% used" : "đã sử dụng {relative}%",
@@ -117,6 +132,7 @@ OC.L10N.register(
     "Create new folder" : "Tạo thư mục mới",
     "This name is already in use." : "Tên này đã được sử dụng.",
     "Create" : "Tạo",
+    "Refresh" : "Tải mới",
     "Fill template fields" : "Tự động điền các trường thông tin",
     "Submit" : "Gửi",
     "Choose a file or folder to transfer" : "Chọn tệp hoặc thư mục cần chuyển",
@@ -130,11 +146,11 @@ OC.L10N.register(
     "Choose file or folder to transfer" : "Chọn tệp hoặc thư mục để chuyển",
     "Change" : "Thay đổi",
     "New owner" : "Chủ sở hữu mới",
+    "Cancel" : "Hủy bỏ",
+    "Rename" : "Đổi tên",
     "Select file or folder to link to" : "Chọn tập tin hoặc thư mục để liên kết tới",
     "Choose {file}" : "Chọn {file}",
-    "Share" : "Chia sẻ",
-    "Shared by link" : "Được chia sẻ với liên kết",
-    "Shared" : "Đã chia sẻ",
+    "Files settings" : "Cài đặt tập tin",
     "Switch to list view" : "Chuyển sang chế độ xem danh sách",
     "Switch to grid view" : "Chuyển sang chế độ xem dạng lưới",
     "Upload was cancelled by user" : "Tải lên bị hủy bởi người dùng",
@@ -143,47 +159,27 @@ OC.L10N.register(
     "Error during upload: {message}" : "Lỗi khi đang tải lên: {message}",
     "Error during upload, status code {status}" : "Lỗi khi đang tải lên, mã lỗi {status}",
     "Unknown error during upload" : "Lỗi không xác định trong quá trình tải lên",
-    "\"{displayName}\" action executed successfully" : "Hành động \"{displayName}\" đã thực thi thành công",
     "Loading current folder" : "Đang tải thư mục hiện tại",
     "Retry" : "Thử lại",
     "No files in here" : "Không có tệp nào",
     "Upload some content or sync with your devices!" : "Tải lên một số nội dung hoặc đồng bộ với thiết bị của bạn!",
     "Go back" : "Quay lại",
     "Views" : "Lượt xem",
-    "Files settings" : "Cài đặt tập tin",
+    "Loading …" : "Đang tải …",
     "Your files" : "Tập tin của bạn",
     "Open in files" : "Mở trong Tệp",
     "File cannot be accessed" : "Không thể truy cập tập tin",
     "The file could not be found or you do not have permissions to view it. Ask the sender to share it." : "Không thể tìm thấy tệp hoặc bạn không có quyền xem tệp. Hãy yêu cầu người gửi cấp quyền truy cập.",
-    "Clipboard is not available" : "Bộ nhớ tạm không có sẵn",
-    "WebDAV URL copied to clipboard" : "Đã sao chép URL WebDAV vào bộ nhớ tạm",
-    "Sort favorites first" : "Sắp xếp mục yêu thích trước",
-    "Sort folders before files" : "Sắp xếp thư mục trước tập tin",
-    "Show hidden files" : "Hiển thị các tệp ẩn",
-    "Crop image previews" : "Xén ảnh xem trước",
-    "Enable the grid view" : "Bật chế độ xem lưới",
-    "Enable folder tree" : "Bật cây thư mục",
-    "Additional settings" : "Cài đặt bổ sung",
-    "Copy to clipboard" : "Sao chép vào bộ nhớ tạm",
-    "Use this address to access your Files via WebDAV" : "Sử dụng địa chỉ này để truy cập Tệp của bạn qua WebDAV",
-    "If you have enabled 2FA, you must create and use a new app password by clicking here." : "Nếu bạn đã bật 2FA, bạn phải tạo và sử dụng mật khẩu ứng dụng mới bằng cách nhấp vào đây.",
-    "Keyboard shortcuts" : "Phím tắt",
-    "Selection" : "Lựa chọn",
-    "Navigation" : "Điều hướng",
-    "View" : "Xem",
-    "You" : "Bạn",
-    "Shared multiple times with different people" : "Được chia sẻ nhiều lần với những người khác nhau",
-    "Error while loading the file data" : "Lỗi xảy ra trong khi tải dữ liệu tệp",
-    "Owner" : "Chủ sở hữu",
-    "Remove from favorites" : "Xóa khỏi ưa thích",
-    "Add to favorites" : "Thêm vào ưa thích",
-    "Tags" : "Nhãn",
+    "Allow to restrict filenames to ensure files can be synced with all clients. By default all filenames valid on POSIX (e.g. Linux or macOS) are allowed." : "Giới hạn tên tệp để đảm bảo tệp có thể đáp ứng với toàn bộ người dùng. Mặc định hệ thống sẽ cho phép các tập tin có tên hợp lệ trên hệ POSIX (vd. Linux hoặc macOS).",
+    "Files compatibility" : "Khả năng tương thích của tập tin",
+    "Enforce Windows compatibility" : "Bắt buộc tên tệp phải tương thích với Windows",
+    "This will block filenames not valid on Windows systems, like using reserved names or special characters. But this will not enforce compatibility of case sensitivity." : "Tính năng này sẽ chặn tên tệp không hợp lệ trên hệ thống Windows, như sử dụng tên dành riêng hoặc ký tự đặc biệt. Tuy nhiên, tính năng này sẽ không bắt buộc với chữ in hoa và in thường.",
     "Blank" : "Trống",
     "Unable to create new file from template" : "Không thể tạo tệp mới từ mẫu",
     "Pick a template for {name}" : "Hãy chọn một mẫu cho {name}",
     "Create a new file with the selected template" : "Tạo tệp mới với mẫu đã chọn",
     "Creating file" : "Tạo tệp",
-    "Deletion cancelled" : "Thao tác xóa bị hủy",
+    "Delete" : "Xóa",
     "Leave this share" : "Rời khỏi mục chia sẻ này",
     "Leave these shares" : "Rời khỏi mục chia sẻ",
     "Disconnect storage" : "Ngắt kết nối bộ nhớ",
@@ -194,48 +190,33 @@ OC.L10N.register(
     "Delete files" : "Xoá các tập tin",
     "Delete folder" : "Xoá thư mục",
     "Delete folders" : "Xoá các thư mục",
-    "Delete" : "Xóa",
     "_You are about to permanently delete {count} item_::_You are about to permanently delete {count} items_" : ["Bặn sắp xoá vĩnh viễn {count} mục"],
     "_You are about to delete {count} item_::_You are about to delete {count} items_" : ["Bạn sắp xoá {count} mục"],
     "Confirm deletion" : "Xác nhận xoá",
-    "Cancel" : "Hủy bỏ",
-    "Moving \"{source}\" to \"{destination}\" …" : "Di chuyển \"{source}\" đến \"{destination}\" …",
-    "Copying \"{source}\" to \"{destination}\" …" : "Sao chéo \"{source}\" đến \"{destination}\" …",
+    "Download" : "Tải về",
+    "Add to favorites" : "Thêm vào ưa thích",
+    "Remove from favorites" : "Xóa khỏi ưa thích",
+    "Move" : "Dịch chuyển",
+    "Copy" : "Sao chép",
+    "Move or copy" : "Di chuyển hoặc sao chép",
+    "Destination is not a folder" : "Đích đến không phải là một thư mục",
+    "This file/folder is already in that directory" : "Tệp/thư mục này đã có trong thư mục đó",
     "You cannot move a file/folder onto itself or into a subfolder of itself" : "Bạn không thể di chuyển một tập tin/thư mục vào chính nó hoặc vào một thư mục con của chính nó",
-    "(copy)" : "(sao chép)",
-    "(copy %n)" : "(sao chép %n)",
-    "Move cancelled" : "Di chuyển bị dừng",
     "A file or folder with that name already exists in this folder" : "Tệp hoặc thư mục có tên đó đã tồn tại trong thư mục này",
     "The files are locked" : "Tập tin bị khoá",
     "The file does not exist anymore" : "Tập tin không tồn tại nữa",
     "Choose destination" : "Lựa chọn điểm đến",
     "Copy to {target}" : "Copy to {target}",
-    "Copy" : "Sao chép",
     "Move to {target}" : "Di chuyển đến {target}",
-    "Move" : "Dịch chuyển",
     "Move or copy operation failed" : "Thao tác di chuyển hoặc sao chép thất bại",
-    "Move or copy" : "Di chuyển hoặc sao chép",
-    "Cancelled move or copy of \"{filename}\"." : "Đã huỷ việc di chuyển hoặc sao chép của \"{filename}\".",
-    "Cancelled move or copy operation" : "Đã hủy thao tác di chuyển hoặc sao chép",
     "Open folder {displayName}" : "Mở thư mục {displayName}",
     "Open in Files" : "Mở trong Tệp",
-    "Open file locally" : "Mở tệp cục bộ (local)/ ngoại tuyến",
-    "Failed to redirect to client" : "Không thể chuyển hướng đến ứng dụng khách",
     "Open locally" : "Mở cục bộ (local)/ ngoại tuyến",
-    "Rename" : "Đổi tên",
-    "Open details" : "Mở chi tiết",
+    "Failed to redirect to client" : "Không thể chuyển hướng đến ứng dụng khách",
+    "Open file locally" : "Mở tệp cục bộ (local)/ ngoại tuyến",
+    "Details" : "Chi tiết",
     "View in folder" : "Xem trong thư mục",
-    "Today" : "Hôm nay",
-    "Last 7 days" : "7 ngày trước",
-    "Last 30 days" : "30 ngày trước",
-    "Documents" : "Tài liệu",
-    "Spreadsheets" : "Bảng tính",
-    "Presentations" : "Bản trình chiếu",
-    "Folders" : "Thư mục",
-    "Audio" : "Âm thanh",
-    "Photos and images" : "Ảnh",
-    "Videos" : "Phim",
-    "New folder creation cancelled" : "Lỗi tạo thư mục",
+    "Type" : "Loại",
     "Created new folder \"{name}\"" : "Đã tạo thư mục mới \"{name}\"",
     "Unable to initialize the templates directory" : "Không thể khởi tạo thư mục mẫu",
     "Create templates folder" : "Tạo thư mục mẫu",
@@ -248,20 +229,19 @@ OC.L10N.register(
     "Unable to create the directory {directory}" : "Không thể tạo đường dẫn {directory}",
     "Some files could not be uploaded" : "Một số tệp tin không thể tải lên",
     "Files uploaded successfully" : "Tệp tin được tải lên thành công",
-    "Some files could not be copied" : "Một số tập tin không thể sao chép",
-    "Some files could not be moved" : "Một số tập tin không thể dịch chuyển",
     "Files copied successfully" : "Tệp tin được sao chép thành công",
     "Files moved successfully" : "Tệp tin được di chuyển thành công",
+    "Some files could not be copied" : "Một số tập tin không thể sao chép",
+    "Some files could not be moved" : "Một số tập tin không thể dịch chuyển",
     "Conflicts resolution skipped" : "Đã bỏ qua giải quyết xung đột",
     "Upload cancelled" : "Hủy tải lên",
+    "Could not rename \"{oldName}\", it does not exist any more" : "Không thể đổi tên \"{oldName}\", tệp tin không còn tồn tại",
+    "The name \"{newName}\" is already used in the folder \"{dir}\". Please choose a different name." : "Tên \"{newName}\" đã được sử dụng trong thư mục \"{dir}\". Vui lòng chọn một tên khác.",
+    "Could not rename \"{oldName}\"" : "Không thể đổi tên \"{oldName}\"",
     "This operation is forbidden" : "Thao tác bị cấm",
-    "This directory is unavailable, please check the logs or contact the administrator" : "Thư mục này không sẵn có, hãy kiểm tra log hoặc liên hệ người quản lý",
     "Storage is temporarily not available" : "Kho lưu trữ tạm thời không khả dụng",
-    "_{folderCount} folder_::_{folderCount} folders_" : ["thư mục {folderCount}"],
-    "_{fileCount} file_::_{fileCount} files_" : ["tệp {fileCount}"],
-    "_1 file and {folderCount} folder_::_1 file and {folderCount} folders_" : ["1 tệp và thư mục {folderCount}"],
-    "_{fileCount} file and 1 folder_::_{fileCount} files and 1 folder_" : ["tệp {fileCount} và 1 thư mục"],
-    "{fileCount} files and {folderCount} folders" : "Tệp {fileCount} và thư mục {folderCount}",
+    "_%n file_::_%n files_" : ["%n tập tin"],
+    "_%n folder_::_%n folders_" : ["%n thư mục"],
     "Filename must not be empty." : "Tên tập tin không thể trống",
     "\"{char}\" is not allowed inside a filename." : "\"{char}\" không được phép bên trong tên tệp.",
     "\"{segment}\" is a reserved name and not allowed for filenames." : "\"{segment}\" là tên dành riêng và không được phép cho tên tệp.",
@@ -270,9 +250,7 @@ OC.L10N.register(
     "List of favorite files and folders." : "Danh sách tệp và thư mục yêu thích.",
     "No favorites yet" : "Chưa có yêu thích nào",
     "Files and folders you mark as favorite will show up here" : "Các tệp và thư mục mà bạn đánh dấu là yêu thích sẽ hiển thị ở đây",
-    "All files" : "Tất cả tệp tin",
     "List of your files and folders." : "Danh sách các tập tin và thư mục của bạn.",
-    "All folders" : "Tất cả tệp tin",
     "List of your files and folders that are not shared." : "Danh sách tệp tin và thư mục không được chia sẻ của bạn.",
     "No personal files found" : "Không có tệp cá nhân nào được tìm thấy",
     "Files that are not shared will show up here." : "Các tệp và thư mục bạn đã không chia sẻ sẽ hiện thị ở đây.",
@@ -280,105 +258,44 @@ OC.L10N.register(
     "List of recently modified files and folders." : "Danh sách các tập tin và thư mục được sửa đổi gần đây.",
     "No recently modified files" : "Không có tập tin được sửa đổi gần đây",
     "Files and folders you recently modified will show up here." : "Các tập tin và thư mục bạn sửa đổi gần đây sẽ hiển thị ở đây.",
+    "Search" : "Tìm kiếm",
     "No entries found in this folder" : "Chưa có mục nào trong thư mục",
     "Select all" : "Chọn tất cả",
     "Upload too large" : "Tập tin tải lên quá lớn",
     "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Các tập tin bạn đang tải lên vượt quá kích thước tối đa cho phép trên máy chủ .",
-    "File could not be found" : "Tệp tin không tồn tại",
-    "Download" : "Tải về",
-    "Show list view" : "Hiển thị chế độ xem danh sách",
-    "Show grid view" : "Hiển thị chế độ xem lưới",
-    "Close" : "Đóng",
-    "Could not create folder \"{dir}\"" : "Không thể tạo thư mục “{dir}”",
-    "This will stop your current uploads." : "Hành động này sẽ dừng các tải lên hiện hành.",
-    "Upload cancelled." : "Hủy tải lên",
-    "Processing files …" : "Đang xử lý các tệp tin...",
-    "…" : "...",
-    "Unable to upload {filename} as it is a directory or has 0 bytes" : "không thể tải {filename} lên do nó là một thư mục hoặc có kích thước bằng 0 byte",
-    "Not enough free space, you are uploading {size1} but only {size2} is left" : "Không đủ dung lượng trống, bạn đang tải {size1} nhưng chỉ còn {size2} trống",
-    "Target folder \"{dir}\" does not exist any more" : "Thư mục đích \"{dir}\" không còn tồn tại",
-    "An unknown error has occurred" : "Một lỗi không rõ đã xảy ra",
-    "File could not be uploaded" : "Không thể tải lên tập tin",
-    "Uploading …" : "Đang tải lên …",
-    "Uploading … ({currentNumber}/{total})" : "Đang tải lên … ({currentNumber}/{total})",
-    "{loadedSize} of {totalSize} ({bitrate})" : "{loadedSize} trong tổng số {totalSize} ({bitrate})",
-    "Uploading that item is not supported" : "Tải lên mục đó không được hỗ trợ",
-    "Error when assembling chunks, status code {status}" : "Lỗi khi lắp ráp khối, mã trạng thái {status}",
-    "Choose target folder" : "Chọn thư mục đích",
-    "Set reminder" : "Thiết lập nhắc nhở",
+    "Upload (max. %s)" : "Tải lên (tối đa %s)",
+    "Renamed \"{oldName}\" to \"{newName}\"" : "Đã đổi tên \"{oldName}\" thành \"{newName}\"",
+    "Clear filter" : "Xóa bộ lọc",
+    "\"{displayName}\" batch action executed successfully" : "Chỉnh sửa hàng loạt \"{displayName}\" được thực hiện thành công",
+    "\"{displayName}\" action failed" : "Hành động \"{displayName}\" đã thực thi thất bại",
+    "Shared by link" : "Được chia sẻ với liên kết",
+    "Shared" : "Đã chia sẻ",
+    "\"{displayName}\" action executed successfully" : "Hành động \"{displayName}\" đã thực thi thành công",
+    "Clipboard is not available" : "Bộ nhớ tạm không có sẵn",
+    "WebDAV URL copied to clipboard" : "Đã sao chép URL WebDAV vào bộ nhớ tạm",
+    "Enable the grid view" : "Bật chế độ xem lưới",
+    "Enable folder tree" : "Bật cây thư mục",
+    "Copy to clipboard" : "Sao chép vào bộ nhớ tạm",
+    "Use this address to access your Files via WebDAV" : "Sử dụng địa chỉ này để truy cập Tệp của bạn qua WebDAV",
+    "If you have enabled 2FA, you must create and use a new app password by clicking here." : "Nếu bạn đã bật 2FA, bạn phải tạo và sử dụng mật khẩu ứng dụng mới bằng cách nhấp vào đây.",
+    "Keyboard shortcuts" : "Phím tắt",
+    "You" : "Bạn",
+    "Shared multiple times with different people" : "Được chia sẻ nhiều lần với những người khác nhau",
+    "Error while loading the file data" : "Lỗi xảy ra trong khi tải dữ liệu tệp",
+    "Tags" : "Nhãn",
+    "Deletion cancelled" : "Thao tác xóa bị hủy",
     "Edit locally" : "Chỉnh sửa cục bộ/ngoại tuyến",
-    "Open" : "Mở",
-    "Could not load info for file \"{file}\"" : "Không thể tải thông tin cho tệp \"{file}\"",
-    "Details" : "Chi tiết",
-    "Please select tag(s) to add to the selection" : "Vui lòng chọn (các) thẻ để thêm vào lựa chọn",
-    "Apply tag(s) to selection" : "Áp dụng (các) thẻ cho lựa chọn",
-    "Select directory \"{dirName}\"" : "Chọn thư mục \"{dirName}\"",
-    "Select file \"{fileName}\"" : "Chọn tệp tin \"{fileName}\"",
-    "Unable to determine date" : "Không thể xác định ngày",
-    "Could not move \"{file}\", target exists" : "Không thể di chuyển \"{file}\", trùng đích đến",
-    "Could not move \"{file}\"" : "Không thể di chuyển \"{file}\"",
-    "copy" : "sao chép",
-    "Could not copy \"{file}\", target exists" : "Không thể sao chép \"{file}\",  tệp tin đích đã tồn tại",
-    "Could not copy \"{file}\"" : "Không thể sao chép tệp tin \"{file}\"",
-    "Copied {origin} inside {destination}" : "Được sao chép {origin} vào trong {destination}",
-    "Copied {origin} and {nbfiles} other files inside {destination}" : "Đã sao chép {origin} và {nbfiles} các file vào trong {destination}",
-    "{newName} already exists" : "{newName} đã có",
-    "Could not rename \"{fileName}\", it does not exist any more" : "Không thể đổi tên \"{fileName}\", tập tin không tồn tại",
-    "The name \"{targetName}\" is already used in the folder \"{dir}\". Please choose a different name." : "Tên \"{targetName}\" đã được dùng trong thư mục \"{dir}\". Hãy thử tên khác",
-    "Could not rename \"{fileName}\"" : "Không thể đổi tên \"{fileName}\"",
-    "Could not create file \"{file}\"" : "Không thể tạo tập tin \"{file}\"",
-    "Could not create file \"{file}\" because it already exists" : "Không thể tạo tập tin \"{file}\" vì đã có ",
-    "Could not create folder \"{dir}\" because it already exists" : "Không thể tạo thư mục “{dir}” vì đã có",
-    "Could not fetch file details \"{file}\"" : "Không thể lấy chi tiết tệp \"{file}\"",
-    "Error deleting file \"{fileName}\"." : "Lỗi khi xóa tập tin \"{fileName}\".",
-    "No search results in other folders for {tag}{filter}{endtag}" : "Không có kết quả tìm kiếm trong các thư mục khác cho {tag}{filter}{endtag}",
-    "Enter more than two characters to search in other folders" : "Nhập nhiều hơn hai ký tự để tìm kiếm trong các thư mục khác",
-    "_%n folder_::_%n folders_" : ["%n thư mục"],
-    "_%n file_::_%n files_" : ["%n tập tin"],
-    "{dirs} and {files}" : "{dirs} và {files}",
-    "_including %n hidden_::_including %n hidden_" : ["Bao gồm %n ẩn"],
-    "You do not have permission to upload or create files here" : "Bạn không đủ quyền để Tải lên hoặc Tạo tập tin ở đây",
-    "_Uploading %n file_::_Uploading %n files_" : ["Đang tải lên %n tập tin"],
-    "New" : "Tạo mới",
-    "New file/folder menu" : "Menu tập tin/thư mục mới",
-    "Select file range" : "Chọn phạm vi tệp",
-    "{used}%" : "{used}%",
-    "{used} used" : "{used} được sử dụng",
-    "\"{name}\" is an invalid file name." : "\"{name}\" không được chấp nhận",
-    "File name cannot be empty." : "Tên file không được rỗng",
-    "\"/\" is not allowed inside a file name." : "\"/\" không được phép có trong tên tệp.",
-    "\"{name}\" is not an allowed filetype" : "\"{name}\" không phải là loại tập tin được cho phép",
-    "Storage of {owner} is full, files cannot be updated or synced anymore!" : "Bộ nhớ của {owner} đã đầy, không thể cập nhật hoặc đồng bộ hóa tệp được nữa!",
-    "Group folder \"{mountPoint}\" is full, files cannot be updated or synced anymore!" : "Thư mục nhóm \"{mountPoint}\" đã đầy, không thể cập nhật hoặc đồng bộ hóa tệp được nữa!",
-    "External storage \"{mountPoint}\" is full, files cannot be updated or synced anymore!" : "Bộ nhớ ngoài \"{mountPoint}\" đã đầy, không thể cập nhật hoặc đồng bộ hóa tệp được nữa!",
-    "Your storage is full, files cannot be updated or synced anymore!" : "Bộ nhớ của bạn đã đầy, không thể cập nhật hoặc đồng bộ hóa tệp được nữa!",
-    "Storage of {owner} is almost full ({usedSpacePercent}%)." : "Dung lượng lưu trữ {owner} gần đầy ({usedSpacePercent}%).",
-    "Group folder \"{mountPoint}\" is almost full ({usedSpacePercent}%)." : "Thư mục nhóm \"{mountPoint}\" gần đầy ({usedSpacePercent}%).",
-    "External storage \"{mountPoint}\" is almost full ({usedSpacePercent}%)." : "Bộ nhớ ngoài \"{mountPoint}\" gần đầy ({usedSpacePercent}%).",
-    "Your storage is almost full ({usedSpacePercent}%)." : "Dung lượng lưu trữ của bạn gần đầy rồi ({usedSpacePercent}%).",
-    "_matches \"{filter}\"_::_match \"{filter}\"_" : ["khớp với \"{filter}\""],
-    "Direct link was copied (only works for people who have access to this file/folder)" : "Đã sao chép đường dẫn trực tiếp(Chỉ áp dụng đối với người dùng có quyền truy cập vào thư mục/tệp tin)",
-    "Path" : "Đường dẫn",
-    "Favorited" : "Được ưa thích",
-    "Copy direct link (only works for people who have access to this file/folder)" : "Sao chép liên kết trực tiếp (chỉ hoạt động đối với những người dùng có quyền truy cập vào tệp / thư mục này)",
-    "Upload file" : "Tải lên tập tin",
-    "Not favorited" : "Không được yêu thích",
-    "An error occurred while trying to update the tags" : "Đã xảy ra lỗi khi cố gắng cập nhật tags",
-    "Storage informations" : "Thông tin lưu trữ",
-    "Choose file" : "Chọn tập tin",
-    "Go to the previous folder" : "Chuyển đến thư mục trước đó",
-    "Open the files app settings" : "Mở cài đặt ứng dụng tệp",
-    "Unable to change the favourite state of the file" : "Không thể thay đổi trạng thái yêu thích của tệp",
-    "Edit file locally" : "Chỉnh sửa tập tin ngoại tuyến",
-    "Edit online" : "Chỉnh sửa trực tuyến",
-    "Create new templates folder" : "Tạo thư mục mẫu mới",
-    "List of favorites files and folders." : "Danh sách các tập tin và thư mục yêu thích.",
-    "Personal Files" : "Tệp tin cá nhân",
-    "Text file" : "Tập tin văn bản",
-    "New text file.txt" : "Tệp văn bản mới.txt",
-    "Favored" : "Được ưa thích",
-    "Favor" : "Ưa thích",
-    "Not favored" : "Không được ưa thích",
-    "Filter filenames…" : "Lọc tên tệp…"
+    "Moving \"{source}\" to \"{destination}\" …" : "Di chuyển \"{source}\" đến \"{destination}\" …",
+    "Copying \"{source}\" to \"{destination}\" …" : "Sao chéo \"{source}\" đến \"{destination}\" …",
+    "(copy)" : "(sao chép)",
+    "(copy %n)" : "(sao chép %n)",
+    "Move cancelled" : "Di chuyển bị dừng",
+    "Cancelled move or copy of \"{filename}\"." : "Đã huỷ việc di chuyển hoặc sao chép của \"{filename}\".",
+    "Cancelled move or copy operation" : "Đã hủy thao tác di chuyển hoặc sao chép",
+    "Open details" : "Mở chi tiết",
+    "Photos and images" : "Ảnh",
+    "New folder creation cancelled" : "Lỗi tạo thư mục",
+    "This directory is unavailable, please check the logs or contact the administrator" : "Thư mục này không sẵn có, hãy kiểm tra log hoặc liên hệ người quản lý",
+    "All folders" : "Tất cả tệp tin"
 },
 "nplurals=1; plural=0;");
