@@ -54,7 +54,7 @@ OC.L10N.register(
     "Limit must be a positive integer." : "限制必须是正整数。",
     "The replacement character may only be a single character." : "替换字符只能是单个字符。",
     "Filename sanitization already started." : "文件名清理已开始。",
-    "No filename sanitization inprogress." : "没有正在进行的文件名清理。",
+    "No filename sanitization in progress." : "没有正在进行的文件名清理。",
     "Favorite files" : "收藏的文件",
     "No favorites" : "无收藏",
     "More favorites" : "更多收藏",
@@ -78,6 +78,8 @@ OC.L10N.register(
     "Reload current directory" : "重新载入当前目录",
     "Go to the \"{dir}\" directory" : "前往“{dir}”目录",
     "Current directory path" : "当前文件目录",
+    "Share" : "共享",
+    "Reload content" : "重新加载内容",
     "Your have used your space quota and cannot upload files anymore" : "你已用完你的空间配额，无法再上传更多文件",
     "You do not have permission to upload or create files here." : "您没有在此处上传或创建文件的权限。",
     "Drag and drop files here to upload" : "将文件拖放至此处以上传",
@@ -92,7 +94,6 @@ OC.L10N.register(
     "This node is unavailable" : "此节点不可用",
     "Another entry with the same name already exists." : "另一相同名称的条目已存在。",
     "Invalid filename." : "无效文件名称。",
-    "Renamed \"{oldName}\" to \"{newName}\"" : "已将“{oldName}”重命名为“{newName}”",
     "Rename file" : "重命名文件",
     "Folder" : "文件夹",
     "Unknown file type" : "未知文件类型",
@@ -102,21 +103,71 @@ OC.L10N.register(
     "{ext} text" : "{ext} 文本",
     "Pending" : "等待",
     "Unknown date" : "未知日期",
-    "Clear filter" : "清除筛选",
-    "Modified" : "修改日期",
-    "Search everywhere" : "在所有位置搜索",
-    "Type" : "类型",
     "Active filters" : "已开启的过滤器",
     "Remove filter" : "移除过滤条件",
+    "Today" : "今日",
+    "Last 7 days" : "过去 7 天",
+    "Last 30 days" : "过去 30 天",
+    "This year ({year})" : "今年（{year}）",
+    "Last year ({year})" : "去年（{year}）",
+    "Custom range" : "自定义范围",
+    "Custom date range" : "自定义日期范围",
+    "Search everywhere" : "全局搜索",
+    "Documents" : "文档",
+    "Spreadsheets" : "表格",
+    "Presentations" : "幻灯片",
+    "PDFs" : "PDF",
+    "Folders" : "文件夹",
+    "Audio" : "音频",
+    "Images" : "图片",
+    "Videos" : "视频",
+    "Filters" : "筛选器",
+    "Back to filters" : "返回筛选器",
+    "Appearance" : "外观",
+    "Show hidden files" : "显示隐藏文件",
+    "Show file type column" : "显示文件类型列",
+    "Show file extensions" : "显示文件扩展名",
+    "Crop image previews" : "裁剪图片预览",
+    "General" : "常规",
+    "Sort favorites first" : "收藏排序优先",
+    "Sort folders before files" : "将文件夹排在文件前面",
+    "Enable folder tree view" : "启用文件夹树视图",
+    "Default view" : "默认视图",
+    "All files" : "全部文件",
+    "Personal files" : "个人文件",
+    "Additional settings" : "其他设置",
+    "Actions" : "操作",
+    "File actions" : "文件操作",
+    "Selection" : "选择",
+    "Select all files" : "选择所有文件",
+    "Deselect all" : "全部取消选择",
+    "Select or deselect" : "选择或取消选择",
+    "Select a range" : "选择范围",
+    "Navigation" : "导航",
+    "Go to parent folder" : "转到上层文件夹",
+    "Go to file above" : "转到上方文件",
+    "Go to file below" : "转到下方文件",
+    "Go left in grid" : "在网格中向左",
+    "Go right in grid" : "在网格中向右",
+    "View" : "查看",
+    "Toggle grid view" : "切换网格视图",
+    "Show those shortcuts" : "显示快捷键",
+    "Warnings" : "警告",
+    "Warn before changing a file extension" : "更改文件扩展名前发出警告",
+    "Warn before deleting a file" : "删除文件前发出警告",
+    "WebDAV URL" : "WebDAV URL",
+    "Create an app password" : "创建应用密码",
+    "Required for WebDAV authentication because Two-Factor Authentication is enabled for this account." : "由于此账号已启用双因素身份验证，因此需要进行 WebDAV 身份验证。",
+    "How to access files using WebDAV" : "如何使用 WebDAV 访问文件",
     "Total rows summary" : "总行摘要",
     "Toggle selection for all files and folders" : "切换所有文件和文件夹的选择",
     "Name" : "名称",
     "File type" : "文件类型",
     "Size" : "大小",
+    "Modified" : "修改日期",
     "{displayName}: failed on some elements" : "{displayName}：在部分上元素失败",
     "{displayName}: done" : "{displayName}：完成",
     "{displayName}: failed" : "{displayName}：失败",
-    "Actions" : "操作",
     "(selected)" : "（已选择）",
     "List of files and folders." : "文件与文件夹列表。",
     "You have used your space quota and cannot upload files anymore." : "您的剩余空间配额不足以继续上传文件。",
@@ -124,10 +175,11 @@ OC.L10N.register(
     "This list is not fully rendered for performance reasons. The files will be rendered as you navigate through the list." : "出于性能考虑，此列表未完全呈现。文件将在您浏览列表时呈现。",
     "File not found" : "文件未找到",
     "_{count} selected_::_{count} selected_" : ["已选择 {count} 个"],
-    "Search everywhere …" : "在所有位置搜索…",
-    "Search here …" : "在此搜索…",
+    "Search everywhere …" : "全局搜索 …",
+    "Search here …" : "在此搜索 …",
     "Search scope options" : "搜索范围选项",
     "Search here" : "在此搜索",
+    "Owner" : "拥有者",
     "{usedQuotaByte} used" : "已使用 {usedQuotaByte}",
     "{used} of {quota} used" : "已使用 {used}（共 {quota}）",
     "{relative}% used" : "已使用 {relative}%",
@@ -144,7 +196,7 @@ OC.L10N.register(
     "Failed to refresh filename sanitization status." : "无法刷新文件名清理状态。",
     "Filename sanitization in progress." : "正在进行文件名清理。",
     "Currently {processedUsers} of {totalUsers} accounts are already processed." : "目前已处理 {processedUsers} 个账号，共 {totalUsers} 个。",
-    "Preparing …" : "正在准备…",
+    "Preparing …" : "正在准备 …",
     "Refresh" : "刷新",
     "All files have been santized for Windows filename support." : "所有文件都已清理，以支持 Windows 文件名。",
     "Some files could not be sanitized, please check your logs." : "部分文件无法进行清理，请检查您的日志。",
@@ -159,7 +211,7 @@ OC.L10N.register(
     "Sanitize filenames" : "清理文件名",
     "(starting)" : "（正在启动）",
     "Fill template fields" : "填写模板字段",
-    "Submitting fields …" : "正在提交字段…",
+    "Submitting fields …" : "正在提交字段 …",
     "Submit" : "使用",
     "Choose a file or folder to transfer" : "选择要转移的文件或文件夹",
     "Transfer" : "转移",
@@ -181,11 +233,11 @@ OC.L10N.register(
     "Removing the file extension \"{old}\" may render the file unreadable." : "删除文件扩展名 \"{old}\" 可能会导致文件无法读取。",
     "Adding the file extension \"{new}\" may render the file unreadable." : "添加文件扩展名 \"{new}\" 可能会导致文件无法读取。",
     "Do not show this dialog again." : "不再显示此对话框。",
+    "Cancel" : "取消",
+    "Rename" : "重命名",
     "Select file or folder to link to" : "选择需要链接的文件或文件夹",
     "Choose {file}" : "选择 {file}",
-    "Share" : "共享",
-    "Shared by link" : "通过链接共享",
-    "Shared" : "已共享",
+    "Files settings" : "文件设置",
     "Switch to list view" : "切换为列表视图",
     "Switch to grid view" : "切换到网格视图",
     "The file could not be found" : "找不到文件",
@@ -195,96 +247,46 @@ OC.L10N.register(
     "Error during upload: {message}" : "上传时发生错误: {message}",
     "Error during upload, status code {status}" : "上传时发生错误，状态码 {status}",
     "Unknown error during upload" : "上传时发生未知错误",
+    "File list is reloading" : "文件列表正在重新加载",
     "Loading current folder" : "正在载入当前文件夹",
     "Retry" : "重试",
     "No files in here" : "这里没有文件",
     "Upload some content or sync with your devices!" : "上传一些内容或与您的设备同步！",
     "Go back" : "返回",
     "Views" : "视图",
-    "Files settings" : "文件设置",
+    "Loading …" : "正在加载 …",
     "Your files" : "你的文件",
     "Open in files" : "在文件中打开",
     "File cannot be accessed" : "文件无法访问",
     "The file could not be found or you do not have permissions to view it. Ask the sender to share it." : "找不到该文件，或是您没有查看该文件的权限。请要求发送者分享它。",
     "No search results for “{query}”" : "没有“{query}”的搜索结果",
     "Search for files" : "搜索文件",
-    "Clipboard is not available" : "剪贴板不可用",
-    "WebDAV URL copied" : "WebDAV URL 已复制",
-    "General" : "常规",
-    "Default view" : "默认视图",
-    "All files" : "全部文件",
-    "Personal files" : "个人文件",
-    "Sort favorites first" : "收藏排序优先",
-    "Sort folders before files" : "将文件夹排在文件前面",
-    "Folder tree" : "文件夹树",
-    "Appearance" : "外观",
-    "Show hidden files" : "显示隐藏文件",
-    "Show file type column" : "显示文件类型列",
-    "Show file extensions" : "显示文件扩展名",
-    "Crop image previews" : "裁剪图片预览",
-    "Additional settings" : "其他设置",
-    "WebDAV" : "WebDAV",
-    "WebDAV URL" : "WebDAV URL",
-    "Copy" : "复制",
-    "How to access files using WebDAV" : "如何使用 WebDAV 访问文件",
-    "Two-Factor Authentication is enabled for your account, and therefore you need to use an app password to connect an external WebDAV client." : "您的账号已启用双因素身份验证，因此您需要使用应用密码来连接外部 WebDAV 客户端。",
-    "Warnings" : "警告",
-    "Warn before changing a file extension" : "更改文件扩展名前发出警告",
-    "Warn before deleting files" : "删除文件前发出警告",
-    "Keyboard shortcuts" : "键盘快捷键",
-    "File actions" : "文件操作",
-    "Rename" : "重命名",
-    "Delete" : "删除",
-    "Add or remove favorite" : "添加或移除收藏",
-    "Manage tags" : "管理标签",
-    "Selection" : "选择",
-    "Select all files" : "选择所有文件",
-    "Deselect all" : "全部取消选择",
-    "Select or deselect" : "选择或取消选择",
-    "Select a range" : "选择范围",
-    "Navigation" : "导航",
-    "Go to parent folder" : "转到上层文件夹",
-    "Go to file above" : "转到上方文件",
-    "Go to file below" : "转到下方文件",
-    "Go left in grid" : "在网格中向左",
-    "Go right in grid" : "在网格中向右",
-    "View" : "查看",
-    "Toggle grid view" : "切换网格视图",
-    "Open file sidebar" : "打开文件侧边栏",
-    "Show those shortcuts" : "显示快捷键",
     "Allow to restrict filenames to ensure files can be synced with all clients. By default all filenames valid on POSIX (e.g. Linux or macOS) are allowed." : "允许限制文件名称以确保文件可以与所有客户端同步。默认状态下，所有POSIX（例如 Linux 或 macOS）系统有效的文件名都是被允许的。",
     "After enabling the Windows compatible filenames, existing files cannot be modified anymore but can be renamed to valid new names by their owner." : "启用与 Windows 兼容的文件名后，无法再修改现有文件，但可以由其所有者重命名为有效的新名称。",
     "Failed to toggle Windows filename support" : "无法切换 Windows 文件名支持",
     "Files compatibility" : "文件兼容性",
     "Enforce Windows compatibility" : "强制 Windows 兼容性",
     "This will block filenames not valid on Windows systems, like using reserved names or special characters. But this will not enforce compatibility of case sensitivity." : "这将阻止在 Windows 系统中无效的文件名称，比如使用保留字符。但这不会强制大小写敏感性兼容。",
-    "You" : "您",
-    "Shared multiple times with different people" : "与不同的用户多次分享",
-    "Unable to change the favorite state of the file" : "无法更改文件的收藏状态",
-    "Error while loading the file data" : "加载文件数据时出错",
-    "Owner" : "拥有者",
-    "Remove from favorites" : "从收藏中移除",
-    "Add to favorites" : "添加到收藏",
-    "Tags" : "标签",
     "Blank" : "空白",
     "Unable to create new file from template" : "无法从模板创建新文件",
     "Pick a template for {name}" : "给 {name} 挑选一个模板",
     "Create a new file with the selected template" : "用所选模板创建一个新文件",
     "Creating file" : "正在创建文件",
     "Save as {displayName}" : "保存为 {displayName}",
-    "Save as …" : "保存为…",
-    "Converting files …" : "正在转换文件…",
+    "Save as …" : "另存为 …",
+    "Converting files …" : "正在转换文件 …",
     "Failed to convert files: {message}" : "无法转换文件：{message}",
     "All files failed to be converted" : "无法转换全部文件",
     "One file could not be converted: {message}" : "有一个文件无法转换：{message}",
-    "_One file could not be converted_::_%n files could not be converted_" : ["无法转换 %n 个文件"],
-    "_One file successfully converted_::_%n files successfully converted_" : ["已成功转换 %n 个文件"],
-    "Files successfully converted" : "文件已成功转换",
+    "_%n file could not be converted_::_%n files could not be converted_" : ["无法转换 %n 个文件"],
+    "_%n file converted_::_%n files converted_" : ["已转换 %n 个文件"],
+    "Files converted" : "文件已转换",
     "Failed to convert files" : "无法转换文件",
-    "Converting file …" : "正在转换文件…",
+    "Converting file …" : "正在转换文件 …",
     "File successfully converted" : "文件已成功转换",
     "Failed to convert file: {message}" : "无法转换文件：{message}",
     "Failed to convert file" : "无法转换文件",
+    "Delete" : "删除",
     "Leave this share" : "离开此共享",
     "Leave these shares" : "离开此分享",
     "Disconnect storage" : "断开与存储空间的连接",
@@ -298,26 +300,28 @@ OC.L10N.register(
     "_You are about to permanently delete {count} item_::_You are about to permanently delete {count} items_" : ["您正要永久删除 {count} 个项目"],
     "_You are about to delete {count} item_::_You are about to delete {count} items_" : ["您正要删除 {count} 个项目"],
     "Confirm deletion" : "确认删除",
-    "Cancel" : "取消",
     "Download" : "下载",
     "The requested file is not available." : "请求的文件不可用。",
     "The requested files are not available." : "请求的文件不可用。",
-    "Moving \"{source}\" to \"{destination}\" …" : "正在移动 “{source}” 至 “{destination}” ...",
-    "Copying \"{source}\" to \"{destination}\" …" : "正在复制 “{source}” 至 “{destination}” ...",
+    "Add to favorites" : "添加到收藏",
+    "Remove from favorites" : "从收藏中移除",
+    "Add or remove favorite" : "添加或移除收藏",
+    "Move" : "移动",
+    "Copy" : "复制",
+    "Move or copy" : "移动或复制",
     "Destination is not a folder" : "目标不是一个文件夹",
     "This file/folder is already in that directory" : "该文件/文件夹已经存在与该目录中",
     "You cannot move a file/folder onto itself or into a subfolder of itself" : "你无法将文件/文件夹移动至其自身或子文件夹中",
-    "(copy)" : "（复制）",
-    "(copy %n)" : "(复制 %n)",
     "A file or folder with that name already exists in this folder" : "相同的文件/文件夹已存在于该文件夹中",
     "The files are locked" : "文件已锁定",
     "The file does not exist anymore" : "文件不存在",
+    "Moving \"{source}\" to \"{destination}\" …" : "正在将“{source}”移动到“{destination}” …",
+    "Copying \"{source}\" to \"{destination}\" …" : "正在将“{source}”复制到“{destination}” …",
     "Choose destination" : "选择目标路径",
     "Copy to {target}" : "复制到 {target}",
     "Move to {target}" : "移动到 {target}",
-    "Move" : "移动",
     "Move or copy operation failed" : "移动或复制失败",
-    "Move or copy" : "移动或复制",
+    "Open folder" : "打开文件夹",
     "Open folder {displayName}" : "打开文件夹{displayName}",
     "Open in Files" : "在文件中打开",
     "Open locally" : "本地打开",
@@ -327,26 +331,17 @@ OC.L10N.register(
     "Retry and close" : "重试并关闭",
     "Open online" : "在线打开",
     "Details" : "详细信息",
+    "Open the details sidebar" : "打开详情侧边栏",
+    "Unfavorite" : "取消收藏",
     "View in folder" : "在文件夹中查看",
-    "Today" : "今日",
-    "Last 7 days" : "过去 7 天",
-    "Last 30 days" : "过去 30 天",
-    "This year ({year})" : "今年（{year}）",
-    "Last year ({year})" : "去年（{year}）",
-    "Documents" : "文档",
-    "Spreadsheets" : "表格",
-    "Presentations" : "幻灯片",
-    "PDFs" : "PDF",
-    "Folders" : "文件夹",
-    "Audio" : "音频",
-    "Images" : "图片",
-    "Videos" : "视频",
+    "Type" : "类型",
     "Created new folder \"{name}\"" : "已创建新文件夹“{name}”",
     "Unable to initialize the templates directory" : "无法初始化模板目录",
     "Create templates folder" : "创建模板文件夹",
     "Templates" : "模板",
     "New template folder" : "新建模板文件夹",
     "In folder" : "文件夹内",
+    "Pick folder to search in" : "选择要搜索的文件夹",
     "Search in all files" : "在所有文件中搜索",
     "Search in folder: {folder}" : "在文件夹内搜索：{folder}",
     "One of the dropped files could not be processed" : "无法处理其中一个已删除的文件",
@@ -356,10 +351,10 @@ OC.L10N.register(
     "Some files could not be uploaded" : "部分文件无法上传",
     "Files uploaded successfully" : "上传文件成功",
     "No files to process" : "没有需要处理的文件",
-    "Some files could not be copied" : "无法复制部分文件",
-    "Some files could not be moved" : "无法移动部分文件",
     "Files copied successfully" : "复制文件成功",
     "Files moved successfully" : "移动文件成功",
+    "Some files could not be copied" : "无法复制部分文件",
+    "Some files could not be moved" : "无法移动部分文件",
     "Conflicts resolution skipped" : "已跳过冲突解决",
     "Upload cancelled" : "已取消上传",
     "Could not rename \"{oldName}\", it does not exist any more" : "无法重命名“{oldName}”，此文件已经不存在",
@@ -381,6 +376,7 @@ OC.L10N.register(
     "No favorites yet" : "暂无收藏",
     "Files and folders you mark as favorite will show up here" : "收藏的文件和文件夹会在这里显示",
     "List of your files and folders." : "您的文件与文件件列表。",
+    "Folder tree" : "文件夹树",
     "List of your files and folders that are not shared." : "尚未分享的文件与文件夹",
     "No personal files found" : "找不到个人文件",
     "Files that are not shared will show up here." : "尚未分享的文件会显示在此处",
@@ -394,119 +390,32 @@ OC.L10N.register(
     "Select all" : "全部选择",
     "Upload too large" : "上传文件过大",
     "The files you are trying to upload exceed the maximum size for file uploads on this server." : "您尝试上传的文件大小超过了服务器的限制。",
-    "File could not be found" : "文件未找到",
-    "Show list view" : "显示列表视图",
-    "Show grid view" : "显示网格视图",
-    "Close" : "关闭",
-    "Could not create folder \"{dir}\"" : "无法创建文件夹“{dir}”",
-    "This will stop your current uploads." : "这会终止您当前的上传。",
-    "Upload cancelled." : "上传已取消。",
-    "Processing files …" : "正在处理文件 ...",
-    "…" : "...",
-    "Unable to upload {filename} as it is a directory or has 0 bytes" : "无法上传 {filename}，因为它是一个目录或者是大小为 0 的空文件",
-    "Not enough free space, you are uploading {size1} but only {size2} is left" : "可用空间不足，您上传的文件大小为 {size1} ，但可用空间仅剩 {size2}",
-    "Target folder \"{dir}\" does not exist any more" : "目标文件夹“{dir}”不存在",
-    "An unknown error has occurred" : "发生了未知错误。",
-    "File could not be uploaded" : "文件无法上传",
-    "Uploading …" : "正在上传 ...",
-    "{remainingTime} ({currentNumber}/{total})" : "{remainingTime} ({currentNumber}/{total})",
-    "Uploading … ({currentNumber}/{total})" : "上传中 ... （{currentNumber}／{total}）",
-    "{loadedSize} of {totalSize} ({bitrate})" : "{loadedSize} / {totalSize} ({bitrate})",
-    "Uploading that item is not supported" : "不支持上传此项目",
-    "Error when assembling chunks, status code {status}" : "组装块时发生错误，状态码 {status}",
-    "Choose target folder" : "选择目标文件夹",
-    "Set reminder" : "设置提醒",
-    "Edit locally" : "本地编辑",
-    "Open" : "打开",
-    "Could not load info for file \"{file}\"" : "无法加载文件“{file}”的信息",
-    "Please select tag(s) to add to the selection" : "请选择要添加到所选项目的标签",
-    "Apply tag(s) to selection" : "将标签应用到所选项目",
-    "Select directory \"{dirName}\"" : "选择目录“{dirName}”",
-    "Select file \"{fileName}\"" : "选择文件“{fileName}”",
-    "Unable to determine date" : "无法确定日期",
-    "This directory is unavailable, please check the logs or contact the administrator" : "此目录不可用，请检查日志或联系管理员",
-    "Could not move \"{file}\", target exists" : "无法移动“{file}”，目标已存在",
-    "Could not move \"{file}\"" : "无法移动“{file}”",
-    "copy" : "复制",
-    "Could not copy \"{file}\", target exists" : "无法复制“{file}”，目标已存在",
-    "Could not copy \"{file}\"" : "无法复制“{file}”",
-    "Copied {origin} inside {destination}" : "在 {destination} 内复制 {origin}",
-    "Copied {origin} and {nbfiles} other files inside {destination}" : "在 {destination} 内复制了 {origin} 和 {nbfiles} 个其他文件",
-    "{newName} already exists" : "{newName} 已经存在",
-    "Could not create file \"{file}\"" : "无法创建文件“{file}”",
-    "Could not create file \"{file}\" because it already exists" : "无法创建文件“{file}”，因为它已经存在",
-    "Could not create folder \"{dir}\" because it already exists" : "无法创建文件夹“{dir}”，因为它已经存在",
-    "Could not fetch file details \"{file}\"" : "无法获取文件详细信息“{file}”",
-    "Error deleting file \"{fileName}\"." : "删除文件“{fileName}”时出错。",
-    "No search results in other folders for {tag}{filter}{endtag}" : "在其它的文件夹里没有关于 {tag}{filter}{endtag} 的搜索结果",
-    "Enter more than two characters to search in other folders" : "输入至少三个字符，以搜索其他文件夹",
-    "{dirs} and {files}" : "{dirs} 和 {files}",
-    "_including %n hidden_::_including %n hidden_" : ["包括 %n 个隐藏文件"],
-    "You do not have permission to upload or create files here" : "您没有在此上传或创建文件的权限",
-    "_Uploading %n file_::_Uploading %n files_" : ["正在上传 %n 个文件"],
-    "New" : "新建",
-    "New file/folder menu" : "新建文件/文件夹菜单",
-    "Select file range" : "选择文件范围",
-    "{used}%" : "{used}%",
-    "{used} used" : "已使用 {used} 存储空间",
-    "\"{name}\" is an invalid file name." : "“{name}”是一个无效的文件名。",
-    "File name cannot be empty." : "文件名不能为空。",
-    "\"/\" is not allowed inside a file name." : "文件名不能包含“/”。",
-    "\"{name}\" is not an allowed filetype" : "“{name}”不是允许的文件类型",
-    "Storage of {owner} is full, files cannot be updated or synced anymore!" : "{owner} 的存储已满，无法再更新或同步文件了！",
-    "Group folder \"{mountPoint}\" is full, files cannot be updated or synced anymore!" : "群组文件夹“{mountPoint}”已满，无法再更新或同步文件！",
-    "External storage \"{mountPoint}\" is full, files cannot be updated or synced anymore!" : "外部存储器“{mountPoint}”已满，无法再更新或同步文件！",
-    "Your storage is full, files cannot be updated or synced anymore!" : "您的的存储已满，无法继续更新或同步文件！",
-    "Storage of {owner} is almost full ({usedSpacePercent}%)." : "{owner} 的存储空间几乎已满 ({usedSpacePercent}%)。",
-    "Group folder \"{mountPoint}\" is almost full ({usedSpacePercent}%)." : "组文件夹“{mountPoint}”的存储空间几乎已满 ({usedSpacePercent}%)。",
-    "External storage \"{mountPoint}\" is almost full ({usedSpacePercent}%)." : "外部存储“{mountPoint}”的存储空间几乎已满 ({usedSpacePercent}%)。",
-    "Your storage is almost full ({usedSpacePercent}%)." : "您的存储空间几乎已满（{usedSpacePercent}%）",
-    "_matches \"{filter}\"_::_match \"{filter}\"_" : ["匹配“{filter}”"],
-    "Direct link was copied (only works for people who have access to this file/folder)" : "已复制直接链接（仅适用于有权访问此文件/文件夹的用户）",
-    "Path" : "路径",
-    "_%n byte_::_%n bytes_" : ["%n 字节"],
-    "Favored" : "已加入收藏",
-    "Favor" : "收藏",
-    "Copy direct link (only works for people who have access to this file/folder)" : "复制直接链接(仅适用于有权访问此文件/文件夹的用户)",
-    "Upload file" : "上传文件",
-    "Not favored" : "未收藏",
-    "An error occurred while trying to update the tags" : "更新标签时出错",
+    "%1$s (renamed)" : "%1$s（已重命名）",
+    "renamed file" : "已重命名文件",
     "Upload (max. %s)" : "上传 （最大 %s）",
-    "\"{displayName}\" action executed successfully" : "“{displayName}”操作执行成功",
-    "\"{displayName}\" action failed" : "“{displayName}”操作执行失败",
+    "After enabling the windows compatible filenames, existing files cannot be modified anymore but can be renamed to valid new names by their owner." : "启用与 Windows 兼容的文件名后，无法再修改现有文件，但可以由其所有者重命名为有效的新名称。",
+    "It is also possible to migrate files automatically after enabling this setting, please refer to the documentation about the occ command." : "启用此设置后，也可以自动迁移文件，请参阅有关 occ 命令的文档。",
+    "Renamed \"{oldName}\" to \"{newName}\"" : "已将“{oldName}”重命名为“{newName}”",
+    "Clear filter" : "清除筛选",
     "\"{displayName}\" failed on some elements" : "“{displayName}”在部分元素上失败",
     "\"{displayName}\" batch action executed successfully" : "批量操作“{displayName}”运行成功",
-    "Submitting fields…" : "提交字段...",
-    "Filter filenames…" : "过滤文件名...",
+    "\"{displayName}\" action failed" : "“{displayName}”操作执行失败",
+    "Submitting fields …" : "正在提交字段…",
+    "Shared by link" : "通过链接共享",
+    "Shared" : "已共享",
+    "\"{displayName}\" action executed successfully" : "“{displayName}”操作执行成功",
+    "Filter file names …" : "筛选文件名…",
+    "Clipboard is not available" : "剪贴板不可用",
     "WebDAV URL copied to clipboard" : "WebDAV 链接已复制到剪贴板",
     "Enable the grid view" : "启用网格视图",
     "Enable folder tree" : "启用文件夹树",
+    "WebDAV" : "WebDAV",
     "Copy to clipboard" : "复制到剪贴板",
     "Use this address to access your Files via WebDAV" : "使用此地址通过 WebDAV 访问您的文件",
     "If you have enabled 2FA, you must create and use a new app password by clicking here." : "如果启用两步验证，您必须点击此处来创建和使用一个新的应用程序密码。",
-    "Deletion cancelled" : "已取消删除",
-    "Move cancelled" : "已取消移动",
-    "Cancelled move or copy of \"{filename}\"." : "取消移动或复制“{filename}”.",
-    "Cancelled move or copy operation" : "已取消移动或复制操作",
-    "Open details" : "打开详情",
-    "Photos and images" : "照片和图像",
-    "New folder creation cancelled" : "取消创建新文件夹",
-    "_{folderCount} folder_::_{folderCount} folders_" : ["{folderCount} 个文件夹"],
-    "_{fileCount} file_::_{fileCount} files_" : ["{fileCount} 个文件"],
-    "_1 file and {folderCount} folder_::_1 file and {folderCount} folders_" : ["1 个文件夹及 {folderCount} 个文件夹"],
-    "_{fileCount} file and 1 folder_::_{fileCount} files and 1 folder_" : ["{fileCount} 个文件及 1 个文件夹"],
-    "{fileCount} files and {folderCount} folders" : "{fileCount} 个文件及 {folderCount} 个文件夹",
-    "All folders" : "所有文件夹",
-    "Personal Files" : "个人文件",
-    "Text file" : "文本文件",
-    "New text file.txt" : "新建文本文件.txt",
-    "%1$s (renamed)" : "%1$s（已重命名）",
-    "renamed file" : "已重命名文件",
-    "After enabling the windows compatible filenames, existing files cannot be modified anymore but can be renamed to valid new names by their owner." : "启用与 Windows 兼容的文件名后，无法再修改现有文件，但可以由其所有者重命名为有效的新名称。",
-    "It is also possible to migrate files automatically after enabling this setting, please refer to the documentation about the occ command." : "启用此设置后，也可以自动迁移文件，请参阅有关 occ 命令的文档。",
-    "Filter file names …" : "筛选文件名…",
     "Prevent warning dialogs from open or reenable them." : "防止打开或重新启用警告对话框。",
     "Show a warning dialog when changing a file extension." : "更改文件扩展名时显示警告对话框。",
+    "Keyboard shortcuts" : "键盘快捷键",
     "Speed up your Files experience with these quick shortcuts." : "这些快捷键可以加快你的“文件”体验。",
     "Open the actions menu for a file" : "打开文件的操作菜单",
     "Rename a file" : "重命名文件",
@@ -522,6 +431,32 @@ OC.L10N.register(
     "Navigate to the file on the left (in grid mode)" : "跳转至左侧文件（在网格模式下）",
     "Navigate to the file on the right (in grid mode)" : "跳转至右侧文件（在网格模式下）",
     "Toggle the grid view" : "切换网格视图",
-    "Open the sidebar for a file" : "在侧边栏打开文件"
+    "Open the sidebar for a file" : "在侧边栏打开文件",
+    "You" : "您",
+    "Shared multiple times with different people" : "与不同的用户多次分享",
+    "Unable to change the favorite state of the file" : "无法更改文件的收藏状态",
+    "Error while loading the file data" : "加载文件数据时出错",
+    "Tags" : "标签",
+    "Save as …" : "另存为…",
+    "Converting files …" : "正在转换文件…",
+    "Converting file …" : "正在转换文件…",
+    "Deletion cancelled" : "删除已取消",
+    "Edit locally" : "本地编辑",
+    "Moving \"{source}\" to \"{destination}\" …" : "正在将“{source}”移动到“{destination}”…",
+    "Copying \"{source}\" to \"{destination}\" …" : "正在将“{source}”复制到“{destination}”",
+    "(copy)" : "（复制）",
+    "(copy %n)" : "(复制 %n)",
+    "Move cancelled" : "移动已取消",
+    "Cancelled move or copy of \"{filename}\"." : "已取消移动或复制“{filename}”。",
+    "Cancelled move or copy operation" : "已取消移动或复制操作",
+    "Open details" : "打开详情",
+    "Photos and images" : "照片和图像",
+    "New folder creation cancelled" : "新文件夹创建已取消",
+    "This directory is unavailable, please check the logs or contact the administrator" : "此目录不可用，请检查日志或联系管理员",
+    "All folders" : "所有文件夹",
+    "Open file sidebar" : "打开文件侧边栏",
+    "Search everywhere …" : "全局搜索…",
+    "Search here …" : "在此搜索…",
+    "Preparing …" : "正在准备…"
 },
 "nplurals=1; plural=0;");
