@@ -78,6 +78,8 @@ OC.L10N.register(
     "Reload current directory" : "重新載入目前的目錄",
     "Go to the \"{dir}\" directory" : "前往「{dir}」目錄",
     "Current directory path" : "目前目錄路徑",
+    "Share" : "分享",
+    "Reload content" : "重新載入內容",
     "Your have used your space quota and cannot upload files anymore" : "您已用完您的空間配額，無法再上傳檔案",
     "You do not have permission to upload or create files here." : "您無權在此上傳或建立檔案。",
     "Drag and drop files here to upload" : "將檔案拖放到此處以上傳",
@@ -92,7 +94,6 @@ OC.L10N.register(
     "This node is unavailable" : "此節點不可用",
     "Another entry with the same name already exists." : "已存在另一個同名條目。",
     "Invalid filename." : "無效的檔案名稱。",
-    "Renamed \"{oldName}\" to \"{newName}\"" : "已將「{oldName}」重新命名為「{newName}」",
     "Rename file" : "重新命名檔案",
     "Folder" : "資料夾",
     "Unknown file type" : "未知檔案類型",
@@ -102,12 +103,26 @@ OC.L10N.register(
     "{ext} text" : "{ext} 文字",
     "Pending" : "待處理",
     "Unknown date" : "未知日期",
-    "Clear filter" : "清除過濾條件",
-    "Modified" : "修改時間",
-    "Search everywhere" : "到處搜尋",
-    "Type" : "類型",
     "Active filters" : "作用中的過濾條件",
     "Remove filter" : "移除過濾條件",
+    "Today" : "今日",
+    "Last 7 days" : "過去7天",
+    "Last 30 days" : "過去30天",
+    "This year ({year})" : "今年 ({year})",
+    "Last year ({year})" : "去年 ({year})",
+    "Custom range" : "自訂範圍",
+    "Custom date range" : "自訂日期範圍",
+    "Search everywhere" : "到處搜尋",
+    "Documents" : "文件",
+    "Spreadsheets" : "試算表",
+    "Presentations" : "簡報",
+    "PDFs" : "PDF",
+    "Folders" : "資料夾",
+    "Audio" : "音訊",
+    "Images" : "圖片",
+    "Videos" : "影片",
+    "Filters" : "過濾",
+    "Back to filters" : "回到篩選器",
     "Appearance" : "外觀",
     "Show hidden files" : "顯示隱藏檔",
     "Show file type column" : "顯示檔案類型欄位",
@@ -136,7 +151,6 @@ OC.L10N.register(
     "Go right in grid" : "在網格中向右",
     "View" : "檢視",
     "Toggle grid view" : "切換網格檢視",
-    "Open file sidebar" : "開啟檔案側邊欄",
     "Show those shortcuts" : "顯示這些快捷鍵",
     "Warnings" : "警告",
     "Warn before changing a file extension" : "變更副檔名前警告",
@@ -150,6 +164,7 @@ OC.L10N.register(
     "Name" : "名稱",
     "File type" : "檔案類型",
     "Size" : "大小",
+    "Modified" : "修改時間",
     "{displayName}: failed on some elements" : "{displayName}：在部份元素上失敗",
     "{displayName}: done" : "{displayName}：完成",
     "{displayName}: failed" : "{displayName}：失敗",
@@ -218,12 +233,14 @@ OC.L10N.register(
     "Removing the file extension \"{old}\" may render the file unreadable." : "移除檔案副檔名「{old}」可能會導致檔案無法讀取。",
     "Adding the file extension \"{new}\" may render the file unreadable." : "加入檔案副檔名「{new}」可能會導致檔案無法讀取。",
     "Do not show this dialog again." : "不要再次顯示此對話方塊。",
+    "Rename file to hidden" : "將檔案重新命名為隱藏檔案",
+    "Prefixing a filename with a dot may render the file hidden." : "在檔案名稱前加點號可能會導致檔案隱藏。",
+    "Are you sure you want to rename the file to \"{filename}\"?" : "您確定您想要重新命名檔案為「{filename}」嗎？",
+    "Cancel" : "取消",
+    "Rename" : "重新命名",
     "Select file or folder to link to" : "選取要連結的檔案或資料夾",
     "Choose {file}" : "選擇 {file}",
     "Files settings" : "檔案設定",
-    "Share" : "分享",
-    "Shared by link" : "透過連結分享",
-    "Shared" : "已分享",
     "Switch to list view" : "切換至列表檢視",
     "Switch to grid view" : "切換到格狀檢視",
     "The file could not be found" : "找不到檔案",
@@ -233,6 +250,7 @@ OC.L10N.register(
     "Error during upload: {message}" : "上傳時發生錯誤：{message}",
     "Error during upload, status code {status}" : "上傳時發生錯誤，狀態碼 {status}",
     "Unknown error during upload" : "上傳時發生未知的錯誤",
+    "File list is reloading" : "正在重新載入檔案清單",
     "Loading current folder" : "正在載入目前資料夾",
     "Retry" : "重試",
     "No files in here" : "沒有任何檔案",
@@ -285,30 +303,29 @@ OC.L10N.register(
     "_You are about to permanently delete {count} item_::_You are about to permanently delete {count} items_" : ["您將要永久刪除 {count} 個項目"],
     "_You are about to delete {count} item_::_You are about to delete {count} items_" : ["您將要刪除 {count} 個項目"],
     "Confirm deletion" : "確認刪除",
-    "Cancel" : "取消",
     "Download" : "下載",
     "The requested file is not available." : "無法取得所請求的檔案。",
     "The requested files are not available." : "無法取得所請求的檔案。",
     "Add to favorites" : "新增至喜愛",
     "Remove from favorites" : "從喜愛中移除",
     "Add or remove favorite" : "新增或移除最愛",
-    "Moving \"{source}\" to \"{destination}\" …" : "正在移動「{source}」至「{destination}」 ……",
-    "Copying \"{source}\" to \"{destination}\" …" : "正在複製「{source}」至「{destination}」 ……",
+    "Move" : "移動",
+    "Copy" : "複製",
+    "Move or copy" : "移動或複製",
     "Destination is not a folder" : "目的地不是資料夾",
     "This file/folder is already in that directory" : "此檔案/資料夾已在該目錄中",
     "You cannot move a file/folder onto itself or into a subfolder of itself" : "您無法將檔案/資料夾移動到其自身或子資料夾中",
-    "(copy)" : "（副本）",
-    "(copy %n)" : "（副本 %n）",
     "A file or folder with that name already exists in this folder" : "此資料夾中已經存在同名的檔案或資料夾",
     "The files are locked" : "檔案已鎖定",
     "The file does not exist anymore" : "檔案已不存在",
+    "Moving \"{source}\" to \"{destination}\" …" : "正在移動「{source}」至「{destination}」 ……",
+    "Moving {count} files to \"{destination}\" …" : "正在將 {count} 個檔案移動到「{destination}」……",
+    "Copying \"{source}\" to \"{destination}\" …" : "正在複製「{source}」至「{destination}」 ……",
+    "Copying {count} files to \"{destination}\" …" : "正在將 {count} 個檔案複製到「{destination}」……",
     "Choose destination" : "選擇目的地",
     "Copy to {target}" : "複製到 {target}",
-    "Copy" : "複製",
     "Move to {target}" : "移動到 {target}",
-    "Move" : "移動",
     "Move or copy operation failed" : "移動或複製操作失敗",
-    "Move or copy" : "移動或複製",
     "Open folder" : "開啟資料夾",
     "Open folder {displayName}" : "開啟資料夾 {displayName}",
     "Open in Files" : "以「檔案」開啟",
@@ -318,29 +335,18 @@ OC.L10N.register(
     "The file should now open on your device. If it doesn't, please check that you have the desktop app installed." : "檔案現在應該可以在您的裝置上開啟。如果打不開，請檢查您是否有安裝桌面應用程式。",
     "Retry and close" : "重試並關閉",
     "Open online" : "線上開啟",
-    "Rename" : "重新命名",
     "Details" : "詳細資料",
+    "Open the details sidebar" : "開啟詳細資訊側邊欄",
     "Unfavorite" : "取消收藏",
     "View in folder" : "在資料夾中檢視",
-    "Today" : "今日",
-    "Last 7 days" : "過去7天",
-    "Last 30 days" : "過去30天",
-    "This year ({year})" : "今年 ({year})",
-    "Last year ({year})" : "去年 ({year})",
-    "Documents" : "文件",
-    "Spreadsheets" : "試算表",
-    "Presentations" : "簡報",
-    "PDFs" : "PDF",
-    "Folders" : "資料夾",
-    "Audio" : "音訊",
-    "Images" : "圖片",
-    "Videos" : "影片",
+    "Type" : "類型",
     "Created new folder \"{name}\"" : "已建立新資料夾「{name}」",
     "Unable to initialize the templates directory" : "無法初始化範本目錄",
     "Create templates folder" : "建立範本資料夾",
     "Templates" : "範本",
     "New template folder" : "新範本資料夾",
     "In folder" : "在資料夾中",
+    "Pick folder to search in" : "請挑選要搜尋的資料夾",
     "Search in all files" : "在所有檔案中搜尋",
     "Search in folder: {folder}" : "在資料夾中搜尋：{folder}",
     "One of the dropped files could not be processed" : "無法處理其中一個投遞的檔案",
@@ -350,10 +356,10 @@ OC.L10N.register(
     "Some files could not be uploaded" : "無法上傳部份檔案",
     "Files uploaded successfully" : "檔案上傳成功",
     "No files to process" : "沒有要處理的檔案",
-    "Some files could not be copied" : "無法複製部份檔案",
-    "Some files could not be moved" : "有些檔案無法被移動",
     "Files copied successfully" : "檔案複製成功",
     "Files moved successfully" : "檔案移動成功",
+    "Some files could not be copied" : "無法複製部份檔案",
+    "Some files could not be moved" : "有些檔案無法被移動",
     "Conflicts resolution skipped" : "已略過衝突解決",
     "Upload cancelled" : "已取消上傳",
     "Could not rename \"{oldName}\", it does not exist any more" : "無法命名檔案「{oldName}」，此檔案已不存在",
@@ -394,10 +400,14 @@ OC.L10N.register(
     "Upload (max. %s)" : "上傳（最多 %s）",
     "After enabling the windows compatible filenames, existing files cannot be modified anymore but can be renamed to valid new names by their owner." : "啟用與 Windows 相容的檔案名稱後，無法再修改現有檔案，但可以由其擁有者重新命名為有效的新名稱。",
     "It is also possible to migrate files automatically after enabling this setting, please refer to the documentation about the occ command." : "啟用此設定後，也可以自動遷移檔案，詳情請參閱關於 occ 命令的文件。",
+    "Renamed \"{oldName}\" to \"{newName}\"" : "已將「{oldName}」重新命名為「{newName}」",
+    "Clear filter" : "清除過濾條件",
     "\"{displayName}\" failed on some elements" : "「{displayName}」在某些元素上失敗",
     "\"{displayName}\" batch action executed successfully" : "「{displayName}」批次動作執行成功",
     "\"{displayName}\" action failed" : "「{displayName}」操作失敗",
     "Submitting fields …" : "正在遞交欄位……",
+    "Shared by link" : "透過連結分享",
+    "Shared" : "已分享",
     "\"{displayName}\" action executed successfully" : "「{displayName}」動作執行成功",
     "Filter file names …" : "過濾檔案名稱……",
     "Clipboard is not available" : "剪貼簿無法使用",
@@ -439,6 +449,8 @@ OC.L10N.register(
     "Edit locally" : "在本機編輯",
     "Moving \"{source}\" to \"{destination}\" …" : "正在移動「{source}」至「{destination}」……",
     "Copying \"{source}\" to \"{destination}\" …" : "正在複製「{source}」至「{destination}」……",
+    "(copy)" : "（副本）",
+    "(copy %n)" : "（副本 %n）",
     "Move cancelled" : "移動已取消",
     "Cancelled move or copy of \"{filename}\"." : "已取消移動或複製「{filename}」。",
     "Cancelled move or copy operation" : "已取消移動或複製操作",
@@ -447,6 +459,7 @@ OC.L10N.register(
     "New folder creation cancelled" : "已取消建立新資料夾",
     "This directory is unavailable, please check the logs or contact the administrator" : "這個目錄無法取用，請檢查伺服器紀錄檔或聯絡管理員",
     "All folders" : "所有資料夾",
+    "Open file sidebar" : "開啟檔案側邊欄",
     "Search everywhere …" : "搜尋各處……",
     "Search here …" : "搜尋此處……",
     "Preparing …" : "正在準備……"
