@@ -71,7 +71,6 @@ OC.L10N.register(
     "Sharing %1$s failed because the back end does not allow shares from type %2$s" : "Споделянето %1$s не бе успешно, защото вътрешния сървър не позволява споделяния от тип %2$s",
     "Please specify a valid federated group ID" : "Моля, посочете валиден идентификатор на федерирана група",
     "Sharing %s failed because the back end does not support room shares" : "Споделянето %s не бе успешно, защото вътрешния сървър не позволява споделяния на стаите",
-    "Sharing %s failed because the back end does not support ScienceMesh shares" : "Споделянето %s не бе успешно, защото вътрешния сървър не позволява споделяния на приложението ScienceMesh",
     "Unknown share type" : "Неизвестен тип споделяне",
     "Not a directory" : "Не е  директория",
     "Could not lock node" : "Възелът не можа да се заключи",
@@ -95,15 +94,17 @@ OC.L10N.register(
     "You received {share} to group {group} as a share by {user}" : "Получихте {share} за група {group} като споделяне от {user}",
     "Accept" : "Приемане",
     "Decline" : "Отхвърляне",
-    "People" : "Хора",
+    "you" : "ти",
     "Expiration date" : "Валидност",
+    "Select a date" : "Избор на дата",
     "Set a password" : "Задаване на парола",
     "Password" : "Парола",
-    "Link copied to clipboard" : "Връзката е копирана в клипборда",
+    "Link copied" : "Връзката е копирана",
     "Share link" : "Връзка за споделяне",
-    "Copy to clipboard" : "Копиране в клипборда",
+    "Copy" : "Копие",
     "Send link via email" : "Сподели връзка с имейл",
     "Select" : "Избери",
+    "The uploaded files are visible only to you unless you choose to share them." : "Качените файлове са видими само за теб, освен, ако не решиш да ги споделиш с друг.",
     "Close" : "Затваряне",
     "Error creating the share: {errorMessage}" : "Грешка при създаване на споделянето: {errorMessage}",
     "Error creating the share" : "Грешка при създаване на споделянето",
@@ -128,8 +129,7 @@ OC.L10N.register(
     "Via “{folder}”" : "Чрез “{folder}”",
     "Unshare" : "Прекрати споделянето",
     "Cannot copy, please copy the link manually" : "Не може да се копира, моля, копирайте връзката ръчно",
-    "Copy internal link to clipboard" : "Копиране на вътрешна връзката в клипборда",
-    "Link copied" : "Връзката е копирана",
+    "Copy internal link" : "Копиране на вътрешна връзка",
     "Internal link" : "Вътрешна връзка",
     "{shareWith} by {initiator}" : "{shareWith} чрез {initiator}",
     "Shared via link by {initiator}" : "Споделено чрез връзка от {initiator}",
@@ -138,7 +138,6 @@ OC.L10N.register(
     "Share link ({index})" : "Споделяне на връзка ({index})",
     "Create public link" : "Създаване на публична връзка",
     "Actions for \"{title}\"" : "Действия за „{title}“",
-    "Copy public link of \"{title}\" to clipboard" : "Копиране на публичната връзка на „{title}“ в клипборда",
     "Error, please enter proper password and/or expiration date" : "Грешка, моля да въведете правилната парола и / или срок на годност",
     "Link share created" : "Създадено споделяне на връзка",
     "Error while creating the share" : "Грешка при създаване на споделянето",
@@ -153,18 +152,17 @@ OC.L10N.register(
     "Can edit" : "Може да се редактира",
     "Custom permissions" : "Персонализиране на права",
     "Resharing is not allowed" : "Повторното споделяне е забранено",
-    "Name or email …" : "Име или имейл",
-    "Name, email, or Federated Cloud ID …" : "Име, имейл или Federed Cloud ID/ИД за облачно пространство/ ...",
-    "Searching …" : "Търсене ...",
     "No elements found." : "Няма намерени елементи",
-    "Search globally" : "Глобално търсене ",
+    "Search everywhere" : "Търси навсякъде",
     "Guest" : "Гост",
     "Group" : "Група",
     "Email" : "Имейл",
+    "Team" : "Екип",
     "Talk conversation" : "Talk разговор",
     "Deck board" : "Deck табло",
     "ScienceMesh" : "ScienceMesh /приложение/",
     "on {server}" : "на {server}",
+    "Search for internal recipients" : "Търси вътрешни получатели",
     "File drop" : "Пускане/Преместване/ на файл",
     "Terms of service" : "Условия за ползване",
     "Read" : "Четене",
@@ -194,8 +192,12 @@ OC.L10N.register(
     "this share just expired." : "Това споделяне току-що изтече.",
     "Shared with you by {owner}" : "Споделено с Вас от {owner}.",
     "Link to a file" : "Линк към файл",
+    "Open in Files" : "Отворете във Файлове",
     "Shared" : "Споделен",
+    "Shared multiple times with different people" : "Споделяно многократно с различни хора",
+    "Sharing options" : "Опции за споделяне",
     "Shared with others" : "Споделени с други",
+    "People" : "Хора",
     "No file" : "Без файл",
     "No shares" : "Няма споделяния",
     "Shared with you" : "Споделени с вас",
@@ -213,14 +215,29 @@ OC.L10N.register(
     "Folder \"{path}\" has been unshared" : "Папка „{path}“не е споделена",
     "Share label saved" : "Запазен е етикет за споделяне",
     "Share password saved" : "Запазена е парола за споделяне",
-    "Shared by" : "Споделено от",
-    "Shared with" : "Споделено с",
     "Password created successfully" : "Създаването на парола е успешно",
     "Error generating password from password policy" : "Грешка при генериране на парола от политиката за пароли",
     "Shared with you and the group {group} by {owner}" : "Споделено от {owner} с Вас и групата {group} .",
     "Shared with you and {circle} by {owner}" : "Споделено с вас и {circle} от {owner}",
     "Shared with you and the conversation {conversation} by {owner}" : "Споделено с вас и разговора {conversation} от {owner}",
     "Shared with you in a conversation by {owner}" : "Споделено с вас в разговор от {owner}",
+    "Share not found" : "Споделянето не е открито",
+    "Back to %s" : "Обратно към %s",
+    "Add to your Nextcloud" : "Добавете към Nextcloud",
+    "Sharing %s failed because the back end does not support ScienceMesh shares" : "Споделянето %s не бе успешно, защото вътрешния сървър не позволява споделяния на приложението ScienceMesh",
+    "Link copied to clipboard" : "Връзката е копирана в клипборда",
+    "Copy to clipboard" : "Копиране в клипборда",
+    "Copy internal link to clipboard" : "Копиране на вътрешна връзката в клипборда",
+    "Copy public link of \"{title}\" to clipboard" : "Копиране на публичната връзка на „{title}“ в клипборда",
+    "Name or email …" : "Име или имейл",
+    "Name, email, or Federated Cloud ID …" : "Име, имейл или Federed Cloud ID/ИД за облачно пространство/ ...",
+    "Searching …" : "Търсене ...",
+    "Search globally" : "Глобално търсене ",
+    "Name" : "Име",
+    "Enter your name" : "Въведете вашето име",
+    "Filename must not be empty." : "Името на файла не трябва да е празно.",
+    "Shared by" : "Споделено от",
+    "Shared with" : "Споделено с",
     "Share note" : "Сподели бележка",
     "Show list view" : "Показване с изглед на списък",
     "Show grid view" : "Показване в решетъчен изглед",
@@ -229,23 +246,6 @@ OC.L10N.register(
     "Select or drop files" : "Изберете файл или преместете с мишката",
     "Uploading files" : "Качване на файлове",
     "Uploaded files:" : "Качени файлове:",
-    "By uploading files, you agree to the %1$sterms of service%2$s." : "С качването на файлове, вие се съгласявате с %1$s условията на услугата%2$s.",
-    "Share not found" : "Споделянето не е открито",
-    "Back to %s" : "Обратно към %s",
-    "Add to your Nextcloud" : "Добавете към Nextcloud",
-    "Waiting…" : "Изчакване...",
-    "error" : "грешка",
-    "finished" : "завършен",
-    "This will stop your current uploads." : "Това ще прекрати всички ваши текущи процеси по качване на файлове.",
-    "Move or copy" : "Премести или копирай",
-    "You can upload into this folder" : "Може да качвате в папката",
-    "No compatible server found at {remote}" : "Не беше намерен съвместим сървър на {remote}",
-    "Invalid server URL" : "URL адреса на сървъра не е валиден",
-    "Failed to add the public link to your Nextcloud" : "Неуспешно добавяне на публичната връзка към вашия Nextcloud",
-    "Download all files" : "Изтегли всички файлове",
-    "Search for share recipients" : "Търсене на получатели на споделяне",
-    "No recommendations. Start typing." : "Няма препоръки. Започнете да пишете.",
-    "Enter your name" : "Въведете вашето име",
-    "Name" : "Име"
+    "By uploading files, you agree to the %1$sterms of service%2$s." : "С качването на файлове, вие се съгласявате с %1$s условията на услугата%2$s."
 },
 "nplurals=2; plural=(n != 1);");
