@@ -74,7 +74,6 @@ OC.L10N.register(
     "Please specify a valid federated account ID" : "Navesti je treba veljaven ID zveznega računa",
     "Please specify a valid federated group ID" : "Navesti je treba veljaven ID zvezne skupine",
     "Sharing %s failed because the back end does not support room shares" : "Souporaba %s je spodletela, ker sistem ne dovoli souporabe znotraj posameznih sob",
-    "Sharing %s failed because the back end does not support ScienceMesh shares" : "Souporaba %s je spodletela, ker sistem ne podpira souporabe ScienceMesh",
     "Unknown share type" : "Neznana vrsta mesta souporabe",
     "Not a directory" : "Predmet ni mapa",
     "Could not lock node" : "Vozlišča ni mogoče zakleniti",
@@ -97,7 +96,7 @@ OC.L10N.register(
     "You received {share} to group {group} as a share by {user}" : "{user} vam omogoča souporabo {share} prek skupine {group}",
     "Accept" : "Sprejmi",
     "Decline" : "Zavrni",
-    "People" : "Osebe",
+    "you" : "vi",
     "Expiration date" : "Datum preteka",
     "Select a date" : "Izbor datuma",
     "Set a password" : "Nastavi geslo",
@@ -173,9 +172,7 @@ OC.L10N.register(
     "Can edit" : "Lahko ureja",
     "Custom permissions" : "Dovoljenja po meri",
     "Resharing is not allowed" : "Nadaljnja souporaba ni dovoljena",
-    "Name or email …" : "Ime ali elektronski naslov ...",
-    "Name, email, or Federated Cloud ID …" : "Ime, elektronski naslov, ali ID zveznega oblaka ...",
-    "Searching …" : "Poteka iskanje ...",
+    "Searching …" : "Poteka iskanje ...",
     "No elements found." : "Ni najdenih predmetov",
     "Search everywhere" : "Išči povsod",
     "Guest" : "Gost",
@@ -224,6 +221,7 @@ OC.L10N.register(
     "Shared multiple times with different people" : "V več souporabah z različnimi uporabniki",
     "Sharing options" : "Možnosti souporabe",
     "Shared with others" : "V souporabi  z drugimi",
+    "People" : "Osebe",
     "Public share" : "Javna objava",
     "No shares" : "Ni še vpisanih mest souporabe",
     "Shared with you" : "V souporabi z vami",
@@ -240,8 +238,6 @@ OC.L10N.register(
     "Error updating the share" : "Napaka posodabljanja mesta souporabe",
     "File \"{path}\" has been unshared" : "Souporaba datoteke »{path}« je odstranjena",
     "Folder \"{path}\" has been unshared" : "Souporaba mape »{path}« je odstranjena",
-    "Shared by" : "Souporabo omogoča",
-    "Shared with" : "V skupni rabi z uporabnikom",
     "Password created successfully" : "Geslo je uspešno ustvarjeno",
     "Error generating password from password policy" : "Napaka ustvarjanja gesla po določenih varnostnih pravilih",
     "Shared with you and the group {group} by {owner}" : "{owner} omogoča vam in skupini {group} souporabo",
@@ -251,35 +247,28 @@ OC.L10N.register(
     "Share not found" : "Mesta souporabe ni mogoče najti.",
     "Back to %s" : "Nazaj na %s",
     "Add to your Nextcloud" : "Dodaj v oblak Nextcloud",
-    "Waiting…" : "Čakanje na povezavo ...",
-    "error" : "napaka",
-    "finished" : "končano",
-    "This will stop your current uploads." : "S tem bodo zaustavljena vsa pošiljanja v oblak.",
-    "Move or copy" : "Premakni ali kopiraj",
-    "You can upload into this folder" : "V to mapo je dovoljeno pošiljati datoteke",
-    "Show list view" : "Pokaži seznamski pogled",
-    "Show grid view" : "Pokaži mrežni pogled",
-    "No compatible server found at {remote}" : "Skladnega strežnika na {remote} ni mogoče najti",
-    "Invalid server URL" : "Neveljaven naslov URL strežnika",
-    "Failed to add the public link to your Nextcloud" : "Dodajanje javne povezave v oblak je spodletelo.",
-    "Download all files" : "Prejmi vse datoteke",
+    "Sharing %s failed because the back end does not support ScienceMesh shares" : "Souporaba %s je spodletela, ker sistem ne podpira souporabe ScienceMesh",
     "Link copied to clipboard" : "Povezava je kopirana v odložišče",
-    "_1 email address already added_::_{count} email addresses already added_" : ["{count} elektronski naslov je že dodan","{count} elektronska naslova sta že dodana","{count} elektronski naslovi so že dodani","{count} elektronskih naslovov je že dodanih"],
     "Copy to clipboard" : "Kopiraj v odložišče",
     "Copy internal link to clipboard" : "Kopiraj notranjo povezavo v odložišče",
     "Copy public link of \"{title}\" to clipboard" : "Kopiraj javno povezavo do mape »{title}« v odložišče",
+    "Name or email …" : "Ime ali elektronski naslov ...",
+    "Name, email, or Federated Cloud ID …" : "Ime, elektronski naslov, ali ID zveznega oblaka ...",
+    "Searching …" : "Poteka iskanje ...",
     "Search globally" : "Splošno iskanje",
-    "Search for share recipients" : "Iskanje prejemnikov mesta souporabe",
-    "No recommendations. Start typing." : "Ni priporočil; začnite vpisovati",
+    "Name" : "Ime podpisnika",
     "Enter your name" : "Vpišite ime",
+    "Filename must not be empty." : "Ime datoteke ne sme biti prazno.",
+    "Shared by" : "Souporabo omogoča",
+    "Shared with" : "V skupni rabi z uporabnikom",
     "Share note" : "Omogoči souporabo zabeležke",
+    "Show list view" : "Pokaži seznamski pogled",
+    "Show grid view" : "Pokaži mrežni pogled",
     "Upload files to %s" : "Pošlji datoteke v račun %s",
     "Note" : "Opomba",
     "Select or drop files" : "Izberte ali povlecite datoteke",
     "Uploading files" : "Pošiljanje datotek",
     "Uploaded files:" : "Poslane datoteke:",
-    "By uploading files, you agree to the %1$sterms of service%2$s." : "S pošiljanjem datotek v oblak sprejemate tudi %1$spogoje uporabe storitve%2$s.",
-    "Name" : "Ime podpisnika",
-    "Filename must not be empty." : "Ime datoteke ne sme biti prazno."
+    "By uploading files, you agree to the %1$sterms of service%2$s." : "S pošiljanjem datotek v oblak sprejemate tudi %1$spogoje uporabe storitve%2$s."
 },
 "nplurals=4; plural=(n%100==1 ? 0 : n%100==2 ? 1 : n%100==3 || n%100==4 ? 2 : 3);");
