@@ -24,12 +24,13 @@ OC.L10N.register(
     "Download on Google play store" : "Transferir na loja Google Play",
     "Close" : "Fechar",
     "Download For Windows, Mac OS and Linux." : "Transferir para Windows, Mac OS e Linux.",
+    "Skip" : "Ignorar",
     "Privacy" : "Privacidade",
     "Community" : "Comunidade",
     "Share via email" : "Partilhar via correio eletrónico",
     "Get the apps to sync your files" : "Obtenha as aplicações para sincronizar os seus ficheiros",
     "Server address" : "Endereço do servidor",
-    "Read more" : "Ler mais",
-    "Smarter team sharing with Team folders" : "Partilha de equipa mais inteligente com as Pastas de Equipa."
+    "Smarter team sharing with Team folders" : "Partilha de equipa mais inteligente com as Pastas de Equipa.",
+    "Read more" : "Ler mais"
 },
 "nplurals=3; plural=(n == 0 || n == 1) ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
