@@ -8,12 +8,13 @@ OC.L10N.register(
     "Desktop client" : "Client desktop",
     "iOS app" : "Aplicație iOS",
     "Close" : "Închide",
+    "Skip" : "Sari peste",
     "Privacy" : "Confidențialitate",
     "Community" : "Comunitate",
     "Get the apps to sync your files" : "Obține aplicația pentru sincronizarea fișierelor",
     "Server address" : "Adresă server",
     "What's new?" : "Ce este nou?",
-    "Read more" : "Citește mai mult",
-    "Share on social media" : "Partajează pe rețelele de socializare"
+    "Share on social media" : "Partajează pe rețelele de socializare",
+    "Read more" : "Citește mai mult"
 },
 "nplurals=3; plural=(n==1?0:(((n%100>19)||((n%100==0)&&(n!=0)))?2:1));");
