@@ -21,6 +21,9 @@ OC.L10N.register(
     "Mark selection as favorite" : "Märgi valitud lemmikuks",
     "Add selection to favorites" : "Lisa valitud lemmikute hulka",
     "Remove selection from favorites" : "Eemalda valitud lemmikute hulgast",
+    "This name is already in use." : "See nimi on juba kasutusel.",
+    "\"{char}\" is not allowed inside a filename." : "„{char}“ pole failinimedes lubatud.",
+    "Invalid filename." : "Vigane failinimi.",
     "Name of the album" : "Albumi nimi",
     "Location of the album" : "Albumi asukoht",
     "Back" : "Tagasi",
@@ -39,51 +42,49 @@ OC.L10N.register(
     "Add people or groups who can edit your album" : "Lisa inimesi ja gruppe, kes võivad su albumit muuta",
     "Search people or groups" : "Otsi inimesi või gruppe",
     "No recommendations. Start typing." : "Soovitusi pole. Alusta trükkimist.",
-    "Group" : "Grupp",
-    "Remove {collaboratorLabel} from the collaborators list" : "Eemalda {collaboratorLabel} kaasautorite hulgast",
     "Copy the public link" : "Kopeeri avalik link",
     "Public link copied!" : "Avalik link kopeeritud!",
     "Copy public link" : "Kopeeri avalik link",
     "Delete the public link" : "Kustuta avalik link",
     "Create public link share" : "Jaga avaliku lingiga",
     "Share via public link" : "Jaga avaliku lingi kaudu",
-    "This collection does not exist" : "Seda kollektsiooni pole olemas",
+    "This collection does not exist" : "Seda kogumikku pole olemas",
     "An error occurred" : "Tekkis tõrge",
     "No picture for this day" : "Selleks päevaks ei ole pilti",
     "Picture taken on this day will show up here." : "Sellel päeval tehtud pilt ilmub siia.",
     "More photos from this day" : "Rohkem pilte tänasest",
+    "_%n photos_::_%n photos_" : ["%n foto","%n fotot"],
     "_%n unassigned photo_::_%n unassigned photos_" : ["%n määramata foto","%n määramata fotot"],
     "Favorite" : "Lemmik",
     "Favorite image, open the full size \"{name}\" image" : "Lemmikpilt, ava täissuuruses \"{name}\" pilt",
     "Open the full size \"{name}\" image" : "Ava pilt \"{name}\" täissuuruses",
     "Select image {imageName}" : "Vali pilt {imageName}",
     "Open the \"{name}\" folder" : "Ava kaust \"{name}\"",
-    "Back to {folder}" : "Tagasi kausta {folder}",
     "Go back" : "Mine tagasi",
-    "Share this folder" : "Jaga seda kausta",
+    "Select a custom date range" : "Vali enda määratud ajavahemik",
+    "Select a date range" : "Vali kuupäevavahemik",
+    "Date range" : "Kuupäevade vahemik",
+    "Select filters" : "Vali filtrid",
     "Dates" : "Kuupäevad",
     "Jump to specific date in list" : "Hüppa nimekirjas kindlale kuupäevale",
     "Jump to {date}" : "Hüppa {date} juurde",
     "Add to {destination}" : "Lisa {destination}-sse",
-    "The destination folder is owned by {owner}" : "Sihtkausta omab {owner}",
+    "The destination folder is owned by {owner}" : "Sihtkausta omanik on {owner}",
     "There are no photos or videos yet!" : "Ühtegi fotot ega videot pole veel!",
     "_{years} year ago_::_{years} years ago_" : ["{years} aasta tagasi","{years} aastat tagasi"],
-    "Enable squared photos view" : "Luba piltide ruutvaade",
+    "Squared photos view" : "Piltide ruudustikuvaade",
     "Delete source directory" : "Kustuta lähtekaust",
     "Pick folder" : "Vali kaust",
     "Select a source folder for your media" : "Vali oma meediale lähtekaust",
+    "Media folders" : "Meediakaustad",
+    "Choose the folders from where photos and videos are shown." : "Vali kaustad, kust fotosid ja videoid näidatakse.",
     "All folders" : "Kõik kaustad",
     "Add a Photos source for the timelines" : "Lisa fotode allikas ajajoonele",
     "Add folder" : "Lisa kaust",
-    "Select the default upload location for your media" : "Vali oma meediale vaikimisi üleslaadimise kaust",
     "Home" : "Avaleht",
-    "Choose default Photos upload and Albums location" : "Vali vaikimisi fotode üleslaadimise ja albumite asukoht",
-    "Choose a different folder" : "Vali mõni muu kaust",
-    "View" : "Vaata",
-    "Media folders" : "Meediakaustad",
-    "Choose the folders from where photos and videos are shown." : "Vali kaustad, kust fotosid ja videoid näidatakse.",
+    "Select the default upload location for your media" : "Vali oma meediale vaikimisi üleslaadimise kaust",
     "Upload folder" : "Üleslaadimiskaust",
-    "Choose the folder where photos and albums are uploaded to." : "Vali kaust, kuhu fotod ja albumid üles laaditakse",
+    "General" : "Üldine",
     "_%n photo_::_%n photos_" : ["%n foto","%n fotot"],
     "Unselect all" : "Eemalda kogu valik",
     "Add photos to this album" : "Lisa sellesse albumisse fotosid",
@@ -115,7 +116,7 @@ OC.L10N.register(
     "This might take some time depending on the size of your photo library." : "See võib sõltuvalt fototeegi suurusest natuke aega võtta.",
     "Recognized people will show up here" : "Siin näidatakse tuvastatud inimesi",
     "This folder does not exist" : "Seda kausta pole olemas",
-    "Loading folders …" : "Kaustada laadimine …",
+    "Loading folders…" : "Laadin kaustu…",
     "No photos in here" : "Siin ei ole fotosid",
     "Taken on {date} at {time}" : "Pildistatud {date} {time}",
     "This place does not have any photos or videos yet!" : "Siin kohas pole veel ühtegi fotot ega videot!",
@@ -129,16 +130,16 @@ OC.L10N.register(
     "Photos with tags will show up here" : "Siin näidatakse sildistatud fotosid",
     "Popular tags" : "Populaarsed sildid",
     "All tags" : "Kõik sildid",
+    "Create new album from filters" : "Loo uus album filtrite alusel",
     "One of the source folders does not exist" : "Ühte lähtekaustadest pole olemas",
     "Add to album" : "Lisa albumisse",
     "Delete selection" : "Kustuta valik",
     "No photos or videos in here" : "Siin pole fotosid ega videosid",
     "Unassigned faces" : "Määramata näod",
-    "_%n photos_::_%n photos_" : ["%n foto","%n fotot"],
-    "Failed to fetch collection." : "Kollektsiooni laadimine ebaõnnestus.",
-    "Failed to fetch collections list." : "Kollektsioonide loendi laadimine ebaõnnestus.",
+    "Failed to fetch collection." : "Kogumiku laadimine ei õnnestunud.",
+    "Failed to fetch collections list." : "Kogumiku loendi laadimine ei õnnestunud.",
     "Failed to fetch faces list." : "Nägude loendi laadimine ebaõnnestus.",
-    "Error fetching files" : "Viga failide laadimisel.",
+    "Error fetching files" : "Viga failide laadimisel",
     "All your media" : "Kogu su meedia",
     "Album {title}" : "Album {title}",
     "Shared Albums" : "Jagatud albumid",
@@ -147,8 +148,24 @@ OC.L10N.register(
     "Tagged photos" : "Sildistatud fotod",
     "Tagged photo {title}" : "Sildistatud foto {title}",
     "{title}'s face" : "{title} nägu",
+    "Last week" : "Eelmisel nädalal",
+    "Last Month" : "Eelmisel kuul",
+    "Custom…" : "Kohandatud…",
     "{startDate} to {endDate}" : "{startDate} kuni {endDate}",
     "Details" : "Üksikasjad",
+    "Failed to add {fileBaseName} to collection {collectionFileName}" : "„{fileBaseName}“ lisamine „{collectionFileName}“ kogumikku ei õnnestunud",
+    "Failed to delete {fileBaseName}" : "Ei õnnestunud kustutada: „{fileBaseName}“",
+    "Failed to create {collectionFileName}" : "„{collectionFileName}“ kogumiku loomine ei õnnestunud",
+    "Failed to rename {currentCollectionFileName} to {newCollectionFileName}" : "Ei õnnestunud muuta kogumiku nime: „{currentCollectionFileName}“ → „{newCollectionFileName}“",
+    "Failed to update properties of {collectionFileName} with {properties}" : "„{collectionFileName}“ faili „{properties}“ omaduste muutmine ei õnnestunud",
+    "Delete collection" : "Kustuta kogumik",
+    "Leave shared album" : "Lahku jagatud albumist",
+    "Are you sure you want to delete {collectionName}? This action cannot be undone." : "Kas sa oled kindel, et soovid „{collectionName}“ kogumiku kustutada? Seda tegevust ei saa tagasi pöörata.",
+    "Failed to delete {collectionFileName}" : "Kogumiku kustutamine ei õnnestunud: „{collectionFileName}“",
+    "Cancel" : "Katkesta",
+    "Confirm" : "Kinnita",
+    "Failed to move {fileBaseName} to person {faceName}" : "„{fileBaseName}“ teisaldamine kasutajale „{faceName}“ ei õnnestunud",
+    "Failed to remove {fileBaseName}" : "„{fileBaseName}“ eemaldamine ei õnnestunud",
     "Failed to rename {oldName} to {faceName}" : "Ei õnnestunud muuta nime: „{oldName}“ → „{faceName}“",
     "Failed to delete {faceName}" : "Ei õnnestunud kustutada: „{faceName}“",
     "Failed to delete {fileId}" : "Ei õnnestunud kustutada: „{fileId}“",
@@ -156,7 +173,17 @@ OC.L10N.register(
     "Failed to set favorite state for {fileId}" : "Ei õnnestunud määrata olekut lemmikuna: „{fileId}“",
     "Failed to set favorite state for {fileName}" : "Ei õnnestunud määrata olekut lemmikuna: „{fileName}“",
     "Could not load photos folder" : "Fotode kausta laadimine ei õnnestunud",
-    "One of the source folders does not exists" : "Ühte lähtekaustadest pole olemas",
-    "Add" : "Lisa"
+    "Group" : "Grupp",
+    "Remove {collaboratorLabel} from the collaborators list" : "Eemalda {collaboratorLabel} kaasautorite hulgast",
+    "Back to {folder}" : "Tagasi kausta {folder}",
+    "Share this folder" : "Jaga seda kausta",
+    "Enable squared photos view" : "Luba piltide ruutvaade",
+    "Choose default Photos upload and Albums location" : "Vali vaikimisi fotode üleslaadimise ja albumite asukoht",
+    "Choose a different folder" : "Vali mõni muu kaust",
+    "View" : "Vaata",
+    "Choose the folder where photos and albums are uploaded to." : "Vali kaust, kuhu fotod ja albumid üles laaditakse",
+    "Loading folders …" : "Kaustada laadimine …",
+    "Add" : "Lisa",
+    "Loading folders …" : "Laadin kaustu…"
 },
 "nplurals=2; plural=(n != 1);");
