@@ -21,6 +21,9 @@ OC.L10N.register(
     "Mark selection as favorite" : "Merkitse valinta suosikeiksi",
     "Add selection to favorites" : "Lisää valinta suosikkeihin",
     "Remove selection from favorites" : "Poista valinta suosikeista",
+    "This name is already in use." : "Tämä nimi on jo käytössä.",
+    "\"{char}\" is not allowed inside a filename." : "\"{char}\" ei ole sallittu tiedoston nimessä.",
+    "Invalid filename." : "Epäkelpo tiedostonimi.",
     "Name of the album" : "Albumin nimi",
     "Location of the album" : "Albumin sijainti",
     "Back" : "Takaisin",
@@ -39,8 +42,6 @@ OC.L10N.register(
     "Add people or groups who can edit your album" : "Lisää henkilöitä tai ryhmiä, jotka voivat muokata albumia",
     "Search people or groups" : "Etsi käyttäjiä tai ryhmiä",
     "No recommendations. Start typing." : "Ei suosituksia. Aloita kirjoittaminen.",
-    "Group" : "Ryhmä",
-    "Remove {collaboratorLabel} from the collaborators list" : "Poista {collaboratorLabel} osanottajista",
     "Copy the public link" : "Kopioi julkinen linkki",
     "Public link copied!" : "Julkinen linkki kopioitu!",
     "Copy public link" : "Kopioi julkinen linkki",
@@ -52,14 +53,17 @@ OC.L10N.register(
     "No picture for this day" : "Ei kuvaa tälle päivälle",
     "Picture taken on this day will show up here." : "Tänä päivänä otettu kuva näkyy täällä.",
     "More photos from this day" : "Lisää kuvia tältä päivältä",
+    "_%n photos_::_%n photos_" : ["%n kuva","%n kuvaa"],
     "_%n unassigned photo_::_%n unassigned photos_" : ["%n määrittämätön kuva","%n määrittämätöntä kuvaa"],
     "Favorite" : "Suosikki",
     "Open the full size \"{name}\" image" : "Avaa kuva \"{name}\" todellisessa koossa",
     "Select image {imageName}" : "Valitse kuva {imageName}",
     "Open the \"{name}\" folder" : "Avaa kansio \"{name}\"",
-    "Back to {folder}" : "Takaisin kansioon {folder}",
     "Go back" : "Mene takaisin",
-    "Share this folder" : "Jaa tämä kansio",
+    "Select a custom date range" : "Valitse omavalintainen aikaväli",
+    "Select a date range" : "Valitse aikaväli",
+    "Date range" : "Päiväväli",
+    "Select filters" : "Valitse suodattimet",
     "Dates" : "Päivät",
     "Jump to specific date in list" : "Siirry määrättyyn päivään listassa",
     "Jump to {date}" : "Siirry päivään {date}",
@@ -67,21 +71,17 @@ OC.L10N.register(
     "The destination folder is owned by {owner}" : "Kohdekansion omistaa {owner}",
     "There are no photos or videos yet!" : "Ei kuvia tai videoita vielä!",
     "_{years} year ago_::_{years} years ago_" : ["{years} vuosi sitten","{years} vuotta sitten"],
-    "Enable squared photos view" : "Ota käyttöön neliömäinen kuvanäkymä",
     "Delete source directory" : "Poista lähdekansio",
     "Pick folder" : "Valitse kansio",
     "Select a source folder for your media" : "Valitse median lähdekansio",
-    "All folders" : "Kaikki kansiot",
-    "Add folder" : "Lisää kansio",
-    "Select the default upload location for your media" : "Valitse oletussijainti lähetettävälle medialle",
-    "Home" : "Koti",
-    "Choose default Photos upload and Albums location" : "Valitse kuvien ja albumien oletussijainti",
-    "Choose a different folder" : "Valitse eri kansio",
-    "View" : "Näytä",
     "Media folders" : "Mediakansiot",
     "Choose the folders from where photos and videos are shown." : "Valitse kansiot, joista kuvat ja videot näytetään.",
+    "All folders" : "Kaikki kansiot",
+    "Add folder" : "Lisää kansio",
+    "Home" : "Koti",
+    "Select the default upload location for your media" : "Valitse oletussijainti lähetettävälle medialle",
     "Upload folder" : "Lähetä kansio",
-    "Choose the folder where photos and albums are uploaded to." : "Valitse kansio, johon kuvat ja albumit lähetetään.",
+    "General" : "Yleiset",
     "_%n photo_::_%n photos_" : ["%n kuva","%n kuvaa"],
     "Unselect all" : "Poista valinnat",
     "Add photos to this album" : "Lisää kuvia tähän albumiin",
@@ -113,7 +113,7 @@ OC.L10N.register(
     "This might take some time depending on the size of your photo library." : "Tämä saattaa kestää hetken riippuen kuvakirjastosi koosta.",
     "Recognized people will show up here" : "Tunnistetut henkilöt näkyvät täällä",
     "This folder does not exist" : "Tätä kansiota ei ole olemassa",
-    "Loading folders …" : "Ladataan kansioita…",
+    "Loading folders…" : "Ladataan kansioita…",
     "No photos in here" : "Ei kuvia täällä",
     "Taken on {date} at {time}" : "Otettu {date} kello {time}",
     "This place does not have any photos or videos yet!" : "Tässä sijainnissa ei ole vielä kuvia tai videoita!",
@@ -127,11 +127,12 @@ OC.L10N.register(
     "Photos with tags will show up here" : "Tunnisteilla varustetut kuvat näkyvät täällä",
     "Popular tags" : "Suositut tunnisteet",
     "All tags" : "Kaikki tunnisteet",
+    "Create new album from filters" : "Luo uusi albumi suodattimista",
+    "One of the source folders does not exist" : "Jotakin lähdekansiota ei ole olemassa",
     "Add to album" : "Lisää albumiin",
     "Delete selection" : "Poista valinta",
     "No photos or videos in here" : "Ei kuvia tai videoita",
     "Unassigned faces" : "Määrittämättömät kasvot",
-    "_%n photos_::_%n photos_" : ["%n kuva","%n kuvaa"],
     "Failed to fetch collection." : "Kokoelman haku epäonnistui.",
     "Failed to fetch collections list." : "Kokoelmalistan haku epäonnistui.",
     "Failed to fetch faces list." : "Kasvolistauksen noutaminen epäonnistui.",
@@ -144,12 +145,33 @@ OC.L10N.register(
     "Tagged photos" : "Tunnisteilla varustetut kuvat",
     "Tagged photo {title}" : "Kuvaan {title} asetettu tunniste",
     "{title}'s face" : "Henkilön {title} kasvot",
+    "Last week" : "Viime viikko",
+    "Last Month" : "Viime kuukausi",
+    "Custom…" : "Omavalintainen…",
     "{startDate} to {endDate}" : "{startDate} - {endDate}",
     "Details" : "Tiedot",
+    "Failed to add {fileBaseName} to collection {collectionFileName}" : "Kohteen {fileBaseName} lisääminen kokoelmaan {collectionFileName} epäonnistui",
+    "Failed to delete {fileBaseName}" : "Kohteen {fileBaseName} poistaminen epäonnistui",
+    "Failed to create {collectionFileName}" : "Kokoelman {collectionFileName} luominen epäonnistui",
+    "Delete collection" : "Poista kokoelma",
+    "Leave shared album" : "Poistu jaetusta albumista",
+    "Failed to delete {collectionFileName}" : "Kohteen {collectionFileName} poistaminen epäonnistui",
+    "Cancel" : "Peruuta",
+    "Confirm" : "Vahvista",
     "Failed to delete {faceName}" : "Kohteen {faceName} poistaminen epäonnistui",
     "Failed to delete {fileId}" : "Kohteen {fileId} poistaminen epäonnistui",
     "Failed to delete {fileName}" : "Kohteen {fileName} poistaminen epäonnistui",
-    "One of the source folders does not exists" : "Yksi lähdekansioista ei ole olemassa",
-    "Add" : "Lisää"
+    "Group" : "Ryhmä",
+    "Remove {collaboratorLabel} from the collaborators list" : "Poista {collaboratorLabel} osanottajista",
+    "Back to {folder}" : "Takaisin kansioon {folder}",
+    "Share this folder" : "Jaa tämä kansio",
+    "Enable squared photos view" : "Ota käyttöön neliömäinen kuvanäkymä",
+    "Choose default Photos upload and Albums location" : "Valitse kuvien ja albumien oletussijainti",
+    "Choose a different folder" : "Valitse eri kansio",
+    "View" : "Näytä",
+    "Choose the folder where photos and albums are uploaded to." : "Valitse kansio, johon kuvat ja albumit lähetetään.",
+    "Loading folders …" : "Ladataan kansioita…",
+    "Add" : "Lisää",
+    "Loading folders …" : "Ladataan kansioita …"
 },
 "nplurals=2; plural=(n != 1);");
