@@ -21,6 +21,9 @@ OC.L10N.register(
     "Mark selection as favorite" : "Marquer la sélection comme favorite",
     "Add selection to favorites" : "Ajouter la sélection aux favoris",
     "Remove selection from favorites" : "Retirer la sélection des favoris",
+    "This name is already in use." : "Ce nom est déjà utilisé.",
+    "\"{char}\" is not allowed inside a filename." : "\"{char}\" n'est pas autorisé dans un nom de fichier.",
+    "Invalid filename." : "Nom de fichier invalide.",
     "Name of the album" : "Nom de l’album",
     "Location of the album" : "Emplacement de l’album",
     "Back" : "Retour",
@@ -39,14 +42,12 @@ OC.L10N.register(
     "Add people or groups who can edit your album" : "Ajoutez des personnes ou des groupes qui peuvent modifier votre album",
     "Search people or groups" : "Recherche des personnes ou des groupes",
     "No recommendations. Start typing." : "Pas de suggestion. Commencez à écrire.",
-    "Group" : "Groupe",
-    "Remove {collaboratorLabel} from the collaborators list" : "Supprimer {collaboratorLabel} de la liste des collaborateurs",
     "Copy the public link" : "Copier le lien public",
     "Public link copied!" : "Lien public copié !",
     "Copy public link" : "Copier le lien public",
     "Delete the public link" : "Supprimer le lien public",
     "Create public link share" : "Créer un partage par lien public",
-    "Share via public link" : "Partager via un lien public",
+    "Share via public link" : "Partager par lien public",
     "This collection does not exist" : "Cette collection n’existe pas",
     "An error occurred" : "Une erreur est survenue",
     "No picture for this day" : "Aucune image ce jour",
@@ -55,37 +56,35 @@ OC.L10N.register(
     "_%n photos_::_%n photos_" : ["%n photo","%n photos","%n photos"],
     "_%n unassigned photo_::_%n unassigned photos_" : ["%n photo non assignée","%n photos non assignées","%n photos non assignées"],
     "Favorite" : "Favoris",
-    "Favorite image, open the full size \"{name}\" image" : "Image favorite, ouvrir dans sa taille originale",
+    "Favorite image, open the full size \"{name}\" image" : "Image favorite, ouvrir l'image \"{name}\" en taille réelle",
     "Open the full size \"{name}\" image" : "Ouvrir l’image « {name} » dans sa taille originale",
     "Select image {imageName}" : "Sélectionner l’image {imageName}",
-    "Open the \"{name}\" folder" : "Ouvrir le dossier « {name} »",
+    "Open the \"{name}\" folder" : "Ouvrir le dossier \"{name}\"",
     "Go back" : "Revenir en arrière",
-    "Date range" : "Plage de dates",
+    "Select a custom date range" : "Sélectionner une période personnalisée",
     "Select a date range" : "Sélectionner une plage de dates",
-    "Select places" : "Sélectionner les lieux",
+    "Date range" : "Plage de dates",
+    "Select filters" : "Sélectionner des filtres",
     "Dates" : "Dates",
-    "Jump to specific date in list" : "Sauter à une date spécifique dans la liste",
+    "Jump to specific date in list" : "Aller à une date spécifique dans la liste",
     "Jump to {date}" : "Aller au {date}",
     "Add to {destination}" : "Ajouter à {destination}",
-    "The destination folder is owned by {owner}" : "La destination du dossier appartient à {owner}",
+    "The destination folder is owned by {owner}" : "Le dossier de destination appartient à {owner}",
     "There are no photos or videos yet!" : "Il n’y a pas encore de photos ou de vidéos !",
     "_{years} year ago_::_{years} years ago_" : ["Il y a {years} ans","Il y a {years} ans","Il y a {years} an(s)"],
-    "Enable squared photos view" : "Activer l’affichage en miniatures carrées",
+    "Squared photos view" : "Vue des photos en carrés",
     "Delete source directory" : "Supprimer le dossier source",
     "Pick folder" : "Choisir un dossier",
     "Select a source folder for your media" : "Sélectionner un dossier source pour vos médias",
+    "Media folders" : "Dossiers de médias",
+    "Choose the folders from where photos and videos are shown." : "Sélectionnez les dossiers d'où proviennent les photos et les vidéos affichées.",
     "All folders" : "Tous les dossiers",
     "Add a Photos source for the timelines" : "Ajouter une source de Photos pour les chronologies",
     "Add folder" : "Ajouter un dossier",
-    "Select the default upload location for your media" : "Sélectionnez l’emplacement de téléversement par défaut de vos médias",
     "Home" : "Personnel",
-    "Choose default Photos upload and Albums location" : "Choisir l’emplacement par défaut pour le téléversement des photos et des albums",
-    "Choose a different folder" : "Choisir un dossier différent ",
-    "View" : "Affichage",
-    "Media folders" : "Dossiers médias",
-    "Choose the folders from where photos and videos are shown." : "Choisir les dossiers où les photos et vidéos seront affichées.",
+    "Select the default upload location for your media" : "Sélectionnez l’emplacement de téléversement par défaut de vos médias",
     "Upload folder" : "Dossier de téléversement",
-    "Choose the folder where photos and albums are uploaded to." : "Choisir le dossier où les photos et albums sont téléversés.",
+    "General" : "Général",
     "_%n photo_::_%n photos_" : ["%n photo","%n photos","%n photos"],
     "Unselect all" : "Tout désélectionner",
     "Add photos to this album" : "Ajouter des photos à cet album",
@@ -117,14 +116,14 @@ OC.L10N.register(
     "This might take some time depending on the size of your photo library." : "Cela peut prendre un certain temps en fonction de la taille de votre photothèque.",
     "Recognized people will show up here" : "Les personnes reconnues apparaîtront ici",
     "This folder does not exist" : "Ce dossier n’existe pas",
-    "Loading folders …" : "Chargement des dossiers ...",
+    "Loading folders…" : "Chargement des dossiers…",
     "No photos in here" : "Aucune photo",
     "Taken on {date} at {time}" : "Prise le {date} à {time}",
     "This place does not have any photos or videos yet!" : "Ce lieu n’a pas encore de photos ou de vidéos !",
     "Add photos to this place" : "Ajouter des photos à ce lieu",
     "Cover photo for place {placeName}" : "Photo de couverture pour le lieu {placeName}",
     "There is no place yet!" : "Il n’y a pas encore de lieu !",
-    "Cover photo for shared album {albumName}" : "Photo de couverture pour l’album partagé {albumName}.",
+    "Cover photo for shared album {albumName}" : "Photo de couverture pour l’album partagé {albumName}",
     "Back to tags overview" : "Retour à l’aperçu des étiquettes",
     "No photos with this tag yet" : "Pas de photo avec cette étiquette pour l’instant",
     "No tags yet" : "Aucune étiquette pour le moment",
@@ -149,18 +148,41 @@ OC.L10N.register(
     "Tagged photos" : "Photos étiquetées ",
     "Tagged photo {title}" : "Photo étiquetée {title}",
     "{title}'s face" : "Visage de {title}",
+    "Last week" : "La semaine dernière",
+    "Last Month" : "Le mois dernier",
+    "Custom…" : "Personnalisé...",
     "{startDate} to {endDate}" : "{startDate} au {endDate}",
     "Details" : "Détails",
-    "Failed to rename {oldName} to {faceName}" : "Échec du renommage de {oldName} en {faceName}.",
-    "Failed to delete {faceName}" : "Échec de la suppression de {faceName}.",
-    "Failed to delete {fileId}" : "Échec de la suppression de {fileId}.",
-    "Failed to delete {fileName}" : "Échec de la suppression de {fileName}.",
-    "Failed to set favorite state for {fileId}" : "Impossible de définir l’état des favoris pour {fileId}.",
-    "Failed to set favorite state for {fileName}" : "Impossible de définir l’état des favoris pour {fileName}.",
+    "Failed to add {fileBaseName} to collection {collectionFileName}" : "Impossible d'ajouter {fileBaseName} à la collection {collectionFileName}",
+    "Failed to delete {fileBaseName}" : "Impossible de supprimer {fileBaseName}",
+    "Failed to create {collectionFileName}" : "Impossible de créer {collectionFileName}",
+    "Failed to rename {currentCollectionFileName} to {newCollectionFileName}" : "Impossible de renommer {currentCollectionFileName} en {newCollectionFileName}",
+    "Failed to update properties of {collectionFileName} with {properties}" : "Impossible de mettre à jour {collectionFileName} avec {properties}",
+    "Leave shared album" : "Quitter l'album partagé",
+    "Are you sure you want to delete {collectionName}? This action cannot be undone." : "Êtes-vous sûr de vouloir supprimer {collectionName} ? Cette action ne peut pas être annulée.",
+    "Failed to delete {collectionFileName}" : "Impossible de supprimer {collectionFileName}",
+    "Cancel" : "Annuler",
+    "Confirm" : "Confirmer",
+    "Failed to move {fileBaseName} to person {faceName}" : "Impossible de déplacer {fileBaseName} vers {faceName} ",
+    "Failed to remove {fileBaseName}" : "Impossible de supprimer {fileBaseName}",
+    "Failed to rename {oldName} to {faceName}" : "Impossible de renommer {oldName} en {faceName}",
+    "Failed to delete {faceName}" : "Impossible de supprimer {faceName}",
+    "Failed to delete {fileId}" : "Impossible de supprimer {fileId}",
+    "Failed to delete {fileName}" : "Impossible de supprimer {fileName}",
+    "Failed to set favorite state for {fileId}" : "Impossible de définir l’état favori pour {fileId}",
+    "Failed to set favorite state for {fileName}" : "Impossible de définir l’état favori pour {fileName}",
     "Could not load photos folder" : "Impossible de charger le dossier des photos",
+    "Group" : "Groupe",
+    "Remove {collaboratorLabel} from the collaborators list" : "Supprimer {collaboratorLabel} de la liste des collaborateurs",
     "Back to {folder}" : "Revenir au dossier {folder}",
     "Share this folder" : "Partager ce dossier",
-    "One of the source folders does not exists" : "L’un des dossiers source n’existe pas",
-    "Add" : "Ajouter"
+    "Enable squared photos view" : "Activer la vue des photos en carrés",
+    "Choose default Photos upload and Albums location" : "Choisir l’emplacement par défaut pour le téléversement des photos et des albums",
+    "Choose a different folder" : "Choisir un dossier différent ",
+    "View" : "Affichage",
+    "Choose the folder where photos and albums are uploaded to." : "Choisir le dossier où les photos et albums sont téléversés.",
+    "Loading folders …" : "Chargement des dossiers ...",
+    "Add" : "Ajouter",
+    "Loading folders …" : "Chargement des dossiers…"
 },
 "nplurals=3; plural=(n == 0 || n == 1) ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
