@@ -47,7 +47,7 @@ OC.L10N.register(
     "Copy public link" : "Копіювати публічне посилання",
     "Delete the public link" : "Вилучити публічне посилання",
     "Create public link share" : "Створити посилання спільного доступу",
-    "Share via public link" : "Поділіться через публічне посилання",
+    "Share via public link" : "Поділітися через публічне посилання",
     "This collection does not exist" : "Ця колекція не існує",
     "An error occurred" : "Виникла помилка",
     "No picture for this day" : "Відсутні зображення цього дня",
@@ -72,22 +72,19 @@ OC.L10N.register(
     "The destination folder is owned by {owner}" : "Власником каталогу призначення є {owner}",
     "There are no photos or videos yet!" : "Ще немає фото чи відео!",
     "_{years} year ago_::_{years} years ago_" : ["{years} рік тому","{years} років тому","{years} років тому","{years} років тому"],
-    "Enable squared photos view" : "Увімкнути перегляд фотографій у квадраті",
+    "Squared photos view" : "Прямокутний вигляд фото",
     "Delete source directory" : "Вилучити каталог джерела",
     "Pick folder" : "Вибрати каталог",
     "Select a source folder for your media" : "Виберіть каталог джерела для ваших світлин чи відеозаписів",
+    "Media folders" : "Каталоги з мультимедійним вмістом",
+    "Choose the folders from where photos and videos are shown." : "Виберіть каталоги, з яких показувати світлини та відеозаписи.",
     "All folders" : "Усі каталоги",
     "Add a Photos source for the timelines" : "Додати джерело світлин до хронології",
     "Add folder" : "Додати теку",
-    "Select the default upload location for your media" : "Виберіть типове розташування для завантаження ваших світлин чи відеозаписів",
     "Home" : "Домівка",
-    "Choose default Photos upload and Albums location" : "Виберіть типове розташування для завантаження світлин та альбомів",
-    "Choose a different folder" : "Виберіть інший каталог",
-    "View" : "Перегляд",
-    "Media folders" : "Каталоги з мультимедійним вмістом",
-    "Choose the folders from where photos and videos are shown." : "Виберіть каталоги, з яких показувати світлини та відеозаписи.",
+    "Select the default upload location for your media" : "Виберіть типове розташування для завантаження ваших світлин чи відеозаписів",
     "Upload folder" : "Завантажити каталог",
-    "Choose the folder where photos and albums are uploaded to." : "Виберіть каталог, до якого завантажувати світлини та альбоми.",
+    "General" : "Загальне",
     "_%n photo_::_%n photos_" : ["%n фото","%n фото","%n фото","%n фото"],
     "Unselect all" : "Зняти вибір",
     "Add photos to this album" : "Додайте фотографії до цього альбому",
@@ -161,7 +158,12 @@ OC.L10N.register(
     "Failed to create {collectionFileName}" : "Не вдалося створити {collectionFileName}",
     "Failed to rename {currentCollectionFileName} to {newCollectionFileName}" : "Не вдалося перейменувати {currentCollectionFileName} у {newCollectionFileName}",
     "Failed to update properties of {collectionFileName} with {properties}" : "Не вдалося оновити властивості {collectionFileName} на {properties}",
+    "Delete collection" : "Вилучити колекцію",
+    "Leave shared album" : "Вийти зі спільного альбому",
+    "Are you sure you want to delete {collectionName}? This action cannot be undone." : "Дійсно вилучити {collectionName}? Цю дію неможливо буде повернути.",
     "Failed to delete {collectionFileName}" : "Не вдалося вилучити {collectionFileName}",
+    "Cancel" : "Скасувати",
+    "Confirm" : "Підтвердити",
     "Failed to move {fileBaseName} to person {faceName}" : "Не вдалося перенести {fileBaseName} до особи {faceName}",
     "Failed to remove {fileBaseName}" : "Не вдалося вилучити {fileBaseName}",
     "Failed to rename {oldName} to {faceName}" : "Не вдалося перейменувати {oldName} у {faceName}",
@@ -175,8 +177,13 @@ OC.L10N.register(
     "Remove {collaboratorLabel} from the collaborators list" : "Вилучити {collaboratorLabel} зі списку співавторів",
     "Back to {folder}" : "Повернутися до каталогу {folder}",
     "Share this folder" : "Надати спільний доступ до каталогу",
+    "Enable squared photos view" : "Увімкнути перегляд фотографій у квадраті",
+    "Choose default Photos upload and Albums location" : "Виберіть типове розташування для завантаження світлин та альбомів",
+    "Choose a different folder" : "Виберіть інший каталог",
+    "View" : "Перегляд",
+    "Choose the folder where photos and albums are uploaded to." : "Виберіть каталог, до якого завантажувати світлини та альбоми.",
     "Loading folders …" : "Завантаження папок…",
-    "One of the source folders does not exists" : "Один з каталогів джерел відсутній",
-    "Add" : "Додати"
+    "Add" : "Додати",
+    "Loading folders …" : "Завантаження каталогів ..."
 },
 "nplurals=4; plural=(n % 1 == 0 && n % 10 == 1 && n % 100 != 11 ? 0 : n % 1 == 0 && n % 10 >= 2 && n % 10 <= 4 && (n % 100 < 12 || n % 100 > 14) ? 1 : n % 1 == 0 && (n % 10 ==0 || (n % 10 >=5 && n % 10 <=9) || (n % 100 >=11 && n % 100 <=14 )) ? 2: 3);");
