@@ -20,8 +20,11 @@ use OCP\FilesMetadata\Event\MetadataLiveEvent;
  * @template-implements IEventListener<Event|MetadataLiveEvent|MetadataBackgroundEvent>
  */
 class PlaceMetadataProvider implements IEventListener {
+
+	public const METADATA_KEY = 'photos-place';
+
 	public function __construct(
-		private MediaPlaceManager $mediaPlaceManager,
+		private readonly MediaPlaceManager $mediaPlaceManager,
 	) {
 	}
 
@@ -42,9 +45,9 @@ class PlaceMetadataProvider implements IEventListener {
 
 		if ($event instanceof MetadataBackgroundEvent) {
 			$metadata = $event->getMetadata();
-			$place = $this->mediaPlaceManager->getPlaceForFile($event->getNode()->getId());
+			$place = $this->mediaPlaceManager->getPlaceForMetadata($metadata);
 			if ($place !== null) {
-				$metadata->setString('photos-place', $place, true);
+				$metadata->setString(self::METADATA_KEY, $place, true);
 			}
 		}
 	}
