@@ -15,6 +15,9 @@ OC.L10N.register(
     "Not supported!" : "No está soportado.",
     "Press ⌘-C to copy." : "Pulsa ⌘-C para copiar.",
     "Press Ctrl-C to copy." : "Pulsa Ctrl-C para copiar.",
+    "Unknown" : "Desconocido",
+    "%1$d days, %2$d hours, %3$d minutes, %4$d seconds" : "%1$d días, %2$d horas, %3$d minutos, %4$d segundos",
+    "%1$d hours, %2$d minutes, %3$d seconds" : "%1$d horas, %2$d minutos, %3$d segundos",
     "System" : "Sistema",
     "Monitoring" : "Monitorización",
     "Monitoring app with useful server information" : "App de monitorización con información útil sobre el servidor",
@@ -63,11 +66,14 @@ OC.L10N.register(
     "PHP" : "PHP",
     "Version:" : "Versión:",
     "Memory limit:" : "Límite de memoria:",
+    "MB" : "MB",
     "Max execution time:" : "Tiempo máx. de ejecución:",
+    "seconds" : "seconds",
     "Upload max size:" : "Tamaño máx. de subida:",
     "OPcache Revalidate Frequency:" : "Frecuencia de Revalidación de OPcache:",
     "Extensions:" : "Extensiones:",
     "Unable to list extensions" : "No se pueden listar las extensiones",
+    "PHP Info:" : "PHP Info:",
     "Show phpinfo" : "Mostrar phpinfo",
     "FPM worker pool" : "Pool de workers FPM",
     "Pool name:" : "Nombre del pool:",
