@@ -1,15 +1,6 @@
 OC.L10N.register(
     "settings",
     {
-    "Unable to change password" : "Ei suuda salasõna muuta",
-    "Very weak password" : "Väga nõrk salasõna",
-    "Weak password" : "Nõrk salasõna",
-    "So-so password" : "Enam-vähem sobiv salasõna",
-    "Good password" : "Hea salasõna",
-    "Strong password" : "Väga hea salasõna",
-    "Groups" : "Grupid",
-    "Group list is empty" : "Gruppide loend on tühi",
-    "Unable to retrieve the group list" : "Gruppide loendi pärimine ebaõnnestus",
     "{actor} added you to group {group}" : "{actor} lisas sind gruppi {group}",
     "You added {user} to group {group}" : "Sa lisasid kasutaja {user} gruppi {group}",
     "{actor} added {user} to group {group}" : "{actor} lisas kasutaja {user} gruppi {group}",
@@ -40,13 +31,16 @@ OC.L10N.register(
     "Remote wipe was started on %1$s" : "Kaugkustutamine algas: %1$s",
     "Remote wipe has finished on %1$s" : "Kaugkustutamine lõppes: %1$s",
     "Your <strong>password</strong> or <strong>email</strong> was modified" : "Sinu <strong>salasõna</strong> või <strong>e-posti aadress</strong> on muudetud",
-    "Settings" : "Seaded",
+    "Settings" : "Seadistused",
     "Could not remove app." : "Rakenduse eemaldamine ei õnnestunud.",
     "Could not update app." : "Rakenduse uuendamine ei õnnestunud.",
+    "One time login" : "Ühekordse sisselogimise võimalus",
+    "QR Code login" : "QR-koodiga sisselogimine",
     "Wrong password" : "Vale salasõna",
     "Unable to change personal password" : "Isikliku salasõna muutmine ei õnnestu",
     "Saved" : "Salvestatud",
     "No Login supplied" : "Kasutajanimi on sisestamata",
+    "Unable to change password" : "Ei suuda salasõna muuta",
     "Unable to change password. Password too long." : "Salasõna muutmine ei õnnestu. Salasõna on liiga pikk.",
     "Authentication error" : "Autentimise viga",
     "Please provide an admin recovery password; otherwise, all account data will be lost." : "Palun sisesta peakasutaja taastesalasõna - vastasel juhul kaotad ligipääsu kõikidele kasutajakonto andmetele.",
@@ -60,13 +54,13 @@ OC.L10N.register(
     "Well done, %s!" : "Hästi tehtud, %s!",
     "If you received this email, the email configuration seems to be correct." : "Kui said selle kirja, näib e-posti seadistus õige.",
     "Email could not be sent. Check your mail server log" : "E-kirja saatmine ebaõnnestus. Kontrolli oma meiliserveri logi",
-    "A problem occurred while sending the email. Please revise your settings. (Error: %s)" : "E-kirja saatmisel tekkis viga. Palun vaata seaded üle. (Viga: %s)",
+    "A problem occurred while sending the email. Please revise your settings. (Error: %s)" : "E-kirja saatmisel tekkis viga. Palun vaata seadistused üle. (Viga: %s)",
     "You need to set your account email before being able to send test emails. Go to %s for that." : "Enne e-kirjade testsaatmist pead seadistama oma e-posti aadressi. Selleks vaata siia: %s.",
     "Recently active" : "Hiljuti aktiivne",
     "Disabled accounts" : "Väljalülitatud kasutajakonto",
     "Invalid account" : "Vigane kasutajakonto",
     "Invalid mail address" : "Vigane e-posti aadress",
-    "Settings saved" : "Seaded salvestatud",
+    "Settings saved" : "Seadistused on salvestatud",
     "Unable to change full name" : "Täisnime muutmine ebaõnnestus",
     "Unable to change email address" : "E-posti aadressi muutmine ebaõnnestus",
     "Unable to set invalid phone number" : "Vigase telefoninumbri lisamine pole võimalik",
@@ -99,19 +93,20 @@ OC.L10N.register(
     "Personal" : "Isiklik",
     "Administration" : "Haldus",
     "Users" : "Kasutajad",
-    "Additional settings" : "Lisaseaded",
+    "Additional settings" : "Lisaseadistused",
     "Assistant" : "Abiline",
     "Administration privileges" : "Peakasutaja õigused",
     "Groupware" : "Grupitöö",
     "Overview" : "Ülevaade",
     "Quick presets" : "Kiired eelseadistused",
-    "Basic settings" : "Põhiseaded",
+    "Basic settings" : "Põhiseadistused",
     "Sharing" : "Jagamine",
     "Availability" : "Saadavus",
     "Calendar" : "Kalender",
     "Personal info" : "Isiklik info",
     "Mobile & desktop" : "Mobiil ja töölaud",
     "Artificial Intelligence" : "Tehisintellekt",
+    "None / STARTTLS" : "Puudub / STARTTLS",
     "Email server" : "E-kirjade server",
     "Mail Providers" : "E-posti teenusepakkujad",
     "Mail provider enables sending emails directly through the user's personal email account. At present, this functionality is limited to calendar invitations. It requires Nextcloud Mail 4.1 and an email account in Nextcloud Mail that matches the user's email address in Nextcloud." : "Lisaks järgnevale üldisele valikule on võimalik ka isikliku e-postiikonto kasutamine. Hetkel toimib see võimalus vaid Nextcloudi kalendrikutsete puhul ning eelduseks on Nextcloud Mail 4.1 või suurem ning seal seadistatud e-postikonto vastab kasutaja e-postiaadressile Nextcloudi profiilis.",
@@ -141,6 +136,9 @@ OC.L10N.register(
     "Some files have not passed the integrity check. {link1} {link2}" : "Mõned failid pole läbinud andmetervikluse kontrolli. {link1} {link2}",
     "List of invalid files…" : "Vigaste failide loend…",
     "Rescan…" : "Skaneeri uuesti…",
+    "Database missing columns" : "Andmebaasis on puudu veerge",
+    "Missing optional column \"%s\" in table \"%s\"." : "Mittekohustuslik veerg „%s“ on puudu tabelist „%s“.",
+    "The database is missing some optional columns. Due to the fact that adding columns on big tables could take some time they were not added automatically when they can be optional. By running \"occ db:add-missing-columns\" those missing columns could be added manually while the instance keeps running. Once the columns are added some features might improve responsiveness or usability." : "Andmebaasist  on puudu mõned täiendavad väljad. Kuna suurtesse tabelitesse uute veergude lisamine on ressursimahukas ja kui veerg ise soovituslik, siis see tihti jäetakse automaatse lisamise puhul vahele. Kasutades käsku „occ db:add-missing-columns“ saad need veerud sobilikul hetkel ise lisada. Peale lisamistmõne funktsionaalsuse kiirus ja kasutatavus võivad paraneda.",
     "Database missing indices" : "Andmebaasis on puudu mõned indeksid",
     "Missing indices:" : "Puuduvad indeksid:",
     "\"%s\" in table \"%s\"" : "„%s“ tabelis „%s“",
@@ -165,10 +163,15 @@ OC.L10N.register(
     "Logging level configured correctly." : "Logimistase on korrektselt seadistatud",
     "Failed to write and read a value from local cache." : "Väärtuse lugemine kohalikust puhvrist ja kirjutamine sinna ei õnnestunud.",
     "Failed to write and read a value from distributed cache." : "Väärtuse lugemine hajutatud puhvrist ja kirjutamine sinna ei õnnestunud.",
+    "Mimetype migrations available" : "MIME-tüüpide (failitüüpide) uuendamine on võimalik",
+    "One or more mimetype migrations are available. Occasionally new mimetypes are added to better handle certain file types. Migrating the mimetypes take a long time on larger instances so this is not done automatically during upgrades. Use the command `occ maintenance:repair --include-expensive` to perform the migrations." : "Sul on võimalik teha üks või enam MIME-tüüpide uuendust. Vahetevahel lisame uusi MIME-tüüpe, mis tagavad failide mugavama ja parema kasutamise. Vastava uuenduse tegemiseks võib mahukates serverites kuluda palju aega ja seega seda ei tehta üldise uuenduse ajal automaatselt. Palun kasuta uuendamiseks käsku „occ maintenance:repair --include-expensive“.",
     "MySQL row format" : "MySQL-i rea vorming",
     "You are not using MySQL" : "Sa ei kasuta MySQL-i",
     "None of your tables use ROW_FORMAT=Compressed" : "Mitte ükski sinu tabelitest ei kasuta „ROW_FORMAT=Compressed“ tingimust",
     "Incorrect row format found in your database. ROW_FORMAT=Dynamic offers the best database performances for Nextcloud. Please update row format on the following list: %s." : "Sinu andmebaasis leidus vale rea vorming. Nextcloudi puhul tagab parima jõudluse „ROW_FORMAT=Dynamic“ seadistus. Palun uuenda järgnevas loendis näidatud ridade vorming: %s.",
+    "PHP APCu configuration" : "PHP APCu seadistus",
+    "Your APCu cache has been running full, consider increasing the apc.shm_size php setting." : "Sinu serveri PHP APCu puhver on on pidevalt täis. Lahenduseks palun kaalu PHP-seadistustest „apc.shm_size“ väärtuse suurendamist.",
+    "Your APCu cache is almost full at %s%%, consider increasing the apc.shm_size php setting." : "Sinu serveri PHP APCu puhver on on üsna täis (%s%%). Lahenduseks palun kaalu PHP-seadistustest „apc.shm_size“ väärtuse suurendamist.",
     "PHP default charset" : "PHP vaikimisi märgistik",
     "PHP configuration option \"default_charset\" should be UTF-8" : "PHP seadistuse „default_charset“ väärtus peab olema UTF-8",
     "PHP set_time_limit" : "PHP set_time_limit",
@@ -239,6 +242,20 @@ OC.L10N.register(
     "_Most tasks were successful in the last day._::_Most tasks were successful in the last %n days._" : ["Enamuse käskude käivitamine viimase päeva jooksul õnnestus.","Enamuse käskude käivitamine viimase %n päeva jooksul õnnestus."],
     "_A lot of tasks failed in the last day. Consider checking the nextcloud log for errors and investigating whether the AI provider apps have been set up correctly._::_A lot of tasks failed in the last %n days. Consider checking the nextcloud log for errors and investigating whether the AI provider apps have been set up correctly._" : ["Paljude käskude käivitamine viimase päeva jooksul ei õnnestunud. Vigade tuvastamiseks palun vaata Nextcloudi logidesse ja kontrolli, kas tehisaru teenusepakkujad on korrektselt seadistatud.","Paljude käskude käivitamine viimase %n päeva jooksul ei õnnestunud. Vigade tuvastamiseks palun vaata Nextcloudi logidesse ja kontrolli, kas tehisaru teenusepakkujad on korrektselt seadistatud."],
     "The PHP function \"disk_free_space\" is disabled, which prevents the check for enough space in the temporary directories." : "PHP funktsioon „disk_free_space“ pole kasutusel. Selle puudumine takistab ajutiste kaustade jaoks vajaliku andmeruumi kontrollimist.",
+    "- %.1f GiB available in %s (PHP temporary directory)" : "- %.1f GiB on saadaval kaustas „%s“ (PHP ajutine kaust)",
+    "- %.1f GiB available in %s (Nextcloud temporary directory)" : "- %.1f GiB on saadaval kaustas „%s“ (Nextcloudi ajutine kaust)",
+    "Temporary directory is correctly configured:\n%s" : "Ajutine kaust on seadistatud korrektselt:\n%s",
+    "Second factor configuration" : "Kaheastmelise autentimise seadistus",
+    "This instance has no second factor provider available." : "Selles serveris pole kaheastmelise autentimise teenusepakkujaid saadaval.",
+    "Second factor providers are available but two-factor authentication is not enforced." : "Kaheastmelise autentimise teenusepakkujad on saadaval, kuid nende kasutamine pole kohustuslik.",
+    "Second factor providers are available and enforced: %s." : "Kaheastmelise autentimise teenusepakkujad on saadaval ning nende kasutamine on kohustuslik: %s.",
+    ".well-known URLs" : "„.well-known“ võrguaadressid",
+    "`check_for_working_wellknown_setup` is set to false in your configuration, so this check was skipped." : "Kuna „check_for_working_wellknown_setup“ seadistus on selle serveri seadistustes olekus „false“, siis on vastav kontroll jäänud vahele.",
+    "Could not check that your web server serves `.well-known` correctly. Please check manually." : "Ei õnnestunud kontrollida, kas sinu veebiserver edastab „.well-known“ võrguaadresse korrektselt. Palun kontrolli seda käsitsi või muu teenusega.",
+    "Your web server is not properly set up to resolve `.well-known` URLs, failed on:\n`%s`" : "Sinu veebiserver ei edasta „.well-known“ võrguaadresse korrektselt, viga tekkis siin:\n„%s“",
+    "Your server is correctly configured to serve `.well-known` URLs." : "Sinu veebiserver edastab „.well-known“ võrguaadresse korrektselt.",
+    "Font file loading" : "Kirjatüübi fail on laadimas",
+    "Could not check for {extension} loading support. Please check manually if your webserver serves `.{extension}` files." : "Ei õnnestunud kontrollida, kas „{extension}“-failide tugi toimib. Palun kontrolli käsitsi, kas sinu veebiserver suudab edastada „{extension}“ faile.",
     "Profile information" : "Kasutajaprofiili teave",
     "Profile picture, full name, email, phone number, address, website, Twitter, organisation, role, headline, biography, and whether your profile is enabled" : "Profiilipilt, täisnimi, e-posti aadress, telefoninumber, aadress, veebisait, Twitteri konto, organisatsioon, roll, alapealkiri, elulugu ja asjaolu, kas sinu profiil on kasutusel.",
     "Nextcloud settings" : "Nextcloudi seadistused",
@@ -276,8 +293,8 @@ OC.L10N.register(
     "Shares with guessable tokens may be accessed easily" : "Ligipääs ennustatava tunnusloaga jaosmeediale on väga lihtne",
     "Limit sharing based on groups" : "Piira jagamist gruppide alusel",
     "Allow sharing for everyone (default)" : "Luba jagamine kõikidele (vaikimisi)",
-    "Exclude some groups from sharing" : "Välista mõned grupid jagamisest",
-    "Limit sharing to some groups" : "Piira jagamist mõnede gruppidega",
+    "Exclude some groups" : "Välista mõned grupid",
+    "Allow some groups" : "Luba mõned grupid",
     "Groups allowed to share" : "Grupid, millel on jagamine lubatud",
     "Groups excluded from sharing" : "Jagamisest välistatud grupid",
     "Not allowed groups will still be able to receive shares, but not to initiate them." : "Mittelubatud gruppide liikmed saavad vastu võtta jagamisi, kuid ise jagamisi algatada ei saa.",
@@ -295,6 +312,9 @@ OC.L10N.register(
     "Privacy settings for sharing" : "Jagamise privaatsusseadistused",
     "Sharing autocompletion restrictions" : "Automaattäitmise piirangute jagamine",
     "Also allow autocompletion on full match of the user ID" : "Lisaks luba automaatset täitmist kasutajatunnuse täisvaste puhul",
+    "Also allow autocompletion on full match of the display name" : "Lisaks luba automaatset täitmist kuvatava nime täisvaste puhul",
+    "Also allow autocompletion on full match of the user email" : "Lisaks luba automaatset täitmist e-posti aadressi täisvaste puhul",
+    "Do not use second user displayname for full match" : "Ära pruugi kasutaja teist kuvatavat nime täisvaste otsimiseks",
     "Show disclaimer text on the public link upload page (only shown when the file list is hidden)" : "Kuva avaliku lingiga üleslaadimise lehel lahtiütluste tekst (vaid siis, kui failide loend on peidetud)",
     "Disclaimer text" : "Vastutusest lahtiütluse tekst",
     "This text will be shown on the public link upload page when the file list is hidden." : "Seda teksti näidatakse avaliku lingiga üleslaadimise lehel kui failide loend on peidetud.",
@@ -322,8 +342,16 @@ OC.L10N.register(
     "This app is supported via your current Nextcloud subscription." : "See rakendus on toetatud sinu praeguses Nextcloudi tellimuses. ",
     "Featured apps are developed by and within the community. They offer central functionality and are ready for production use." : "Esiletõstetud rakendusi arendatakse kogukonna poolt. Nad pakuvad võimalust kasutada olulist funktsionaalsust ning on sobilikud igapäevaseks kasutuseks.",
     "Community rating: {score}/5" : "Kogukonna hinnang: {score}/5",
+    "Office suite switching is managed through the Nextcloud All-in-One interface." : "Kontoritarkvarapakettide vahetamine toimub Nextcloudi kõik-ühes (All-in-One) kasutajaliidesest.",
+    "Please use the AIO interface to switch between office suites." : "Paluna kasuta kontoritarkvarapakettide vahetamiseks Nextcloudi kõik-ühes (All-in-One) kasutajaliidesest.",
+    "Select your preferred office suite. Please note that installing requires manual server setup." : "Vali eelistatud kontoritarkvarapakett. Palun arvesta, et paigaldamine eeldab ka serveri käsitsi seadistamist.",
+    "installed" : "paigaldatud",
+    "Learn more" : "Lisateave",
+    "Disable office suites" : "Lülita kontoritarkvarapaketid välja",
     "Disable all" : "Lülita kõik välja",
     "Download and enable all" : "Laadi kõik alla ja võta kasutusele",
+    "All office suites disabled" : "Kõik kontoritarkvarapaketid on lülitatud välja",
+    "{name} enabled" : "{name} on kasutusel",
     "All apps are up-to-date." : "Kõik rakendused on uuendatud",
     "Icon" : "Ikoon",
     "Name" : "Nimi",
@@ -336,6 +364,7 @@ OC.L10N.register(
     "_Update_::_Update all_" : ["Uuenda","Uuenda kõik"],
     "Failed to load groups" : "Gruppe ei õnnestunud laadida",
     "Failed to create group" : "Grupi loomine ei õnnestunud",
+    "Groups" : "Grupid",
     "Creating group…" : "Loon gruppi…",
     "Create group" : "Loo grupp",
     "Group name" : "Grupi nimi",
@@ -363,7 +392,6 @@ OC.L10N.register(
     "Advanced deploy options" : "Kasutuselevõtmise lisavalikud",
     "Edit ExApp deploy options before installation" : "Muuda ExApp konteineri seadistuse enne paigaldamist",
     "Configured ExApp deploy options. Can be set only during installation" : "ExApp'i konteineri seadistuse valikud. Neid saab määrata vaid paigalduse ajal",
-    "Learn more" : "Lisateave",
     "Environment variables" : "Keskonnamuutujad",
     "ExApp container environment variables" : "ExApp konteineri keskonnamuutujad",
     "No environment variables defined" : "Ühtegi keskonnamuutujat pole defineeritud",
@@ -409,7 +437,7 @@ OC.L10N.register(
     "Documentation" : "Dokumentatsioon",
     "Interact" : "Suhtle meiega",
     "Report a bug" : "Teata veast",
-    "Request feature" : "Palu arendajatel funktsionaalsuse lisamist",
+    "Request feature" : "Palu arendajatelt funktsionaalsuse lisamist",
     "Ask questions or discuss" : "Küsi nõu või aruta",
     "Rate the app" : "Hinda rakendust",
     "Rate" : "Hinda",
@@ -696,6 +724,27 @@ OC.L10N.register(
     "No devices configured." : "Ühtegi seadet pole seadistatud.",
     "The following devices are configured for your account:" : "Järgmised seadmed on seadistatud kasutama sinu kontot:",
     "Your browser does not support WebAuthn." : "Sinu veebibrauseril puudub WebAuthni tugi.",
+    "Email sent successfully" : "E-kirja saatmine õnnestus",
+    "Failed to send email" : "E-kirja saatmine ei õnnestunud",
+    "Failed to save email settings" : "E-posti seadistuste salvestamine ei õnnestunud",
+    "It is important to set up this server to be able to send emails, like for password reset and notifications." : "On oluline, et e-kirjade saatmise võimekus on seadistatud. Seda kasutatakse näiteks salasõnade lähtestamiseks ja teavituste saatmiseks.",
+    "The server configuration is read-only so the mail settings cannot be changed using the web interface." : "Serveri seadistused on vaid lugemisolekus ja neid ei saa veebiliidesest muuta.",
+    "Mail delivery is disabled by instance config \"{config}\"." : "E-kirjade edastamine on keelatud serveri seadistuse „{config}“ alusel.",
+    "Send mode" : "Saatmise viis",
+    "Encryption" : "Krüpteerimine",
+    "Sendmail mode" : "Sendmaili režiim",
+    "Disable certificate verification (insecure)" : "Lülita välja sertifikaadi kontroll (ebaturvaline)",
+    "From address" : "Saatja aadress",
+    "Domain" : "Domeen",
+    "Server address" : "Serveri aadress",
+    "Host" : "Host",
+    "Port" : "Port",
+    "Authentication" : "Autentimine",
+    "Authentication required" : "Autentimine on vajalik",
+    "Sending test email…" : "Saadan testkirja…",
+    "Send test email" : "Saada testkiri",
+    "Saving…" : "Salvestan...",
+    "Save settings" : "Salvesta seadistused",
     "Please double check the {linkStartInstallationGuides}installation guides{linkEnd}, and check for any errors or warnings in the {linkStartLog}log{linkEnd}." : "Palun vaata uuesti {linkStartInstallationGuides}paigaldusjuhendit{linkEnd} ning kontrolli {linkStartLog}logides{linkEnd} leiduvaid vigu ja hoiatusi.",
     "Check the security of your {productName} over {linkStart}our security scan{linkEnd}." : "Testi selle {productName}i serveri turvalisust {linkStart}meie turvakontrolliga{linkEnd}.",
     "Security & setup warnings" : "Turva- ja paigalduse hoiatused",
@@ -711,7 +760,6 @@ OC.L10N.register(
     "App Store" : "Rakendustepood",
     "Loading app list" : "Laadin rakenduste loendit",
     "Loading categories" : "Laadin kategooriaid",
-    "Developer documentation ↗" : "Dokumentatsioon arendajatele ↗",
     "Version {version}, {license}-licensed" : "Versioon {version}, avaldatud {license} litsentsi alusel",
     "Version {version}" : "Versioon {version}",
     "Failed to save selected preset." : "Valitud eelseadistuse salvestamine ei õnnestunud.",
@@ -721,26 +769,24 @@ OC.L10N.register(
     "Admins" : "Peakasutajad",
     "Account group: {group}" : "Kasutajakontode grupp: {group}",
     "Account management" : "Kasutajakontode haldus",
-    "Sending…" : "Saadan...",
-    "Email sent" : "E-kiri on saadetud",
-    "For performance reasons, when you enable encryption on a {productName} server only new and changed files are encrypted." : "Kui võtad {productName}i serveris krüptimise kasutsele, siis jõudlusest johtuvalt krüptitakse vaid uusi ja muudetud faile.",
+    "For performance reasons, when you enable encryption on a {productName} server only new and changed files are encrypted." : "Kui võtad {productName}i serveris krüptimise kasutusele, siis jõudlusest johtuvalt krüptitakse vaid uusi ja muudetud faile.",
     "Location" : "Asukoht",
     "Profile picture" : "Profiilipilt",
     "About" : "Teave",
     "Date of birth" : "Sünnikuupäev",
-    "Full name" : "Täielik nimi",
+    "Full name" : "Täisnimi",
     "Additional email" : "Täiendav e-post",
-    "Fediverse (e.g. Mastodon)" : "Fediverse (nt. Mastodon)",
+    "Fediverse (e.g. Mastodon)" : "Födiversum (nt. Mastodon)",
     "Headline" : "Alapealkiri",
     "Organisation" : "Organisatsioon",
     "Phone number" : "Telefoninumber",
     "Pronouns" : "Asesõna pöördumisel",
     "Role" : "Roll",
-    "X (formerly Twitter)" : "X (varasemalt Twitter)",
+    "X (formerly Twitter)" : "X (varem Twitter)",
     "Bluesky" : "Bluesky",
-    "Website" : "Veebileht",
+    "Website" : "Veebisait",
     "Profile visibility" : "Profiili nähtavus",
-    "Locale" : "Kasutuskoht",
+    "Locale" : "Lokaat",
     "First day of week" : "Nädala esimene päev",
     "timezone" : "ajavöönd",
     "Private" : "Privaatne",
@@ -762,6 +808,17 @@ OC.L10N.register(
     "App bundles" : "Rakenduste kogumikud",
     "Featured apps" : "Esiletõstetud rakendused",
     "Supported apps" : "Toetatud rakendused",
+    "Best Nextcloud integration" : "Parim Nextcloudi lõiming",
+    "Open source" : "Avatud lähtekoodiga",
+    "Good performance" : "Suurepärane jõudlus",
+    "Best security: documents never leave your server" : "Parim turvalisus: dokumendid ei lahku sinu serverist.",
+    "Best ODF compatibility" : "Parim ühilduvus ODF-failidega",
+    "Best support for legacy files" : "Parim pärandfailide tugi",
+    "Good Nextcloud integration" : "Hea Nextcloudi lõiming",
+    "Open core" : "Avatud lähtekoodiga tuum",
+    "Best performance" : "Parim jõudlus",
+    "Limited ODF compatibility" : "Piiratud ühilduvus ODF-failidega",
+    "Best Microsoft compatibility" : "Parim ühilduvus Microsoftiga",
     "Show to everyone" : "Näita kõigile",
     "Show to logged in accounts only" : "Näita vaid sisseloginud kasutajatele",
     "Hide" : "Peida",
@@ -801,39 +858,31 @@ OC.L10N.register(
     "General documentation" : "Üldjuhendid",
     "Legal notice" : "Juriidiline teave",
     "Privacy policy" : "Privaatsusreeglid",
-    "None/STARTTLS" : "Puudub/STARTTLS",
-    "SSL" : "SSL",
-    "Open documentation" : "Ava dokumentatsioon",
-    "It is important to set up this server to be able to send emails, like for password reset and notifications." : "On oluline, et e-kirjade saatmise võimekus on seadistatud. Seda kasutatakse näiteks salasõnade lähtestamiseks ja teavituste saatmiseks.",
-    "Send mode" : "Saatmise viis",
-    "Encryption" : "Krüpteerimine",
-    "Sendmail mode" : "Sendmaili režiim",
-    "From address" : "Saatja aadress",
-    "Server address" : "Serveri aadress",
-    "Port" : "Port",
-    "Authentication" : "Autentimine",
-    "Authentication required" : "Autentimine on vajalik",
-    "Credentials" : "Kasutajatunnused",
-    "SMTP Login" : "SMTP kasutajanimi",
-    "SMTP Password" : "SMTP salasõna",
-    "Save" : "Salvesta",
-    "Test and verify email settings" : "Testi ja kontrolli e-posti seadistusi",
     "Reasons to use Nextcloud in your organization" : "Põhjused, miks peaksid Nextcloudi kasutama oma organisatsioonis",
     "Developed by the {communityopen}Nextcloud community{linkclose}, the {githubopen}source code{linkclose} is licensed under the {licenseopen}AGPL{linkclose}." : "Arendajaks on {communityopen}Nextcloudi kogukond{linkclose},  {githubopen}lähtekood{linkclose} on avaldatud {licenseopen}GNU AGPL{linkclose} litsentsi alusel.",
     "Like our Facebook page" : "Märgi meie Facebooki leht meeldivaks",
-    "Follow us on X" : "Jälgi meid X-is",
     "Follow us on Bluesky" : "Jälgi meid Bluesky's",
     "Follow us on Mastodon" : "Jälgi meid Mastodonis",
     "Check out our blog" : "Loe meie ajaveebi",
     "Subscribe to our newsletter" : "Telli meie uudiskiri",
     "This community release of Nextcloud is unsupported and instant notifications are unavailable." : "See Nextcloudi kogukonnaversioon pole toetatud ja kiirteavitused pole saadaval.",
+    "Open documentation" : "Ava dokumentatsioon",
     "Use a second factor besides your password to increase security for your account." : "Sinu kasutajakonto turvalisuse parandamiseks kasuta lisaks oma salasõnale ka teist autentimisvõimalust.",
     "If you use third party applications to connect to Nextcloud, please make sure to create and configure an app password for each before enabling second factor authentication." : "Kui kasutad kolmanda osapoole rakenduses Nextcloudi ühendust, siis palun taga, et sa lood ja seadistad rakenduse salasõna enne kaheastmelise autentimise kasutusele võtmist.",
+    "Very weak password" : "Väga nõrk salasõna",
+    "Weak password" : "Nõrk salasõna",
+    "So-so password" : "Enam-vähem sobiv salasõna",
+    "Good password" : "Hea salasõna",
+    "Strong password" : "Väga hea salasõna",
+    "Group list is empty" : "Gruppide loend on tühi",
+    "Unable to retrieve the group list" : "Gruppide loendi pärimine ei õnnestunud",
     "Logged in account must be a subadmin" : "Sisselogitud kasutajakonto peab olema peakasutajate alamgrupi liige",
     "- The `%1$s` HTTP header does not contain `%2$s`. This is a potential security or privacy risk, as it is recommended to adjust this setting accordingly." : "- HTTP päisekirje „%1$s“ sisus puudub „%2$s“. See on võimalik turva- ja privaatsusrisk ning me soovitame, et teed vastava muudatuse.",
     "_No scheduled tasks in the last %n hour._::_No scheduled tasks in the last %n hours._" : ["Viimase %n tunni jooksul pole olnud ühtegi ajastatud ülesannet.","Viimase %n tunni jooksul pole olnud ühtegi ajastatud ülesannet."],
     "_The task pickup speed has been ok in the last %n hour._::_The task pickup speed has been ok in the last %n hours._" : ["Ülesannete töötlemise kiirus on viimase %n tunni jooksul olnud mõistlik.","Ülesannete töötlemise kiirus on viimase %n tunni jooksul olnud mõistlik."],
     "_The task pickup speed has been slow in the last %n hour. Many tasks took longer than 4 minutes to be picked up. Consider setting up a worker to process tasks in the background._::_The task pickup speed has been slow in the last %n hours. Many tasks took longer than 4 minutes to be picked up. Consider setting up a worker to process tasks in the background._" : ["Ülesannete töötlemise kiirus on viimase %n tunni jooksul olnud aeglane. Paljude ülesannete töölepanekuks kulus enam, kui 4 minutit. Palun kaalu võimalust, et ülesannete töötlemiseks seadistad taustal töötava protsessihalduri.","Ülesannete töötlemise kiirus on viimase %n tunni jooksul olnud aeglane. Paljude ülesannete töölepanekuks kulus enam, kui 4 minutit. Palun kaalu võimalust, et ülesannete töötlemiseks seadistad taustal töötava protsessihalduri."],
+    "Exclude some groups from sharing" : "Välista mõned grupid jagamisest",
+    "Limit sharing to some groups" : "Piira jagamist mõnede gruppidega",
     "Also allow autocompletion on full match of the user id" : "Lisaks luba automaatset täitmist kasutajatunnuse täisvaste puhul",
     "This app has no minimum Nextcloud version assigned. This will be an error in the future." : "Sellel rakendusel pole määratud minimaalset Nextcloudi versiooni. See põhjustab tulevikus veateateid.",
     "This app has no maximum Nextcloud version assigned. This will be an error in the future." : "Sellel rakendusel pole määratud maksimaalset Nextcloudi versiooni. See põhjustab tulevikus veateateid.",
@@ -844,10 +893,20 @@ OC.L10N.register(
     "Failed to load subadmin groups with details" : "Alamgruppe koos üksikasjadega ei õnnestunud laadida",
     "Loading account …" : "Laadin kasutajakontot…",
     "Adding your device …" : "Lisan sinu seadet…",
+    "Developer documentation ↗" : "Dokumentatsioon arendajatele ↗",
+    "Sending…" : "Saadan...",
+    "Email sent" : "E-kiri on saadetud",
     "For performance reasons, when you enable encryption on a Nextcloud server only new and changed files are encrypted." : "Kui võtad Nextcloudi serveris krüptimise kasutsele, siis jõudlusest johtuvalt krüptitakse vaid uusi ja muudetud faile.",
     "{progress}% Deploying …" : "Võtan kasutusele {progress}%…",
     "{progress}% Initializing …" : "Valmendan {progress}%…",
     "This app is not marked as compatible with your Nextcloud version. If you continue you will still be able to install the app. Note that the app might not work as expected." : "See rakendus pole märgitud ühilduvaks sinu Nextcloudi serveri versiooniga. Kui jätkad, siis saad ta ikkagi paigaldada, aga palun arvesta, et ta ei pruugi toimida ootuspäraselt.",
+    "None/STARTTLS" : "Puudub/STARTTLS",
+    "SSL" : "SSL",
+    "Credentials" : "Kasutajatunnused",
+    "SMTP Login" : "SMTP kasutajanimi",
+    "SMTP Password" : "SMTP salasõna",
+    "Save" : "Salvesta",
+    "Test and verify email settings" : "Testi ja kontrolli e-posti seadistusi",
     "It's important for the security and performance of your instance that everything is configured correctly. To help you with that we are doing some automatic checks. Please see the linked documentation for more information." : "Sinu serveri turvalisuse ja jõudluse jaoks on oluline, et kõik oleks korrektselt seadistatud. Sinu aitamiseks käivitame mõned automaatsed testid ja kontrollid. Lisateavet leiad viidatud juhendist.",
     "Checking for system and security issues." : "Kontrollin süsteemivigade ja turvaprobleemide olemasolu.",
     "Please double check the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%1$s\">installation guides ↗</a>, and check for any errors or warnings in the <a href=\"%2$s\">log</a>." : "Palun vaata uuesti <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%1$s\">paigaldusjuhendit ↗</a> ning kontrolli <a href=\"%2$s\">logides</a> leiduvaid vigu ja hoiatusi.",
