@@ -1,25 +1,6 @@
 OC.L10N.register(
     "settings",
     {
-    "Private" : "خصوصی",
-    "Only visible to people matched via phone number integration through Talk on mobile" : "نمایان تنها برای افرادی که با یکپارچگی شماره تلفن از طریق Talk روی تلفن همراه مطابقند",
-    "Local" : "محلی",
-    "Only visible to people on this instance and guests" : "نمایان تنها برای افراد روی این نمونه و میهانان",
-    "Federated" : "همگانی",
-    "Only synchronize to trusted servers" : "هم‌گام سازی تنها با کارسازهای مورد اعتماد",
-    "Published" : "منتشر شده",
-    "Synchronize to trusted servers and the global and public address book" : "هم‌گام سازی با کارسازهای مورد اعتماد و دفترچه نشانی‌های عمومی",
-    "Verify" : "تأیید",
-    "Verifying …" : "تأیید کردن…",
-    "Unable to change password" : "نمی‌توان رمز را تغییر داد",
-    "Very weak password" : "رمز عبور بسیار ضعیف",
-    "Weak password" : "رمز عبور ضعیف",
-    "So-so password" : "رمز عبور متوسط",
-    "Good password" : "رمز عبور خوب",
-    "Strong password" : "رمز عبور قوی",
-    "Groups" : "گروه ها",
-    "Group list is empty" : "سیاههٔ گروه‌ها خالیست",
-    "Unable to retrieve the group list" : "ناتوان در گرفتن سیاهٔ گروه‌ها",
     "{actor} added you to group {group}" : "{actor} به گروه {group} افزودتان",
     "You added {user} to group {group}" : "{user} را به گروه {group} افزودید",
     "{actor} added {user} to group {group}" : "{actor} کاربر {user} را به گروه {group} افزود",
@@ -56,6 +37,7 @@ OC.L10N.register(
     "Wrong password" : "رمز عبور اشتباه است",
     "Unable to change personal password" : "نمی‌توان گذرواژه شخصی را تغییر داد",
     "Saved" : "ذخیره شد",
+    "Unable to change password" : "نمی‌توان رمز را تغییر داد",
     "Unable to change password. Password too long." : "Unable to change password. Password too long.",
     "Authentication error" : "خطا در اعتبار سنجی",
     "Wrong admin recovery password. Please check the password and try again." : "رمز مدیریتی بازیابی غلط است. لطفاً رمز را کنترل کرده و دوباره امتحان نمایید.",
@@ -102,7 +84,6 @@ OC.L10N.register(
     "Administration" : "مدیریت",
     "Users" : "کاربران",
     "Additional settings" : "تنظیمات اضافی",
-    "Artificial Intelligence" : "هوش مصنوعی",
     "Administration privileges" : "اجازه‌های مدیریتی",
     "Groupware" : "کار گروهی",
     "Overview" : "نمای کلّی",
@@ -112,10 +93,13 @@ OC.L10N.register(
     "Calendar" : "تقویم",
     "Personal info" : "اطّلاعات شخصی",
     "Mobile & desktop" : "همراه و میزکار",
+    "Artificial Intelligence" : "هوش مصنوعی",
     "Email server" : "سرور ایمیل",
     "Background jobs" : "کارهای پس‌زمینه",
     "Unlimited" : "نامحدود",
     "Verifying" : "تآیید کردن",
+    "Verifying …" : "تأیید کردن…",
+    "Verify" : "تأیید",
     "Your data directory and files are probably accessible from the internet. The .htaccess file is not working. It is strongly recommended that you configure your web server so that the data directory is no longer accessible, or move the data directory outside the web server document root." : "Your data directory and files are probably accessible from the internet. The .htaccess file is not working. It is strongly recommended that you configure your web server so that the data directory is no longer accessible, or move the data directory outside the web server document root.",
     "The database is missing some optional columns. Due to the fact that adding columns on big tables could take some time they were not added automatically when they can be optional. By running \"occ db:add-missing-columns\" those missing columns could be added manually while the instance keeps running. Once the columns are added some features might improve responsiveness or usability." : "The database is missing some optional columns. Due to the fact that adding columns on big tables could take some time they were not added automatically when they can be optional. By running \"occ db:add-missing-columns\" those missing columns could be added manually while the instance keeps running. Once the columns are added some features might improve responsiveness or usability.",
     "The database is missing some primary keys. Due to the fact that adding primary keys on big tables could take some time they were not added automatically. By running \"occ db:add-missing-primary-keys\" those missing primary keys could be added manually while the instance keeps running." : "The database is missing some primary keys. Due to the fact that adding primary keys on big tables could take some time they were not added automatically. By running \"occ db:add-missing-primary-keys\" those missing primary keys could be added manually while the instance keeps running.",
@@ -123,6 +107,9 @@ OC.L10N.register(
     "This server has no working internet connection: Multiple endpoints could not be reached. This means that some of the features like mounting external storage, notifications about updates or installation of third-party apps will not work. Accessing files remotely and sending of notification emails might not work, either. Establish a connection from this server to the internet to enjoy all features." : "This server has no working internet connection: Multiple endpoints could not be reached. This means that some of the features like mounting external storage, notifications about updates or installation of third-party apps will not work. Accessing files remotely and sending of notification emails might not work, either. Establish a connection from this server to the internet to enjoy all features.",
     "Disabled" : "غیرفعال شده",
     "The old server-side-encryption format is enabled. We recommend disabling this." : "The old server-side-encryption format is enabled. We recommend disabling this.",
+    "Logging level" : "سطح گزارش‌دهی",
+    "The logging level is set to debug level. Use debug level only when you have a problem to diagnose, and then reset your log level to a less-verbose level as it outputs a lot of information, and can affect your server performance." : "سطح گزارش‌دهی روی حالت اشکال‌زدایی (debug) تنظیم شده است. از سطح اشکال‌زدایی تنها زمانی استفاده کنید که مشکلی برای تشخیص دارید، سپس سطح گزارش خود را به حالت کم‌حجم‌تری بازگردانید زیرا این حالت حجم زیادی از اطلاعات را خروجی می‌دهد و می‌تواند بر عملکرد نمونهٔ شما تأثیر منفی بگذارد.",
+    "Logging level configured correctly." : "سطح گزارش‌دهی به درستی تنظیم شد.",
     "The PHP function \"set_time_limit\" is not available. This could result in scripts being halted mid-execution, breaking your installation. Enabling this function is strongly recommended." : "The PHP function \"set_time_limit\" is not available. This could result in scripts being halted mid-execution, breaking your installation. Enabling this function is strongly recommended.",
     "Supported" : "پشتیبانی شده",
     "PHP does not seem to be setup properly to query system environment variables. The test with getenv(\"PATH\") only returns an empty response." : "PHP does not seem to be setup properly to query system environment variables. The test with getenv(\"PATH\") only returns an empty response.",
@@ -133,13 +120,13 @@ OC.L10N.register(
     "Your database does not run with \"READ COMMITTED\" transaction isolation level. This can cause problems when multiple actions are executed in parallel." : "Your database does not run with \"READ COMMITTED\" transaction isolation level. This can cause problems when multiple actions are executed in parallel.",
     "Profile information" : "اطلاعات نمایه",
     "Nextcloud settings" : "تنظیمات نکست کلود",
-    "Task:" : "Task:",
     "Enable" : "فعال",
     "Machine translation" : "Machine translation",
     "Machine translation can be implemented by different apps. Here you can define the precedence of the machine translation apps you have installed at the moment." : "Machine translation can be implemented by different apps. Here you can define the precedence of the machine translation apps you have installed at the moment.",
     "Image generation" : "Image generation",
     "Text processing" : "Text processing",
     "Text processing tasks can be implemented by different apps. Here you can set which app should be used for which task." : "Text processing tasks can be implemented by different apps. Here you can set which app should be used for which task.",
+    "Task:" : "Task:",
     "Here you can decide which group can access certain sections of the administration settings." : "Here you can decide which group can access certain sections of the administration settings.",
     "Unable to modify setting" : "Unable to modify setting",
     "None" : "هیچ‌کدام",
@@ -153,8 +140,6 @@ OC.L10N.register(
     "Enforce password protection" : "اجبار برای محافظت توسط رمز عبور",
     "Enforce expiration date" : "اعمال تاریخ اتمام اشتراک گذاری",
     "Set default expiration date for shares to other servers" : "Set default expiration date for shares to other servers",
-    "If autocompletion \"same group\" and \"phone number integration\" are enabled a match in either is enough to show the user." : "If autocompletion \"same group\" and \"phone number integration\" are enabled a match in either is enough to show the user.",
-    "Allow autocompletion when entering the full name or email address (ignoring missing phonebook match and being in the same group)" : "Allow autocompletion when entering the full name or email address (ignoring missing phonebook match and being in the same group)",
     "Show disclaimer text on the public link upload page (only shown when the file list is hidden)" : "Show disclaimer text on the public link upload page (only shown when the file list is hidden)",
     "This text will be shown on the public link upload page when the file list is hidden." : "این متن هنگام پنهان کردن لیست پرونده در صفحه بارگذاری پیوند عمومی نشان داده می شود.",
     "Default share permissions" : "مجوزهای اشتراکی پیش فرض",
@@ -167,11 +152,13 @@ OC.L10N.register(
     "Two-factor authentication is not enforced for members of the following groups." : "Two-factor authentication is not enforced for members of the following groups.",
     "Excluded groups" : "گروه‌های مستثنی",
     "Save changes" : "ذخیرهٔ تغییرات",
+    "Default" : "پیش‌فرض",
     "Update to {update}" : "به‌روز رسانی به {update} ",
     "Remove" : "برداشتن",
     "Featured" : "برگزیده",
     "This app is supported via your current Nextcloud subscription." : "این کاره از طریق اشتراک فعلی نکست کلودتان پشتیبانی می شود.",
     "Featured apps are developed by and within the community. They offer central functionality and are ready for production use." : "برنامه‌های برگزیده توسط و در داخل جامعه توسعه داده می‌شوند. این برنامه‌ها، عملکردهای مرکزی را ارائه می‌دهند و برای استفاده نهایی آماده هستند.",
+    "Learn more" : "بیشتر بدانید",
     "Disable all" : "از کار انداختن همه",
     "All apps are up-to-date." : "تمامی کاره‌ها به‌روزند.",
     "Icon" : "Icon",
@@ -183,31 +170,31 @@ OC.L10N.register(
     "No apps found for your version" : "هیچ برنامه‌ای برای نسخه‌ی شما یافت نشد",
     "_%n app has an update available_::_%n apps have an update available_" : ["۱ کاره به‌روز رسانی دارد","%n کاره به‌روز رسانی دارند"],
     "_Update_::_Update all_" : ["به‌روز رسانی","به‌روز رسانی همه"],
+    "Groups" : "گروه ها",
+    "Group name" : "نام گروه",
+    "Loading groups…" : "Loading groups…",
     "Loading" : "Loading",
     "Daemon" : "فرایندهای پس زمینه",
     "Type" : "نوع",
-    "Learn more" : "بیشتر بدانید",
     "Confirm" : "تأیید",
     "Cancel" : "منصرف شدن",
     "Description" : "شرح",
     "View in store" : "نمایش در فروشگاه",
     "Visit website" : "سر زدن به پایگاه وب",
-    "Admin documentation" : "مستندات مدیر",
-    "Developer documentation" : "مستندات توسعه‌دهندگان",
+    "Admin documentation" : "مستندات مدیریتی",
+    "Developer documentation" : "مستندات توسعه",
     "Details" : "جزییات",
     "All" : "همه",
-    "Limit app usage to groups" : "محدودیت استفاده از کاره به گروه‌ها",
+    "Limit app usage to groups" : "محدودیت استفاده از برنامه به گروه‌ها",
     "No results" : "بدون نتیجه",
     "Update to {version}" : "به‌روز رسانی به {version}",
-    "This app has no minimum Nextcloud version assigned. This will be an error in the future." : "این برنامه حداقل دارای نسخه بعدی نکست کلود است. این یک خطا در آینده خواهد بود.",
-    "This app has no maximum Nextcloud version assigned. This will be an error in the future." : "این برنامه حداکثر نسخه نکست کلود اختصاصی ندارد. این یک خطا در آینده خواهد بود.",
     "This app cannot be installed because the following dependencies are not fulfilled:" : "امکان نصب این برنامه وجود ندارد، این پیش‌نیازها انجام نشده‌اند:",
     "Author" : "نویسنده",
     "Categories" : "دسته‌ها",
     "Resources" : "منابع",
     "Documentation" : "مستندسازی",
     "Interact" : "تعامل",
-    "Report a bug" : "گزارش یک خطا",
+    "Report a bug" : "گزارش یک اشکال",
     "Request feature" : "درخواست ویژگی",
     "Ask questions or discuss" : "پرسش یا بحث",
     "Rate" : "رتبه‌بندی",
@@ -230,7 +217,7 @@ OC.L10N.register(
     "Devices & sessions" : "دستگاه ها و نشست ها",
     "Web, desktop and mobile clients currently logged in to your account." : "لیست دستگاه ها و نشست های فعال وارد شده با اکانت شما",
     "Error while creating device token" : "هنگام ایجاد نشانه وسیله خطایی رخ داد",
-    "App name" : "نام برنامه",
+    "App name" : "نام کاره",
     "Create new app password" : "ساختن رمزعبور برنامه جدید ",
     "Could not copy app password. Please copy it manually." : "نمی توان رمزعبور برنامه را کپی کرد. لطفاً آن را به صورت دستی کپی کنید.",
     "Login" : "ورود",
@@ -264,10 +251,9 @@ OC.L10N.register(
     "This is the final warning: Do you really want to enable encryption?" : "این آخرین اخطار است: آیا می‌خواهید رمزگذاری را فعال کنید ؟",
     "Submit" : "ارسال",
     "Rename group" : "Rename group",
-    "Remove group" : "برداشتن گروه",
     "Current password" : "گذرواژه کنونی",
     "New password" : "گذرواژه جدید",
-    "Change password" : "تغییر گذر واژه",
+    "Change password" : "تغییر گذرواژه",
     "Choose your profile picture" : "عکس نمایهٔ خود را انتخاب کنید",
     "Please select a valid png or jpg file" : "لطفاً یک فایل png یا jpg معتبر انتخاب کنید",
     "Error setting profile picture" : "خطا در تنظیم عکس نمایه",
@@ -278,12 +264,17 @@ OC.L10N.register(
     "Upload profile picture" : "بارگذاری نگارهٔ نمایه",
     "Choose profile picture from Files" : "تصویر نمایه‌تان را از پرونده‌ها انتخاب کنید",
     "Remove profile picture" : "برداشتن نگارهٔ نمایه",
-    "The file must be a PNG or JPG" : "The file must be a PNG or JPG",
+    "The file must be a PNG or JPG" : "فرمت فایل باید PNG یا JPG باشد",
     "Picture provided by original account" : "نگاره فراهم شده به دست حساب اصلی",
     "Set as profile picture" : "به عنوان عکس نمایه تنظیم کنید",
     "Please note that it can take up to 24 hours for your profile picture to be updated everywhere." : "لطفاً توجه داشته باشید که ممکن است تا 24 ساعت طول بکشد تا عکس نمایه شما در همه جا به روز شود.",
+    "Unable to update date of birth" : "ناتوانی در به‌روزرسانی تاریخ تولد",
+    "Enter your date of birth" : "تاریخ تولدتان را وارد کنید",
     "You are a member of the following groups:" : "عضوی از گروه‌های زیر هستید:",
     "Your full name" : "Your full name",
+    "Unable to update primary email address" : "Unable to update primary email address",
+    "Unable to delete additional email address" : "Unable to delete additional email address",
+    "No email address set" : "آدرس‌ایمیلی تنظیم نشده است",
     "Email options" : "Email options",
     "Remove primary email" : "Remove primary email",
     "Delete email" : "Delete email",
@@ -292,20 +283,17 @@ OC.L10N.register(
     "Set as primary email" : "Set as primary email",
     "Additional email address {index}" : "Additional email address {index}",
     "Unable to delete primary email address" : "Unable to delete primary email address",
-    "Unable to update primary email address" : "Unable to update primary email address",
     "Unable to add additional email address" : "Unable to add additional email address",
     "Unable to update additional email address" : "Unable to update additional email address",
-    "Unable to delete additional email address" : "Unable to delete additional email address",
     "Primary email for password reset and notifications" : "ایمیل اصلی برای بازیابی رمز عبور و دریافت اعلان ها",
-    "No email address set" : "آدرس‌ایمیلی تنظیم نشده است",
     "Your handle" : "Your handle",
     "Your headline" : "عنوان سرصفحه",
+    "No language set" : "زبانی تنظیم نشده است.",
     "Unable to update language" : "Unable to update language",
     "Help translate" : "به ترجمه آن کمک کنید",
-    "No language set" : "زبانی تنظیم نشده است.",
+    "No locale set" : "تنظیمات locale انجام نشده است",
     "Unable to update locale" : "Unable to update locale",
     "Week starts on {firstDayOfWeek}" : "Week starts on {firstDayOfWeek}",
-    "No locale set" : "تنظیمات locale انجام نشده است",
     "Your city" : "شهر شما",
     "Your organisation" : "نام سازمان",
     "Your phone number" : "شماره تلفن شما",
@@ -325,13 +313,14 @@ OC.L10N.register(
     "Change" : "تغییر",
     "Delete" : "حذف",
     "Reshare" : "بازهم‌رسانی",
+    "School" : "مدرسه",
     "Default language" : "زبان پیش فرض",
     "Common languages" : "زبانهای رایج",
     "Other languages" : "Other languages",
     "Password change is disabled because the master key is disabled" : "تغییر رمز غیرفعال شده است زیرا کلید اصلی غیرفعال شده است",
     "No accounts" : "حسابی وجود ندارد",
     "Manager" : "Manager",
-    "Display name" : "نمایش نام",
+    "Display name" : "نام نمایشی",
     "Either password or email is required" : "Either password or email is required",
     "Password (required)" : "Password (required)",
     "Email (required)" : "Email (required)",
@@ -339,20 +328,18 @@ OC.L10N.register(
     "Quota" : "سهم",
     "Language" : "زبان",
     "Set default language" : "Set default language",
-    "_{userCount} account …_::_{userCount} accounts …_" : ["{userCount} حساب ...","{userCount} حساب ..."],
     "_{userCount} account_::_{userCount} accounts_" : ["{userCount} حساب","{userCount} حساب"],
     "Total rows summary" : "خلاصه کل ردیف ها",
     "Scroll to load more rows" : "Scroll to load more rows",
     "Password or insufficient permissions message" : "Password or insufficient permissions message",
     "Avatar" : "آواتار",
-    "Account name" : "Account name",
+    "Account name" : "نام حساب.",
     "Group admin for" : "مدیر گروه برای",
     "Storage location" : "محل ذخیره سازی",
     "Last login" : "آخرین ورود",
     "Account actions" : "اقدامات حساب",
     "{size} used" : "{size} مورد استفاده",
     "Resend welcome email" : "ارسال ایمیل خوش آمدید",
-    "In case of lost device or exiting the organization, this can remotely wipe the Nextcloud data from all devices associated with {userid}. Only works if the devices are connected to the internet." : "در صورت گم شدن دستگاه یا خارج شدن از سازمان ، می توانید داده های نکست کلود را از راه دور از بین همه دستگاه های مرتبط با  {userid} آن پاک کنید. فقط در صورت اتصال دستگاه ها به اینترنت کار می کند.",
     "Remote wipe of devices" : "پاک کردن از راه دور دستگاه ها",
     "Wipe {userid}'s devices" : "دستگاه های {userid} را پاک کنید",
     "Wiped {userid}'s devices" : "Wiped {userid}'s devices",
@@ -364,7 +351,7 @@ OC.L10N.register(
     "Email was successfully changed" : "Email was successfully changed",
     "Welcome mail sent!" : "نامه خوش آمديد ارسال شد",
     "Set the language" : "Set the language",
-    "Done" : "انجام شد",
+    "Done" : "Done",
     "Edit" : "ویرایش",
     "Visibility" : "Visibility",
     "Show language" : "Show language",
@@ -379,34 +366,60 @@ OC.L10N.register(
     "Passwordless authentication requires a secure connection." : "Passwordless authentication requires a secure connection.",
     "Add WebAuthn device" : "Add WebAuthn device",
     "Please authorize your WebAuthn device." : "Please authorize your WebAuthn device.",
-    "Adding your device …" : "Adding your device …",
     "Unnamed device" : "Unnamed device",
     "Passwordless Authentication" : "Passwordless Authentication",
     "Set up your account for passwordless authentication following the FIDO2 standard." : "Set up your account for passwordless authentication following the FIDO2 standard.",
     "No devices configured." : "No devices configured.",
     "The following devices are configured for your account:" : "The following devices are configured for your account:",
     "Your browser does not support WebAuthn." : "Your browser does not support WebAuthn.",
+    "It is important to set up this server to be able to send emails, like for password reset and notifications." : "تنظیم این سرور برای این مهم است که بتواند ایمیل ارسال کند ، مانند تنظیم مجدد گذرواژه و اعلان ها.",
+    "Send mode" : "حالت ارسال",
+    "Encryption" : "رمزگذاری",
+    "Sendmail mode" : "حالت Sendmail",
+    "Disable certificate verification (insecure)" : "غیرفعال کردن تأیید گواهینامه (ناامن)",
+    "From address" : "آدرس فرستنده",
+    "Domain" : "دامنه",
+    "Server address" : "آدرس سرور",
+    "Host" : "میزبان",
+    "Port" : "درگاه",
+    "Authentication" : "احراز هویت",
+    "Authentication required" : "احراز هویت مورد نیاز است",
+    "Saving…" : "در حال ذخیره",
+    "Security & setup warnings" : "اخطارهای نصب و امنیتی",
+    "Try again" : "تلاش دوباره",
+    "All checks passed." : "تمامی موارد با موفقیت چک شدند.",
+    "There are some errors regarding your setup." : "برخی از خطاها در مورد راه اندازی شما وجود دارد",
+    "There are some warnings regarding your setup." : "هشدارهایی درباره تنظیم شما وجود دارد.",
     "As admin you can fine-tune the sharing behavior. Please see the documentation for more information." : "به عنوان مدیر ، می توانید رفتار اشتراک گذاری را تنظیم کنید. لطفا برای اطلاعات بیشتر به اسناد مراجعه کنید.",
     "You need to enable the File sharing App." : "You need to enable the File sharing App.",
+    "Apply" : "اعمال",
     "All accounts" : "همهٔ حساب‌ها",
     "Admins" : "مدیران",
-    "Group name" : "نام گروه",
-    "Sending…" : "در حال ارسال",
-    "Email sent" : "ایمیل ارسال شد",
     "Location" : "مکان",
     "Profile picture" : "تصویر پروفایل",
     "About" : "درباره",
+    "Date of birth" : "تاریخ تولد",
     "Full name" : "نام کامل",
     "Additional email" : "Additional email",
-    "Fediverse (e.g. Mastodon)" : "Fediverse (e.g. Mastodon)",
+    "Fediverse (e.g. Mastodon)" : "فدیورس (مانند ماستودون)",
     "Headline" : "عنوان",
     "Organisation" : "سازمان",
     "Phone number" : "شماره تلفن",
+    "Pronouns" : "ضمایر",
     "Role" : "نقش",
     "Website" : "وب‌ سایت",
     "Profile visibility" : "امکان دیده شدن پروفایل",
     "Locale" : "محل",
+    "First day of week" : "نخستین روز هفته",
+    "Private" : "خصوصی",
+    "Only visible to people matched via phone number integration through Talk on mobile" : "نمایان تنها برای افرادی که با یکپارچگی شماره تلفن از طریق Talk روی تلفن همراه مطابقند",
     "Not available as this property is required for core functionality including file sharing and calendar invitations" : "Not available as this property is required for core functionality including file sharing and calendar invitations",
+    "Local" : "محلی",
+    "Only visible to people on this instance and guests" : "نمایان تنها برای افراد روی این نمونه و میهانان",
+    "Federated" : "همگانی",
+    "Only synchronize to trusted servers" : "هم‌گام سازی تنها با کارسازهای مورد اعتماد",
+    "Published" : "منتشر شده",
+    "Synchronize to trusted servers and the global and public address book" : "هم‌گام سازی با کارسازهای مورد اعتماد و دفترچه نشانی‌های عمومی",
     "Your apps" : "برنامه‌های شما",
     "Active apps" : "برنامه‌های فعال",
     "Disabled apps" : "برنامه‌های غیرفعال",
@@ -421,7 +434,6 @@ OC.L10N.register(
     "Disable" : "غیرفعال",
     "Allow untested app" : "Allow untested app",
     "The app will be downloaded from the App Store" : "The app will be downloaded from the App Store",
-    "This app is not marked as compatible with your Nextcloud version. If you continue you will still be able to install the app. Note that the app might not work as expected." : "این برنامه مطابق با نسخه نکست کلود شما مشخص نشده است. اگر ادامه بدهید همچنان می توانید برنامه را نصب کنید. توجه داشته باشید که برنامه ممکن است مطابق آنچه انتظار می رود کار نکند.",
     "Unknown" : "ناشناخته",
     "Never" : "هرگز",
     "An error occurred during the request. Unable to proceed." : "An error occurred during the request. Unable to proceed.",
@@ -438,30 +450,6 @@ OC.L10N.register(
     "Nextcloud help & privacy resources" : "منابع راهنما و حریم شخصی نکست‌کلود",
     "Legal notice" : "توصیهٔ حقوقی",
     "Privacy policy" : "سیاست محرمانگی",
-    "None/STARTTLS" : "None/STARTTLS",
-    "SSL" : "SSL",
-    "Open documentation" : "بازکردن مستند",
-    "It is important to set up this server to be able to send emails, like for password reset and notifications." : "تنظیم این سرور برای این مهم است که بتواند ایمیل ارسال کند ، مانند تنظیم مجدد گذرواژه و اعلان ها.",
-    "Send mode" : "حالت ارسال",
-    "Encryption" : "رمزگذاری",
-    "Sendmail mode" : "حالت Sendmail",
-    "From address" : "آدرس فرستنده",
-    "Server address" : "آدرس سرور",
-    "Port" : "درگاه",
-    "Authentication" : "احراز هویت",
-    "Authentication required" : "احراز هویت مورد نیاز است",
-    "Credentials" : "اعتبارهای",
-    "SMTP Password" : "رمز عبور SMTP",
-    "Save" : "ذخیره",
-    "Test and verify email settings" : "Test and verify email settings",
-    "Security & setup warnings" : "اخطارهای نصب و امنیتی",
-    "It's important for the security and performance of your instance that everything is configured correctly. To help you with that we are doing some automatic checks. Please see the linked documentation for more information." : "برای امنیت و عملکرد نمونه شما، مهم است که همه چیز به درستی پیکربندی شده باشد. برای کمک به شما در این مورد ، ما برخی از بررسی های خودکار را انجام می دهیم. لطفا برای اطلاعات بیشتر به مستندات مرتبط مراجعه کنید.",
-    "All checks passed." : "تمامی موارد با موفقیت چک شدند.",
-    "There are some errors regarding your setup." : "برخی از خطاها در مورد راه اندازی شما وجود دارد",
-    "There are some warnings regarding your setup." : "هشدارهایی درباره تنظیم شما وجود دارد.",
-    "Checking for system and security issues." : "بررسی مشکلات سیستم و امنیت.",
-    "Please double check the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%1$s\">installation guides ↗</a>, and check for any errors or warnings in the <a href=\"%2$s\">log</a>." : "لطفاً <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%1$s\">راهنماهای نصب</a> را مجددا مرور کرده و هرگونه خطا یا هشدار را در <a href=\"%2$s\">گزارشات log </a> بررسی کنید.",
-    "Check the security of your Nextcloud over <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">our security scan ↗</a>." : "امنیت نکست کلود خود را در مورد <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">اسکن امنیتی ما ↗ </a>بررسی کنید",
     "Reasons to use Nextcloud in your organization" : "دلایلی برای استفاده از نکست‌کلود در سازمان شما",
     "Developed by the {communityopen}Nextcloud community{linkclose}, the {githubopen}source code{linkclose} is licensed under the {licenseopen}AGPL{linkclose}." : "توسعه یافته توسط {communityopen} انجمن نکست کلود {linkclose}، {githubopen} کد منبع {linkclose} تحت مجوز {licenseopen}AGPL{linkclose}است. ",
     "Like our Facebook page" : "پسندیدن صفحه فیس بوک ما",
@@ -469,41 +457,33 @@ OC.L10N.register(
     "Check out our blog" : "وبلاگ ما را بررسی کنید",
     "Subscribe to our newsletter" : "مشترک شدن در خبرنامه ما",
     "This community release of Nextcloud is unsupported and instant notifications are unavailable." : "This community release of Nextcloud is unsupported and instant notifications are unavailable.",
+    "Open documentation" : "بازکردن مستند",
     "Use a second factor besides your password to increase security for your account." : "برای افزایش امنیت حساب کاربری خود ، از یک عامل دوم علاوه بر رمز عبور خود استفاده کنید.",
     "If you use third party applications to connect to Nextcloud, please make sure to create and configure an app password for each before enabling second factor authentication." : "If you use third party applications to connect to Nextcloud, please make sure to create and configure an app password for each before enabling second factor authentication.",
-    "The database is missing some indexes. Due to the fact that adding indexes on big tables could take some time they were not added automatically. By running \"occ db:add-missing-indices\" those missing indexes could be added manually while the instance keeps running. Once the indexes are added queries to those tables are usually much faster." : "The database is missing some indexes. Due to the fact that adding indexes on big tables could take some time they were not added automatically. By running \"occ db:add-missing-indices\" those missing indexes could be added manually while the instance keeps running. Once the indexes are added queries to those tables are usually much faster.",
-    "MariaDB version \"%s\" is used. Nextcloud 21 and higher do not support this version and require MariaDB 10.2 or higher." : "MariaDB version \"%s\" is used. Nextcloud 21 and higher do not support this version and require MariaDB 10.2 or higher.",
-    "MySQL version \"%s\" is used. Nextcloud 21 and higher do not support this version and require MySQL 8.0 or MariaDB 10.2 or higher." : "MySQL version \"%s\" is used. Nextcloud 21 and higher do not support this version and require MySQL 8.0 or MariaDB 10.2 or higher.",
-    "PostgreSQL version \"%s\" is used. Nextcloud 21 and higher do not support this version and require PostgreSQL 9.6 or higher." : "PostgreSQL version \"%s\" is used. Nextcloud 21 and higher do not support this version and require PostgreSQL 9.6 or higher.",
-    "Speech-To-Text" : "Speech-To-Text",
-    "Speech-To-Text can be implemented by different apps. Here you can set which app should be used." : "Speech-To-Text can be implemented by different apps. Here you can set which app should be used.",
-    "None of your currently installed apps provide Speech-To-Text functionality" : "None of your currently installed apps provide Speech-To-Text functionality",
-    "None of your currently installed apps provide Text processing functionality" : "None of your currently installed apps provide Text processing functionality",
-    "Set default expiration date for shares" : "تاریخ انقضا پیش فرض را برای اشتراک گذاری تعیین کنید",
-    "Allow username autocompletion in share dialog and allow access to the system address book" : "Allow username autocompletion in share dialog and allow access to the system address book",
-    "Your biography" : "بیوگرافی شما",
-    "You are using <strong>{usage}</strong>" : "فضای مورد استفاده: <strong>{usage}</strong>",
-    "You are using <strong>{usage}</strong> of <strong>{totalSpace}</strong> (<strong>{usageRelative}%</strong>)" : "شما در حال استفادهٔ <strong>{usage}</strong> از <strong>{totalSpace}</strong> (<strong>{usageRelative}٪</strong>) فضا هستید",
-    "Set user manager" : "Set user manager",
-    "Username will be autogenerated" : "Username will be autogenerated",
-    "Username (required)" : "Username (required)",
-    "New user" : "کاربر جدید",
-    "Groups (required)" : "Groups (required)",
-    "Set user groups" : "Set user groups",
-    "Administered groups" : "Administered groups",
-    "Set user as admin for …" : "Set user as admin for …",
-    "Set user quota" : "Set user quota",
-    "Add new user" : "Add new user",
-    "_{userCount} user …_::_{userCount} users …_" : ["{userCount} user …","{userCount} users …"],
-    "_{userCount} user_::_{userCount} users_" : ["{userCount} user","{userCount} users"],
-    "Loading users …" : "Loading users …",
-    "Username" : "نام کاربری",
-    "User backend" : "پشتیبان کاربر",
-    "User actions" : "User actions",
-    "Add user to group" : "Add user to group",
-    "Server error while trying to add WebAuthn device" : "Server error while trying to add WebAuthn device",
-    "Name your device" : "Name your device",
-    "Active accounts" : "حساب‌های فعال",
-    "Follow us on Twitter" : "ما را در توییتر دنبال کنید"
+    "Very weak password" : "رمز عبور بسیار ضعیف",
+    "Weak password" : "رمز عبور ضعیف",
+    "So-so password" : "رمز عبور متوسط",
+    "Good password" : "رمز عبور خوب",
+    "Strong password" : "رمز عبور قوی",
+    "Group list is empty" : "سیاههٔ گروه‌ها خالیست",
+    "Unable to retrieve the group list" : "ناتوان در گرفتن سیاهٔ گروه‌ها",
+    "This app has no minimum Nextcloud version assigned. This will be an error in the future." : "این برنامه حداقل دارای نسخه بعدی نکست کلود است. این یک خطا در آینده خواهد بود.",
+    "This app has no maximum Nextcloud version assigned. This will be an error in the future." : "این برنامه حداکثر نسخه نکست کلود اختصاصی ندارد. این یک خطا در آینده خواهد بود.",
+    "_{userCount} account …_::_{userCount} accounts …_" : ["{userCount} حساب ...","{userCount} حساب ..."],
+    "In case of lost device or exiting the organization, this can remotely wipe the Nextcloud data from all devices associated with {userid}. Only works if the devices are connected to the internet." : "در صورت گم شدن دستگاه یا خارج شدن از سازمان ، می توانید داده های نکست کلود را از راه دور از بین همه دستگاه های مرتبط با  {userid} آن پاک کنید. فقط در صورت اتصال دستگاه ها به اینترنت کار می کند.",
+    "Adding your device …" : "Adding your device …",
+    "Sending…" : "در حال ارسال",
+    "Email sent" : "ایمیل ارسال شد",
+    "This app is not marked as compatible with your Nextcloud version. If you continue you will still be able to install the app. Note that the app might not work as expected." : "این برنامه مطابق با نسخه نکست کلود شما مشخص نشده است. اگر ادامه بدهید همچنان می توانید برنامه را نصب کنید. توجه داشته باشید که برنامه ممکن است مطابق آنچه انتظار می رود کار نکند.",
+    "None/STARTTLS" : "None/STARTTLS",
+    "SSL" : "SSL",
+    "Credentials" : "اعتبارهای",
+    "SMTP Password" : "رمز عبور SMTP",
+    "Save" : "ذخیره",
+    "Test and verify email settings" : "Test and verify email settings",
+    "It's important for the security and performance of your instance that everything is configured correctly. To help you with that we are doing some automatic checks. Please see the linked documentation for more information." : "برای امنیت و عملکرد نمونه شما، مهم است که همه چیز به درستی پیکربندی شده باشد. برای کمک به شما در این مورد ، ما برخی از بررسی های خودکار را انجام می دهیم. لطفا برای اطلاعات بیشتر به مستندات مرتبط مراجعه کنید.",
+    "Checking for system and security issues." : "بررسی مشکلات سیستم و امنیت.",
+    "Please double check the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%1$s\">installation guides ↗</a>, and check for any errors or warnings in the <a href=\"%2$s\">log</a>." : "لطفاً <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%1$s\">راهنماهای نصب</a> را مجددا مرور کرده و هرگونه خطا یا هشدار را در <a href=\"%2$s\">گزارشات log </a> بررسی کنید.",
+    "Check the security of your Nextcloud over <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">our security scan ↗</a>." : "امنیت نکست کلود خود را در مورد <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">اسکن امنیتی ما ↗ </a>بررسی کنید"
 },
 "nplurals=2; plural=(n > 1);");
