@@ -1,25 +1,6 @@
 OC.L10N.register(
     "settings",
     {
-    "Private" : "개인",
-    "Only visible to people matched via phone number integration through Talk on mobile" : "전화번호 통합으로 연결된 사용자에게만 보임",
-    "Local" : "로컬",
-    "Only visible to people on this instance and guests" : "이 인스턴스의 사용자와 손님만 볼 수 있음",
-    "Federated" : "연합",
-    "Only synchronize to trusted servers" : "신뢰할 수 있는 서버만 동기화할 수 있습니다.",
-    "Published" : "발행됨",
-    "Synchronize to trusted servers and the global and public address book" : "신뢰할 수 있는 서버와 전역 및 개인 연락처에 동기화",
-    "Verify" : "확인",
-    "Verifying …" : "확인 중 …",
-    "Unable to change password" : "암호를 변경할 수 없음",
-    "Very weak password" : "매우 약한 암호",
-    "Weak password" : "약한 암호",
-    "So-so password" : "그저 그런 암호",
-    "Good password" : "좋은 암호",
-    "Strong password" : "강력한 암호",
-    "Groups" : "그룹",
-    "Group list is empty" : "그룹 목록이 비었음",
-    "Unable to retrieve the group list" : "그룹 목록을 받아올 수 없음",
     "{actor} added you to group {group}" : "{actor} 가 당신을 {group} 그룹에 추가했습니다.",
     "You added {user} to group {group}" : "당신은 {user}를 {group} 그룹에 추가했습니다.",
     "{actor} added {user} to group {group}" : "{actor} 가 {user}를 {group} 그룹에 추가했습니다.",
@@ -57,6 +38,7 @@ OC.L10N.register(
     "Unable to change personal password" : "개인 패스워드를 변경할 수 없음",
     "Saved" : "저장됨",
     "No Login supplied" : "로그인 정보 없음",
+    "Unable to change password" : "암호를 변경할 수 없음",
     "Unable to change password. Password too long." : "패스워드를 변경할 수 없음. 패스워드가 너무 긺.",
     "Authentication error" : "인증 오류",
     "Please provide an admin recovery password; otherwise, all account data will be lost." : "관리자 복구 암호를 입력하십시오. 그렇지 않으면 모든 계정 데이터가 초기화됩니다.",
@@ -104,6 +86,7 @@ OC.L10N.register(
     "Set your password" : "내 암호 설정하기",
     "Go to %s" : "%s(으)로 이동",
     "Install Client" : "클라이언트 설치",
+    "Logged in account must be a sub admin" : "로그인한 계정은 부관리자여야 합니다.",
     "Apps" : "앱",
     "Personal" : "개인",
     "Administration" : "관리",
@@ -113,6 +96,7 @@ OC.L10N.register(
     "Administration privileges" : "관리 권한",
     "Groupware" : "그룹웨어",
     "Overview" : "개요",
+    "Quick presets" : "빠른 사전 설정",
     "Basic settings" : "기본 설정",
     "Sharing" : "공유",
     "Availability" : "시간 조율",
@@ -127,10 +111,14 @@ OC.L10N.register(
     "User's email account" : "사용자 이메일 계정",
     "System email account" : "시스템 이메일 계정",
     "Security & setup checks" : "보안 & 설정 검사",
+    "Settings presets" : "사전 설정된 설정",
     "Background jobs" : "배경 작업",
     "Unlimited" : "무제한",
     "Verifying" : "검사",
+    "Verifying …" : "확인 중 …",
+    "Verify" : "확인",
     "Allowed admin IP ranges" : "허용된 관리자 IP 범위",
+    "Admin IP filtering isn't applied." : "관리자 IP 필터링이 적용되지 않습니다.",
     "Configuration key \"%1$s\" expects an array (%2$s found). Admin IP range validation will not be applied." : "\"%1$s\" 설정 키에는 배열(%2$s 발견)이  필요합니다. 관리자 IP 범위 검사가 적용되지 않습니다.",
     "Configuration key \"%1$s\" contains invalid IP range(s): \"%2$s\"" : "\"%1$s\" 설정 키에 잘못된 IP 범위(들이)가 있습니다: \"%2$s\"",
     "Admin IP filtering is correctly configured." : "관리자 IP 필터링이 올바르게 설정되었습니다.",
@@ -148,6 +136,8 @@ OC.L10N.register(
     "Integrity checker has been disabled. Integrity cannot be verified." : "무결성 검사가 비활성화 되었습니다. 무결성을 검증할 수 없습니다.",
     "No altered files" : "대체된 파일 없음",
     "Some files have not passed the integrity check. {link1} {link2}" : "일부 파일이 무결성 검사를 통과하지 못했습니다. {link1} {link2}",
+    "List of invalid files…" : "잘못된 파일들의 목록…",
+    "Rescan…" : "다시 스캔…",
     "Cron errors" : "Cron 오류",
     "It was not possible to execute the cron job via CLI. The following technical errors have appeared:\n%s" : "CLI를 통한 Cron 작업을 수행할 수 없습니다. 다음의 오류가 발생하였습니다: %s",
     "The last cron job ran without errors." : "마지막 Cron 작업이 정상적으로 수행되었습니다.",
@@ -162,6 +152,7 @@ OC.L10N.register(
     "The database is missing some optional columns. Due to the fact that adding columns on big tables could take some time they were not added automatically when they can be optional. By running \"occ db:add-missing-columns\" those missing columns could be added manually while the instance keeps running. Once the columns are added some features might improve responsiveness or usability." : "데이터베이스에 일부 선택적 열이 누락되었습니다. 큰 테이블에 열을 추가하는 데 시간이 걸릴 수 있기 때문에 선택 사항일 수 있는 열이 자동으로 추가되지 않았습니다. 명령행에서 \"occ db:add-missing-columns\"를 실행하면 누락된 열을 인스턴스를 실행되는 동안 수동으로 추가할 수 있습니다. 열이 추가되면 일부 기능의 응답성이나 사용성이 향상될 수 있습니다.",
     "Database missing indices" : "데이터베이스의 색인이 사라졌습니다",
     "Missing indices:" : "빠진 인덱스:",
+    "Detected some missing optional indices. Occasionally new indices are added (by Nextcloud or installed applications) to improve database performance. Adding indices can sometimes take awhile and temporarily hurt performance so this is not done automatically during upgrades. Once the indices are added, queries to those tables should be faster. Use the command `occ db:add-missing-indices` to add them." : "일부 선택적 인덱스가 빠진 것을 감지했습니다. 데이터베이스 성능을 향상하기 위해 때때로 (Nextcloud나 설치된 앱을 통해) 새로운 인덱스가 추가됩니다. 인덱스 추가는 가끔 시간이 걸려 일시적으로 성능을 저하시킬 수 있기 때문에 자동으로 업데이트 중에 실행되지 않습니다. 인덱스가 추가되면 그 테이블에 질의하는 것이 빨라집니다. `occ db:add-missing-indices` 명령을 사용해 추가하세요.",
     "Database missing primary keys" : "데이터베이스의 기본 키가 사라졌습니다",
     "Missing primary key on table \"%s\"." : "표 \"%s\"의 기본키가 사라졌습니다",
     "The database is missing some primary keys. Due to the fact that adding primary keys on big tables could take some time they were not added automatically. By running \"occ db:add-missing-primary-keys\" those missing primary keys could be added manually while the instance keeps running." : "데이터베이스에 일부 기본 키가 누락되었습니다. 큰 테이블에 기본 키를 추가하는 데 시간이 걸릴 수 있기 때문에 자동으로 추가되지 않았습니다. 명령행에서 \"occ db:add-missing-primary-keys\"를 실행하면 인스턴스가 계속 실행되는 동안 누락된 기본 키를 수동으로 추가할 수 있습니다.",
@@ -173,6 +164,7 @@ OC.L10N.register(
     "Default phone region" : "기본 국가 번호",
     "Your installation has no default phone region set. This is required to validate phone numbers in the profile settings without a country code. To allow numbers without a country code, please add \"default_phone_region\" with the respective ISO 3166-1 code of the region to your config file." : "기본 국가 번호가 설정되지 않았습니다. 기본 국가 번호를 설정하면 프로필에서 국가 번호를 생략하고 전화번호를 입력할 수 있습니다. ISO 3166-1 코드를 참조하여 설정 파일에 \"default_phone_region\"을 추가하십시오.",
     "Email test" : "이메일 시험",
+    "Mail delivery is disabled by instance config \"%s\"." : "인스턴스의 \"%s\" 설정에 의해 메일 전달이 비활성화 되었습니다.",
     "Email test was successfully sent" : "시험 이메일이 성공적으로 전송됨",
     "You have not set or verified your email server configuration, yet. Please head over to the \"Basic settings\" in order to set them. Afterwards, use the \"Send email\" button below the form to verify your settings." : "이메일 서버 설정이 입력되지 않았거나 검증되지 않았습니다. \"기본 설정\"으로 이동해 설정을 완료하십시오. 서버 정보를 입력한 후 양식 아래 \"이메일 발송\" 버튼을 눌러 설정을 검증하십시오.",
     "Transactional File Locking" : "트랜잭션 파일 잠금",
@@ -197,32 +189,56 @@ OC.L10N.register(
     "Unable to run check for JavaScript support. Please remedy or confirm manually if your webserver serves `.mjs` files using the JavaScript MIME type." : "JavaScript 지원 여부를 확인할 수 없습니다. 이 웹 서버가 JavaScript MIME 타입을 통해 `.mjs` 파일을 제공하는지를 수동으로 확인하거나 해결하십시오.",
     "Your webserver does not serve `.mjs` files using the JavaScript MIME type. This will break some apps by preventing browsers from executing the JavaScript files. You should configure your webserver to serve `.mjs` files with either the `text/javascript` or `application/javascript` MIME type." : "이 웹 서버는 JavaScript MIME 타입을 활용해 `.mjs` 파일을 제공하지 않습니다. 브라우저에서 JavaScript 파일을 실행할 수 없으므로, 일부 앱이 정상적으로 작동하지 않을 것입니다. 웹 서버가 `text/javascript` 및 `application/javascript` MIME 타입을 활용하여 `.mjs` 파일을 제공하도록 설정하십시오.",
     "JavaScript source map support" : "JavaScript 소스 맵 지원",
+    "Your webserver is not set up to serve `.js.map` files. Without these files, JavaScript Source Maps won't function properly, making it more challenging to troubleshoot and debug any issues that may arise." : "당신의 웹서버가 `.js.map` 파일을 제공하도록 설정되지 않았습니다. 이 파일들 없이는 JavaScript Source Maps가 올바르게 작동하지 않으며, 발생할 문제들을 해결하고 디버깅하기 더 어려워집니다.",
     "Old server-side-encryption" : "구식 서버 측 암호화",
     "Disabled" : "비활성화됨",
     "The old server-side-encryption format is enabled. We recommend disabling this." : "구형 포맷의 서버 측 암호화가 활성화된 상태입니다. 이를 비활성화 하는 것을 권장합니다.",
+    "Logging level" : "로그 단계",
+    "The %1$s configuration option must be a valid integer value." : "%1$s설정 옵션은 유효한 정수 값이어야만 합니다.",
+    "The logging level is set to debug level. Use debug level only when you have a problem to diagnose, and then reset your log level to a less-verbose level as it outputs a lot of information, and can affect your server performance." : "로그 단계가 디버그 단계로 설정되어 있습니다. 디버그 단계는 문제를 진단할 때만 사용하고, 문제가 해결되면 로그 단계를 더 간략한 단계로 되돌리십시오. 디버그 단계는 많은 정보를 출력하여 서버 성능에 영향을 줄 수 있습니다.",
+    "Logging level configured correctly." : "로그 단계가 올바르게 설정되었습니다.",
     "Maintenance window start" : "유지 보수 창 시작",
     "Server has no maintenance window start time configured. This means resource intensive daily background jobs will also be executed during your main usage time. We recommend to set it to a time of low usage, so users are less impacted by the load caused from these heavy tasks." : "서버 유지관리 창의 시작 시간이 설정되지 않았습니다. 많은 사용자가 접속하는 시간대에 자원 집약적인 작업이 실행될 수 있습니다. 부하가 큰 작업에 의해 사용자가 불편을 겪지 않도록, 유지관리 창의 시작 시간을 사용량이 적은 시간대로 설정하십시오.",
     "Maintenance window to execute heavy background jobs is between {start}:00 UTC and {end}:00 UTC" : "유지 보수 창이 부하가 큰 백그라운드 작업을 수행하기 위해 {start}:00 UTC에서 {end}:00 UTC에 동작합니다",
     "Memcache" : "Memcache",
+    "Memcached is configured as distributed cache, but the wrong PHP module (\"memcache\") is installed. Please install the PHP module \"memcached\"." : "Memcached가 분산 캐시로 구성되어 있지만 잘못된 PHP 모듈 (\"memcache\")가 설치되어 있습니다. PHP 모듈 \"memcached\"를 설치하세요.",
+    "Memcached is configured as distributed cache, but the PHP module \"memcached\" is not installed. Please install the PHP module \"memcached\"." : "Memcached가 분산 캐시로 구성되어 있지만 PHP 모듈 \"memcached\"가 설치되어 있지 않습니다. PHP 모듈 \"memcached\"를 설치하세요.",
     "No memory cache has been configured. To enhance performance, please configure a memcache, if available." : "메모리 캐시가 설정되지 않았습니다. 성능 향상을 위해, 가능한 경우 memcache를 설정하십시오.",
+    "Failed to write and read a value from local cache." : "로컬 캐시에 값을 쓰거나 읽을 수 없습니다.",
+    "Failed to write and read a value from distributed cache." : "분산 캐시에 값을 쓰거나 읽을 수 없습니다.",
     "Configured" : "설정됨",
+    "Mimetype migrations available" : "Mimetype 마이그레이션 가능",
+    "One or more mimetype migrations are available. Occasionally new mimetypes are added to better handle certain file types. Migrating the mimetypes take a long time on larger instances so this is not done automatically during upgrades. Use the command `occ maintenance:repair --include-expensive` to perform the migrations." : "하나 이상의 MIME 유형 마이그레이션이 가능합니다. 특정 파일 형식을 더 잘 처리하기 위해 새로운 MIME 유형이 추가되는 경우가 있습니다. 대규모 인스턴스에서는 MIME 유형 마이그레이션에 시간이 오래 걸리므로 업그레이드 시 자동으로 수행되지 않습니다. 마이그레이션을 수행하려면 `occ maintenance:repair --include-expensive` 명령을 사용하십시오.",
+    "MySQL row format" : "MySQL 행 형식",
     "You are not using MySQL" : "MySQL을 사용하고 있지 않습니다",
+    "None of your tables use ROW_FORMAT=Compressed" : "ROW_FORMAT=Compressed인 테이블이 없습니다.",
+    "Incorrect row format found in your database. ROW_FORMAT=Dynamic offers the best database performances for Nextcloud. Please update row format on the following list: %s." : "데이터베이스에서 잘못된 행 형식이 발견되었습니다. ROW_FORMAT=Dynamic은 Nextcloud에서 최상의 데이터베이스 성능을 제공합니다. 다음 목록에서 행 형식을 업데이트하십시오: %s",
     "MySQL Unicode support" : "MySQL 유니코드 지원",
     "MySQL is used as database and does support 4-byte characters" : "MySQL이 데이터베이스로 사용되고 있으며 4바이트 문자를 지원합니다",
     "MySQL is used as database but does not support 4-byte characters. To be able to handle 4-byte characters (like emojis) without issues in filenames or comments for example it is recommended to enable the 4-byte support in MySQL." : "MySQL이 데이터베이스로 사용되고 있으나 4바이트 문자를 지원하지 않고 있습니다. 파일 이름이나 댓글 등에 Emoji와 같은 4바이트 문자를 문제 없이 사용하기 위해, MySQL에서 4바이트 문자 지원을 활성화하길 권장합니다.",
+    "OCS provider resolving" : "OCS 제공자 해석",
+    "Could not check if your web server properly resolves the OCM and OCS provider URLs." : "웹 서버가 OCM 및 OCS 공급자 URL을 제대로 해석하는지 확인할 수 없습니다.",
+    "Your web server is not properly set up to resolve %1$s.\nThis is most likely related to a web server configuration that was not updated to deliver this folder directly.\nPlease compare your configuration against the shipped rewrite rules in \".htaccess\" for Apache or the provided one in the documentation for Nginx.\nOn Nginx those are typically the lines starting with \"location ~\" that need an update." : "웹 서버가 %1$s를 제대로 해석하도록 설정되어 있지 않습니다. \n이 문제는 웹 서버 구성이 해당 폴더를 직접 제공하도록 업데이트되지 않았기 때문일 가능성이 높습니다. \nApache의 경우 \".htaccess\" 파일에 있는 기본 rewrite 규칙과, Nginx의 경우 설명서에 제공된 rewrite 규칙과 현재 구성을 비교해 보세요.\nNginx의 경우 일반적으로 \"location ~\"로 시작하는 줄을 업데이트해야 합니다.",
     "Overwrite CLI URL" : "CLI URL 덮어쓰기",
     "The \"overwrite.cli.url\" option in your config.php is correctly set to \"%s\"." : "\"overwrite.cli.url\" 옵션이 config.php에서 \"%s\"(으)로 바르게 설정되어 있습니다.",
     "The \"overwrite.cli.url\" option in your config.php is set to \"%s\" which is a correct URL. Suggested URL is \"%s\"." : "\"overwrite.cli.url\" 옵션이 config.php에서 \"%s\"(으)로 바르게 설정되어 있습니다. 권장 URL은 \"%s\" 입니다.",
     "Please make sure to set the \"overwrite.cli.url\" option in your config.php file to the URL that your users mainly use to access this Nextcloud. Suggestion: \"%s\". Otherwise there might be problems with the URL generation via cron. (It is possible though that the suggested URL is not the URL that your users mainly use to access this Nextcloud. Best is to double check this in any case.)" : "주로 사용할 URL이 config.php 파일의 \"overwrite.cli.url\" 옵션에 올바르게 설정되어 있는지 확인하십시오. 제안: \"%s\". 설정이 잘못되었을 경우 cron을 통한 URL 생성에 문제가 생길 수 있습니다. (제안된 URL이 이 Nextcloud에 접근하는 주된 URL이 아닐 수 있습니다. 따라서, 해당 사항을 직접 재확인하는 것이 좋습니다.)",
+    "PHP APCu configuration" : "PHP APCu 설정",
+    "Your APCu cache has been running full, consider increasing the apc.shm_size php setting." : "APCu 캐시가 가득 찼으므로, php 설정에서 apc.shm_size를 늘리는 것을 고려해 보세요.",
+    "Your APCu cache is almost full at %s%%, consider increasing the apc.shm_size php setting." : "APCu 캐시가 %s%%정도로 거의 가득 찼으므로, php 설정에서 apc.shm_size를 늘리는 것을 고려해 보세요.",
     "PHP default charset" : "PHP 기본 문자셋",
     "PHP configuration option \"default_charset\" should be UTF-8" : "PHP 설정 \"default_charset\"이 UTF-8이어야 합니다",
     "PHP set_time_limit" : "PHP set_time_limit",
     "The function is available." : "기능을 사용할 수 있습니다.",
     "The PHP function \"set_time_limit\" is not available. This could result in scripts being halted mid-execution, breaking your installation. Enabling this function is strongly recommended." : "PHP 함수 \"set_time_limit\"을 사용할 수 없습니다. 스크립트가 실행 중간에 중지되어 설치를 깨트릴 수도 있습니다. 이 함수를 활성화하는 것을 추천합니다.",
+    "Freetype" : "FreeType",
     "Supported" : "지원됨",
     "Your PHP does not have FreeType support, resulting in breakage of profile pictures and the settings interface." : "PHP에 Freetype 지원이 없습니다. 프로필 사진과 설정 인터페이스가 올바르게 표시되지 않을 수도 있습니다.",
     "PHP getenv" : "PHP getenv",
     "PHP does not seem to be setup properly to query system environment variables. The test with getenv(\"PATH\") only returns an empty response." : "PHP에서 시스템 환경 변수를 올바르게 조회할 수 없는 것 같습니다. getenv(\"PATH\") 시험 결과 빈 값이 반환되었습니다.",
+    "PHP file size upload limit" : "PHP 파일 크기 업로드 제한",
+    "The PHP upload_max_filesize is too low. A size of at least %1$s is recommended. Current value: %2$s." : "PHP의 upload_max_filesize가 너무 작습니다. 최소한 %1$s 이상의 크기를 권장합니다. 현재 값: %2$s.",
+    "The PHP post_max_size is too low. A size of at least %1$s is recommended. Current value: %2$s." : "PHP의 post_max_filesize가 너무 작습니다. 최소한 %1$s 이상의 크기를 권장합니다. 현재 값: %2$s.",
     "PHP memory limit" : "PHP 메모리 제한",
     "PHP modules" : "PHP 모듈",
     "increases language translation performance and fixes sorting of non-ASCII characters" : ": 번역 성능을 개선과 비ASCII 문자의 바른 정렬을 위해 사용",
@@ -305,8 +321,6 @@ OC.L10N.register(
     "Exclude groups from creating link shares" : "특정 그룹에 대해 링크 공유 생성을 금지하도록 설정",
     "Limit sharing based on groups" : "그룹별로 공유 제한하기",
     "Allow sharing for everyone (default)" : "그룹별 공유 기능 제한 없음 (기본값)",
-    "Exclude some groups from sharing" : "공유 기능을 제한할 그룹 지정",
-    "Limit sharing to some groups" : "공유 기능을 허용할 그룹 지정",
     "Groups allowed to share" : "공유가 허용된 그룹",
     "Groups excluded from sharing" : "공유에서 제외된 그룹",
     "Not allowed groups will still be able to receive shares, but not to initiate them." : "공유가 제한된 그룹은 다른 사람의 데이터를 공유 받을 수는 있지만, 다른 사람에게 자신의 데이터를 공유할 수는 없습니다.",
@@ -349,6 +363,7 @@ OC.L10N.register(
     "This app is supported via your current Nextcloud subscription." : "이 앱은 당신의 현재 Nextcloud 구독을 통해 지원됩니다.",
     "Featured apps are developed by and within the community. They offer central functionality and are ready for production use." : "추천 앱은 커뮤니티에서 개발했습니다. 이들은 생산성 업무에 있어 중심적인 기능을 담당하며 즉각 사용될 수 있습니다.",
     "Community rating: {score}/5" : "커뮤니티 평가: {score}/5",
+    "Learn more" : "자세히 알아보기",
     "Disable all" : "전체 비활성화",
     "Download and enable all" : "모두 다운로드 및 사용",
     "All apps are up-to-date." : "모든 앱이 최신 버전입니다.",
@@ -362,6 +377,7 @@ OC.L10N.register(
     "_%n app has an update available_::_%n apps have an update available_" : ["%n개의 앱을 업데이트 할 수 있습니다."],
     "_Update_::_Update all_" : ["모두 업데이트"],
     "Failed to create group" : "그룹을 만들 수 없음",
+    "Groups" : "그룹",
     "Creating group…" : "그룹 생성 ...",
     "Create group" : "그룹 생성",
     "Group name" : "그룹 이름",
@@ -385,7 +401,6 @@ OC.L10N.register(
     "Display Name" : "표시 이름",
     "GPUs support" : "GPU 지원<br>",
     "Compute device" : "컴퓨팅 장치",
-    "Learn more" : "자세히 알아보기",
     "Environment variables" : "환경 변수",
     "Read-only" : "읽기 전용",
     "Confirm" : "확인",
@@ -488,6 +503,7 @@ OC.L10N.register(
     "Rename group" : "그룹 이름 바꾸기",
     "Current password" : "현재 암호",
     "New password" : "새 암호",
+    "Change password" : "암호 변경",
     "Choose your profile picture" : "프로필 사진을 선택하십시오",
     "Please select a valid png or jpg file" : "올바른 PNG 또는 JPG 파일을 선택하십시오",
     "Error setting profile picture" : "프로필 사진 설정 중 오류 발생",
@@ -506,6 +522,9 @@ OC.L10N.register(
     "Enter your date of birth" : "생일을 입력하세요",
     "You are a member of the following groups:" : "당신은 다음 그룹의 멤버입니다:",
     "Your full name" : "내 전체 이름",
+    "Unable to update primary email address" : "주 이메일 주소를 갱신할 수 없음",
+    "Unable to delete additional email address" : "추가 이메일 주소를 삭제할 수 없음",
+    "No email address set" : "이메일 주소가 설정되지 않음",
     "Email options" : "이메일 옵션",
     "Remove primary email" : "주 이메일 삭제",
     "Delete email" : "이메일 삭제",
@@ -514,23 +533,20 @@ OC.L10N.register(
     "Set as primary email" : "주 이메일로 지정",
     "Additional email address {index}" : "추가 이메일 주소 {index}",
     "Unable to delete primary email address" : "주 이메일 주소를 삭제할 수 없음",
-    "Unable to update primary email address" : "주 이메일 주소를 갱신할 수 없음",
     "Unable to add additional email address" : "추가 이메일 주소를 추가할 수 없음",
     "Unable to update additional email address" : "추가 이메일 주소를 갱신할 수 없음",
-    "Unable to delete additional email address" : "추가 이메일 주소를 삭제할 수 없음",
     "Primary email for password reset and notifications" : "암호 초기화 및 알림 수신용 주 이메일 주소",
-    "No email address set" : "이메일 주소가 설정되지 않음",
     "Your handle" : "내 아이디",
     "Derived from your locale ({weekDayName})" : "지역의 규정을 바탕으로 함({weekDayName})",
     "Your headline" : "내 표제",
+    "No language set" : "언어가 설정되지 않음",
     "Unable to update language" : "언어를 갱신할 수 없음",
     "Languages" : "언어",
     "Help translate" : "번역 돕기",
-    "No language set" : "언어가 설정되지 않음",
+    "No locale set" : "지역이 설정되지 않음",
     "Unable to update locale" : "지역을 갱신할 수 없음",
     "Locales" : "지역",
     "Week starts on {firstDayOfWeek}" : "일주일이 {firstDayOfWeek}에 시작함",
-    "No locale set" : "지역이 설정되지 않음",
     "Your city" : "내 도시",
     "Your organisation" : "내 조직",
     "Your phone number" : "내 휴대폰 번호",
@@ -558,7 +574,6 @@ OC.L10N.register(
     "Other languages" : "다른 언어",
     "Password change is disabled because the master key is disabled" : "마스터 키가 비활성화 되어 암호 변경이 비활성화 됨",
     "No accounts" : "계정 없음",
-    "Loading accounts …" : "계정 불러오는 중 ...",
     "List of accounts. This list is not fully rendered for performance reasons. The accounts will be rendered as you navigate through the list." : "계정 목록입니다. 성능 저하를 막기 위해 이 목록을 완전히 처리하지 않았습니다. 계속 탐색하면 남은 목록이 자동으로 처리됩니다.",
     "Manager" : "담당 관리자",
     "New account" : "새로운 계정",
@@ -593,7 +608,6 @@ OC.L10N.register(
     "Password was successfully changed" : "암호를 성공적으로 변경함",
     "Email was successfully changed" : "이메일을 성공적으로 변경함",
     "Welcome mail sent!" : "환영 메일을 보냈습니다!",
-    "Loading account …" : "계정 불러오는 중 ...",
     "Change display name" : "표시 이름 변경",
     "Set new password" : "새 암호 설정",
     "You do not have permissions to see the details of this account" : "이 계정의 상세정보를 볼 권한이 없습니다.",
@@ -621,13 +635,26 @@ OC.L10N.register(
     "Passwordless authentication requires a secure connection." : "무암호 인증을 위해 보안 연결이 필요합니다.",
     "Add WebAuthn device" : "WebAuthn 기기 추가",
     "Please authorize your WebAuthn device." : "내 WebAuthn 기기를 인증하십시오.",
-    "Adding your device …" : "장치 추가 중 …",
     "Unnamed device" : "이름 없는 장치",
     "Passwordless Authentication" : "무암호 인증",
     "Set up your account for passwordless authentication following the FIDO2 standard." : "FIDO2 기준을 준수하여 계정에 무암호 인증을 설정하세요.",
     "No devices configured." : "설정된 기기가 없습니다.",
     "The following devices are configured for your account:" : "다음의 기기가 계정에 설정되었습니다:",
     "Your browser does not support WebAuthn." : "WebAuthn이 현재 브라우저를 지원하지 않습니다.",
+    "It is important to set up this server to be able to send emails, like for password reset and notifications." : "암호 초기화 및 알림 이메일을 보내려면 이메일 서버를 설정해야 합니다.",
+    "Send mode" : "보내기 모드",
+    "Encryption" : "암호화",
+    "Sendmail mode" : "Sendmail 모드",
+    "Disable certificate verification (insecure)" : "인증서 검증 비활성화 (안전하지 않음)",
+    "From address" : "보낸 사람 주소",
+    "Domain" : "도메인",
+    "Server address" : "서버 주소",
+    "Host" : "호스트",
+    "Port" : "포트",
+    "Authentication" : "인증",
+    "Authentication required" : "인증 필요함",
+    "Saving…" : "저장 중…",
+    "Save settings" : "설정 저장",
     "Security & setup warnings" : "보안 및 설치 경고",
     "Try again" : "다시 시도",
     "All checks passed." : "모든 검사를 통과했습니다.",
@@ -635,13 +662,10 @@ OC.L10N.register(
     "There are some warnings regarding your setup." : "설정을 살펴본 결과 몇 가지 경고할 것이 있습니다.",
     "As admin you can fine-tune the sharing behavior. Please see the documentation for more information." : "관리자로 공유 행동을 미세 조정할 수 있습니다. 더 많은 정보를 보려면 문서를 참조하십시오.",
     "You need to enable the File sharing App." : "파일 공유 앱을 활성화해야 합니다.",
-    "Developer documentation ↗" : "개발자 문서 ↗",
     "Apply" : "적용",
     "Admins" : "관리자",
     "Account group: {group}" : "계정 그룹: {group}",
     "Account management" : "계정 관리",
-    "Sending…" : "보내는 중…",
-    "Email sent" : "이메일 보냄",
     "Location" : "위치",
     "Profile picture" : "프로필 사진",
     "About" : "정보",
@@ -658,8 +682,16 @@ OC.L10N.register(
     "Profile visibility" : "프로필 표시 여부",
     "Locale" : "지역",
     "First day of week" : "주 시작 요일",
+    "Private" : "개인",
+    "Only visible to people matched via phone number integration through Talk on mobile" : "전화번호 통합으로 연결된 사용자에게만 보임",
     "Not available as this property is required for core functionality including file sharing and calendar invitations" : "이 설정은 파일 공유, 달력 초대 등 핵심 기능에 필요하므로 비울 수 없습니다",
+    "Local" : "로컬",
+    "Only visible to people on this instance and guests" : "이 인스턴스의 사용자와 손님만 볼 수 있음",
+    "Federated" : "연합",
+    "Only synchronize to trusted servers" : "신뢰할 수 있는 서버만 동기화할 수 있습니다.",
     "Not available as federation has been disabled for your account, contact your system administration if you have any questions" : "이 계정에 대한 연합이 비활성화되어 현재 사용할 수 없는 상태입니다. 시스템 관리자에게 문의하십시오.",
+    "Published" : "발행됨",
+    "Synchronize to trusted servers and the global and public address book" : "신뢰할 수 있는 서버와 전역 및 개인 연락처에 동기화",
     "Your apps" : "내 앱",
     "Active apps" : "활성화된 앱",
     "Disabled apps" : "비활성화된 앱",
@@ -697,23 +729,6 @@ OC.L10N.register(
     "General documentation" : "일반 문서",
     "Legal notice" : "법적 고지",
     "Privacy policy" : "개인 정보 취급 방침",
-    "None/STARTTLS" : "없음/STARTTLS",
-    "SSL" : "SSL",
-    "Open documentation" : "문서 열기",
-    "It is important to set up this server to be able to send emails, like for password reset and notifications." : "암호 초기화 및 알림 이메일을 보내려면 이메일 서버를 설정해야 합니다.",
-    "Send mode" : "보내기 모드",
-    "Encryption" : "암호화",
-    "Sendmail mode" : "Sendmail 모드",
-    "From address" : "보낸 사람 주소",
-    "Server address" : "서버 주소",
-    "Port" : "포트",
-    "Authentication" : "인증",
-    "Authentication required" : "인증 필요함",
-    "Credentials" : "인증 정보",
-    "SMTP Login" : "SMTP 로그인",
-    "SMTP Password" : "SMTP 암호",
-    "Save" : "저장",
-    "Test and verify email settings" : "이메일 설정 테스트 및 검증",
     "Reasons to use Nextcloud in your organization" : "당신의 조직에서 Nextcloud를 사용해야 할 이유",
     "Developed by the {communityopen}Nextcloud community{linkclose}, the {githubopen}source code{linkclose} is licensed under the {licenseopen}AGPL{linkclose}." : "{communityopen}Nextcloud 커뮤니티{linkclose}에서 개발, {githubopen}소스 코드{linkclose}는 {licenseopen}<abbr title=\"Affero General Public License\">AGPL</abbr>{linkclose} 라이선스를 따릅니다.",
     "Like our Facebook page" : "Facebook 페이지에서 좋아요 누르기",
@@ -721,25 +736,36 @@ OC.L10N.register(
     "Check out our blog" : "블로그 확인하기",
     "Subscribe to our newsletter" : "뉴스레터 구독하기",
     "This community release of Nextcloud is unsupported and instant notifications are unavailable." : "이 Nextcloud 커뮤니티 릴리즈는 지원되지 않으며 즉각적인 알림을 사용할 수 없습니다.",
+    "Open documentation" : "문서 열기",
     "Use a second factor besides your password to increase security for your account." : "사용자의 계정을 더욱 안전하게 보호하기 위해 암호와 함께 2단계 인증을 사용하세요.",
     "If you use third party applications to connect to Nextcloud, please make sure to create and configure an app password for each before enabling second factor authentication." : "Nextcloud에 연결하기 위해 서드파티 애플리케이션을 사용할 경우 2차 인증을 활성화하기 앞서 각 애플리케이션에 대한 앱 암호를 생성, 설정하십시오.",
+    "Very weak password" : "매우 약한 암호",
+    "Weak password" : "약한 암호",
+    "So-so password" : "그저 그런 암호",
+    "Good password" : "좋은 암호",
+    "Strong password" : "강력한 암호",
+    "Group list is empty" : "그룹 목록이 비었음",
+    "Unable to retrieve the group list" : "그룹 목록을 받아올 수 없음",
     "Logged in account must be a subadmin" : "로그인한 계정은 부관리자여야 합니다.",
-    "File locking" : "파일 잠금",
-    "Transactional file locking is disabled, this might lead to issues with race conditions. Enable \"filelocking.enabled\" in config.php to avoid these problems." : "트랜잭션 파일 잠금이 비활성화되어 있어 동시 접근 시 문제가 발생할 수 있습니다. config.php에서 \"filelocking.enabled\"를 활성화하여 이 문제를 방지하십시오.",
-    "The PHP memory limit is below the recommended value of %s." : "PHP 메모리 제한이 추천값인 %s보다 작습니다.",
-    "for WebAuthn passwordless login" : ": WebAuthn 무암호 인증을 위해 사용",
-    "for WebAuthn passwordless login, and SFTP storage" : ": WebAuthn 무암호 인증 및 SFTP 저장소를 위해 사용",
-    "Set default expiration date for shares" : "공유에 대한 기본 만료 날짜 설정",
-    "If autocompletion \"same group\" and \"phone number integration\" are enabled a match in either is enough to show the user." : "\"같은 그룹\" 또는 \"전화번호 기반\" 자동 채우기가 활성화되었을 경우 각 항목에 일치하는 사용자가 자동으로 표시됩니다.",
-    "Restrict account name autocompletion to users based on phone number integration" : "계정 이름 자동 완성을 전화번호 통합이 된 사용자에게로 제한",
-    "Allow autocompletion when entering the full name or email address (ignoring missing phonebook match and being in the same group)" : "전체 이름 또는 이메일 주소를 입력했을 때 사용자 이름 자동 채우기를 허용 (전화번호 일치/소속 그룹 일치 여부에 대한 설정값을 무시)",
+    "Exclude some groups from sharing" : "공유 기능을 제한할 그룹 지정",
+    "Limit sharing to some groups" : "공유 기능을 허용할 그룹 지정",
     "This app has no minimum Nextcloud version assigned. This will be an error in the future." : "이 앱은 Nextcloud 최소 버전을 지정하지 않았습니다. 차후 버전에서는 오류로 처리됩니다.",
     "This app has no maximum Nextcloud version assigned. This will be an error in the future." : "이 앱은 Nextcloud 최대 버전을 지정하지 않았습니다. 차후 버전에서는 오류로 처리됩니다.",
-    "Your biography" : "내 소개문구",
-    "You are using <strong>{usage}</strong>" : "<strong>{usage}</strong>를 사용하고 있습니다.",
-    "You are using <strong>{usage}</strong> of <strong>{totalSpace}</strong> (<strong>{usageRelative}%</strong>)" : "전체 <strong>{totalSpace}</strong> 중 <strong>{usage}</strong>(<strong>{usageRelative}%</strong>)를 사용하고 있습니다.",
+    "Loading accounts …" : "계정 불러오는 중 ...",
     "In case of lost device or exiting the organization, this can remotely wipe the Nextcloud data from all devices associated with {userid}. Only works if the devices are connected to the internet." : "기기를 분실했거나 조직에서 이탈할 경우, 이를 통해 모든 기기에 있는 {userid} 관련 Nextcloud 데이터를 원격으로 삭제할 수 있습니다. 해당 기기들이 인터넷에 연결된 경우에 한하여 작동합니다.",
+    "Loading account …" : "계정 불러오는 중 ...",
+    "Adding your device …" : "장치 추가 중 …",
+    "Developer documentation ↗" : "개발자 문서 ↗",
+    "Sending…" : "보내는 중…",
+    "Email sent" : "이메일 보냄",
     "This app is not marked as compatible with your Nextcloud version. If you continue you will still be able to install the app. Note that the app might not work as expected." : "이 앱은 현재 Nextcloud 버젼과 호환되지 않습니다.  이 앱을 설치하면, 제대로 작동하지 않을 수 있습니다.",
+    "None/STARTTLS" : "없음/STARTTLS",
+    "SSL" : "SSL",
+    "Credentials" : "인증 정보",
+    "SMTP Login" : "SMTP 로그인",
+    "SMTP Password" : "SMTP 암호",
+    "Save" : "저장",
+    "Test and verify email settings" : "이메일 설정 테스트 및 검증",
     "It's important for the security and performance of your instance that everything is configured correctly. To help you with that we are doing some automatic checks. Please see the linked documentation for more information." : "정확한 설정은 인스턴스의 보안과 성능에 중요합니다. 아래의 자동 진단 결과를 참조하여 최적의 설정으로 조정하십시오. 더 자세한 정보를 위해서 링크된 문서를 참고하세요.",
     "Checking for system and security issues." : "시스템과 보안에 대한 문제를 확인하는 중",
     "Please double check the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%1$s\">installation guides ↗</a>, and check for any errors or warnings in the <a href=\"%2$s\">log</a>." : "<a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%1$s\">설치 가이드 ↗</a>를 다시 한 번 확인한 다음 <a href=\"%2$s\">로그</a>의 경고나 오류를 확인하세요.",
