@@ -1,25 +1,6 @@
 OC.L10N.register(
     "settings",
     {
-    "Private" : "Privat",
-    "Only visible to people matched via phone number integration through Talk on mobile" : "Kun synlig for personer som matches via telefonnummerintegrasjon via Talk på mobil",
-    "Local" : "Lokal",
-    "Only visible to people on this instance and guests" : "Kun synlig for personer i denne installasjonen og for gjester",
-    "Federated" : "Sammenknyttet",
-    "Only synchronize to trusted servers" : "Synkroniser kun til betrodde servere",
-    "Published" : "Publisert",
-    "Synchronize to trusted servers and the global and public address book" : "Synkroniser til betrodde servere og den globale og offentlige adresseboken",
-    "Verify" : "Bekreft",
-    "Verifying …" : "Bekrefter…",
-    "Unable to change password" : "Kunne ikke endre passord",
-    "Very weak password" : "Veldig svakt passord",
-    "Weak password" : "Svakt passord",
-    "So-so password" : "Bob-bob-passord",
-    "Good password" : "Bra passord",
-    "Strong password" : "Sterkt passord",
-    "Groups" : "Grupper",
-    "Group list is empty" : "Gruppeliste er tom",
-    "Unable to retrieve the group list" : "Kunne ikke hente gruppelisten",
     "{actor} added you to group {group}" : "{actor} la deg til i gruppen {group}",
     "You added {user} to group {group}" : "Du la til {user} i gruppen {group}",
     "{actor} added {user} to group {group}" : "{actor} la {user} til i gruppen {group}",
@@ -57,6 +38,7 @@ OC.L10N.register(
     "Unable to change personal password" : "Kan ikke endre personlig passord",
     "Saved" : "Lagret",
     "No Login supplied" : "Ingen pålogging følger med",
+    "Unable to change password" : "Kunne ikke endre passord",
     "Unable to change password. Password too long." : "Kan ikke endre passord. Passordet er for langt.",
     "Authentication error" : "Autentiseringsfeil",
     "Please provide an admin recovery password; otherwise, all account data will be lost." : "Vennligst oppgi et administratorgjenopprettingspassord; ellers vil alle kontodata gå tapt.",
@@ -129,6 +111,8 @@ OC.L10N.register(
     "Background jobs" : "Bakgrunnsjobber",
     "Unlimited" : "Ubegrenset",
     "Verifying" : "Verifiserer",
+    "Verifying …" : "Bekrefter…",
+    "Verify" : "Bekreft",
     "Allowed admin IP ranges" : "Tillatte IP-områder for administrator",
     "Configuration key \"%1$s\" expects an array (%2$s found). Admin IP range validation will not be applied." : "Konfigurasjonsnøkkel \"%1$s\" forventer en nøkkel (%2$s funnet). Validering av IP-området for administrator blir ikke anvendt.",
     "Configuration key \"%1$s\" contains invalid IP range(s): \"%2$s\"" : "Konfigurasjonsnøkkel \"%1$s\" inneholder ugyldig(e) IP-område(r): \"%2$s\"",
@@ -348,8 +332,6 @@ OC.L10N.register(
     "Exclude groups from creating link shares" : "Ekskluder grupper fra å opprette delte koblingsressurser",
     "Limit sharing based on groups" : "Begrens deling basert på grupper",
     "Allow sharing for everyone (default)" : "Tillat deling for alle (standard)",
-    "Exclude some groups from sharing" : "Utelukk noen grupper fra deling",
-    "Limit sharing to some groups" : "Begrens deling til noen grupper",
     "Groups allowed to share" : "Grupper som kan dele",
     "Groups excluded from sharing" : "Grupper ekskludert fra deling",
     "Not allowed groups will still be able to receive shares, but not to initiate them." : "Ikke tillatte grupper vil fortsatt kunne motta delinger, men ikke starte dem.",
@@ -391,6 +373,7 @@ OC.L10N.register(
     "This app is supported via your current Nextcloud subscription." : "Denne appen er støttet av ditt nåværende Nextcloud abonnement.",
     "Featured apps are developed by and within the community. They offer central functionality and are ready for production use." : "Anbefalte apper er utviklet av og innenfor fellesskapet. De tilbyr sentral funksjonalitet og er klare for bruk i produksjon.",
     "Community rating: {score}/5" : "Samfunnsvurdering: {score}/5",
+    "Learn more" : "Lær mer",
     "Disable all" : "Deaktiver alle",
     "Download and enable all" : "Last ned og aktiver alle",
     "All apps are up-to-date." : "Alle apper er oppdatert.",
@@ -404,6 +387,7 @@ OC.L10N.register(
     "_%n app has an update available_::_%n apps have an update available_" : ["%n app har en oppdatering tilgjengelig","%n apper har en oppdatering tilgjengelig"],
     "_Update_::_Update all_" : ["Oppdater","Oppdater alle"],
     "Failed to create group" : "Kunne ikke opprette gruppe",
+    "Groups" : "Grupper",
     "Creating group…" : "Oppretter gruppe...",
     "Create group" : "Opprett gruppe",
     "Group name" : "Gruppenavn",
@@ -426,7 +410,6 @@ OC.L10N.register(
     "Display Name" : "Visningsnavn",
     "GPUs support" : "Støtte for GPUer",
     "Compute device" : "Beregningsenhet",
-    "Learn more" : "Lær mer",
     "Confirm" : "Bekreft",
     "Cancel" : "Avbryt",
     "Description" : "Beskrivelse",
@@ -551,6 +534,9 @@ OC.L10N.register(
     "You are using {s}{usage}{/s} of {s}{totalSpace}{/s} ({s}{usageRelative}%{/s})" : "Du bruker {s}{usage}{/s} of {s}{totalSpace}{/s} ({s}{usageRelative}%{/s})",
     "You are a member of the following groups:" : "Du er medlem av følgende grupper:",
     "Your full name" : "Ditt fulle navn",
+    "Unable to update primary email address" : "Kan ikke oppdatere primær e-postadresse",
+    "Unable to delete additional email address" : "Kan ikke slette ytterligere e-postadresse",
+    "No email address set" : "E-postadresse ikke satt",
     "Email options" : "Alternativer for e-post",
     "Options for additional email address {index}" : "Alternativer for ekstra e-postadresse {index}",
     "Remove primary email" : "Fjern primær e-post",
@@ -560,25 +546,22 @@ OC.L10N.register(
     "Set as primary email" : "Angi som primær e-post",
     "Additional email address {index}" : "Ekstra e-postadresse {index}",
     "Unable to delete primary email address" : "Kan ikke slette primær e-postadresse",
-    "Unable to update primary email address" : "Kan ikke oppdatere primær e-postadresse",
     "Unable to add additional email address" : "Kan ikke legge til ytterligere e-postadresse",
     "Unable to update additional email address" : "Kan ikke oppdatere ytterligere e-postadresse",
-    "Unable to delete additional email address" : "Kan ikke slette ytterligere e-postadresse",
     "Primary email for password reset and notifications" : "Primær e-postadresse for tilbakestilling av passord og varsler",
-    "No email address set" : "E-postadresse ikke satt",
     "Your handle" : "Ditt brukernavn",
     "Derived from your locale ({weekDayName})" : "Avledet fra din nasjonale innstilling ({weekDayName})",
     "Unable to update first day of week" : "Kan ikke oppdatere første dag i uken",
     "Day to use as the first day of week" : "Dag som skal brukes som første dag i uken",
     "Your headline" : "Din overskrift",
+    "No language set" : "Språk ikke satt",
     "Unable to update language" : "Kan ikke oppdatere språket",
     "Languages" : "Språk",
     "Help translate" : "Bidra til oversettelsen",
-    "No language set" : "Språk ikke satt",
+    "No locale set" : "Ingen nasjonal innstilling angitt",
     "Unable to update locale" : "Kan ikke oppdatere lokaliteten",
     "Locales" : "Nasjonale innstillinger",
     "Week starts on {firstDayOfWeek}" : "Uken starter på {firstDayOfWeek}",
-    "No locale set" : "Ingen nasjonal innstilling angitt",
     "Your city" : "Byen din",
     "Your organisation" : "Din organisasjon",
     "Your phone number" : "Ditt telefonnummer",
@@ -612,7 +595,6 @@ OC.L10N.register(
     "Other languages" : "Andre språk",
     "Password change is disabled because the master key is disabled" : "Passordendring er deaktivert fordi hoved-nøkkelen er deaktivert",
     "No accounts" : "Ingen kontoer",
-    "Loading accounts …" : "Laster kontoer…",
     "List of accounts. This list is not fully rendered for performance reasons. The accounts will be rendered as you navigate through the list." : "Liste over kontoer. Denne listen er ikke fullstendig gjengitt av ytelsesgrunner. Kontoene blir gjengitt når du navigerer gjennom listen.",
     "Manager" : "Sjef",
     "Set line manager" : "Angi linjeleder",
@@ -628,13 +610,11 @@ OC.L10N.register(
     "Member of the following groups" : "Medlem av følgende grupper",
     "Set account groups" : "Angi kontogrupper",
     "Admin of the following groups" : "Administrator for følgende grupper",
-    "Set account as admin for …" : "Angi konto som administrator for...",
     "Quota" : "Kvote",
     "Set account quota" : "Angi kontokvote",
     "Language" : "Språk",
     "Set default language" : "Angi standard språk",
     "Add new account" : "Legg til ny konto",
-    "_{userCount} account …_::_{userCount} accounts …_" : ["{userCount} konto…","{userCount} kontoer…"],
     "_{userCount} account_::_{userCount} accounts_" : ["{userCount} konto","{userCount} kontoer"],
     "Total rows summary" : "Sammendrag av totalrader",
     "Scroll to load more rows" : "Rull for å laste inn flere rader",
@@ -664,7 +644,6 @@ OC.L10N.register(
     "Password was successfully changed" : "Passord ble endret",
     "Email was successfully changed" : "E-post ble endret",
     "Welcome mail sent!" : "Velkomst-epost sendt!",
-    "Loading account …" : "Laster konto…",
     "Change display name" : "Endre visningsnavn",
     "Set new password" : "Angi nytt passord",
     "You do not have permissions to see the details of this account" : "Du har ikke tillatelser til å se detaljer om denne kontoen",
@@ -697,13 +676,26 @@ OC.L10N.register(
     "Passwordless authentication requires a secure connection." : "Passordløs autentisering krever en sikker tilkobling.",
     "Add WebAuthn device" : "Legg til WebAuthn-enhet",
     "Please authorize your WebAuthn device." : "Vennligst autoriser WebAuthn-enheten din",
-    "Adding your device …" : "Legger til enheten...",
     "Unnamed device" : "Ikke navngitt enhet",
     "Passwordless Authentication" : "Passordløs autentisering",
     "Set up your account for passwordless authentication following the FIDO2 standard." : "Sett opp kontoen din for passordløs autentisering i henhold til FIDO2-standarden.",
     "No devices configured." : "Ingen enheter konfigurert.",
     "The following devices are configured for your account:" : "Følgende enheter er konfigurert for kontoen din:",
     "Your browser does not support WebAuthn." : "Nettleseren din støtter ikke WebAuthn.",
+    "It is important to set up this server to be able to send emails, like for password reset and notifications." : "Det er viktig å sette opp denne serveren for å kunne sende e-poster, som tilbakestilling av e-poster og merknader.",
+    "Send mode" : "Forsendelsesmåte",
+    "Encryption" : "Kryptering",
+    "Sendmail mode" : "Sendmail-modus",
+    "Disable certificate verification (insecure)" : "Deaktiver verifisering av sertifikat (usikkert)",
+    "From address" : "Fra adresse",
+    "Domain" : "Domene",
+    "Server address" : "Serveradresse",
+    "Host" : "Server",
+    "Port" : "Port",
+    "Authentication" : "Autentisering",
+    "Authentication required" : "Autentisering kreves",
+    "Saving…" : "Lagrer…",
+    "Save settings" : "Lagre innstillinger",
     "Security & setup warnings" : "Advarsler om sikkerhet og oppsett",
     "Try again" : "Prøv igjen",
     "All checks passed." : "Alle sjekker bestått.",
@@ -714,7 +706,6 @@ OC.L10N.register(
     "App Store" : "Appbutikk",
     "Loading app list" : "Laster appliste",
     "Loading categories" : "Laster kategorier",
-    "Developer documentation ↗" : "Utviklerdokumentasjon ↗",
     "Version {version}, {license}-licensed" : "Versjon {version}, {license}-lisensiert",
     "Version {version}" : "Versjon {version}",
     "Apply" : "Bruk",
@@ -722,8 +713,6 @@ OC.L10N.register(
     "Admins" : "Administratorer",
     "Account group: {group}" : "Kontogruppe: {group}",
     "Account management" : "Kontoadministrasjon",
-    "Sending…" : "Sender…",
-    "Email sent" : "E-post sendt",
     "Location" : "Sted",
     "Profile picture" : "Profilbilde",
     "About" : "Om",
@@ -737,12 +726,21 @@ OC.L10N.register(
     "Pronouns" : "Pronomen",
     "Role" : "Rolle",
     "X (formerly Twitter)" : "X (tidligere Twitter)",
+    "Bluesky" : "Bluesky",
     "Website" : "Nettsted",
     "Profile visibility" : "Profil-synlighet",
     "Locale" : "Nasjonal innstilling",
     "First day of week" : "Første dag i uken",
+    "Private" : "Privat",
+    "Only visible to people matched via phone number integration through Talk on mobile" : "Kun synlig for personer som matches via telefonnummerintegrasjon via Talk på mobil",
     "Not available as this property is required for core functionality including file sharing and calendar invitations" : "Ikke tilgjengelig siden denne egenskapen kreves for kjernefunksjonalitet, inkludert fildeling og kalenderinvitasjoner.",
+    "Local" : "Lokal",
+    "Only visible to people on this instance and guests" : "Kun synlig for personer i denne installasjonen og for gjester",
+    "Federated" : "Sammenknyttet",
+    "Only synchronize to trusted servers" : "Synkroniser kun til betrodde servere",
     "Not available as federation has been disabled for your account, contact your system administration if you have any questions" : "Ikke tilgjengelig ettersom sammenknytning er deaktivert for kontoen din. Kontakt systemadministratoren hvis du har spørsmål.",
+    "Published" : "Publisert",
+    "Synchronize to trusted servers and the global and public address book" : "Synkroniser til betrodde servere og den globale og offentlige adresseboken",
     "Not available as publishing account specific data to the lookup server is not allowed, contact your system administration if you have any questions" : "Ikke tilgjengelig da publisering av kontospesifikke data til oppslagsserveren ikke er tillatt, kontakt systemadministratoren hvis du har spørsmål.",
     "Discover" : "Oppdag",
     "Your apps" : "Dine apper",
@@ -785,53 +783,46 @@ OC.L10N.register(
     "General documentation" : "Generell dokumentasjon",
     "Legal notice" : "Juridisk varsel",
     "Privacy policy" : "Personvern politikk",
+    "Reasons to use Nextcloud in your organization" : "Grunner til å bruke Nextcloud i organisasjonen din",
+    "Developed by the {communityopen}Nextcloud community{linkclose}, the {githubopen}source code{linkclose} is licensed under the {licenseopen}AGPL{linkclose}." : "Utviklet av {communityopen}Nextcloud-miljøet{linkclose},  {githubopen}kildekoden{linkclose} er lisensiert under {licenseopen}AGPL{linkclose}.",
+    "Like our Facebook page" : "Lik vår Facebook-side",
+    "Follow us on Mastodon" : "Følg oss på Mastadon",
+    "Check out our blog" : "Sjekk ut bloggen vår",
+    "Subscribe to our newsletter" : "Abonner på vårt nyhetsbrev",
+    "This community release of Nextcloud is unsupported and instant notifications are unavailable." : "Denne community-utgaven av NextCloud er ikke understøttet og umiddelbare varsler er derfor ikke tilgjengelig. ",
+    "Open documentation" : "Åpne dokumentasjonen",
+    "Use a second factor besides your password to increase security for your account." : "Bruk en annen faktor i tillegg til passordet ditt for å øke sikkerheten for kontoen din.",
+    "If you use third party applications to connect to Nextcloud, please make sure to create and configure an app password for each before enabling second factor authentication." : "Hvis du bruker tredjepartsapplikasjoner for å koble til Nextcloud, må du sørge for å opprette og konfigurere et app-passord for hver før du aktiverer tofaktorautentisering.",
+    "Very weak password" : "Veldig svakt passord",
+    "Weak password" : "Svakt passord",
+    "So-so password" : "Bob-bob-passord",
+    "Good password" : "Bra passord",
+    "Strong password" : "Sterkt passord",
+    "Group list is empty" : "Gruppeliste er tom",
+    "Unable to retrieve the group list" : "Kunne ikke hente gruppelisten",
+    "Logged in account must be a subadmin" : "Pålogget konto må være en underadministrator",
+    "- The `%1$s` HTTP header does not contain `%2$s`. This is a potential security or privacy risk, as it is recommended to adjust this setting accordingly." : "- HTTP-hodet '%1$s' inneholder ikke '%2$s'. Dette er en potensiell sikkerhets- eller personvernrisiko, da det anbefales å justere denne innstillingen tilsvarende.",
+    "Exclude some groups from sharing" : "Utelukk noen grupper fra deling",
+    "Limit sharing to some groups" : "Begrens deling til noen grupper",
+    "This app has no minimum Nextcloud version assigned. This will be an error in the future." : "Denne appen har ingen minimumversjon av Nextcloud definert. Dette vil være en feil i fremtiden.",
+    "This app has no maximum Nextcloud version assigned. This will be an error in the future." : "Denne appen har ingen høyeste versjon av Nextcloud definert. Dette vil være en feil i fremtiden.",
+    "Loading accounts …" : "Laster kontoer…",
+    "Set account as admin for …" : "Angi konto som administrator for...",
+    "_{userCount} account …_::_{userCount} accounts …_" : ["{userCount} konto…","{userCount} kontoer…"],
+    "In case of lost device or exiting the organization, this can remotely wipe the Nextcloud data from all devices associated with {userid}. Only works if the devices are connected to the internet." : "I tilfelle man har mistet enheter eller skal ut av organisasjonen, så kan dette fjernslette Nextcloud data fra alle enheter tilknyttet bruker med {userid}. Dette fungerer kun dersom enhetene er tilkoblet internett.",
+    "Loading account …" : "Laster konto…",
+    "Adding your device …" : "Legger til enheten...",
+    "Developer documentation ↗" : "Utviklerdokumentasjon ↗",
+    "Sending…" : "Sender…",
+    "Email sent" : "E-post sendt",
+    "This app is not marked as compatible with your Nextcloud version. If you continue you will still be able to install the app. Note that the app might not work as expected." : "Denne appen er ikke merket som kompatibel med Nextcloud-versjonen. Hvis du fortsetter, vil du fortsatt kunne installere appen. Vær oppmerksom på at appen kanskje ikke fungerer som forventet.",
     "None/STARTTLS" : "None/STARTTLS",
     "SSL" : "SSL",
-    "Open documentation" : "Åpne dokumentasjonen",
-    "It is important to set up this server to be able to send emails, like for password reset and notifications." : "Det er viktig å sette opp denne serveren for å kunne sende e-poster, som tilbakestilling av e-poster og merknader.",
-    "Send mode" : "Forsendelsesmåte",
-    "Encryption" : "Kryptering",
-    "Sendmail mode" : "Sendmail-modus",
-    "From address" : "Fra adresse",
-    "Server address" : "Serveradresse",
-    "Port" : "Port",
-    "Authentication" : "Autentisering",
-    "Authentication required" : "Autentisering kreves",
     "Credentials" : "Påloggingsdetaljer",
     "SMTP Login" : "SMTP-pålogging",
     "SMTP Password" : "SMTP-passord",
     "Save" : "Lagre",
     "Test and verify email settings" : "Test og bekreft e-postinnstillinger",
-    "Reasons to use Nextcloud in your organization" : "Grunner til å bruke Nextcloud i organisasjonen din",
-    "Developed by the {communityopen}Nextcloud community{linkclose}, the {githubopen}source code{linkclose} is licensed under the {licenseopen}AGPL{linkclose}." : "Utviklet av {communityopen}Nextcloud-miljøet{linkclose},  {githubopen}kildekoden{linkclose} er lisensiert under {licenseopen}AGPL{linkclose}.",
-    "Like our Facebook page" : "Lik vår Facebook-side",
-    "Follow us on X" : "Følg oss på X",
-    "Follow us on Mastodon" : "Følg oss på Mastadon",
-    "Check out our blog" : "Sjekk ut bloggen vår",
-    "Subscribe to our newsletter" : "Abonner på vårt nyhetsbrev",
-    "This community release of Nextcloud is unsupported and instant notifications are unavailable." : "Denne community-utgaven av NextCloud er ikke understøttet og umiddelbare varsler er derfor ikke tilgjengelig. ",
-    "Use a second factor besides your password to increase security for your account." : "Bruk en annen faktor i tillegg til passordet ditt for å øke sikkerheten for kontoen din.",
-    "If you use third party applications to connect to Nextcloud, please make sure to create and configure an app password for each before enabling second factor authentication." : "Hvis du bruker tredjepartsapplikasjoner for å koble til Nextcloud, må du sørge for å opprette og konfigurere et app-passord for hver før du aktiverer tofaktorautentisering.",
-    "Logged in account must be a subadmin" : "Pålogget konto må være en underadministrator",
-    "To allow this check to run you have to make sure that your Web server can connect to itself. Therefore it must be able to resolve and connect to at least one of its `trusted_domains` or the `overwrite.cli.url`. This failure may be the result of a server-side DNS mismatch or outbound firewall rule." : "For å la denne kontrollen kjøre, må du sørge for at webserveren din kan koble til seg selv. Derfor må den kunne løse og koble til minst en dens 'trusted_domains' eller 'overwrite.cli.url'. Denne feilen kan være et resultat av ikke-DNS-samsvar på serversiden eller en regel for utgående brannmur.",
-    "File locking" : "Låsing av filer",
-    "Transactional file locking is disabled, this might lead to issues with race conditions. Enable \"filelocking.enabled\" in config.php to avoid these problems." : "Låsing av transaksjonsfiler er deaktivert, dette kan føre til problemer med løpsforholdene. Aktiver \"filelocking.enabled\" i config.php for å unngå disse problemene.",
-    "The PHP memory limit is below the recommended value of %s." : "PHP-minnegrensen er under den anbefalte verdien på %s.",
-    "for WebAuthn passwordless login" : "for WebAuthn-passordfripålogging",
-    "for WebAuthn passwordless login, and SFTP storage" : "for WebAuthn-passordfripålogging og SFTP-lagring",
-    "- The `%1$s` HTTP header does not contain `%2$s`. This is a potential security or privacy risk, as it is recommended to adjust this setting accordingly." : "- HTTP-hodet '%1$s' inneholder ikke '%2$s'. Dette er en potensiell sikkerhets- eller personvernrisiko, da det anbefales å justere denne innstillingen tilsvarende.",
-    "PostgreSQL version \"%s\" detected. PostgreSQL >=12 and <=16 is suggested for best performance, stability and functionality with this version of Nextcloud." : "PostgreSQL-versjon \"%s\" oppdaget. PostgreSQL >=12 og <=16 foreslås for best ytelse, stabilitet og funksjonalitet med denne versjonen av Nextcloud.",
-    "Set default expiration date for shares" : "Angi standard utløpsdato for delinger",
-    "If autocompletion \"same group\" and \"phone number integration\" are enabled a match in either is enough to show the user." : "Hvis autofullføring \"samme gruppe\" og \"telefonnummerintegrasjon\" er aktivert, er en match i begge nok til å vise brukeren.",
-    "Restrict account name autocompletion to users based on phone number integration" : "Begrens automatisk fullføring av kontonavn til brukere basert på integrering av telefonnummer",
-    "Allow autocompletion when entering the full name or email address (ignoring missing phonebook match and being in the same group)" : "Tillat autofullføring når du skriver inn fullt navn eller e-postadresse (ignorerer manglende telefonbok-treff og er i samme gruppe)",
-    "This app has no minimum Nextcloud version assigned. This will be an error in the future." : "Denne appen har ingen minimumversjon av Nextcloud definert. Dette vil være en feil i fremtiden.",
-    "This app has no maximum Nextcloud version assigned. This will be an error in the future." : "Denne appen har ingen høyeste versjon av Nextcloud definert. Dette vil være en feil i fremtiden.",
-    "Your biography" : "Din biografi",
-    "You are using <strong>{usage}</strong>" : "Du bruker <strong>{usage}</strong>",
-    "You are using <strong>{usage}</strong> of <strong>{totalSpace}</strong> (<strong>{usageRelative}%</strong>)" : "Du bruker <strong>{usage}</strong> av <strong>{totalSpace}</strong> (<strong>{usageRelative}%</strong>)",
-    "In case of lost device or exiting the organization, this can remotely wipe the Nextcloud data from all devices associated with {userid}. Only works if the devices are connected to the internet." : "I tilfelle man har mistet enheter eller skal ut av organisasjonen, så kan dette fjernslette Nextcloud data fra alle enheter tilknyttet bruker med {userid}. Dette fungerer kun dersom enhetene er tilkoblet internett.",
-    "This app is not marked as compatible with your Nextcloud version. If you continue you will still be able to install the app. Note that the app might not work as expected." : "Denne appen er ikke merket som kompatibel med Nextcloud-versjonen. Hvis du fortsetter, vil du fortsatt kunne installere appen. Vær oppmerksom på at appen kanskje ikke fungerer som forventet.",
     "It's important for the security and performance of your instance that everything is configured correctly. To help you with that we are doing some automatic checks. Please see the linked documentation for more information." : "Det er viktig for sikkerheten og ytelsen på din installasjon at alt er satt opp rett. For å hjelpe deg er det satt i verk noen automatiske sjekker. Se vedlagt lenke for å lese mer i dokumentasjonen.",
     "Checking for system and security issues." : "Sjekker for system- og sikkerhetsfeil.",
     "Please double check the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%1$s\">installation guides ↗</a>, and check for any errors or warnings in the <a href=\"%2$s\">log</a>." : "Dobbeltsjekk <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%1$s\">installasjonsguidene ↗</a> og se etter feil eller advarsler i <a href=\"%2$s\">loggen</a>.",
