@@ -1,25 +1,6 @@
 OC.L10N.register(
     "settings",
     {
-    "Private" : "Privado",
-    "Only visible to people matched via phone number integration through Talk on mobile" : "Visível apenas a pessoas cujo acesso é realizado através de número de telefone, na app Talk em dispositivos móveis.",
-    "Local" : "Local",
-    "Only visible to people on this instance and guests" : "Visível apenas a pessoas nesta instância e a convidados",
-    "Federated" : "Federada",
-    "Only synchronize to trusted servers" : "Apenas sincronizar em servidores confiáveis",
-    "Published" : "Publicado",
-    "Synchronize to trusted servers and the global and public address book" : "Sincronizar a servidor confiável e global e lista de endereço público",
-    "Verify" : "Verificar",
-    "Verifying …" : "A verificar...",
-    "Unable to change password" : "Não é possível alterar a sua palavra-passe ",
-    "Very weak password" : "Palavra-passe muito fraca",
-    "Weak password" : "Palavra-passe fraca",
-    "So-so password" : "Palavra-passe aceitável",
-    "Good password" : "Palavra-passe boa",
-    "Strong password" : "Palavra-passe forte",
-    "Groups" : "Grupos",
-    "Group list is empty" : "Lista de grupo vazia",
-    "Unable to retrieve the group list" : "Não foi possível recolher a lista de grupo",
     "An administrator added you to group {group}" : "Um administrador adicionou-o ao grupo {group}",
     "An administrator added {user} to group {group}" : "Um administrador adicionou {user} ao grupo {group}",
     "{actor} removed you from group {group}" : "{actor} removeu-o do grupo {group}",
@@ -34,13 +15,17 @@ OC.L10N.register(
     "Security" : "Segurança",
     "You successfully logged in using two-factor authentication (%1$s)" : "Autenticado com sucesso utilizando autenticação de dois fatores (%1$s)",
     "A login attempt using two-factor authentication failed (%1$s)" : "Tentativa falhada de autenticação utilizando dois fatores (%1$s)",
+    "Remote wipe was started on %1$s" : "Eliminação remota iniciada em %1$s ",
+    "Remote wipe has finished on %1$s" : "Eliminação remota terminou em %1$s",
     "Your <strong>password</strong> or <strong>email</strong> was modified" : "A <strong>password</strong> ou <strong>email</strong> foram modificados",
     "Settings" : "Configurações",
     "Could not remove app." : "Não foi possível remover a aplicação",
     "Could not update app." : "Não foi possível atualizar a aplicação",
+    "QR Code login" : "Iniciar sessão com código QR",
     "Wrong password" : "Palavra-passe errada",
     "Unable to change personal password" : "Não foi possível mudar a palavra-passe pessoal",
     "Saved" : "Guardado",
+    "Unable to change password" : "Não é possível alterar a sua palavra-passe ",
     "Unable to change password. Password too long." : "Não foi possível mudar a palavra-passe. Palavra-passe demasiado longa.",
     "Authentication error" : "Erro na autenticação",
     "Wrong admin recovery password. Please check the password and try again." : "Palavra-passe de recuperação do administrador errada. Por favor, verifique a palavra-passe e tente novamente.",
@@ -52,11 +37,16 @@ OC.L10N.register(
     "If you received this email, the email configuration seems to be correct." : "Se recebeu este email, a configuração do serviço de email deverá estar correta.",
     "Email could not be sent. Check your mail server log" : "O email não pode ser enviado. Por favor verifique os logs do seu servidor de e-mail.",
     "A problem occurred while sending the email. Please revise your settings. (Error: %s)" : "Ocorreu um problema ao enviar o e-mail. Por favor verifique as suas definições. (Erro: %s)",
+    "Recently active" : "Ativo recentemente",
+    "Disabled accounts" : "Contas desativadas",
     "Invalid account" : "Conta inválida",
     "Invalid mail address" : "Endereço de correio eletrónico inválido",
     "Settings saved" : "Definições guardadas",
     "Unable to change full name" : "Não foi possível alterar o seu nome completo",
     "Unable to change email address" : "Não foi possível alterar o seu endereço de e-mail",
+    "Unable to set invalid phone number" : "Número de telefone inválido",
+    "Unable to set invalid website" : "Website inválido",
+    "Some account data was invalid" : "Alguns dados são inválidos",
     "In order to verify your Twitter account, post the following tweet on Twitter (please make sure to post it without any line breaks):" : "Por forma a validar a sua conta de Twitter, por favor publique o seguinte Twitter ( garanta que a publicação não contém quebras de linha):",
     "In order to verify your Website, store the following content in your web-root at '.well-known/CloudIdVerificationCode.txt' (please make sure that the complete text is in one line):" : "Por forma de validar o Website, por favor publique o conteúdo seguinte na sua raiz em 'well-known/CloudIdVerificationCode.txt' (garanta que o texto completo se encontra numa única linha):",
     "%1$s changed your password on %2$s." : "%1$s modificou a sua senha em %2$s.",
@@ -74,6 +64,7 @@ OC.L10N.register(
     "Welcome aboard" : "Bem-vindo a bordo",
     "Welcome aboard %s" : "Bem-vindo a bordo %s",
     "Welcome to your %s account, you can add, protect, and share your data." : "Bem-vindo à conta %s, aqui pode adicionar, proteger e partilhar os seus dados.",
+    "Your Login is: %s" : "O seu Login é: %s",
     "Set your password" : "Escolher senha",
     "Go to %s" : "Ir para %s",
     "Install Client" : "Instalar Cliente",
@@ -82,6 +73,7 @@ OC.L10N.register(
     "Administration" : "Administração",
     "Users" : "Utilizadores",
     "Additional settings" : "Definições adicionais",
+    "Assistant" : "Assistente",
     "Administration privileges" : "Privilégios de administração",
     "Overview" : "Visão Geral",
     "Basic settings" : "Definições básicas",
@@ -94,6 +86,8 @@ OC.L10N.register(
     "Background jobs" : "Tarefas de segundo plano",
     "Unlimited" : "Ilimitado",
     "Verifying" : "A verificar",
+    "Verifying …" : "A verificar...",
+    "Verify" : "Verificar",
     "Internet connectivity" : "Conetividade da Internet",
     "Internet connectivity is disabled in configuration file." : "A conetividade da Internet está desativada no ficheiro de configuração.",
     "Disabled" : "Desativado",
@@ -114,13 +108,16 @@ OC.L10N.register(
     "Allow public uploads" : "Permitir Envios Públicos",
     "Always ask for a password" : "Pedir sempre a senha",
     "Enforce password protection" : "Forçar proteção por palavra-passe",
+    "Set default expiration date for internal shares" : "Defina a data de expiração predefinida para as partilhas internas.",
     "Enforce expiration date" : "Forçar a data de expiração",
     "This text will be shown on the public link upload page when the file list is hidden." : "Este texto será exibido na página de carregamento de ligações públicas quando a lista de ficheiros estiver oculta. ",
     "Limit to groups" : "Limitado a grupos",
     "Save changes" : "Guardar alterações",
+    "Default" : "Predefinido",
     "Update to {update}" : "Atualizar para {update}",
     "Remove" : "Remover",
     "Featured" : "Destacado",
+    "Learn more" : "Conheça melhor",
     "Disable all" : "Desativar todos",
     "Download and enable all" : "Transferir e ativar tudo",
     "All apps are up-to-date." : "Todas as aplicações estão atualizadas",
@@ -131,22 +128,22 @@ OC.L10N.register(
     "Results from other categories" : "Resultados de outras categorias",
     "No apps found for your version" : "Nenhuma aplicação encontrada para a sua versão",
     "_Update_::_Update all_" : ["Atualizar","Atualizar todos","Atualizar todos"],
+    "Groups" : "Grupos",
+    "Group name" : "Nome do grupo",
     "Loading" : "A carregar",
     "Type" : "Tipo",
-    "Learn more" : "Conheça melhor",
     "Confirm" : "Confirmar",
     "Cancel" : "Cancelar",
     "Description" : "Descrição",
     "View in store" : "Ver na loja",
     "Visit website" : "Visitar o website",
-    "Admin documentation" : "Documentação do Administrador",
-    "Developer documentation" : "Documentação de Programador",
+    "Usage documentation" : "Documentação de utilização",
+    "Admin documentation" : "Documentação de administrador",
+    "Developer documentation" : "Documentação de programador",
     "Details" : "Detalhes",
     "All" : "Todos",
     "No results" : "Sem resultados",
     "Update to {version}" : "Atualizar para {version}",
-    "This app has no minimum Nextcloud version assigned. This will be an error in the future." : "Esta app não tem a versão mínima do Nextcloud atribuída. Isto será um erro no futuro.",
-    "This app has no maximum Nextcloud version assigned. This will be an error in the future." : "Esta app não tem a versão máxima do Nextcloud atribuída. Isto será um erro no futuro.",
     "This app cannot be installed because the following dependencies are not fulfilled:" : "Esta aplicação não pode ser instalada porque as seguintes dependências não podem ser realizadas:",
     "Author" : "Autor",
     "Categories" : "Categorias",
@@ -159,6 +156,7 @@ OC.L10N.register(
     "Rate" : "Classificar",
     "Changelog" : "Registo de alterações",
     "Google Chrome for Android" : "Google Chrome para Android",
+    "{productName} Android app" : "{productName} Aplicação Android",
     "Sync client" : "Sincronizar cliente",
     "This session" : "Esta sessão",
     "{client} - {version} ({system})" : "{client} - {version} ({system})",
@@ -173,11 +171,12 @@ OC.L10N.register(
     "Devices & sessions" : "Sessões e dispositivos",
     "Web, desktop and mobile clients currently logged in to your account." : "Os clientes da Web, de PC e móveis estão atualmente autenticados na sua conta.",
     "Error while creating device token" : "Erro durante a criação do token do dispositivo",
-    "App name" : "Nome da App",
+    "App name" : "Nome da aplicação",
     "Create new app password" : "Criar nova palavra-passe de aplicação",
     "Login" : "Iniciar Sessão",
     "Password" : "Palavra-passe",
     "Profile" : "Perfil",
+    "Password confirmation is required" : "Confirmação de senha necessária",
     "Server-side encryption" : "Atualizar App",
     "Server-side encryption makes it possible to encrypt files which are uploaded to this server. This comes with limitations like a performance penalty, so enable this only if needed." : "A cifra do lado do servidor possibilita cifrar os ficheiros que serão enviados para este servidor. Isto implica um impacto no desempenho e só deverá ser ativo quando necessário.",
     "Enable server-side encryption" : "Ativar encriptação do lado do servidor",
@@ -190,9 +189,10 @@ OC.L10N.register(
     "It is always good to create regular backups of your data, in case of encryption make sure to backup the encryption keys along with your data." : "É sempre bom criar cópias de segurança regulares dos seus dados, em caso de encriptação tenha a certeza de que faz cópia das chaves de encriptação em conjunto com os seus dados.",
     "This is the final warning: Do you really want to enable encryption?" : "Este é o aviso final: quer mesmo ativar a encriptação?",
     "Submit" : "Submeter",
+    "Rename group" : "Renomear grupo",
+    "Delete group" : "Apagar grupo",
     "Current password" : "Palavra-passe atual",
     "New password" : "Nova palavra-passe",
-    "Change password" : "Alterar palavra-passe",
     "Choose your profile picture" : "Escolher imagem de perfil",
     "Please select a valid png or jpg file" : "Escolha ficheiro png ou jpg válido",
     "Error setting profile picture" : "Erro a definir imagem de perfil",
@@ -207,39 +207,63 @@ OC.L10N.register(
     "Set as profile picture" : "Definir como imagem de perfil",
     "You are a member of the following groups:" : "Membro dos seguintes grupos:",
     "Your full name" : "Nome completo",
+    "No email address set" : "Nenhum endereço de email estabelecido",
     "Email options" : "Opções de correio eletrónico",
     "Remove primary email" : "Remoção de correio eletrónico principal",
     "Delete email" : "Apagar correio eletrónico",
     "Unset as primary email" : "Remove atribuição de correio eletrónico como principal",
-    "No email address set" : "Nenhum endereço de email estabelecido",
     "Help translate" : "Ajude a traduzir",
+    "Week starts on {firstDayOfWeek}" : "Semana começa em {firstDayOfWeek}",
     "Your phone number" : "O seu número de telefone",
+    "Edit your Profile visibility" : "Editar a visibilidade do seu Perfil",
+    "Enable profile" : "Ativar perfil",
     "Add" : "Adicionar",
     "Create" : "Criar",
     "Change" : "Mudar",
-    "Delete" : "Apagar",
+    "Delete" : "Eliminar",
     "Reshare" : "Partilhar novamente",
-    "Display name" : "Nome de apresentação",
+    "Enabled applications" : "Aplicações ativadas",
+    "Disabled applications" : "Aplicações desativadas",
+    "Setup warnings" : "Configurar avisos",
+    "Display name" : "Nome a exibir",
     "Email" : "Email",
     "Quota" : "Quota",
     "Language" : "Idioma",
     "Total rows summary" : "Resumo do total de linhas",
     "Avatar" : "Avatar",
+    "Account name" : "Nome da conta",
     "Group admin for" : "Administrador de grupo para",
     "Storage location" : "Localização do armazenamento",
     "Last login" : "Último início de sessão",
     "{size} used" : "{size} utilizado",
+    "Delete account" : "Remover conta",
+    "Disable account" : "Desativar conta",
+    "Enable account" : "Ativar conta",
     "Done" : "Concluído",
     "Edit" : "Editar",
     "Visibility" : "Visibilidade",
     "Show last login" : "Mostrar último início de sessão",
+    "Sorting" : "Ordenação",
     "Send email" : "Enviar email",
     "Default quota" : "Quota padrão",
+    "It is important to set up this server to be able to send emails, like for password reset and notifications." : "É importante configurar este servidor para ser possível enviar emails, possibilitando enviar notificações bem como possibilitar a recuperação de senhas.",
+    "Send mode" : "Modo de Envio",
+    "Encryption" : "Encriptação",
+    "From address" : "Do endereço",
+    "Domain" : "Domínio",
+    "Server address" : "Endereço do Servidor",
+    "Host" : "Anfitrião",
+    "Port" : "Porta",
+    "Authentication" : "Autenticação",
+    "Authentication required" : "Autenticação necessária",
+    "Saving…" : "A guardar...",
+    "Please double check the {linkStartInstallationGuides}installation guides{linkEnd}, and check for any errors or warnings in the {linkStartLog}log{linkEnd}." : "Por favor verifique novamente os\n{linkStartInstallationGuides}guias de instalação\n{linkEnd} e verifique se há erros ou avisos no \n{linkStartLog}registo{linkEnd}.",
+    "Security & setup warnings" : "Avisos de configuração e segurança",
+    "All checks passed." : "Todas as verificações passaram.",
+    "There are some warnings regarding your setup." : "Existem alguns avisos referentes à sua configuração.",
     "As admin you can fine-tune the sharing behavior. Please see the documentation for more information." : "Como administrador pode afinar o comportamento de partilha. Por favor veja a documentação para mais informação.",
+    "Apply" : "Aplicar",
     "Admins" : "Administrador",
-    "Group name" : "Nome do grupo",
-    "Sending…" : "A enviar...",
-    "Email sent" : "Mensagem de correio eletrónico enviada",
     "Location" : "Localização",
     "Profile picture" : "Foto do perfil",
     "About" : "Sobre",
@@ -249,6 +273,14 @@ OC.L10N.register(
     "Phone number" : "Número de telefone",
     "Role" : "Função",
     "Website" : "Website",
+    "Private" : "Privado",
+    "Only visible to people matched via phone number integration through Talk on mobile" : "Visível apenas a pessoas cujo acesso é realizado através de número de telefone, na app Talk em dispositivos móveis.",
+    "Local" : "Local",
+    "Only visible to people on this instance and guests" : "Visível apenas a pessoas nesta instância e a convidados",
+    "Federated" : "Federada",
+    "Only synchronize to trusted servers" : "Apenas sincronizar em servidores confiáveis",
+    "Published" : "Publicado",
+    "Synchronize to trusted servers and the global and public address book" : "Sincronizar a servidor confiável e global e lista de endereço público",
     "Your apps" : "As suas apps",
     "Disabled apps" : "Apps desativadas",
     "Updates" : "Atualizações",
@@ -263,33 +295,37 @@ OC.L10N.register(
     "The app has been enabled but needs to be updated. You will be redirected to the update page in 5 seconds." : "A aplicação foi ativada mas necessita ser atualizada. Irá ser redirecionado para a página de atualização em 5 segundos.",
     "Do you really want to wipe your data from this device?" : "Tem a certeza que deseja apagar os dados deste dispositivo?",
     "Confirm wipe" : "Confirmação de limpeza",
+    "There were too many requests from your network. Retry later or contact your administrator if this is an error." : "Foram efetuados demasiados pedidos a partir da sua rede. Tente mais tarde ou contacte o administrador se for um erro.",
     "Error" : "Erro",
     "Forum" : "Fórum",
     "Legal notice" : "Informação legal",
     "Privacy policy" : "Política de privacidade",
-    "SSL" : "SSL",
-    "Open documentation" : "Abrir documentação",
-    "It is important to set up this server to be able to send emails, like for password reset and notifications." : "É importante configurar este servidor para ser possível enviar emails, possibilitando enviar notificações bem como possibilitar a recuperação de senhas.",
-    "Send mode" : "Modo de Envio",
-    "Encryption" : "Encriptação",
-    "From address" : "Do endereço",
-    "Server address" : "Endereço do Servidor",
-    "Port" : "Porta",
-    "Authentication" : "Autenticação",
-    "Authentication required" : "Autenticação necessária",
-    "Credentials" : "Credenciais",
-    "SMTP Password" : "Palavra-passe SMTP",
-    "Save" : "Guardar",
-    "Security & setup warnings" : "Avisos de configuração e segurança",
-    "All checks passed." : "Todas as verificações passaram.",
     "Developed by the {communityopen}Nextcloud community{linkclose}, the {githubopen}source code{linkclose} is licensed under the {licenseopen}AGPL{linkclose}." : "Desenvolvido pela [communityopen]Comunidade Nextcloud[linkclose]. O [githubcode]código fonte[/linkclose] está licenciado sob [licenseopen]AGPL[linkclose].",
     "Like our Facebook page" : "Deixe um Gosto na nossa página do Facebook",
     "Check out our blog" : "Veja o nosso blog",
     "Subscribe to our newsletter" : "Subscreva as nossas notícias",
     "This community release of Nextcloud is unsupported and instant notifications are unavailable." : "Este lançamento comunitário do Nextcloud não é compatível e as notificações instantâneas não estão disponíveis.",
-    "Your biography" : "Biografia",
-    "Username" : "Nome de utilizador",
-    "User backend" : "Backend do utilizador",
-    "Follow us on Twitter" : "Siga-nos no Twitter"
+    "Open documentation" : "Abrir documentação",
+    "Very weak password" : "Palavra-passe muito fraca",
+    "Weak password" : "Palavra-passe fraca",
+    "So-so password" : "Palavra-passe aceitável",
+    "Good password" : "Palavra-passe boa",
+    "Strong password" : "Palavra-passe forte",
+    "Group list is empty" : "Lista de grupo vazia",
+    "Unable to retrieve the group list" : "Não foi possível recolher a lista de grupo",
+    "This app has no minimum Nextcloud version assigned. This will be an error in the future." : "Esta app não tem a versão mínima do Nextcloud atribuída. Isto será um erro no futuro.",
+    "This app has no maximum Nextcloud version assigned. This will be an error in the future." : "Esta app não tem a versão máxima do Nextcloud atribuída. Isto será um erro no futuro.",
+    "Loading accounts …" : "A carregar contas ...",
+    "Loading account …" : "A carregar a conta ...",
+    "Adding your device …" : "A adicionar o seu dispositivo ...",
+    "Sending…" : "A enviar...",
+    "Email sent" : "Mensagem de correio eletrónico enviada",
+    "SSL" : "SSL",
+    "Credentials" : "Credenciais",
+    "SMTP Password" : "Palavra-passe SMTP",
+    "Save" : "Guardar",
+    "Test and verify email settings" : "Testar e verificar as definições de e-mail",
+    "Please double check the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%1$s\">installation guides ↗</a>, and check for any errors or warnings in the <a href=\"%2$s\">log</a>." : "Por favor, verifique novamente os <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%1$s\">guias de instalação ↗</a> e procure erros ou avisos no <a href=\"%2$s\">registo</a>.",
+    "Check the security of your Nextcloud over <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">our security scan ↗</a>." : "Verificar a segurança do seu Nextcloud através da nossa <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">ferramenta de análise de segurança</a>. "
 },
 "nplurals=3; plural=(n == 0 || n == 1) ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
