@@ -1,25 +1,6 @@
 OC.L10N.register(
     "settings",
     {
-    "Private" : "Riêng tư",
-    "Only visible to people matched via phone number integration through Talk on mobile" : "Chỉ hiển thị với những người phù hợp thông qua tích hợp số điện thoại thông qua Talk trên thiết bị di động",
-    "Local" : "Cục bộ",
-    "Only visible to people on this instance and guests" : "Chỉ hiển thị với mọi người trong trường hợp này và khách",
-    "Federated" : "Federated",
-    "Only synchronize to trusted servers" : "Chỉ đồng bộ đối với máy chủ tin cậy",
-    "Published" : "Đã đăng",
-    "Synchronize to trusted servers and the global and public address book" : "Đồng bộ với máy chủ tin cậy và sổ địa chỉ toàn cầu và công khai",
-    "Verify" : "Xác minh",
-    "Verifying …" : "Đang xác minh ...",
-    "Unable to change password" : "Không thể thay đổi mật khẩu",
-    "Very weak password" : "Mật khẩu rất yếu",
-    "Weak password" : "Mật khẩu yếu",
-    "So-so password" : "Mật khẩu tương tự",
-    "Good password" : "Mật khẩu tốt",
-    "Strong password" : "Mật khẩu mạnh",
-    "Groups" : "Nhóm",
-    "Group list is empty" : "Danh sách nhóm trống",
-    "Unable to retrieve the group list" : "Không thể truy xuất danh sách nhóm",
     "{actor} added you to group {group}" : "{actor} đã thêm bạn vào nhóm {group}",
     "You added {user} to group {group}" : "Bạn đã thêm {user} vào nhóm {group}",
     "{actor} added {user} to group {group}" : "{actor} đã thêm {user} vào nhóm {group}",
@@ -56,6 +37,7 @@ OC.L10N.register(
     "Wrong password" : "Mật khẩu không chính xác",
     "Unable to change personal password" : "Không thể thay đổi mật khẩu cá nhân",
     "Saved" : "Đã lưu",
+    "Unable to change password" : "Không thể thay đổi mật khẩu",
     "Unable to change password. Password too long." : "Không thể đổi mật khẩu. Mật khẩu quá dài.",
     "Authentication error" : "Lỗi xác thực",
     "Wrong admin recovery password. Please check the password and try again." : "Sai mật khẩu khôi phục quản trị viên. Vui lòng kiểm tra mật khẩu và thử lại.",
@@ -115,6 +97,8 @@ OC.L10N.register(
     "Background jobs" : "Các công việc trong nền",
     "Unlimited" : "Không giới hạn",
     "Verifying" : "Đang xác minh",
+    "Verifying …" : "Đang xác minh ...",
+    "Verify" : "Xác minh",
     "Your data directory and files are probably accessible from the internet. The .htaccess file is not working. It is strongly recommended that you configure your web server so that the data directory is no longer accessible, or move the data directory outside the web server document root." : "Thư mục dữ liệu và tệp của bạn có thể truy cập được từ internet. Tệp .htaccess không hoạt động. Chúng tôi khuyên bạn nên cấu hình máy chủ web của mình để thư mục dữ liệu không thể truy cập được nữa hoặc di chuyển thư mục dữ liệu ra ngoài thư mục gốc tài liệu máy chủ web.",
     "The database is missing some optional columns. Due to the fact that adding columns on big tables could take some time they were not added automatically when they can be optional. By running \"occ db:add-missing-columns\" those missing columns could be added manually while the instance keeps running. Once the columns are added some features might improve responsiveness or usability." : "Cơ sở dữ liệu thiếu một số cột tùy chọn. Do thực tế là việc thêm cột trên các bảng lớn có thể mất một chút thời gian, chúng không được thêm tự động khi chúng có thể là tùy chọn. Bằng cách chạy \"occ db:add-missing-columns\", các cột bị thiếu đó có thể được thêm thủ công trong khi phiên bản tiếp tục chạy. Sau khi các cột được thêm vào, một số tính năng có thể cải thiện khả năng phản hồi hoặc khả năng sử dụng.",
     "The database is missing some primary keys. Due to the fact that adding primary keys on big tables could take some time they were not added automatically. By running \"occ db:add-missing-primary-keys\" those missing primary keys could be added manually while the instance keeps running." : "Cơ sở dữ liệu thiếu một số khóa chính. Do thực tế là việc thêm các khóa chính trên các bảng lớn có thể mất một thời gian, chúng không được thêm tự động. Bằng cách chạy \"occ db:add-missing-primary-keys\", các khóa chính bị thiếu đó có thể được thêm thủ công trong khi phiên bản tiếp tục chạy.",
@@ -177,6 +161,7 @@ OC.L10N.register(
     "Featured" : "Tính năng được trang bị",
     "This app is supported via your current Nextcloud subscription." : "Ứng dụng này được hỗ trợ thông qua thuê bao Nextcloud hiện tại của bạn.",
     "Featured apps are developed by and within the community. They offer central functionality and are ready for production use." : "Các ứng dụng nổi bật được phát triển bởi và trong cộng đồng. Chúng cung cấp chức năng trung tâm và sẵn sàng để sử dụng trong sản xuất.",
+    "Learn more" : "Đọc nhiều hơn",
     "Disable all" : "Vô hiệu hóa tất cả",
     "Download and enable all" : "Tải xuống và kích hoạt tất cả",
     "All apps are up-to-date." : "Tất cả ứng dụng được cập nhật.",
@@ -190,12 +175,12 @@ OC.L10N.register(
     "_%n app has an update available_::_%n apps have an update available_" : ["%n ứng dụng có sẵn bản cập nhật"],
     "_Update_::_Update all_" : ["Cập nhật tất cả"],
     "Failed to create group" : "Không tạo được nhóm",
+    "Groups" : "Nhóm",
     "Create group" : "Tạo nhóm",
     "Group name" : "Tên nhóm",
     "Please enter a valid group name" : "Vui lòng nhập tên nhóm hợp lệ",
     "Loading" : "Đang tải",
     "Type" : "Loại",
-    "Learn more" : "Đọc nhiều hơn",
     "Confirm" : "Xác nhận",
     "Cancel" : "Hủy",
     "Description" : "Mô tả",
@@ -285,6 +270,9 @@ OC.L10N.register(
     "Please note that it can take up to 24 hours for your profile picture to be updated everywhere." : "Xin lưu ý rằng có thể mất tới 24 giờ để ảnh hồ sơ của bạn được cập nhật ở mọi nơi.",
     "You are a member of the following groups:" : "Bạn là thành viên của các nhóm sau:",
     "Your full name" : "Tên đầy đủ của bạn",
+    "Unable to update primary email address" : "Không thể cập nhật địa chỉ email chính",
+    "Unable to delete additional email address" : "Không thể xóa địa chỉ email bổ sung",
+    "No email address set" : "Chưa thiết lập địa chỉ email",
     "Email options" : "Tùy chọn email",
     "Remove primary email" : "Xóa email chính",
     "Delete email" : "Xóa email",
@@ -293,19 +281,16 @@ OC.L10N.register(
     "Set as primary email" : "Đặt làm email chính",
     "Additional email address {index}" : "Địa chỉ email bổ sung {index}",
     "Unable to delete primary email address" : "Không thể xóa địa chỉ email chính",
-    "Unable to update primary email address" : "Không thể cập nhật địa chỉ email chính",
     "Unable to add additional email address" : "Không thể thêm địa chỉ email bổ sung",
     "Unable to update additional email address" : "Không thể cập nhật địa chỉ email bổ sung",
-    "Unable to delete additional email address" : "Không thể xóa địa chỉ email bổ sung",
     "Primary email for password reset and notifications" : "Email chính để đặt lại mật khẩu và thông báo",
-    "No email address set" : "Chưa thiết lập địa chỉ email",
     "Your headline" : "Tiêu đề của bạn",
+    "No language set" : "Không có ngôn ngữ",
     "Unable to update language" : "Không thể cập nhật ngôn ngữ",
     "Help translate" : "Hỗ trợ dịch thuật",
-    "No language set" : "Không có ngôn ngữ",
+    "No locale set" : "Không có ngôn ngữ nào được đặt",
     "Unable to update locale" : "Không thể cập nhật ngôn ngữ",
     "Week starts on {firstDayOfWeek}" : "Tuần bắt đầu vào {firstDayOfWeek}",
-    "No locale set" : "Không có ngôn ngữ nào được đặt",
     "Your city" : "Thành phố",
     "Your organisation" : "Tổ chức",
     "Your phone number" : "Số điện thoại",
@@ -379,13 +364,25 @@ OC.L10N.register(
     "Passwordless authentication requires a secure connection." : "Xác thực không cần mật khẩu yêu cầu kết nối an toàn.",
     "Add WebAuthn device" : "Thêm thiết bị WebAuthn",
     "Please authorize your WebAuthn device." : "Vui lòng ủy quyền cho thiết bị WebAuthn của bạn.",
-    "Adding your device …" : "Đang thêm thiết bị của bạn…",
     "Unnamed device" : "Thiết bị chưa được đặt tên",
     "Passwordless Authentication" : "Xác thực không cần mật khẩu",
     "Set up your account for passwordless authentication following the FIDO2 standard." : "Thiết lập tài khoản của bạn để xác thực không cần mật khẩu theo tiêu chuẩn FIDO2.",
     "No devices configured." : "Không có thiết bị nào được định cấu hình.",
     "The following devices are configured for your account:" : "Các thiết bị sau được định cấu hình cho tài khoản của bạn:",
     "Your browser does not support WebAuthn." : "Trình duyệt của bạn không hỗ trợ WebAuthn.",
+    "It is important to set up this server to be able to send emails, like for password reset and notifications." : "Điều quan trọng là phải thiết lập máy chủ này để có thể gửi email, chẳng hạn như để đặt lại mật khẩu và thông báo.",
+    "Send mode" : "Chế độ gửi",
+    "Encryption" : "Mã hóa",
+    "Sendmail mode" : "Chế độ gửi thư",
+    "Disable certificate verification (insecure)" : "Tắt xác minh chứng chỉ (không an toàn)",
+    "From address" : "Từ địa chỉ",
+    "Domain" : "Miền",
+    "Server address" : "Địa chỉ máy chủ",
+    "Host" : "Máy chủ",
+    "Port" : "Cổng",
+    "Authentication" : "Xác thực",
+    "Authentication required" : "Cần phải được xác thực",
+    "Saving…" : "Đang lưu...",
     "Security & setup warnings" : "Bảo mật và thiết lập cảnh báo",
     "Try again" : "Thử lại",
     "All checks passed." : "Tất cả các kiểm tra đã thoả điều kiện",
@@ -395,8 +392,6 @@ OC.L10N.register(
     "You need to enable the File sharing App." : "Bạn cần kích hoạt Ứng dụng chia sẻ tệp.",
     "Apply" : "Áp dụng",
     "Admins" : "Quản trị viên",
-    "Sending…" : "Đang gửi...",
-    "Email sent" : "Email đã được gửi",
     "Location" : "Vị trí",
     "Profile picture" : "Ảnh đại diện",
     "About" : "Giới thiệu",
@@ -409,7 +404,15 @@ OC.L10N.register(
     "Website" : "Website",
     "Profile visibility" : "Tấm nhìn hồ sơ",
     "Locale" : "Ngôn ngữ",
+    "Private" : "Riêng tư",
+    "Only visible to people matched via phone number integration through Talk on mobile" : "Chỉ hiển thị với những người phù hợp thông qua tích hợp số điện thoại thông qua Talk trên thiết bị di động",
     "Not available as this property is required for core functionality including file sharing and calendar invitations" : "Không có sẵn vì thuộc tính này là bắt buộc đối với chức năng cốt lõi bao gồm chia sẻ tệp và lời mời lịch",
+    "Local" : "Cục bộ",
+    "Only visible to people on this instance and guests" : "Chỉ hiển thị với mọi người trong trường hợp này và khách",
+    "Federated" : "Federated",
+    "Only synchronize to trusted servers" : "Chỉ đồng bộ đối với máy chủ tin cậy",
+    "Published" : "Đã đăng",
+    "Synchronize to trusted servers and the global and public address book" : "Đồng bộ với máy chủ tin cậy và sổ địa chỉ toàn cầu và công khai",
     "Your apps" : "Ứng dụng của bạn",
     "Active apps" : "Ứng dụng kích hoạt",
     "Disabled apps" : "Ứng dụng vô hiệu hóa",
@@ -442,30 +445,25 @@ OC.L10N.register(
     "Legal notice" : "Thông cáo pháp lý",
     "Privacy policy" : "Chính sách riêng tư",
     "Open documentation" : "Mở tài liệu",
-    "It is important to set up this server to be able to send emails, like for password reset and notifications." : "Điều quan trọng là phải thiết lập máy chủ này để có thể gửi email, chẳng hạn như để đặt lại mật khẩu và thông báo.",
-    "Send mode" : "Chế độ gửi",
-    "Encryption" : "Mã hóa",
-    "Sendmail mode" : "Chế độ gửi thư",
-    "From address" : "Từ địa chỉ",
-    "Server address" : "Địa chỉ máy chủ",
-    "Port" : "Cổng",
-    "Authentication" : "Xác thực",
-    "Authentication required" : "Cần phải được xác thực",
+    "Use a second factor besides your password to increase security for your account." : "Sử dụng yếu tố thứ hai ngoài mật khẩu để tăng tính bảo mật cho tài khoản của bạn.",
+    "Very weak password" : "Mật khẩu rất yếu",
+    "Weak password" : "Mật khẩu yếu",
+    "So-so password" : "Mật khẩu tương tự",
+    "Good password" : "Mật khẩu tốt",
+    "Strong password" : "Mật khẩu mạnh",
+    "Group list is empty" : "Danh sách nhóm trống",
+    "Unable to retrieve the group list" : "Không thể truy xuất danh sách nhóm",
+    "This app has no minimum Nextcloud version assigned. This will be an error in the future." : "Ứng dụng này không có phiên bản Nextcloud tối thiểu được chỉ định. Đây sẽ là một lỗi trong tương lai.",
+    "This app has no maximum Nextcloud version assigned. This will be an error in the future." : "Ứng dụng này không có phiên bản Nextcloud tối đa được chỉ định. Đây sẽ là một lỗi trong tương lai.",
+    "In case of lost device or exiting the organization, this can remotely wipe the Nextcloud data from all devices associated with {userid}. Only works if the devices are connected to the internet." : "Trong trường hợp thiết bị bị mất hoặc thoát khỏi tổ chức, thao tác này có thể xóa từ xa dữ liệu Nextcloud khỏi tất cả các thiết bị được liên kết với {userid}. Chỉ hoạt động nếu các thiết bị được kết nối với internet.",
+    "Adding your device …" : "Đang thêm thiết bị của bạn…",
+    "Sending…" : "Đang gửi...",
+    "Email sent" : "Email đã được gửi",
+    "This app is not marked as compatible with your Nextcloud version. If you continue you will still be able to install the app. Note that the app might not work as expected." : "Ứng dụng này không được đánh dấu là tương thích với phiên bản Nextcloud của bạn. Nếu bạn tiếp tục, bạn vẫn có thể cài đặt ứng dụng. Lưu ý rằng ứng dụng có thể không hoạt động như mong đợi.",
     "Credentials" : "Giấy chứng nhận",
     "SMTP Password" : "Mật khẩu SMTP",
     "Save" : "Lưu",
     "Test and verify email settings" : "Kiểm tra và xác minh cài đặt email",
-    "Use a second factor besides your password to increase security for your account." : "Sử dụng yếu tố thứ hai ngoài mật khẩu để tăng tính bảo mật cho tài khoản của bạn.",
-    "Set default expiration date for shares" : "Đặt ngày hết hạn mặc định cho cổ phiếu",
-    "If autocompletion \"same group\" and \"phone number integration\" are enabled a match in either is enough to show the user." : "Nếu tính năng tự động hoàn thành \"cùng nhóm\" và \"tích hợp số điện thoại\" được bật thì kết quả khớp trong cả hai đều đủ để hiển thị cho người dùng.",
-    "Allow autocompletion when entering the full name or email address (ignoring missing phonebook match and being in the same group)" : "Cho phép tự động điền khi nhập họ tên hoặc địa chỉ email (bỏ qua trùng danh bạ bị thiếu và thuộc cùng một nhóm)",
-    "This app has no minimum Nextcloud version assigned. This will be an error in the future." : "Ứng dụng này không có phiên bản Nextcloud tối thiểu được chỉ định. Đây sẽ là một lỗi trong tương lai.",
-    "This app has no maximum Nextcloud version assigned. This will be an error in the future." : "Ứng dụng này không có phiên bản Nextcloud tối đa được chỉ định. Đây sẽ là một lỗi trong tương lai.",
-    "Your biography" : "Tiểu sử của bạn",
-    "You are using <strong>{usage}</strong>" : "Bạn đang sử dụng {usage}",
-    "You are using <strong>{usage}</strong> of <strong>{totalSpace}</strong> (<strong>{usageRelative}%</strong>)" : "Bạn đang sử dụng {usage} trên {totalSpace} ({usageRelative}%)",
-    "In case of lost device or exiting the organization, this can remotely wipe the Nextcloud data from all devices associated with {userid}. Only works if the devices are connected to the internet." : "Trong trường hợp thiết bị bị mất hoặc thoát khỏi tổ chức, thao tác này có thể xóa từ xa dữ liệu Nextcloud khỏi tất cả các thiết bị được liên kết với {userid}. Chỉ hoạt động nếu các thiết bị được kết nối với internet.",
-    "This app is not marked as compatible with your Nextcloud version. If you continue you will still be able to install the app. Note that the app might not work as expected." : "Ứng dụng này không được đánh dấu là tương thích với phiên bản Nextcloud của bạn. Nếu bạn tiếp tục, bạn vẫn có thể cài đặt ứng dụng. Lưu ý rằng ứng dụng có thể không hoạt động như mong đợi.",
     "It's important for the security and performance of your instance that everything is configured correctly. To help you with that we are doing some automatic checks. Please see the linked documentation for more information." : "Điều quan trọng đối với tính bảo mật và hiệu suất của phiên bản của bạn là mọi thứ đều được đặt cấu hình chính xác. Để giúp bạn điều đó, chúng tôi đang thực hiện một số kiểm tra tự động. Vui lòng xem tài liệu được liên kết để biết thêm thông tin.",
     "Checking for system and security issues." : "Kiểm tra các vấn đề về hệ thống và bảo mật."
 },
