@@ -56,6 +56,7 @@ OC.L10N.register(
     "Failed to delete tag" : "Błąd usuwania etykiety",
     "Create or edit tags" : "Utwórz lub edytuj etykietę:",
     "Search for a tag to edit" : "Wyszukaj etykietę do edycji",
+    "Collaborative tags …" : "Tagi współdzielone …",
     "No tags to select" : "Brak etykiet do zaznaczenia",
     "Tag name" : "Nazwa etykiety",
     "Tag level" : "Poziom etykiety",
@@ -86,6 +87,7 @@ OC.L10N.register(
     "Failed to load tags" : "Nie udało się załadować etykiet",
     "Failed to select tag" : "Nie udało się wybrać tagu",
     "System admin disabled tag creation. You can only use existing ones." : "Administrator systemu wyłączył tworzenie tagów. Można używać tylko istniejących tagów.",
+    "Loading collaborative tags …" : "Wczytywanie tagów współdzielonych …",
     "Search or create collaborative tags" : "Wyszukaj lub utwórz wspólne tagi",
     "No tags to select, type to create a new tag" : "Brak tagów do wyboru, wpisz, aby utworzyć nowy tag",
     "Unable to update setting" : "Nie udało się zaktualizować ustawienia",
