@@ -77,6 +77,7 @@ OC.L10N.register(
     "Insert emoji" : "Lisää emoji",
     "Mention someone" : "Mainitse käyttäjä",
     "name" : "nimi",
+    "Smart picker" : "Älykäs valitsin",
     "Action" : "Toiminto",
     "Undo" : "Kumoa",
     "Redo" : "Tee uudelleen",
@@ -114,12 +115,13 @@ OC.L10N.register(
     "Translate to" : "Kohdekieli",
     "Replace" : "Korvaa",
     "Insert" : "Lisää",
+    "Edit" : "Muokkaa",
     "No emoji found" : "Emojia ei löydy",
     "No command found" : "Komentoa ei löytynyt",
     "No user found" : "Käyttäjää ei löytynyt",
     "No suggestion found" : "Ehdotusta ei löytynyt",
     "Upload" : "Lähetä",
-    "Edit" : "Muokkaa",
+    "Insert Table" : "Lisää taulukko",
     "Copy code block" : "Kopioi koodilohko",
     "Copy code" : "Kopioi koodi",
     "Code block options" : "Koodilohkon asetukset",
@@ -153,6 +155,7 @@ OC.L10N.register(
     "Insert link" : "Lisää linkki",
     "Insert attachment" : "Lisää liite",
     "Command" : "Komento",
+    "Option" : "Valinta",
     "Formatting" : "Muotoilu",
     "Select file or folder to link to" : "Valitse tiedosto tai kansio, johon linkitetään",
     "Choose" : "Valitse",
