@@ -10,11 +10,10 @@ OC.L10N.register(
     "The given privacy policy address is not a valid URL" : "L'indirizzo dello specifico criterio di riservatezza non è un URL valido",
     "The given slogan is too long" : "Questo slogan è troppo lungo",
     "The given color is invalid" : "Questo colore non è valido",
-    "Disable-user-theming should be true or false" : "Disattiva-temi-utente deve essere true o false",
+    "Invalid setting key" : "Voce di impostazione non valida",
     "Saved" : "Salvato",
     "Invalid app given" : "Applicazione non valida",
     "Invalid type for setting \"defaultApp\" given" : "Tipo per l'impostazione \"defaultApp\" non valido",
-    "Invalid setting key" : "Voce di impostazione non valida",
     "The file was uploaded" : "Il file è stato caricato",
     "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "Il file caricato supera la direttiva upload_max_filesize in php.ini",
     "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Il file caricato supera la direttiva MAX_FILE_SIZE specificata nel modulo HTML",
@@ -51,75 +50,77 @@ OC.L10N.register(
     "Legal notice" : "Avviso legale",
     "Privacy policy" : "Criterio di riservatezza",
     "Adjust the Nextcloud theme" : "Modifica il tema di Nextcloud",
+    "Could not set global default apps" : "Impossibile impostare le applicazioni predefinite globali",
+    "Navigation bar settings" : "Impostazioni barra di navigazione",
+    "Default app" : "Applicazione predefinita",
+    "The default app is the app that is e.g. opened after login or when the logo in the menu is clicked." : "L'applicazione predefinita è quella che viene aperta dopo l'accesso o quando si fa clic sul logo nel menu.",
+    "Use custom default app" : "Usa applicazione predefinita personalizzata",
+    "Global default app" : "Applicazione predefinita globale",
+    "Global default apps" : "Applicazioni predefinite globali",
+    "Default app priority" : "Priorità applicazione predefinita",
+    "If an app is not enabled for a user, the next app with lower priority is used." : "Se un'applicazione non è abilitata per un utente, viene usata quella successiva con priorità più bassa.",
+    "Theming makes it possible to easily customize the look and feel of your instance and supported clients. This will be visible for all users." : "La gestione dei temi rende semplice la personalizzazione dell'aspetto della tua istanza e dei client supportati. Ciò sarà visibile a tutti gli utenti.",
     "Name" : "Nome",
     "Web link" : "Collegamento web",
-    "a safe home for all your data" : "un posto sicuro per tutti i tuoi dati",
     "Slogan" : "Slogan",
-    "Primary color" : "Colore primario",
-    "The primary color is used for highlighting elements like important buttons. It might get slightly adjusted depending on the current color schema." : "Il colore primario è usato per evidenziare elementi, come pulsanti importanti. Può essere regolato un po' a seconda dello schema di colori attuale.",
+    "a safe home for all your data" : "un posto sicuro per tutti i tuoi dati",
     "Legal notice link" : "Collegamento avviso legale",
     "Privacy policy link" : "Collegamento criteri di riservatezza",
-    "Header logo" : "Logo dell'intestazione",
-    "Upload new header logo" : "Carica nuovo logo dell'intestazione",
-    "Favicon" : "Favicon",
-    "Upload new favicon" : "Carica nuova favicon",
-    "User settings" : "Impostazioni utente",
-    "Disable user theming" : "Disattiva temi utente",
-    "Although you can select and customize your instance, users can change their background and colors. If you want to enforce your customization, you can toggle this on." : "Sebbene tu possa selezionare e personalizzare la tua istanza, gli utenti possono cambiare il loro sfondo e colore. Se vuoi forzare la tua personalizzazione, puoi attivare questo.",
-    "Theming makes it possible to easily customize the look and feel of your instance and supported clients. This will be visible for all users." : "La gestione dei temi rende semplice la personalizzazione dell'aspetto della tua istanza e dei client supportati. Ciò sarà visibile a tutti gli utenti.",
-    "Instead of a background image you can also configure a plain background color. If you use a background image changing this color will influence the color of the app menu icons." : "Al posto di un'immagine, puoi anche configurare un colore di sfondo. Se usi un'immagine di sfondo, cambiare questo colore influenzerà il colore delle icone dei menu.",
-    "Background color" : "Colore di sfondo",
-    "Upload new logo" : "Carica nuovo logo",
-    "Logo" : "Logo",
-    "Upload new background and login image" : "Carica nuova immagine di sfondo e di accesso",
-    "Background and login image" : "Immagine di sfondo e di accesso",
-    "Advanced options" : "Opzioni avanzate",
-    "Install the ImageMagick PHP extension with support for SVG images to automatically generate favicons based on the uploaded logo and color." : "Installa l'estensione ImageMagick di PHP con supporto per le immagini SVG per generare automaticamente favicon basate sul logo caricato e sul colore.",
-    "Universal access is very important to us. We follow web standards and check to make everything usable also without mouse, and assistive software such as screenreaders. We aim to be compliant with the {linkstart}Web Content Accessibility Guidelines{linkend} 2.1 on AA level, with the high contrast theme even on AAA level." : "L'accessibilità universale è molto importante per noi. Seguiamo gli standard web e verifichiamo che tutto sia utilizzabile anche senza mouse e con software di assistenza come gli screen reader. Il nostro obiettivo è quello di essere conformi alle {linkstart}Linee guida per l'accessibilità dei contenuti web{linkend} 2.1 a livello AA, con il tema ad alto contrasto anche a livello AAA.",
-    "If you find any issues, do not hesitate to report them on {issuetracker}our issue tracker{linkend}. And if you want to get involved, come join {designteam}our design team{linkend}!" : "Se trovi qualsiasi problema, non esitare a segnalarlo sul {issuetracker}nostro sistema di segnalazione dei bug{linkend}. E se vuoi partecipare, unisciti alla {designteam}nostra squadra di progettazione{linkend}!",
-    "Unable to apply the setting." : "Impossiblie applicare l'impostazione.",
-    "Appearance and accessibility settings" : "Impostazioni di aspetto e accessibilità",
-    "Misc accessibility options" : "Altre opzioni di accessibilità ",
-    "Enable blur background filter (may increase GPU load)" : "Abilita filtro di sfocamento dello sfondo (può aumentare il carico sulla GPU)",
-    "Customization has been disabled by your administrator" : "La personalizzazione è stata disattivata dall'amministratore",
-    "Set a primary color to highlight important elements. The color used for elements such as primary buttons might differ a bit as it gets adjusted to fulfill accessibility requirements." : "Imposta un colore primario per evidenziare elementi importanti. Il colore usato per elementi come pulsanti principali può essere leggermente diverso, dato che viene regolato per soddisfare i requisiti di accessibilità.",
     "Background and color" : "Sfondo e colore",
-    "The background can be set to an image from the default set, a custom uploaded image, or a plain color." : "Lo sfondo può essere impostato ad un'immagine dal set predefinito, un'immagine caricata a mano, o un colore unico.",
-    "Keyboard shortcuts" : "Scorciatoie da tastiera",
-    "In some cases keyboard shortcuts can interfere with accessibility tools. In order to allow focusing on your tool correctly you can disable all keyboard shortcuts here. This will also disable all available shortcuts in apps." : "In alcuni casi le scorciatoie da tastiera possono interferire con gli strumenti di accessibilità. Per concentrarti correttamente sullo strumento, è possibile disattivare tutte le scorciatoie da tastiera. Verranno disattivate anche tutte le scorciatoie disponibili nelle applicazioni.",
-    "Disable all keyboard shortcuts" : "Disattiva tutte le scorciatoie da tastiera",
+    "Primary color" : "Colore primario",
+    "Background color" : "Colore di sfondo",
+    "Remove background image" : "Rimuovi immagine di sfondo",
+    "Background image" : "Immagine di sfondo",
+    "Favicon" : "Favicon",
+    "Logo" : "Logo",
+    "Although you can select and customize your instance, users can change their background and colors. If you want to enforce your customization, you can toggle this on." : "Sebbene tu possa selezionare e personalizzare la tua istanza, gli utenti possono cambiare il loro sfondo e colore. Se vuoi forzare la tua personalizzazione, puoi attivare questo.",
+    "Disable user theming" : "Disattiva temi utente",
     "Current selected app: {app}, position {position} of {total}" : "Applicazione attualmente selezionata: {app}, posizione {position} di {total}",
     "Move up" : "Sposta su",
     "Move down" : "Sposta giù",
-    "Select a background from your files" : "Seleziona uno sfondo dai tuoi file",
-    "Select background" : "Seleziona sfondo",
-    "No background has been selected" : "Nessuno sfondo selezionato",
-    "Custom background" : "Sfondo personalizzato",
-    "Plain background" : "Sfondo semplice",
-    "Default background" : "Sfondo predefinito",
     "Theme selection is enforced" : "La selezione del tema è obbligata",
     "Could not set the app order" : "Impossibile impostare l'ordine delle applicazioni",
     "Could not reset the app order" : "Impossibile ripristinare l'ordine delle applicazioni",
-    "Navigation bar settings" : "Impostazioni barra di navigazione",
     "You can configure the app order used for the navigation bar. The first entry will be the default app, opened after login or when clicking on the logo." : "Puoi configurare l'ordine delle applicazioni usato per la barra di navigazione. La prima voce sarà l'applicazione predefinita, aperta dopo l'accesso o quando si fa clic sul logo.",
     "The default app can not be changed because it was configured by the administrator." : "L'applicazione predefinita non può essere cambiata perché è stata configurata dall'amministratore.",
     "The app order was changed, to see it in action you have to reload the page." : "L'ordine delle applicazioni è stato cambiato, per vedere le modifiche devi ricaricare la pagina.",
     "Reset default app order" : "Ripristina ordine predefinito delle applicazioni",
+    "Select a background from your files" : "Seleziona uno sfondo dai tuoi file",
+    "Select background" : "Seleziona sfondo",
+    "The background can be set to an image from the default set, a custom uploaded image, or a plain color." : "Lo sfondo può essere impostato ad un'immagine dal set predefinito, un'immagine caricata a mano, o un colore unico.",
+    "Custom background" : "Sfondo personalizzato",
+    "Plain background" : "Sfondo semplice",
+    "Default background" : "Sfondo predefinito",
+    "Keyboard shortcuts" : "Scorciatoie da tastiera",
+    "In some cases keyboard shortcuts can interfere with accessibility tools. In order to allow focusing on your tool correctly you can disable all keyboard shortcuts here. This will also disable all available shortcuts in apps." : "In alcuni casi le scorciatoie da tastiera possono interferire con gli strumenti di accessibilità. Per concentrarti correttamente sullo strumento, è possibile disattivare tutte le scorciatoie da tastiera. Verranno disattivate anche tutte le scorciatoie disponibili nelle applicazioni.",
+    "Disable all keyboard shortcuts" : "Disattiva tutte le scorciatoie da tastiera",
     "Could not set primary color" : "Impossibile impostare il colore primario",
+    "Set a primary color to highlight important elements. The color used for elements such as primary buttons might differ a bit as it gets adjusted to fulfill accessibility requirements." : "Imposta un colore primario per evidenziare elementi importanti. Il colore usato per elementi come pulsanti principali può essere leggermente diverso, dato che viene regolato per soddisfare i requisiti di accessibilità.",
     "Reset primary color" : "Ripristina colore primario",
-    "Could not set global default apps" : "Impossibile impostare le app predefinite globali",
-    "Default app" : "Applicazione predefinita",
-    "The default app is the app that is e.g. opened after login or when the logo in the menu is clicked." : "L'applicazione predefinita è quella che viene aperta dopo l'accesso o quando si fa clic sul logo nel menu.",
-    "Use custom default app" : "Usa app predefinita personalizzata",
-    "Global default app" : "App predefinita globale",
-    "Global default apps" : "App predefinite globali",
-    "Default app priority" : "Priorità app predefinita",
-    "If an app is not enabled for a user, the next app with lower priority is used." : "Se un'app non è abilitata per un utente, viene usata quella successiva con priorità più bassa.",
-    "Select a custom color" : "Seleziona un colore personalizzato",
     "Reset to default" : "Ripristina valori predefiniti",
-    "Upload" : "Carica",
-    "Remove background image" : "Rimuovi immagine di sfondo",
+    "Universal access is very important to us. We follow web standards and check to make everything usable also without mouse, and assistive software such as screenreaders. We aim to be compliant with the {linkstart}Web Content Accessibility Guidelines{linkend} 2.1 on AA level, with the high contrast theme even on AAA level." : "L'accessibilità universale è molto importante per noi. Seguiamo gli standard web e verifichiamo che tutto sia utilizzabile anche senza mouse e con software di assistenza come gli screen reader. Il nostro obiettivo è quello di essere conformi alle {linkstart}Linee guida per l'accessibilità dei contenuti web{linkend} 2.1 a livello AA, con il tema ad alto contrasto anche a livello AAA.",
+    "If you find any issues, do not hesitate to report them on {issuetracker}our issue tracker{linkend}. And if you want to get involved, come join {designteam}our design team{linkend}!" : "Se trovi qualsiasi problema, non esitare a segnalarlo sul {issuetracker}nostro sistema di segnalazione dei bug{linkend}. E se vuoi partecipare, unisciti alla {designteam}nostra squadra di progettazione{linkend}!",
+    "Unable to apply the setting." : "Impossibile applicare l'impostazione.",
+    "Appearance and accessibility settings" : "Impostazioni di aspetto e accessibilità",
+    "Misc accessibility options" : "Altre opzioni di accessibilità ",
+    "Enable blur background filter (may increase GPU load)" : "Abilita filtro di sfocamento dello sfondo (può aumentare il carico sulla GPU)",
+    "Customization has been disabled by your administrator" : "La personalizzazione è stata disattivata dall'amministratore",
+    "Disable-user-theming should be true or false" : "Disattiva-temi-utente deve essere true o false",
+    "The primary color is used for highlighting elements like important buttons. It might get slightly adjusted depending on the current color schema." : "Il colore primario è usato per evidenziare elementi, come pulsanti importanti. Può essere regolato un po' a seconda dello schema di colori attuale.",
+    "Header logo" : "Logo dell'intestazione",
+    "Upload new header logo" : "Carica nuovo logo dell'intestazione",
+    "Upload new favicon" : "Carica nuova favicon",
+    "User settings" : "Impostazioni utente",
+    "Instead of a background image you can also configure a plain background color. If you use a background image changing this color will influence the color of the app menu icons." : "Al posto di un'immagine, puoi anche configurare un colore di sfondo. Se usi un'immagine di sfondo, cambiare questo colore influenzerà il colore delle icone dei menu.",
+    "Upload new logo" : "Carica nuovo logo",
+    "Upload new background and login image" : "Carica nuova immagine di sfondo e di accesso",
+    "Background and login image" : "Immagine di sfondo e di accesso",
+    "Advanced options" : "Opzioni avanzate",
+    "Install the ImageMagick PHP extension with support for SVG images to automatically generate favicons based on the uploaded logo and color." : "Installa l'estensione ImageMagick di PHP con supporto per le immagini SVG per generare automaticamente favicon basate sul logo caricato e sul colore.",
     "Universal access is very important to us. We follow web standards and check to make everything usable also without mouse, and assistive software such as screenreaders. We aim to be compliant with the {guidelines}Web Content Accessibility Guidelines{linkend} 2.1 on AA level, with the high contrast theme even on AAA level." : "L'accesso universale è molto importante per noi. Seguiamo gli standard web e cerchiamo di rendere tutto utilizzabile anche senza mouse, e programmi di assistenza come i lettori dello schermo. Il nostro obiettivo è la compatibilità con la {guidelines}Web Content Accessibility Guidelines{linkend} 2.1 a livello AA, con il tema ad alto contrasto anche a livello AAA. ",
-    ". Unable to apply the setting." : "Impossiblie applicare l'impostazione."
+    ". Unable to apply the setting." : ". Impossibile applicare l'impostazione.",
+    "No background has been selected" : "Nessuno sfondo selezionato",
+    "Select a custom color" : "Seleziona un colore personalizzato",
+    "Upload" : "Carica"
 },
 "nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
