@@ -10,13 +10,25 @@ OC.L10N.register(
     "Out of office" : "Izvan ureda",
     "Working remotely" : "Rad na daljinu",
     "In a call" : "U pozivu",
+    "Be right back" : "Vraćam se odmah",
     "User status" : "Status korisnika",
     "Clear status after" : "Izbriši status nakon",
+    "Emoji for your status message" : "Emoji za poruku statusa",
     "What is your status?" : "Koji je vaš status?",
+    "Predefined statuses" : "Predefinirani statusi",
+    "Previously set" : "Prethodno postavljeno",
+    "Reset status" : "Poništi status",
+    "Reset status to \"{icon} {message}\"" : "Poništi status na \"{icon} {message}\"",
+    "Reset status to \"{message}\"" : "Poništi status na \"{message}\"",
+    "Reset status to \"{icon}\"" : "Poništi status na \"{icon}\"",
     "There was an error saving the status" : "Došlo je do pogreške pri spremanju statusa",
     "There was an error clearing the status" : "Došlo je do pogreške pri brisanju statusa",
+    "There was an error reverting the status" : "Došlo je do pogreške pri vraćanju statusa",
     "Online status" : "Status na mreži",
     "Status message" : "Poruka statusa",
+    "Set absence period" : "Postavi razdoblje odsutnosti",
+    "Set absence period and replacement" : "Postavi razdoblje odsutnosti i zamjenu",
+    "Your status was set automatically" : "Vaš status je postavljen automatski",
     "Clear status message" : "Izbriši poruku statusa",
     "Set status message" : "Postavi poruku statusa",
     "Online" : "Na mreži",
