@@ -184,12 +184,6 @@ OC.L10N.register(
     "Matroska video" : "Відэа Matroska",
     "Windows Media video" : "Відэа Windows Media",
     "AVI video" : "Відэа AVI",
-    "The update is in progress, leaving this page might interrupt the process in some environments." : "Абнаўленне яшчэ ідзе. У некаторых асяроддзях, калі пакінуць гэтую старонку, працэс можа быць перапынены.",
-    "Update to {version}" : "Абнавіць да {version}",
-    "An error occurred." : "Узнікла памылка.",
-    "Please reload the page." : "Перазагрузіце старонку.",
-    "The update was unsuccessful. For more information <a href=\"{url}\">check our forum post</a> covering this issue." : "Абнаўленне было няўдалым. Дадатковая інфармацыя – у прысвечаным гэтаму пытанню паведамленні на <a href=\"{url}\">нашым форуме</a>.",
-    "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud community</a>." : "Абнаўленне было няўдалым. Паведаміце пра гэту праблему <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">супольнасці Nextcloud</a>.",
     "Done" : "Гатова",
     "Applications menu" : "Меню праграм",
     "Apps" : "Праграмы",
@@ -286,8 +280,8 @@ OC.L10N.register(
     "Loading your contacts …" : "Загрузка вашых кантактаў …",
     "Looking for {term} …" : "Пошук {term} …",
     "Search contacts" : "Пошук кантактаў",
-    "Reset search" : "Скінуць пошук",
     "Search contacts …" : "Пошук кантактаў …",
+    "Reset search" : "Скінуць пошук",
     "Could not load your contacts" : "Не ўдалося загрузіць вашы кантакты",
     "No contacts found" : "Кантакты не знойдзены",
     "Show all contacts" : "Паказаць усе кантакты",
@@ -358,6 +352,16 @@ OC.L10N.register(
     "Your browser is not supported. Please upgrade to a newer version or a supported one." : "Ваш браўзер не падтрымліваецца. Абнавіце яго да новай версіі або да той, якая падтрымліваецца.",
     "Continue with this unsupported browser" : "Працягнуць выкарыстанне гэтага браўзера, які не падтрымліваецца",
     "Supported versions" : "Версіі, якія падтрымліваюцца",
+    "The update is in progress, leaving this page might interrupt the process in some environments." : "Абнаўленне яшчэ ідзе. У некаторых асяроддзях, калі пакінуць гэтую старонку, працэс можа быць перапынены.",
+    "App update required" : "Патрэбна абнавіць праграму",
+    "These incompatible apps will be disabled:" : "Гэтыя несумяшчальныя праграмы будуць адключаныя:",
+    "Please make sure that the database, the config folder and the data folder have been backed up before proceeding." : "Перад тым, як працягнуць, пераканайцеся, што ёсць рэзервовыя копіі базы даных, папкі канфігурацыі і папкі даных.",
+    "Start update" : "Запусціць абнаўленне",
+    "Update to {version}" : "Абнавіць да {version}",
+    "Hide details" : "Схаваць падрабязнасці",
+    "Show details" : "Паказаць падрабязнасці",
+    "Update needed" : "Неабходна абнаўленне",
+    "Documentation" : "Дакументацыя",
     "Search {types} …" : "Пошук {types} …",
     "Choose {file}" : "Выбраць {file}",
     "Choose" : "Выбраць",
@@ -382,17 +386,11 @@ OC.L10N.register(
     "Groups" : "Групы",
     "Group list is empty" : "Спіс груп пусты",
     "seconds ago" : "с таму",
-    "Connection to server lost" : "Злучэнне з серверам страчана",
-    "_Problem loading page, reloading in %n second_::_Problem loading page, reloading in %n seconds_" : ["Праблема з загрузкай старонкі, перазагрузка праз %n секунду","Праблема з загрузкай старонкі, перазагрузка праз %n секунды","Праблема з загрузкай старонкі, перазагрузка праз %n секунд","Праблема з загрузкай старонкі, перазагрузка праз %n секунд"],
     "Add to a project" : "Дадаць у праект",
-    "Show details" : "Паказаць падрабязнасці",
-    "Hide details" : "Схаваць падрабязнасці",
     "Rename project" : "Перайменаваць праект",
     "Failed to rename the project" : "Не ўдалося перайменаваць праект",
     "Failed to create a project" : "Не ўдалося стварыць праект",
     "Failed to add the item to the project" : "Не ўдалося дадаць элемент у праект",
-    "New in" : "Новае ў",
-    "View changelog" : "Праглядзець спіс змяненняў",
     "Close \"{dialogTitle}\" dialog" : "Закрыць дыялогавае акно \"{dialogTitle}\"",
     "Clipboard not available, please copy manually" : "Буфер абмену недаступны, скапіюйце ўручную",
     "Personal" : "Асабістыя",
@@ -430,15 +428,6 @@ OC.L10N.register(
     "Cancel login" : "Скасаваць уваход",
     "Access through untrusted domain" : "Доступ праз ненадзейны дамен",
     "Please contact your administrator. If you are an administrator, edit the \"trusted_domains\" setting in config/config.php like the example in config.sample.php." : "Звярніцеся да адміністратара. Калі вы адміністратар, адрэдагуйце параметр \"trusted_domains\" у config/config.php, як у прыкладзе ў config.sample.php.",
-    "App update required" : "Патрэбна абнавіць праграму",
-    "%1$s will be updated to version %2$s" : "%1$s будзе абноўлена да версіі %2$s",
-    "The following apps will be updated:" : "Будуць абноўлены наступныя праграмы:",
-    "These incompatible apps will be disabled:" : "Гэтыя несумяшчальныя праграмы будуць адключаныя:",
-    "The theme %s has been disabled." : "Тэма %s была адключана.",
-    "Please make sure that the database, the config folder and the data folder have been backed up before proceeding." : "Перад тым, як працягнуць, пераканайцеся, што ёсць рэзервовыя копіі базы даных, папкі канфігурацыі і папкі даных.",
-    "Start update" : "Запусціць абнаўленне",
-    "Detailed logs" : "Падрабязныя журналы",
-    "Update needed" : "Неабходна абнаўленне",
     "Maintenance mode" : "Рэжым тэхнічнага абслугоўвання",
     "Contact your system administrator if this message persists or appeared unexpectedly." : "Звярніцеся да сістэмнага адміністратара, калі гэта паведамленне працягвае з'яўляцца або з'явілася нечакана.",
     "Error occurred while checking server setup" : "Падчас праверкі налад сервера адбылася памылка",
@@ -450,6 +439,10 @@ OC.L10N.register(
     "Hello {name}" : "Вітаем, {name}",
     "new" : "новы",
     "_download %n file_::_download %n files_" : ["спампаваць %n файл","спампаваць %n файлы","спампаваць %n файлаў","спампаваць %n файлаў"],
+    "An error occurred." : "Узнікла памылка.",
+    "Please reload the page." : "Перазагрузіце старонку.",
+    "The update was unsuccessful. For more information <a href=\"{url}\">check our forum post</a> covering this issue." : "Абнаўленне было няўдалым. Дадатковая інфармацыя – у прысвечаным гэтаму пытанню паведамленні на <a href=\"{url}\">нашым форуме</a>.",
+    "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud community</a>." : "Абнаўленне было няўдалым. Паведаміце пра гэту праблему <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">супольнасці Nextcloud</a>.",
     "Direct link copied to clipboard" : "Прамая спасылка скапіявана ў буфер абмену",
     "Searching …" : "Пошук …",
     "Logging in …" : "Уваход …",
@@ -461,6 +454,10 @@ OC.L10N.register(
     "Loading more results …" : "Загрузка дадатковых вынікаў …",
     "Search {types} …" : "Пошук {types} …",
     "Saving …" : "Захаванне …",
+    "Connection to server lost" : "Злучэнне з серверам страчана",
+    "_Problem loading page, reloading in %n second_::_Problem loading page, reloading in %n seconds_" : ["Праблема з загрузкай старонкі, перазагрузка праз %n секунду","Праблема з загрузкай старонкі, перазагрузка праз %n секунды","Праблема з загрузкай старонкі, перазагрузка праз %n секунд","Праблема з загрузкай старонкі, перазагрузка праз %n секунд"],
+    "New in" : "Новае ў",
+    "View changelog" : "Праглядзець спіс змяненняў",
     "Very weak password" : "Вельмі слабы пароль",
     "Weak password" : "Слабы пароль",
     "So-so password" : "Абы-які пароль",
@@ -486,6 +483,10 @@ OC.L10N.register(
     "Installing …" : "Усталяванне …",
     "Please log in before granting %1$s access to your %2$s account." : "Увайдзіце ў сістэму, перш чым даць %1$s доступ да вашага ўліковага запісу %2$s.",
     "Currently logged in as %1$s (%2$s)." : "Вы ўвайшлі як %1$s (%2$s).",
-    "You are about to grant %1$s access to your %2$s account." : "Вы збіраецеся даць %1$s доступ да вашага ўліковага запісу %2$s."
+    "You are about to grant %1$s access to your %2$s account." : "Вы збіраецеся даць %1$s доступ да вашага ўліковага запісу %2$s.",
+    "%1$s will be updated to version %2$s" : "%1$s будзе абноўлена да версіі %2$s",
+    "The following apps will be updated:" : "Будуць абноўлены наступныя праграмы:",
+    "The theme %s has been disabled." : "Тэма %s была адключана.",
+    "Detailed logs" : "Падрабязныя журналы"
 },
 "nplurals=4; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<12 || n%100>14) ? 1 : n%10==0 || (n%10>=5 && n%10<=9) || (n%100>=11 && n%100<=14)? 2 : 3);");
