@@ -45,6 +45,8 @@ OC.L10N.register(
     "Input text is too long" : "Vstupní text je příliš dlouhý",
     "Requested task type does not exist" : "Požadovaný typ úkolu neexistuje",
     "Necessary language model provider is not available" : "Nezbytný poskytovatel jazykového modelu není k dsipozici",
+    "Cannot generate more than 12 images" : "Není možné vytvořit více než 12 obrázků",
+    "Cannot generate less than 1 image" : "Není možné vytvořit méně než 1 obrázek",
     "No text to image provider is available" : "Není k dispozici žádný poskytovatel převodu textu na obrázek",
     "Image not found" : "Obrázek nenalezen",
     "No translation provider available" : "Není k dispozici žádný poskytovatel překladu",
@@ -198,15 +200,10 @@ OC.L10N.register(
     "Matroska video" : "Matroska video",
     "Windows Media video" : "Windows Media video",
     "AVI video" : "AVI video",
-    "The update is in progress, leaving this page might interrupt the process in some environments." : "Probíhá aktualizace – opuštění této stránky může v některých prostředích proces přerušit.",
-    "Update to {version}" : "Aktualizovat na {version}",
-    "An error occurred." : "Došlo k chybě.",
-    "Please reload the page." : "Načtěte stránku znovu.",
-    "The update was unsuccessful. For more information <a href=\"{url}\">check our forum post</a> covering this issue." : "Aktualizace nebyla úspěšná. Další informace <a href=\"{url}\">se dočtete v příspěvku na diskuzním fóru</a>, pojednávajícím o tomto problému.",
-    "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud community</a>." : "Aktualizace nebyla úspěšná. Prosím nahlaste tento problém <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">komunitě projektu Nextcloud</a>",
-    "Continue to {productName}" : "Pokračujte k {productName}",
-    "_The update was successful. Redirecting you to {productName} in %n second._::_The update was successful. Redirecting you to {productName} in %n seconds._" : ["Aktualizace proběhla úspěšně. Za %n sekundu budete přesměrováni do {productName}","Aktualizace proběhla úspěšně. Za %n sekundy budete přesměrováni do {productName}","Aktualizace proběhla úspěšně. Za %n sekund budete přesměrováni do {productName}","Aktualizace proběhla úspěšně. Za %n sekundy budete přesměrováni do {productName}"],
     "Done" : "Dokončeno",
+    "Scan QR code to log in" : "Naskenovat QR kód pro přihlášení",
+    "Use {productName} mobile client you want to connect to scan the code" : "K naskenování kódu použijte mobilního klienta {productName} kterým se chcete připojit",
+    "Code will expire {timeCountdown} or after use" : "Platnost kódu skončí za {timeCountdown} nebo po použití",
     "Applications menu" : "Nabídka aplikací",
     "Apps" : "Aplikace",
     "More apps" : "Více aplikací",
@@ -311,10 +308,14 @@ OC.L10N.register(
     "Loading your contacts …" : "Načítání vašich kontaktů …",
     "Looking for {term} …" : "Hledání {term} …",
     "Search contacts" : "Hledat v kontaktech",
-    "Reset search" : "Resetovat hledání",
+    "Filter by team" : "Filtrovat podle týmu",
+    "All teams" : "Všechny týmy",
+    "Search contacts in team {team}" : "Hledat kontakty v týmu {team}",
     "Search contacts …" : "Hledat v kontaktech …",
+    "Reset search" : "Resetovat hledání",
     "Could not load your contacts" : "Nedaří se načíst vaše kontakty",
     "No contacts found" : "Nenalezeny žádné kontakty",
+    "Contacts list" : "Seznam kontaktů",
     "Show all contacts" : "Zobrazit všechny kontakty",
     "Install the Contacts app" : "Nainstalovat aplikaci Kontakty",
     "Search" : "Hledat",
@@ -331,13 +332,17 @@ OC.L10N.register(
     "Login form is disabled." : "Formulář pro přihlášení je vypnut",
     "The Nextcloud login form is disabled. Use another login option if available or contact your administration." : "Přihlašovací formulář je v Nextcloud vypnutý. Použijte jinou možnost přihlášení nebo se obraťte na svého správce.",
     "Connect to your account" : "Propojit s vaším účtem",
+    "Please log in before granting \"{client}\" access to your {instanceName} account." : "Přihlaste se abyste mohli „{client}“ udělit přístup ke svému {instanceName} účtu.",
     "Security warning" : "Varování ohledně zabezpečení",
     "If you are not trying to set up a new device or app, someone is trying to trick you into granting them access to your data. In this case do not proceed and instead contact your system administrator." : "Pokud se nepokoušíte nastavit nové zařízení či aplikaci, někdo se pokouší vás ošálit a získat tak přístup k vašim datům. V takovém případě nepokračujte a obraťte se na svého správce systémů.",
+    "Log in using password" : "Přihlásit s heslem",
     "Alternative log in using app password" : "Alternativní přihlášení pomocí hesla pro aplikaci",
     "Account connected" : "Účet připojen",
     "Your client should now be connected!" : "Váš klient by nyní měl být připojen!",
     "You can close this window." : "Toto okno je možné zavřít.",
     "Account access" : "Přístup k účtu",
+    "Currently logged in as {userDisplayName} ({userId})." : "Nyní jste přihlášeni jako {userDisplayName} ({userId}).",
+    "You are about to grant \"{client}\" access to your {instanceName} account." : "Chystáte se povolit {client} přístup k vašemu {instanceName} účtu.",
     "More actions" : "Další akce",
     "User menu" : "Nabídka uživatele",
     "Your guest name: {user}" : "Vaše jméno, coby hosta: {user}",
@@ -395,6 +400,32 @@ OC.L10N.register(
     "Your browser is not supported. Please upgrade to a newer version or a supported one." : "Vámi využívaný webový prohlížeč není podporován. Přejděte na novější verzi nebo na nějaký podporovaný.",
     "Continue with this unsupported browser" : "Pokračovat s tímto zastaralým prohlížečem",
     "Supported versions" : "Podporované verze",
+    "The update completed with warnings. Please check the details for more information." : "Aktualizace proběhla s varováními. Další informace viz podrobnosti.",
+    "The update completed successfully." : "Aktualizace proběhla úspěšně.",
+    "Preparing update…" : "Příprava aktualizace…",
+    "You will be redirected to {productName} in {count} seconds." : "Za {count} sekund budete přesměrováni do {productName}.",
+    "The update is in progress, leaving this page might interrupt the process in some environments." : "Probíhá aktualizace – opuštění této stránky může v některých prostředích proces přerušit.",
+    "App update required" : "Vyžadována aktualizace aplikace",
+    "{productName} will be updated to version {version}" : "{productName} bude zaktualizován na verzi {version}",
+    "The theme {oldTheme} has been disabled." : "Motiv vzhledu {oldTheme} byl vypnut.",
+    "These incompatible apps will be disabled:" : "Tyto nekompatibilní aplikace budou vypnuty:",
+    "Incompatible apps" : "Nekompatibilní aplikace",
+    "These apps will be updated:" : "Tyto aplikace budou aktualizovány:",
+    "Apps to update" : "Aplikace s aktualizacemi",
+    "{app} from {oldVersion} to {version}" : "{app} z {oldVersion} na {version}",
+    "Please make sure that the database, the config folder and the data folder have been backed up before proceeding." : "Před provedením dalšího kroku se ujistěte, že je zazálohována databáze a složky s nastaveními a daty.",
+    "To avoid timeouts with larger installations, you can instead run the following command from your installation directory:" : "Abyste zabránili překračování časových limitů u větších instalací, můžete místo toho v adresáři s nainstalovanou aplikací spustit:",
+    "Start update" : "Spustit aktualizaci",
+    "Continue to {productName}" : "Pokračujte k {productName}",
+    "Update to {version}" : "Aktualizovat na {version}",
+    "Hide details" : "Skrýt podrobnosti",
+    "Show details" : "Zobrazit podrobnosti",
+    "Update details" : "Podrobnosti aktualizace",
+    "Update needed" : "Je třeba provést aktualizaci",
+    "Please use the command line updater because you have a big instance with more than 50 accounts." : "Použijte aktualizační příkazový řádek, protože máte velkou instanci s více než 50 účty.",
+    "Documentation" : "Dokumentace",
+    "I know that if I continue doing the update via web UI has the risk, that the request runs into a timeout and could cause data loss, but I have a backup and know how to restore my instance in case of a failure." : "Beru na vědomí, že při aktualizaci skrze webové rozhraní hrozí nebezpečí překročení časového limitu požadavku, který může vyústit ve ztrátu dat. Mám pro takový případ zálohu a vím, jak ji v případě nezdaru obnovit.",
+    "Upgrade via web on my own risk" : "Na vlastní nebezpečí aktualizovat skrze web",
     "Search {types} …" : "Hledat {types} …",
     "Choose {file}" : "Zvolit {file}",
     "Choose" : "Vybrat",
@@ -420,19 +451,13 @@ OC.L10N.register(
     "Group list is empty" : "Seznam skupin je prázdný.",
     "Unable to retrieve the group list" : "Nedaří se získat seznam skupiny",
     "seconds ago" : "před několika sekundami",
-    "Connection to server lost" : "Připojení k serveru ztraceno",
-    "_Problem loading page, reloading in %n second_::_Problem loading page, reloading in %n seconds_" : ["Problém s načítáním stránky, obnovení za %n sekundu","Problém s načítáním stránky, obnovení za %n sekundy","Problém s načítáním stránky, obnovení za %n sekund","Problém s načítáním stránky, obnovení za %n sekund"],
     "Add to a project" : "Přidat do projektu",
-    "Show details" : "Zobrazit podrobnosti",
-    "Hide details" : "Skrýt podrobnosti",
     "Rename project" : "Přejmenovat projekt",
     "Failed to rename the project" : "Přejmenování projektu se nezdařilo",
     "Failed to create a project" : "Vytvoření projektu se nezdařilo",
     "Failed to add the item to the project" : "Přidání položky do projektu se nezdařilo",
     "Connect items to a project to make them easier to find" : "Připojte položky k projektu aby je bylo snazší nalézt",
     "Type to search for existing projects" : "Psaním vyhledávejte existující projekty",
-    "New in" : "Nové v",
-    "View changelog" : "Zobrazit souhrn změn",
     "Close \"{dialogTitle}\" dialog" : "Zavřít „{dialogTitle}“ dialog",
     "Email length is at max (255)" : "Délka e-mailu je na maximu (255)",
     "Clipboard not available, please copy manually" : "Schránka není k dispozici – zkopírujte ručně",
@@ -484,20 +509,6 @@ OC.L10N.register(
     "Access through untrusted domain" : "Přístup prostřednictvím nedůvěryhodné domény",
     "Please contact your administrator. If you are an administrator, edit the \"trusted_domains\" setting in config/config.php like the example in config.sample.php." : "Obraťte se na svého správce. Pokud jste jím vy, upravte v souboru s nastaveními config/config.php parametr „trusted_domains“ podle příkladu v config.sample.php.",
     "Further information how to configure this can be found in the %1$sdocumentation%2$s." : "Další informace o tom, jak toto nastavit jsou k dispozici v %1$sdokumentaci%2$s.",
-    "App update required" : "Vyžadována aktualizace aplikace",
-    "%1$s will be updated to version %2$s" : "%1$s bude aktualizováno na verzi %2$s",
-    "The following apps will be updated:" : "Následující aplikace budou aktualizovány:",
-    "These incompatible apps will be disabled:" : "Tyto nekompatibilní aplikace budou vypnuty:",
-    "The theme %s has been disabled." : "Motiv vzhledu %s byl vypnut.",
-    "Please make sure that the database, the config folder and the data folder have been backed up before proceeding." : "Před provedením dalšího kroku se ujistěte, že je zazálohována databáze a složky s nastaveními a daty.",
-    "Start update" : "Spustit aktualizaci",
-    "To avoid timeouts with larger installations, you can instead run the following command from your installation directory:" : "Abyste zabránili překračování časových limitů u větších instalací, můžete místo toho v adresáři s nainstalovanou aplikací spustit:",
-    "Detailed logs" : "Podrobné záznamy událostí",
-    "Update needed" : "Je třeba provést aktualizaci",
-    "Please use the command line updater because you have a big instance with more than 50 accounts." : "Použijte aktualizační příkazový řádek, protože máte velkou instanci s více než 50 účty.",
-    "For help, see the  <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">documentation</a>." : "Pro pomoc, nahlédněte do <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">dokumentace</a>.",
-    "I know that if I continue doing the update via web UI has the risk, that the request runs into a timeout and could cause data loss, but I have a backup and know how to restore my instance in case of a failure." : "Beru na vědomí, že při aktualizaci skrze webové rozhraní hrozí nebezpečí překročení časového limitu požadavku, který může vyústit ve ztrátu dat. Mám pro takový případ zálohu a vím, jak ji v případě nezdaru obnovit.",
-    "Upgrade via web on my own risk" : "Na vlastní nebezpečí aktualizovat skrze web",
     "Maintenance mode" : "Režim údržby",
     "This %s instance is currently in maintenance mode, which may take a while." : "Tato instance %s se právě nachází v režimu údržby a ta může chvíli trvat.",
     "This page will refresh itself when the instance is available again." : "Tato stránka se automaticky znovu načte, jakmile bude tato instance opět dostupná.",
@@ -512,6 +523,11 @@ OC.L10N.register(
     "<strong>These are your search results<script>alert(1)</script></strong>" : "<strong>Toto výsledky pro vaše hledání<script>alert(1)</script></strong>",
     "new" : "nový",
     "_download %n file_::_download %n files_" : ["stáhnout %n soubor","stáhnout %n soubory","stáhnout %n souborů","stáhnout %n souborů"],
+    "An error occurred." : "Došlo k chybě.",
+    "Please reload the page." : "Načtěte stránku znovu.",
+    "The update was unsuccessful. For more information <a href=\"{url}\">check our forum post</a> covering this issue." : "Aktualizace nebyla úspěšná. Další informace <a href=\"{url}\">se dočtete v příspěvku na diskuzním fóru</a>, pojednávajícím o tomto problému.",
+    "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud community</a>." : "Aktualizace nebyla úspěšná. Prosím nahlaste tento problém <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">komunitě projektu Nextcloud</a>",
+    "_The update was successful. Redirecting you to {productName} in %n second._::_The update was successful. Redirecting you to {productName} in %n seconds._" : ["Aktualizace proběhla úspěšně. Za %n sekundu budete přesměrováni do {productName}","Aktualizace proběhla úspěšně. Za %n sekundy budete přesměrováni do {productName}","Aktualizace proběhla úspěšně. Za %n sekund budete přesměrováni do {productName}","Aktualizace proběhla úspěšně. Za %n sekundy budete přesměrováni do {productName}"],
     "Direct link copied to clipboard" : "Přímý odkaz zkopírován do schránky",
     "Searching …" : "Hledání …",
     "Logging in …" : "Přihlašování …",
@@ -524,6 +540,10 @@ OC.L10N.register(
     "Loading more results …" : "Načítání dalších výsledků …",
     "Search {types} …" : "Hledat {types} …",
     "Saving …" : "Ukládání …",
+    "Connection to server lost" : "Připojení k serveru ztraceno",
+    "_Problem loading page, reloading in %n second_::_Problem loading page, reloading in %n seconds_" : ["Problém s načítáním stránky, obnovení za %n sekundu","Problém s načítáním stránky, obnovení za %n sekundy","Problém s načítáním stránky, obnovení za %n sekund","Problém s načítáním stránky, obnovení za %n sekund"],
+    "New in" : "Nové v",
+    "View changelog" : "Zobrazit souhrn změn",
     "Very weak password" : "Velmi snadno prolomitelné heslo",
     "Weak password" : "Snadno prolomitelné heslo",
     "So-so password" : "Ještě použitelné heslo",
@@ -550,6 +570,11 @@ OC.L10N.register(
     "Installing …" : "Instalace …",
     "Please log in before granting %1$s access to your %2$s account." : "Přihlaste se abyste mohli %1$s udělit přístup k vašemu %2$s účtu.",
     "Currently logged in as %1$s (%2$s)." : "Nyní jste přihlášeni jako %1$s (%2$s).",
-    "You are about to grant %1$s access to your %2$s account." : "Chystáte se udělit %1$s přístup ke svému %2$s účtu."
+    "You are about to grant %1$s access to your %2$s account." : "Chystáte se udělit %1$s přístup ke svému %2$s účtu.",
+    "%1$s will be updated to version %2$s" : "%1$s bude aktualizováno na verzi %2$s",
+    "The following apps will be updated:" : "Následující aplikace budou aktualizovány:",
+    "The theme %s has been disabled." : "Motiv vzhledu %s byl vypnut.",
+    "Detailed logs" : "Podrobné záznamy událostí",
+    "For help, see the  <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">documentation</a>." : "Pro pomoc, nahlédněte do <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">dokumentace</a>."
 },
 "nplurals=4; plural=(n == 1 && n % 1 == 0) ? 0 : (n >= 2 && n <= 4 && n % 1 == 0) ? 1: (n % 1 != 0 ) ? 2 : 3;");
