@@ -197,14 +197,6 @@ OC.L10N.register(
     "Matroska video" : "Matroska video",
     "Windows Media video" : "Windows Medie video",
     "AVI video" : "AVI video",
-    "The update is in progress, leaving this page might interrupt the process in some environments." : "Opdateringen er i gang. Forlader du denne side kan der ske fejl i processen som ødelægger din Nextcloud installation",
-    "Update to {version}" : "Opdatér til {version}",
-    "An error occurred." : "Der opstod en fejl.",
-    "Please reload the page." : "Genindlæs venligst siden.",
-    "The update was unsuccessful. For more information <a href=\"{url}\">check our forum post</a> covering this issue." : "Opdateringen blev ikke udført korrekt. For mere information <a href=\"{url}\">tjek vores indlæg på forumet</a>, som dækker dette problem.",
-    "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud community</a>." : "Opdateringen blev ikke udført korrekt. Rapporter venligst problemet til <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud fællesskabet</a>.",
-    "Continue to {productName}" : "Fortsæt til {productName}",
-    "_The update was successful. Redirecting you to {productName} in %n second._::_The update was successful. Redirecting you to {productName} in %n seconds._" : ["Opdateringen lykkedes. Omdirigerer dig til {productName} om %n sekund.","Opdateringen lykkedes. Omdirigerer dig til {productName} om %n sekunder."],
     "Done" : "Færdig",
     "Applications menu" : "App menu",
     "Apps" : "Apps",
@@ -307,8 +299,8 @@ OC.L10N.register(
     "Loading your contacts …" : "Indlæser kontakter ...",
     "Looking for {term} …" : "Leder efter {term} …",
     "Search contacts" : "Søg kontakter",
-    "Reset search" : "Nulstil søgning",
     "Search contacts …" : "Søg efter kontakter ...",
+    "Reset search" : "Nulstil søgning",
     "Could not load your contacts" : "Kunne ikke indlæse kontakter.",
     "No contacts found" : "Ingen kontakter",
     "Show all contacts" : "Vis alle kontakter",
@@ -391,6 +383,22 @@ OC.L10N.register(
     "Your browser is not supported. Please upgrade to a newer version or a supported one." : "Din browser understøttes ikke. Opdater venligst til en nyere version, eller vælg en anden der supporteres. ",
     "Continue with this unsupported browser" : "Fortsæt med denne ikke supporterede browser",
     "Supported versions" : "Supporterede versioner",
+    "The update is in progress, leaving this page might interrupt the process in some environments." : "Opdateringen er i gang. Forlader du denne side kan der ske fejl i processen som ødelægger din Nextcloud installation",
+    "App update required" : "Opdatering af app påkræves",
+    "These incompatible apps will be disabled:" : "Følgende inkompatible apps vil blive slået fra:",
+    "These apps will be updated:" : "Følgende apps vil blive opdateret:",
+    "Please make sure that the database, the config folder and the data folder have been backed up before proceeding." : "Sørg venligst for at sikre, at databasen, config-mappen og data-mappen er blevet sikkerhedskopieret inden vi fortsætter.",
+    "To avoid timeouts with larger installations, you can instead run the following command from your installation directory:" : "For at undgå tidsudløb ved større installationer, så kan du i stedet køre følgende kommando fra din installationsmappe:",
+    "Start update" : "Begynd opdatering",
+    "Continue to {productName}" : "Fortsæt til {productName}",
+    "Update to {version}" : "Opdatér til {version}",
+    "Hide details" : "Skjul detaljer",
+    "Show details" : "Vis detaljer",
+    "Update needed" : "Opdatering nødvendig",
+    "Please use the command line updater because you have a big instance with more than 50 accounts." : "Brug venligst kommandolinje opdateringsfunktionen til at opdatere fordi du har en stor installation med mere end 50 brugere.",
+    "Documentation" : "Dokumentation",
+    "I know that if I continue doing the update via web UI has the risk, that the request runs into a timeout and could cause data loss, but I have a backup and know how to restore my instance in case of a failure." : "Jeg ved at hvis jeg fortsætter med at bruge opdateringssystemet via denne web forbindelse risikerer jeg at der opstår en timeout og jeg dermed mister mine data. Men jeg har et en backuip og ved hvordan jeg kan genindlæse den hvis det sker",
+    "Upgrade via web on my own risk" : "Opdatering via web er på mit eget ansvar.",
     "Search {types} …" : "Søg {types} …",
     "Choose {file}" : "Vælg {file}",
     "Choose" : "Vælg",
@@ -416,19 +424,13 @@ OC.L10N.register(
     "Group list is empty" : "Gruppelisten er tom",
     "Unable to retrieve the group list" : "Kan ikke hente gruppelisten",
     "seconds ago" : "få sekunder siden",
-    "Connection to server lost" : "Forbindelsen til serveren er tabt",
-    "_Problem loading page, reloading in %n second_::_Problem loading page, reloading in %n seconds_" : ["Der opstod et problem med at hente siden, prøver igen om %n sekund","Der opstod et problem med at hente siden, prøver igen om %n sekunder"],
     "Add to a project" : "Tilføj til et projekt",
-    "Show details" : "Vis detaljer",
-    "Hide details" : "Skjul detaljer",
     "Rename project" : "Omdøb projekt",
     "Failed to rename the project" : "Kunne ikke omdøbe projektet",
     "Failed to create a project" : "Kunne ikke oprette projekt",
     "Failed to add the item to the project" : "Kunne ikke tilføje objekt til projektet",
     "Connect items to a project to make them easier to find" : "Forbind objekter til et projekt for at gøre dem lettere at finde",
     "Type to search for existing projects" : "Skriv for at søge efter eksisterende projekter",
-    "New in" : "Ny i",
-    "View changelog" : "Se ændringslog",
     "Close \"{dialogTitle}\" dialog" : "Luk dialogboksen \"{dialogTitle}\".",
     "Email length is at max (255)" : "E-maillængde er på maks. (255)",
     "Clipboard not available, please copy manually" : "Udklipsholderen er ikke tilgængeligt, kopier venligst manuelt",
@@ -480,20 +482,6 @@ OC.L10N.register(
     "Access through untrusted domain" : "Adgang gennem et utroværdigt domæne.",
     "Please contact your administrator. If you are an administrator, edit the \"trusted_domains\" setting in config/config.php like the example in config.sample.php." : "Kontakt venligst din administrator. Hvis du er administratoren af denne server, skal du konfigurere \"trusted-domains\" i filen config/config.php. Et eksempel på hvordan kan findes i filen config/config.sample.php",
     "Further information how to configure this can be found in the %1$sdocumentation%2$s." : "Nærmere information om hvordan dette indstilles kan findes i %1$sdokumentationen%2$s.",
-    "App update required" : "Opdatering af app påkræves",
-    "%1$s will be updated to version %2$s" : "%1$s vil blive opdateret til version %2$s",
-    "The following apps will be updated:" : "Følgende app vil blive opdateret:",
-    "These incompatible apps will be disabled:" : "Følgende inkompatible apps vil blive slået fra:",
-    "The theme %s has been disabled." : "Temaet, %s, er blevet deaktiveret.",
-    "Please make sure that the database, the config folder and the data folder have been backed up before proceeding." : "Sørg venligst for at sikre, at databasen, config-mappen og data-mappen er blevet sikkerhedskopieret inden vi fortsætter.",
-    "Start update" : "Begynd opdatering",
-    "To avoid timeouts with larger installations, you can instead run the following command from your installation directory:" : "For at undgå tidsudløb ved større installationer, så kan du i stedet køre følgende kommando fra din installationsmappe:",
-    "Detailed logs" : "Detaljerede logs",
-    "Update needed" : "Opdatering nødvendig",
-    "Please use the command line updater because you have a big instance with more than 50 accounts." : "Brug venligst kommandolinje opdateringsfunktionen til at opdatere fordi du har en stor installation med mere end 50 brugere.",
-    "For help, see the  <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">documentation</a>." : "For hjælp, se  <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">dokumentation</a>.",
-    "I know that if I continue doing the update via web UI has the risk, that the request runs into a timeout and could cause data loss, but I have a backup and know how to restore my instance in case of a failure." : "Jeg ved at hvis jeg fortsætter med at bruge opdateringssystemet via denne web forbindelse risikerer jeg at der opstår en timeout og jeg dermed mister mine data. Men jeg har et en backuip og ved hvordan jeg kan genindlæse den hvis det sker",
-    "Upgrade via web on my own risk" : "Opdatering via web er på mit eget ansvar.",
     "Maintenance mode" : "Vedligeholdelsestilstand",
     "This %s instance is currently in maintenance mode, which may take a while." : "Denne %s-instans befinder sig i vedligeholdelsestilstand for øjeblikket, hvilket kan tage et stykke tid.",
     "This page will refresh itself when the instance is available again." : "Denne side vil genopfriske sig selv, når instancen er tilgængelig igen.",
@@ -508,6 +496,11 @@ OC.L10N.register(
     "<strong>These are your search results<script>alert(1)</script></strong>" : "<strong>Dine søgeresultater<script>alert(1)</script></strong>",
     "new" : "ny",
     "_download %n file_::_download %n files_" : ["hent %n fil","hent %n filer"],
+    "An error occurred." : "Der opstod en fejl.",
+    "Please reload the page." : "Genindlæs venligst siden.",
+    "The update was unsuccessful. For more information <a href=\"{url}\">check our forum post</a> covering this issue." : "Opdateringen blev ikke udført korrekt. For mere information <a href=\"{url}\">tjek vores indlæg på forumet</a>, som dækker dette problem.",
+    "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud community</a>." : "Opdateringen blev ikke udført korrekt. Rapporter venligst problemet til <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud fællesskabet</a>.",
+    "_The update was successful. Redirecting you to {productName} in %n second._::_The update was successful. Redirecting you to {productName} in %n seconds._" : ["Opdateringen lykkedes. Omdirigerer dig til {productName} om %n sekund.","Opdateringen lykkedes. Omdirigerer dig til {productName} om %n sekunder."],
     "Direct link copied to clipboard" : "Direkte link kopieret til udklipsholder",
     "Searching …" : "Søger …",
     "Logging in …" : "Logger ind …",
@@ -520,6 +513,10 @@ OC.L10N.register(
     "Loading more results …" : "Henter flere resultater...",
     "Search {types} …" : "Søg {types} …",
     "Saving …" : "Gemmer…",
+    "Connection to server lost" : "Forbindelsen til serveren er tabt",
+    "_Problem loading page, reloading in %n second_::_Problem loading page, reloading in %n seconds_" : ["Der opstod et problem med at hente siden, prøver igen om %n sekund","Der opstod et problem med at hente siden, prøver igen om %n sekunder"],
+    "New in" : "Ny i",
+    "View changelog" : "Se ændringslog",
     "Very weak password" : "Meget svagt kodeord",
     "Weak password" : "Svagt kodeord",
     "So-so password" : "Jævnt kodeord",
@@ -546,6 +543,11 @@ OC.L10N.register(
     "Installing …" : "Installerer...",
     "Please log in before granting %1$s access to your %2$s account." : "Log venligst ind for at tildele %1$s adgang til din %2$s konto.",
     "Currently logged in as %1$s (%2$s)." : "Logget ind som %1$s (%2$s).",
-    "You are about to grant %1$s access to your %2$s account." : "Du er ved at tildele %1$s adgang til din %2$s konto."
+    "You are about to grant %1$s access to your %2$s account." : "Du er ved at tildele %1$s adgang til din %2$s konto.",
+    "%1$s will be updated to version %2$s" : "%1$s vil blive opdateret til version %2$s",
+    "The following apps will be updated:" : "Følgende app vil blive opdateret:",
+    "The theme %s has been disabled." : "Temaet, %s, er blevet deaktiveret.",
+    "Detailed logs" : "Detaljerede logs",
+    "For help, see the  <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">documentation</a>." : "For hjælp, se  <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">dokumentation</a>."
 },
 "nplurals=2; plural=(n != 1);");
