@@ -71,18 +71,15 @@ OC.L10N.register(
     "The following apps have been disabled: %s" : "La jenaj aplikaĵoj estis malŝatitaj: %s",
     "Already up to date" : "Jam aktuala",
     "Unknown" : "Nekonata",
-    "The update is in progress, leaving this page might interrupt the process in some environments." : "Ĝisdatigo estas farata; forirado de la paĝo povas kelkfoje interrompi la agon.",
-    "Update to {version}" : "Ĝisdatigi al {version}",
-    "An error occurred." : "Eraro okazis.",
-    "Please reload the page." : "Bonvolu reŝargi la paĝon.",
-    "The update was unsuccessful. For more information <a href=\"{url}\">check our forum post</a> covering this issue." : "La ĝisdatigo malsukcesis. Por pli da informoj, <a href=\"{url}\">vidu la forumafisôn</a> pri tio.",
-    "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud community</a>." : "La ĝisdatigo malsukcesis. Bonvolu raporti tiun problemon al la <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud-komunumo</a>.",
+    "Done" : "Farita",
     "Applications menu" : "Aplikaĵa menuo",
     "Apps" : "Aplikaĵoj",
     "More apps" : "Pli da aplikaĵoj",
     "_{count} notification_::_{count} notifications_" : ["{count} sciigoj","{count} sciigoj"],
     "No" : "Ne",
     "Yes" : "Jes",
+    "App password" : "Aplikaĵa pasvorto",
+    "Grant access" : "Doni alirpermeson",
     "Failed to add the public link to your Nextcloud" : "Ne eblis aldoni la publikan ligilon al via Nextcloud",
     "Custom date range" : "Propra data periodo",
     "Pick start date" : "Elekti komencan daton",
@@ -102,7 +99,6 @@ OC.L10N.register(
     "Search in" : "Serĉi en",
     "Log in" : "Ensaluti",
     "Log in to {productName}" : "Saluti al {productName}",
-    "We have detected multiple invalid login attempts from your IP. Therefore your next login is throttled up to 30 seconds." : "Ni eltrovis plurajn nevalidajn provojn ensaluti el via IP-adreso. Do, oni prokrastis vian sekvantan ensaluton dum ĝis 30 sekundoj.",
     "Account name or email" : "Kontonomo aŭ retpoŝta adreso",
     "Server side authentication failed!" : "Ĉeservila aŭtentigo malsukcesis!",
     "Please contact your administrator." : "Bonvolu kontakti vian administranton.",
@@ -137,8 +133,20 @@ OC.L10N.register(
     "No results for {query}" : "Neniu rezulto pri {query}",
     "Forgot password?" : "Ĉu vi forgesis vian pasvorton?",
     "Back" : "Antaŭen",
-    "More actions" : "Pliaj agoj",
+    "Connect to your account" : "Konekti al via konto",
     "Security warning" : "Sekureca averto",
+    "If you are not trying to set up a new device or app, someone is trying to trick you into granting them access to your data. In this case do not proceed and instead contact your system administrator." : "Se vi ne provas agordi novan aparaton aŭ apon, iu provas trompi vin por doni al ili aliron al viaj datumoj. En ĉi tiu kazo ne procedu kaj anstataŭe kontaktu vian sisteman administranton.",
+    "Account connected" : "Konto konektita",
+    "Your client should now be connected!" : "Via kliento estas konektita!",
+    "You can close this window." : "Vi povas fermi tiun ĉi fenestron.",
+    "Account access" : "Aliro al konto",
+    "More actions" : "Pliaj agoj",
+    "This share is password-protected" : "Tiu kunhavigo estas protektata per pasvorto",
+    "The password is wrong or expired. Please try again or request a new one." : "La pasvorto estas malĝusta aŭ eksvalidiĝis. Bonvolu provi denove aŭ peti novan.",
+    "Submit" : "Sendi",
+    "Password sent!" : "Pasvorto sendiĝis!",
+    "Email address" : "Retpoŝtadreso",
+    "Forgot password" : "Pasvorto forgesita",
     "Storage & database" : "Konservejo kaj datumbazo",
     "Data folder" : "Datuma dosierujo",
     "Install and activate additional PHP modules to choose other database types." : "Instalu kaj aktivigu pliajn PHP-modulojn por elekti aliajn datumbazajn specojn..",
@@ -160,6 +168,20 @@ OC.L10N.register(
     "This browser is not supported" : "La retumilo ne estas subtenata",
     "Continue with this unsupported browser" : "Daŭrigi per tiu ne subtenata retumilo",
     "Supported versions" : "Subtenataj versioj",
+    "The update is in progress, leaving this page might interrupt the process in some environments." : "Ĝisdatigo estas farata; forirado de la paĝo povas kelkfoje interrompi la agon.",
+    "App update required" : "Aplikaĵa ĝisdatigo nepras",
+    "These incompatible apps will be disabled:" : "La jenaj malkongruaj aplikaĵoj estos malŝaltataj:",
+    "These apps will be updated:" : "La jenajn aplikaĵoj ĝisdatiĝos:",
+    "Please make sure that the database, the config folder and the data folder have been backed up before proceeding." : "Bonvolu certiĝi, ke la datumbazo, la dosierujo de agordoj kaj la dosierujo de datumoj jam estis savkopiitaj antaŭ ol plui.",
+    "To avoid timeouts with larger installations, you can instead run the following command from your installation directory:" : "Por eviti eltempiĝon ĉe grandaj instalaĵoj, vi povas anstataŭe ruli la jenan komandon en via instalo-dosierujo:",
+    "Start update" : "Ekĝisdatigi",
+    "Update to {version}" : "Ĝisdatigi al {version}",
+    "Hide details" : "Kaŝi la detalojn",
+    "Show details" : "Montri la detalojn",
+    "Update needed" : "Bezonas ĝisdatigi",
+    "Documentation" : "Dokumentaro",
+    "I know that if I continue doing the update via web UI has the risk, that the request runs into a timeout and could cause data loss, but I have a backup and know how to restore my instance in case of a failure." : "Mi scias, ke, se mi daŭrigas la ĝisdatigon per la reteja fasado, estas risko, ke la peto eltempiĝos kaj okazigos perdon de datumoj. Sed, mi havas sekurkopion kaj scias, kiel restaŭri mian servilon okaze de paneo.",
+    "Upgrade via web on my own risk" : "Ĝisdatigi per reteja fasado je mia risko",
     "Choose {file}" : "Elekti {file}",
     "Choose" : "Elekti",
     "Copy to {target}" : "Kopii al {target}",
@@ -179,20 +201,17 @@ OC.L10N.register(
     "(all selected)" : "(ĉiuj elektitaj)",
     "({count} selected)" : "({count} elektitaj)",
     "Error loading file exists template" : "Eraris ŝargo de ŝablono pri ekzistanta dosiero",
+    "Groups" : "Grupoj",
+    "Group list is empty" : "Gruplisto malplenas",
+    "Unable to retrieve the group list" : "Ne eblas ricevi grupliston",
     "seconds ago" : "sekundoj antaŭe",
-    "Connection to server lost" : "Konekto al servilo perdita",
-    "_Problem loading page, reloading in %n second_::_Problem loading page, reloading in %n seconds_" : ["Problemo dum ŝargo de paĝo, reŝargo en %n sekundo","Problemo dum ŝargo de paĝo, reŝargo en %n sekundoj"],
     "Add to a project" : "Aldoni al projekto",
-    "Show details" : "Montri la detalojn",
-    "Hide details" : "Kaŝi la detalojn",
     "Rename project" : "Alinomi la projekton",
     "Failed to rename the project" : "Malsukceso alinomi la projekton",
     "Failed to create a project" : "Malsukceso krei projekton",
     "Failed to add the item to the project" : "Malsukceso aldoni la elementon al la projekto",
     "Connect items to a project to make them easier to find" : "Konekti elementojn al projekto por faciligi ilian trovon",
     "Type to search for existing projects" : "Entajpi por serĉi jam ekzistantajn projektojn",
-    "New in" : "Nova en",
-    "View changelog" : "Vidi ŝanĝoprotokolon",
     "Close \"{dialogTitle}\" dialog" : "Fermi la dialogon \"{dialogTitle}\"",
     "Personal" : "Persona",
     "Accounts" : "Kontoj",
@@ -225,22 +244,7 @@ OC.L10N.register(
     "Skip to navigation of app" : "Iru al la aplikaĵa navigado",
     "Go to %s" : "Iri al %s",
     "Get your own free account" : "Ekhavu vian propran senpagan konton",
-    "Connect to your account" : "Konekti al via konto",
-    "Please log in before granting %1$s access to your %2$s account." : "Bv. unue ensaluti por doni al %1$s aliron al via konto %2$s.",
-    "If you are not trying to set up a new device or app, someone is trying to trick you into granting them access to your data. In this case do not proceed and instead contact your system administrator." : "Se vi ne provas agordi novan aparaton aŭ apon, iu provas trompi vin por doni al ili aliron al viaj datumoj. En ĉi tiu kazo ne procedu kaj anstataŭe kontaktu vian sisteman administranton.",
-    "App password" : "Aplikaĵa pasvorto",
-    "Grant access" : "Doni alirpermeson",
-    "Account access" : "Aliro al konto",
-    "Currently logged in as %1$s (%2$s)." : "Aktuale salutinta kiel %1$s (%2$s).",
-    "You are about to grant %1$s access to your %2$s account." : "Vi tuj donos permeson al %1$s aliri al via konto %2$s.",
-    "Account connected" : "Konto konektita",
-    "Your client should now be connected!" : "Via kliento estas konektita!",
-    "You can close this window." : "Vi povas fermi tiun ĉi fenestron.",
     "Previous" : "Antaŭa",
-    "This share is password-protected" : "Tiu kunhavigo estas protektata per pasvorto",
-    "The password is wrong or expired. Please try again or request a new one." : "La pasvorto estas malĝusta aŭ eksvalidiĝis. Bonvolu provi denove aŭ peti novan.",
-    "Email address" : "Retpoŝtadreso",
-    "Password sent!" : "Pasvorto sendiĝis!",
     "Two-factor authentication" : "Dufaza aŭtentigo",
     "Enhanced security is enabled for your account. Choose a second factor for authentication:" : "Plibonigita sekurigo estas ebligita por via konto. Elektu duan fazon por aŭtentigo:",
     "Could not load at least one of your enabled two-factor auth methods. Please contact your admin." : "Ne eblis ŝargi almenaŭ unu el viaj ebligitaj metodoj pri dufaza aŭtentigo. Bv. kontakti vian administranton.",
@@ -255,19 +259,6 @@ OC.L10N.register(
     "Access through untrusted domain" : "Aliro tra nefidinda domajno",
     "Please contact your administrator. If you are an administrator, edit the \"trusted_domains\" setting in config/config.php like the example in config.sample.php." : "Bv. kontakti vian administranton. Se vi estas administranto, modifu la agordon „trusted_domains“ (fidindaj domajnoj en la angla) en la dosiero config/config.php (estas ekzemplo en config.sample.php).",
     "Further information how to configure this can be found in the %1$sdocumentation%2$s." : "Pliaj informoj pri agordo de tio troveblas en la %1$sdokumentaro%2$s.",
-    "App update required" : "Aplikaĵa ĝisdatigo nepras",
-    "%1$s will be updated to version %2$s" : "%1$s ĝisdatiĝos al versio %2$s",
-    "The following apps will be updated:" : "La jenaj aplikaĵoj estos ĝisdatigitaj:",
-    "These incompatible apps will be disabled:" : "La jenaj malkongruaj aplikaĵoj estos malŝaltataj:",
-    "The theme %s has been disabled." : "La etoso %s estis malebligita.",
-    "Please make sure that the database, the config folder and the data folder have been backed up before proceeding." : "Bonvolu certiĝi, ke la datumbazo, la dosierujo de agordoj kaj la dosierujo de datumoj jam estis savkopiitaj antaŭ ol plui.",
-    "Start update" : "Ekĝisdatigi",
-    "To avoid timeouts with larger installations, you can instead run the following command from your installation directory:" : "Por eviti eltempiĝon ĉe grandaj instalaĵoj, vi povas anstataŭe ruli la jenan komandon en via instalo-dosierujo:",
-    "Detailed logs" : "Detalaj protokoloj",
-    "Update needed" : "Bezonas ĝisdatigi",
-    "For help, see the  <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">documentation</a>." : "Vidu la  <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">dokumentaron</a> por helpo.",
-    "I know that if I continue doing the update via web UI has the risk, that the request runs into a timeout and could cause data loss, but I have a backup and know how to restore my instance in case of a failure." : "Mi scias, ke, se mi daŭrigas la ĝisdatigon per la reteja fasado, estas risko, ke la peto eltempiĝos kaj okazigos perdon de datumoj. Sed, mi havas sekurkopion kaj scias, kiel restaŭri mian servilon okaze de paneo.",
-    "Upgrade via web on my own risk" : "Ĝisdatigi per reteja fasado je mia risko",
     "Maintenance mode" : "Reĝimo de prizorgado",
     "This %s instance is currently in maintenance mode, which may take a while." : "La servilo %s estas nun en reĝimo de prizorgado, tio eble daŭros longatempe.",
     "This page will refresh itself when the instance is available again." : "Tiu ĉi paĝo aktualiĝos mem, kiam la servilo redisponeblos.",
@@ -282,14 +273,23 @@ OC.L10N.register(
     "<strong>These are your search results<script>alert(1)</script></strong>" : "<strong>Jen via serĉ-rezultoj<script>alert(1)</script></strong>",
     "new" : "nova",
     "_download %n file_::_download %n files_" : ["elŝuti %n dosieron","elŝuti %n dosierojn"],
+    "An error occurred." : "Eraro okazis.",
+    "Please reload the page." : "Bonvolu reŝargi la paĝon.",
+    "The update was unsuccessful. For more information <a href=\"{url}\">check our forum post</a> covering this issue." : "La ĝisdatigo malsukcesis. Por pli da informoj, <a href=\"{url}\">vidu la forumafisôn</a> pri tio.",
+    "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud community</a>." : "La ĝisdatigo malsukcesis. Bonvolu raporti tiun problemon al la <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud-komunumo</a>.",
     "Searching …" : "Serĉado ...",
     "Logging in …" : "Ensaluti...",
+    "We have detected multiple invalid login attempts from your IP. Therefore your next login is throttled up to 30 seconds." : "Ni eltrovis plurajn nevalidajn provojn ensaluti el via IP-adreso. Do, oni prokrastis vian sekvantan ensaluton dum ĝis 30 sekundoj.",
     "Loading apps …" : "Ŝargado de aplikaĵoj...",
     "Installing apps …" : "Instalado de aplikaĵoj...",
     "Loading your contacts …" : "Ŝargo de viaj kontaktoj...",
     "Looking for {term} …" : "Serĉo de {term}…",
     "Search contacts …" : "Serĉi kontaktojn…",
     "Saving …" : "Konservado...",
+    "Connection to server lost" : "Konekto al servilo perdita",
+    "_Problem loading page, reloading in %n second_::_Problem loading page, reloading in %n seconds_" : ["Problemo dum ŝargo de paĝo, reŝargo en %n sekundo","Problemo dum ŝargo de paĝo, reŝargo en %n sekundoj"],
+    "New in" : "Nova en",
+    "View changelog" : "Vidi ŝanĝoprotokolon",
     "Very weak password" : "Tre malforta pasvorto",
     "Weak password" : "Malforta pasvorto",
     "So-so password" : "Mezbona pasvorto",
@@ -310,6 +310,14 @@ OC.L10N.register(
     "Configure the database" : "Agordi la datumbazon",
     "Only %s is available." : "Nur %s disponeblas.",
     "Database account" : "Datumbaza konto",
-    "Installing …" : "Instalante…"
+    "Installing …" : "Instalante…",
+    "Please log in before granting %1$s access to your %2$s account." : "Bv. unue ensaluti por doni al %1$s aliron al via konto %2$s.",
+    "Currently logged in as %1$s (%2$s)." : "Aktuale salutinta kiel %1$s (%2$s).",
+    "You are about to grant %1$s access to your %2$s account." : "Vi tuj donos permeson al %1$s aliri al via konto %2$s.",
+    "%1$s will be updated to version %2$s" : "%1$s ĝisdatiĝos al versio %2$s",
+    "The following apps will be updated:" : "La jenaj aplikaĵoj estos ĝisdatigitaj:",
+    "The theme %s has been disabled." : "La etoso %s estis malebligita.",
+    "Detailed logs" : "Detalaj protokoloj",
+    "For help, see the  <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">documentation</a>." : "Vidu la  <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">dokumentaron</a> por helpo."
 },
 "nplurals=2; plural=(n != 1);");
