@@ -66,14 +66,6 @@ OC.L10N.register(
     "The following apps have been disabled: %s" : "Las siguientes aplicaciones se han desactivado: %s",
     "Already up to date" : "Ya está actualizado",
     "Unknown" : "Desconocido",
-    "The update is in progress, leaving this page might interrupt the process in some environments." : "La actualización está en curso, abandonar esta página puede interrumpir el proceso en algunos ambientes. ",
-    "Update to {version}" : "Actualizar a {version}",
-    "An error occurred." : "Se presentó un error.",
-    "Please reload the page." : "Por favor vuelve a cargar la página.",
-    "The update was unsuccessful. For more information <a href=\"{url}\">check our forum post</a> covering this issue." : "La actualización no fue exitosa. Para más información <a href=\"{url}\">consulta nuestro comentario  en el foro </a> que cubre este tema. ",
-    "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud community</a>." : "La actualización no fue exitosa. Por favor reporta este tema a la <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Comunidad Nextcloud</a>.",
-    "Continue to {productName}" : "Continuar a {productName}",
-    "_The update was successful. Redirecting you to {productName} in %n second._::_The update was successful. Redirecting you to {productName} in %n seconds._" : ["La actualización se realizó correctamente. Redireccionándolo a {productName} en %n segundo.","La actualización se realizó correctamente. Redireccionándolo a {productName} en %n segundos.","La actualización se realizó correctamente. Redireccionándolo a {productName} en %n segundos."],
     "Done" : "Hecho",
     "Apps" : "Aplicaciones",
     "More apps" : "Más aplicaciones",
@@ -190,6 +182,21 @@ OC.L10N.register(
     "Your browser is not supported. Please upgrade to a newer version or a supported one." : "Tu navegador no es compatible. Por favor, actualízalo a una versión más nueva o una compatible.",
     "Continue with this unsupported browser" : "Continuar con este navegador no compatible",
     "Supported versions" : "Versiones compatibles",
+    "The update is in progress, leaving this page might interrupt the process in some environments." : "La actualización está en curso, abandonar esta página puede interrumpir el proceso en algunos ambientes. ",
+    "App update required" : "Se requiere una actualización de la aplicación",
+    "These incompatible apps will be disabled:" : "Las siguientes aplicaciones incompatibles serán deshabilitadas:",
+    "These apps will be updated:" : "Las siguientes apllicaciones se actualizarán:",
+    "Please make sure that the database, the config folder and the data folder have been backed up before proceeding." : "Por favor asegurarte de que la base de datos, la carpeta de configuración y las carpetas de datos hayan sido respaldadas antes de continuar. ",
+    "To avoid timeouts with larger installations, you can instead run the following command from your installation directory:" : "Para evitar la expiración de tiempo en instalaciones grandes, puedes ejecutar el siguiente comando desde tu directorio de instalación:",
+    "Start update" : "Iniciar actualización",
+    "Continue to {productName}" : "Continuar a {productName}",
+    "Update to {version}" : "Actualizar a {version}",
+    "Hide details" : "Ocultar detalles",
+    "Show details" : "Mostrar detalles",
+    "Update needed" : "Se requiere de una actualización",
+    "Documentation" : "Documentación",
+    "I know that if I continue doing the update via web UI has the risk, that the request runs into a timeout and could cause data loss, but I have a backup and know how to restore my instance in case of a failure." : "Estoy conciente de que si continúo haciendo la actualización vía web, la interfaz de usuario corre el riesgo de que el tiempo de la solicitud expire y cause pérdida de datos, pero cuento con un respaldo y sé como restaurar mi instancia en caso de una falla. ",
+    "Upgrade via web on my own risk" : "Actualizar vía Web bajo mi propio riesgo",
     "Choose" : "Seleccionar",
     "Copy" : "Copiar",
     "Move" : "Mover",
@@ -211,19 +218,13 @@ OC.L10N.register(
     "Group list is empty" : "La lista de grupos esta vacía",
     "Unable to retrieve the group list" : "No fue posible recuperar la lista del gurpo",
     "seconds ago" : "hace segundos",
-    "Connection to server lost" : "Se ha perdido la conexión con el servidor",
-    "_Problem loading page, reloading in %n second_::_Problem loading page, reloading in %n seconds_" : ["Se presentó un error al cargar la página, recargando en %n segundo","Se presentó un error al cargar la página, recargando en %n segundos","Se presentó un error al cargar la página, recargando en %n segundos"],
     "Add to a project" : "Agregar a un proyecto",
-    "Show details" : "Mostrar detalles",
-    "Hide details" : "Ocultar detalles",
     "Rename project" : "Renombrar proyecto",
     "Failed to rename the project" : "Error al cambiar el nombre del proyecto",
     "Failed to create a project" : "Error al crear un proyecto",
     "Failed to add the item to the project" : "Error al agregar el elemento al proyecto",
     "Connect items to a project to make them easier to find" : "Conecta elementos a un proyecto para que sean más fáciles de encontrar",
     "Type to search for existing projects" : "Escribe para buscar proyectos existentes",
-    "New in" : "Nuevo en",
-    "View changelog" : "Ver registro de cambios",
     "Close \"{dialogTitle}\" dialog" : "Cerrar diálogo \"{dialogTitle}\"",
     "Personal" : "Personal",
     "Accounts" : "Cuentas",
@@ -271,19 +272,6 @@ OC.L10N.register(
     "Access through untrusted domain" : "Accesa a través de un dominio no de confianza",
     "Please contact your administrator. If you are an administrator, edit the \"trusted_domains\" setting in config/config.php like the example in config.sample.php." : "Por favor contacta a tu adminsitrador. Si tu eres un administrador, edita la propiedad \"trusted_domains\" en el archivo config/config.php como en el ejemplo config.sample.php.",
     "Further information how to configure this can be found in the %1$sdocumentation%2$s." : "Para obtener más información sobre cómo configurar esto, consulta la %1$sdocumentación%2$s.",
-    "App update required" : "Se requiere una actualización de la aplicación",
-    "%1$s will be updated to version %2$s" : "%1$s se actualizará a la versión %2$s",
-    "The following apps will be updated:" : "Las siguientes aplicaciones se actualizarán:",
-    "These incompatible apps will be disabled:" : "Las siguientes aplicaciones incompatibles serán deshabilitadas:",
-    "The theme %s has been disabled." : "El tema %s ha sido deshabilitado. ",
-    "Please make sure that the database, the config folder and the data folder have been backed up before proceeding." : "Por favor asegurarte de que la base de datos, la carpeta de configuración y las carpetas de datos hayan sido respaldadas antes de continuar. ",
-    "Start update" : "Iniciar actualización",
-    "To avoid timeouts with larger installations, you can instead run the following command from your installation directory:" : "Para evitar la expiración de tiempo en instalaciones grandes, puedes ejecutar el siguiente comando desde tu directorio de instalación:",
-    "Detailed logs" : "Bitácoras detalladas",
-    "Update needed" : "Se requiere de una actualización",
-    "For help, see the  <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">documentation</a>." : "Para más ayuda, por favor consulta la <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">documentación</a>.",
-    "I know that if I continue doing the update via web UI has the risk, that the request runs into a timeout and could cause data loss, but I have a backup and know how to restore my instance in case of a failure." : "Estoy conciente de que si continúo haciendo la actualización vía web, la interfaz de usuario corre el riesgo de que el tiempo de la solicitud expire y cause pérdida de datos, pero cuento con un respaldo y sé como restaurar mi instancia en caso de una falla. ",
-    "Upgrade via web on my own risk" : "Actualizar vía Web bajo mi propio riesgo",
     "Maintenance mode" : "Modo de mantenimiento",
     "This %s instance is currently in maintenance mode, which may take a while." : "Esta instancia %s se encuentra actualmente en modo mantenimiento, que podría tomar algo de tiempo. ",
     "This page will refresh itself when the instance is available again." : "Esta página se actualizará automáticamente cuando la instancia esté disponible nuevamente.",
@@ -298,6 +286,11 @@ OC.L10N.register(
     "<strong>These are your search results<script>alert(1)</script></strong>" : "<strong>Estos son los resultados de tu búsqueda <script>alert(1)</script></strong>",
     "new" : "nuevo",
     "_download %n file_::_download %n files_" : ["Descargar %n archivos","Descargar %n archivos","Descargar %n archivos"],
+    "An error occurred." : "Se presentó un error.",
+    "Please reload the page." : "Por favor vuelve a cargar la página.",
+    "The update was unsuccessful. For more information <a href=\"{url}\">check our forum post</a> covering this issue." : "La actualización no fue exitosa. Para más información <a href=\"{url}\">consulta nuestro comentario  en el foro </a> que cubre este tema. ",
+    "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud community</a>." : "La actualización no fue exitosa. Por favor reporta este tema a la <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Comunidad Nextcloud</a>.",
+    "_The update was successful. Redirecting you to {productName} in %n second._::_The update was successful. Redirecting you to {productName} in %n seconds._" : ["La actualización se realizó correctamente. Redireccionándolo a {productName} en %n segundo.","La actualización se realizó correctamente. Redireccionándolo a {productName} en %n segundos.","La actualización se realizó correctamente. Redireccionándolo a {productName} en %n segundos."],
     "Searching …" : "Buscando...",
     "Logging in …" : "Iniciando sesión ...",
     "We have detected multiple invalid login attempts from your IP. Therefore your next login is throttled up to 30 seconds." : "Hemos detectado múltiples intentos de inicio de sesión desde tu IP. Por lo tanto tu siguiente incio de sesión se retrasará hasta 30 segundos. ",
@@ -309,6 +302,10 @@ OC.L10N.register(
     "Loading more results …" : "Cargando más resultados ...",
     "Search {types} …" : "Buscar {types} ...",
     "Saving …" : "Saving …",
+    "Connection to server lost" : "Se ha perdido la conexión con el servidor",
+    "_Problem loading page, reloading in %n second_::_Problem loading page, reloading in %n seconds_" : ["Se presentó un error al cargar la página, recargando en %n segundo","Se presentó un error al cargar la página, recargando en %n segundos","Se presentó un error al cargar la página, recargando en %n segundos"],
+    "New in" : "Nuevo en",
+    "View changelog" : "Ver registro de cambios",
     "Very weak password" : "Contraseña muy débil",
     "Weak password" : "Contraseña débil",
     "So-so password" : "Contraseña aceptable",
@@ -331,6 +328,11 @@ OC.L10N.register(
     "Installing …" : "Instalando...",
     "Please log in before granting %1$s access to your %2$s account." : "Inicia sesión antes de otorgar acceso a %1$s a tu cuenta de %2$s.",
     "Currently logged in as %1$s (%2$s)." : "Actualmente iniciado sesión como %1$s (%2$s).",
-    "You are about to grant %1$s access to your %2$s account." : "Estás a punto de otorgar acceso a %1$s a tu cuenta de %2$s."
+    "You are about to grant %1$s access to your %2$s account." : "Estás a punto de otorgar acceso a %1$s a tu cuenta de %2$s.",
+    "%1$s will be updated to version %2$s" : "%1$s se actualizará a la versión %2$s",
+    "The following apps will be updated:" : "Las siguientes aplicaciones se actualizarán:",
+    "The theme %s has been disabled." : "El tema %s ha sido deshabilitado. ",
+    "Detailed logs" : "Bitácoras detalladas",
+    "For help, see the  <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">documentation</a>." : "Para más ayuda, por favor consulta la <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">documentación</a>."
 },
 "nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
