@@ -45,6 +45,8 @@ OC.L10N.register(
     "Input text is too long" : "Sisendtekst on liiga pikk",
     "Requested task type does not exist" : "Küsitud ülesannete tüüpi ei leidu",
     "Necessary language model provider is not available" : "Vajaliku keelemudeli teenusepakkuja pole saadaval",
+    "Cannot generate more than 12 images" : "Ei saa luua üle 12 pildi",
+    "Cannot generate less than 1 image" : "Ei saa luua alla 1 pildi",
     "No text to image provider is available" : "Ühtegi optilise tekstituvastuse teenusepakkujat pole saadaval",
     "Image not found" : "Pilti ei leidu",
     "No translation provider available" : "Ühtegi tõlketeenuse pakkujat pole saadaval",
@@ -198,20 +200,18 @@ OC.L10N.register(
     "Matroska video" : "Matroska video",
     "Windows Media video" : "Windows Media video",
     "AVI video" : "AVI video",
-    "The update is in progress, leaving this page might interrupt the process in some environments." : "Uuendamine on pooleli, sellelt lehelt lahkumine võib mõnes keskkonnas protsessi katkestada.",
-    "Update to {version}" : "Uuenda versioonile {version}",
-    "An error occurred." : "Tekkis viga.",
-    "Please reload the page." : "Palun laadi leht uuesti.",
-    "The update was unsuccessful. For more information <a href=\"{url}\">check our forum post</a> covering this issue." : "Uuendamine ebaõnnestus. Täiendavat infot <a href=\"{url}\">vaata meie foorumipostitusest</a>.",
-    "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud community</a>." : "Uuendamine ebaõnnestus. Palun teavita probleemist <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloudi kogukonda</a>.",
-    "Continue to {productName}" : "Jätka siit: {productName}",
-    "_The update was successful. Redirecting you to {productName} in %n second._::_The update was successful. Redirecting you to {productName} in %n seconds._" : ["Uuendamine õnnestus. Sind suunatakse tagasi {productName} juurde %n sekundi pärast.","Uuendamine õnnestus. Sind suunatakse tagasi {productName} juurde %n sekundi pärast."],
+    "Done" : "Valmis",
+    "Scan QR code to log in" : "Sisselogimiseks skaneeri QR-koodi",
+    "Use {productName} mobile client you want to connect to scan the code" : "Skaneeri seda koode {productName}i mobiilikliendiga, mida soovid kasutada",
+    "Code will expire {timeCountdown} or after use" : "Kood aegub peale kasutamist või {timeCountdown}",
     "Applications menu" : "Rakenduste menüü",
     "Apps" : "Rakendused",
     "More apps" : "Veel rakendusi",
     "_{count} notification_::_{count} notifications_" : ["{count} teavitus","{count} teavitust"],
     "No" : "Ei",
     "Yes" : "Jah",
+    "App password" : "Rakenduse salasõna",
+    "Grant access" : "Anna ligipääs",
     "The remote URL must include the user." : "Kaugserveri võrguaadressis peab leiduma kasutajanimi",
     "Invalid remote URL." : "Vigane kaugserveri võrguaadress",
     "Failed to add the public link to your Nextcloud" : "Avaliku lingi lisamine sinu Nextcloudi ei õnnestunud",
@@ -248,12 +248,13 @@ OC.L10N.register(
     "Results" : "Tulemused",
     "Load more results" : "Laadi veel tulemusi",
     "Search in" : "Otsi siin:",
+    "Partial matches" : "Osaline vaste",
     "Log in" : "Logi sisse",
     "Logging in …" : "Sisselogimisel...",
     "Log in to {productName}" : "Logi sisse: {productName}",
     "Wrong login or password." : "Vale kasutajanimi või salasõna.",
     "This account is disabled" : "See konto pole kasutusel",
-    "We have detected multiple invalid login attempts from your IP. Therefore your next login is throttled up to 30 seconds." : "Me tuvastasime sinu IP-aadressilt palju ebaõnnestunud sisselogimiskatseid. Seetõttu on su järgmine sisselogimine ootel kuni 30 sekundit.",
+    "Too many incorrect login attempts. Please try again in 30 seconds." : "Liiga palju vigaseid sisselogimiskatseid. Palun proovi uuesti 30 sekundi pärast.",
     "Account name or email" : "Konto nimi või e-posti aadress",
     "Account name" : "Kasutajakonto nimi",
     "Server side authentication failed!" : "Serveripoolne autentimine ebaõnnestus!",
@@ -307,10 +308,14 @@ OC.L10N.register(
     "Loading your contacts …" : "Laadin sinu kontakte…",
     "Looking for {term} …" : "Otsin märksõna {term}…",
     "Search contacts" : "Otsi kontakte",
-    "Reset search" : "Lähtesta otsing",
+    "Filter by team" : "Filtreeri tiimi alusel",
+    "All teams" : "Kõik tiimid",
+    "Search contacts in team {team}" : "Otsi „{team}“ tiimi kontakte",
     "Search contacts …" : "Otsi kontakte…",
+    "Reset search" : "Lähtesta otsing",
     "Could not load your contacts" : "Sinu kontaktide laadimine ebaõnnestus",
     "No contacts found" : "Kontakte ei leitud",
+    "Contacts list" : "Kontaktide loend",
     "Show all contacts" : "Näita kõiki kontakte",
     "Install the Contacts app" : "Paigalda Kontaktide rakendus",
     "Search" : "Otsi",
@@ -326,12 +331,33 @@ OC.L10N.register(
     "Back" : "Tagasi",
     "Login form is disabled." : "Sisselogimise leht on keelatud.",
     "The Nextcloud login form is disabled. Use another login option if available or contact your administration." : "Nextcloudi sisselogimisvorm on kasutusel eemaldatud. Kui mõni muu sisselogimisviis on saadaval, siis kasuta seda või küsi lisateavet oma süsteemihaldajalt.",
+    "Connect to your account" : "Ühenda oma kasutajakontoga",
+    "Please log in before granting \"{client}\" access to your {instanceName} account." : "Enne „{client}“ kliendile oma kontole ligipääsu lubamist „{instanceName}“ serveris, palun logi sisse.",
+    "Security warning" : "Turvahoiatus",
+    "If you are not trying to set up a new device or app, someone is trying to trick you into granting them access to your data. In this case do not proceed and instead contact your system administrator." : "Kui sa just hetkel ei ole seadistamas uut seadet või rakendust, siis võib keegi sind proovida petta eesmärgiga saada ligipääs sinu andmetele. Sel juhul palun ära jätka ja võta ühendust oma süsteemihaldajaga.",
+    "Log in using password" : "Logi sisse salasõnaga",
+    "Alternative log in using app password" : "Alternatiivne sisselogimisvõimalus rakenduse salasõnaga",
+    "Account connected" : "Konto ühendatud",
+    "Your client should now be connected!" : "Su klient peaks nüüd olema ühendatud!",
+    "You can close this window." : "Võid selle akna sulgeda.",
+    "Account access" : "Konto ligipääs",
+    "Currently logged in as {userDisplayName} ({userId})." : "Hetkel sisselogitud kasutajana {userDisplayName} ({userId}).",
+    "You are about to grant \"{client}\" access to your {instanceName} account." : "Sa oled „{client}“ kliendile andmas ligipääsu oma {instanceName} kontole.",
     "More actions" : "Täiendavad tegevused",
     "User menu" : "Kasutajamenüü",
     "Your guest name: {user}" : "Sinu külalisnimi: {user}",
     "You are currently not identified." : "Sa oled hetkel tuvastamata.",
     "Set public name" : "Lisa avalik nimi",
     "Change public name" : "Muuda avalikku nime",
+    "This share is password-protected" : "See jaoskaust on kaitstud salasõnaga",
+    "The password is wrong or expired. Please try again or request a new one." : "Salasõna on vale või aegunud. Palun proovi uuesti või taotle uut salasõna.",
+    "Submit" : "Saada",
+    "Please type in your email address to request a temporary password" : "Palun sisesta oma e-posti aadress ajutise salasõna taotlemiseks",
+    "Password sent!" : "Salasõna on saadetud!",
+    "You are not authorized to request a password for this share" : "Sul pole luba selle jaoskausta salasõna taotlemiseks",
+    "Email address" : "E-posti aadress",
+    "Request password" : "Küsi salasõna",
+    "Forgot password" : "Unusta salasõna",
     "Password is too weak" : "Salasõna on liiga nõrk",
     "Password is weak" : "Salasõna on nõrk",
     "Password is average" : "Salasõna on keskpärane",
@@ -343,7 +369,6 @@ OC.L10N.register(
     "For information how to properly configure your server, please {linkStart}see the documentation{linkEnd}" : "Serveri õigeks seadistamiseks {linkStart}leiad teavet dokumentatsioonist{linkEnd}",
     "Autoconfig file detected" : "Tuvastasin autoconfig faili",
     "The setup form below is pre-filled with the values from the config file." : "Järgnev paigaldusvorm on eeltäidetud sellest failist leitud andmetega.",
-    "Security warning" : "Turvahoiatus",
     "Create administration account" : "Loo peakasutaja konto",
     "Administration account name" : "Peakasutaja konto nimi",
     "Administration account password" : "Peakasutaja konto salasõna",
@@ -375,6 +400,32 @@ OC.L10N.register(
     "Your browser is not supported. Please upgrade to a newer version or a supported one." : "Sinu brauser ei ole toetatud. Palun uuenda see uuema versiooni peale või vaheta toetatud brauseri vastu.",
     "Continue with this unsupported browser" : "Jätka selle mittetoetatud brauseriga",
     "Supported versions" : "Toetatud versioonid",
+    "The update completed with warnings. Please check the details for more information." : "Uuendamine lõppes hoiatustega. Lisateavet leiad dokumentatsioonist.",
+    "The update completed successfully." : "Uuendamine õnnestus.",
+    "Preparing update…" : "Valmistun uuendamiseks…",
+    "You will be redirected to {productName} in {count} seconds." : "Sind suunatakse tagasi „{productName}“ toote juurde {count} sekundi möödumisel.",
+    "The update is in progress, leaving this page might interrupt the process in some environments." : "Uuendamine on pooleli, sellelt lehelt lahkumine võib mõnes keskkonnas protsessi katkestada.",
+    "App update required" : "Rakenduse uuendus on kohustuslik",
+    "{productName} will be updated to version {version}" : "{productName} uuendatakse versioonini {version}",
+    "The theme {oldTheme} has been disabled." : "„{oldTheme}“ kujundus on lülitatud välja.",
+    "These incompatible apps will be disabled:" : "Need mitteühilduvad rakendused lülitatakse välja:",
+    "Incompatible apps" : "Ühildumatud rakendused",
+    "These apps will be updated:" : "Neid rakendusi uuendatakse:",
+    "Apps to update" : "Uuendatavad rakendused",
+    "{app} from {oldVersion} to {version}" : "{app}: „{oldVersion}“ → „{version}“",
+    "Please make sure that the database, the config folder and the data folder have been backed up before proceeding." : "Enne jätkamist veendu, et andmebaas ning seadete ja andmete kataloogid on varundatud.",
+    "To avoid timeouts with larger installations, you can instead run the following command from your installation directory:" : "Suurtel saitidel aegumise vältimiseks võid sa paigalduskaustas käivitada järgmise käsu:",
+    "Start update" : "Käivita uuendus",
+    "Continue to {productName}" : "Jätka siit: {productName}",
+    "Update to {version}" : "Uuenda versioonile {version}",
+    "Hide details" : "Peida üksikasjad",
+    "Show details" : "Näita üksikasju",
+    "Update details" : "Uuenduse üksikasjad",
+    "Update needed" : "Uuendamine vajaliik",
+    "Please use the command line updater because you have a big instance with more than 50 accounts." : "Kuna sul on enam kui 50 kasutajaga server, siis palun kasuta uuendamiseks käsureal toimivat uuendajat.",
+    "Documentation" : "Dokumentatsioon ja juhendid",
+    "I know that if I continue doing the update via web UI has the risk, that the request runs into a timeout and could cause data loss, but I have a backup and know how to restore my instance in case of a failure." : "Olen teadlik, et veebiliidese kaudu uuendusega jätkamine hõlmab riski, et päring aegub ja põhjustab andmekadu, aga mul on varundus ja ma tean, kuidas tõrke korral oma instantsi taastada.",
+    "Upgrade via web on my own risk" : "Uuenda veebi kaudu omal vastutusel",
     "Search {types} …" : "Otsi „{types}“…",
     "Choose {file}" : "Vali „{file}“",
     "Choose" : "Vali",
@@ -396,20 +447,17 @@ OC.L10N.register(
     "({count} selected)" : "({count} valitud)",
     "Error loading file exists template" : "Viga faili olemasolu malli laadimisel",
     "Saving …" : "Salvestan…",
+    "Groups" : "Grupid",
+    "Group list is empty" : "Gruppide loend on tühi",
+    "Unable to retrieve the group list" : "Gruppide loendi pärimine ebaõnnestus",
     "seconds ago" : "sekundit tagasi",
-    "Connection to server lost" : "Ühendus serveriga katkes",
-    "_Problem loading page, reloading in %n second_::_Problem loading page, reloading in %n seconds_" : ["Tõrge lehe laadimisel, värskendamine %n sekundi pärast","Tõrge lehe laadimisel, värskendamine %n sekundi pärast"],
     "Add to a project" : "Lisa projektile",
-    "Show details" : "Näita üksikasju",
-    "Hide details" : "Peida üksikasjad",
     "Rename project" : "Muuda projekti nime",
     "Failed to rename the project" : "Projekti nime muutmine ei õnnestunud",
     "Failed to create a project" : "Projekti loomine ebaõnnestus",
     "Failed to add the item to the project" : "Objekti lisamine projekti ei õnnestunud",
     "Connect items to a project to make them easier to find" : "Et objekte oleks lihtsam leida, seo nad projektiga",
     "Type to search for existing projects" : "Olemasolevate projektide otsimiseks kirjuta midagi",
-    "New in" : "Mida on uut",
-    "View changelog" : "Vaata muudatuste logi",
     "Close \"{dialogTitle}\" dialog" : "Sulge „{dialogTitle}“ vaade",
     "Email length is at max (255)" : "E-kirja pikkus on jõudnud lubatud piirini (255)",
     "Clipboard not available, please copy manually" : "Lõikelaud pole saadaval. Palun kopeeri käsitsi",
@@ -446,25 +494,7 @@ OC.L10N.register(
     "Skip to navigation of app" : "Mine rakenduse asukohtade juurde",
     "Go to %s" : "Mine %s",
     "Get your own free account" : "Tee endale tasuta kasutajakonto",
-    "Connect to your account" : "Ühenda oma kasutajakontoga",
-    "Please log in before granting %1$s access to your %2$s account." : "Enne rakendusele %1$s oma %2$s kontole ligipääsu andmist logi sisse.",
-    "If you are not trying to set up a new device or app, someone is trying to trick you into granting them access to your data. In this case do not proceed and instead contact your system administrator." : "Kui sa just hetkel ei ole seadistamas uut seadet või rakendust, siis võib keegi sind proovida petta eesmärgiga saada ligipääs sinu andmetele. Sel juhul palun ära jätka ja võta ühendust oma süsteemihaldajaga.",
-    "App password" : "Rakenduse salasõna",
-    "Grant access" : "Anna ligipääs",
-    "Alternative log in using app password" : "Alternatiivne sisselogimisvõimalus rakenduse salasõnaga",
-    "Account access" : "Konto ligipääs",
-    "Currently logged in as %1$s (%2$s)." : "Hetkel sisselogitus kasutajana %1$s (%2$s).",
-    "You are about to grant %1$s access to your %2$s account." : "Oled andmas rakendusele %1$s ligipääsu oma %2$s kontole.",
-    "Account connected" : "Konto ühendatud",
-    "Your client should now be connected!" : "Su klient peaks nüüd olema ühendatud!",
-    "You can close this window." : "Võid selle akna sulgeda.",
     "Previous" : "Eelmine",
-    "This share is password-protected" : "See jaoskaust on salasõnaga kaitstud",
-    "The password is wrong or expired. Please try again or request a new one." : "Salasõna on vale või aegunud. Palun proovi uuesti või taotle uut salasõna.",
-    "Please type in your email address to request a temporary password" : "Palun sisesta oma e-posti aadress ajutise salasõna taotlemiseks",
-    "Email address" : "E-posti aadress",
-    "Password sent!" : "Salasõna on saadetud!",
-    "You are not authorized to request a password for this share" : "Sul pole luba selle jaoskausta salasõna taotlemiseks",
     "Two-factor authentication" : "Kaheastmeline autentimine",
     "Enhanced security is enabled for your account. Choose a second factor for authentication:" : "Sinu kontol on kasutusel täiendava turvalisuse meetmed. Vali kaheastmelise autentimise jaoks täiendav meetod:",
     "Could not load at least one of your enabled two-factor auth methods. Please contact your admin." : "Ei õnnestunud laadida vähemalt ühte sinu valitud kaheastmelise autentimise meetodit. Palun võta ühendust oma süsteemihaldajaga.",
@@ -479,20 +509,6 @@ OC.L10N.register(
     "Access through untrusted domain" : "Ligipääs läbi ebausaldusväärse domeeni",
     "Please contact your administrator. If you are an administrator, edit the \"trusted_domains\" setting in config/config.php like the example in config.sample.php." : "Palun võta ühendust oma administraatoriga. Kui oled administraator, muuda konfiguratsioonifailis config/config.php sätet \"trusted_domains\", nagu näidis config.sample.php failis.",
     "Further information how to configure this can be found in the %1$sdocumentation%2$s." : "Rohkem infot selle seadistamiseks leiab %1$s dokumentatsioonist %2$s.",
-    "App update required" : "Rakenduse uuendus on kohustuslik",
-    "%1$s will be updated to version %2$s" : "%1$s uuendatakse versioonile %2$s",
-    "The following apps will be updated:" : "Järgmised rakendused uuendatakse:",
-    "These incompatible apps will be disabled:" : "Need mitteühilduvad rakendused lülitatakse välja:",
-    "The theme %s has been disabled." : "Teema %s on keelatud.",
-    "Please make sure that the database, the config folder and the data folder have been backed up before proceeding." : "Enne jätkamist veendu, et andmebaas ning seadete ja andmete kataloogid on varundatud.",
-    "Start update" : "Käivita uuendus",
-    "To avoid timeouts with larger installations, you can instead run the following command from your installation directory:" : "Suurtel saitidel aegumise vältimiseks võid sa paigalduskaustas käivitada järgmise käsu:",
-    "Detailed logs" : "Üksikasjalikud logid",
-    "Update needed" : "Uuendamine vajaliik",
-    "Please use the command line updater because you have a big instance with more than 50 accounts." : "Kuna sul on enam kui 50 kasutajaga server, siis palun kasuta uuendamiseks käsureal toimivat uuendajat.",
-    "For help, see the  <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">documentation</a>." : "Abi saamiseks vaata <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">dokumentatsiooni</a>.",
-    "I know that if I continue doing the update via web UI has the risk, that the request runs into a timeout and could cause data loss, but I have a backup and know how to restore my instance in case of a failure." : "Olen teadlik, et veebiliidese kaudu uuendusega jätkamine hõlmab riski, et päring aegub ja põhjustab andmekadu, aga mul on varundus ja ma tean, kuidas tõrke korral oma instantsi taastada.",
-    "Upgrade via web on my own risk" : "Uuenda veebi kaudu omal vastutusel",
     "Maintenance mode" : "Hooldusrežiim",
     "This %s instance is currently in maintenance mode, which may take a while." : "See %s server on hetkel hooldusrežiimis, mis võib kesta mõnda aega.",
     "This page will refresh itself when the instance is available again." : "See leht värskendab ennast ise, kui instants jälle saadaval on.",
@@ -507,9 +523,15 @@ OC.L10N.register(
     "<strong>These are your search results<script>alert(1)</script></strong>" : "<strong>Need on sinu otsingutulemused: <script>alert(1)</script></strong>",
     "new" : "uus",
     "_download %n file_::_download %n files_" : ["laadi alla %n fail","laadi alla %n faili"],
+    "An error occurred." : "Tekkis viga.",
+    "Please reload the page." : "Palun laadi leht uuesti.",
+    "The update was unsuccessful. For more information <a href=\"{url}\">check our forum post</a> covering this issue." : "Uuendamine ebaõnnestus. Täiendavat infot <a href=\"{url}\">vaata meie foorumipostitusest</a>.",
+    "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud community</a>." : "Uuendamine ebaõnnestus. Palun teavita probleemist <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloudi kogukonda</a>.",
+    "_The update was successful. Redirecting you to {productName} in %n second._::_The update was successful. Redirecting you to {productName} in %n seconds._" : ["Uuendamine õnnestus. Sind suunatakse tagasi {productName} juurde %n sekundi pärast.","Uuendamine õnnestus. Sind suunatakse tagasi {productName} juurde %n sekundi pärast."],
     "Direct link copied to clipboard" : "Otselink on lõikelauale kopeeritud",
     "Searching …" : "Otsin...",
     "Logging in …" : "Sisselogimisel...",
+    "We have detected multiple invalid login attempts from your IP. Therefore your next login is throttled up to 30 seconds." : "Me tuvastasime sinu IP-aadressilt palju ebaõnnestunud sisselogimiskatseid. Seetõttu on su järgmine sisselogimine ootel kuni 30 sekundit.",
     "Loading apps …" : "Rakenduste laadimine …",
     "Installing apps …" : "Rakenduste paigaldamine …",
     "Loading your contacts …" : "Sinu kontaktide laadimine ...",
@@ -518,6 +540,10 @@ OC.L10N.register(
     "Loading more results …" : "Laadin veel tulemusi…",
     "Search {types} …" : "Otsi „{types}“…",
     "Saving …" : "Salvestamine …",
+    "Connection to server lost" : "Ühendus serveriga katkes",
+    "_Problem loading page, reloading in %n second_::_Problem loading page, reloading in %n seconds_" : ["Tõrge lehe laadimisel, värskendamine %n sekundi pärast","Tõrge lehe laadimisel, värskendamine %n sekundi pärast"],
+    "New in" : "Mida on uut",
+    "View changelog" : "Vaata muudatuste logi",
     "Very weak password" : "Väga nõrk salasõna",
     "Weak password" : "Nõrk salasõna",
     "So-so password" : "Enam-vähem sobiv salasõna",
@@ -541,6 +567,14 @@ OC.L10N.register(
     "Configure the database" : "Seadista andmebaasi",
     "Only %s is available." : "Ainult %s on saadaval.",
     "Database account" : "Andmebaasi kasutajakonto",
-    "Installing …" : "Paigaldan…"
+    "Installing …" : "Paigaldan…",
+    "Please log in before granting %1$s access to your %2$s account." : "Enne „%1$s“ rakendusele oma „%2$s“ kontole ligipääsu andmist logi sisse.",
+    "Currently logged in as %1$s (%2$s)." : "Hetkel sisselogitus kasutajana %1$s (%2$s).",
+    "You are about to grant %1$s access to your %2$s account." : "Oled andmas rakendusele %1$s ligipääsu oma %2$s kontole.",
+    "%1$s will be updated to version %2$s" : "%1$s uuendatakse versioonile %2$s",
+    "The following apps will be updated:" : "Järgmised rakendused uuendatakse:",
+    "The theme %s has been disabled." : "Teema %s on keelatud.",
+    "Detailed logs" : "Üksikasjalikud logid",
+    "For help, see the  <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">documentation</a>." : "Abi saamiseks vaata <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">dokumentatsiooni</a>."
 },
 "nplurals=2; plural=(n != 1);");
