@@ -45,6 +45,8 @@ OC.L10N.register(
     "Input text is too long" : "Tá an téacs ionchuir rófhada",
     "Requested task type does not exist" : "Níl an cineál taisc iarrtha ann",
     "Necessary language model provider is not available" : "Níl soláthraí múnla teanga riachtanach ar fáil",
+    "Cannot generate more than 12 images" : "Ní féidir níos mó ná 12 íomhá a ghiniúint",
+    "Cannot generate less than 1 image" : "Ní féidir níos lú ná 1 íomhá a ghiniúint",
     "No text to image provider is available" : "Níl aon soláthraí téacs go híomhá ar fáil",
     "Image not found" : "Ní bhfuarthas an íomhá",
     "No translation provider available" : "Níl aon soláthraí aistriúcháin ar fáil",
@@ -198,15 +200,10 @@ OC.L10N.register(
     "Matroska video" : "Físeán Matroska",
     "Windows Media video" : "Físeán Windows Media",
     "AVI video" : "Físeán AVI",
-    "The update is in progress, leaving this page might interrupt the process in some environments." : "Tá an nuashonrú ar siúl, agus d'fhéadfadh go gcuirfí isteach ar an bpróiseas i dtimpeallachtaí áirithe dá bhfágfaí an leathanach seo.",
-    "Update to {version}" : "Nuashonraigh go {version}",
-    "An error occurred." : "Tharla earráid.",
-    "Please reload the page." : "Athlódáil an leathanach le do thoil.",
-    "The update was unsuccessful. For more information <a href=\"{url}\">check our forum post</a> covering this issue." : "Níor éirigh leis an nuashonrú. Le haghaidh tuilleadh faisnéise <a href=\"{url}\">seiceáil ár bpost fóraim</a> a chlúdaíonn an tsaincheist seo.",
-    "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud community</a>." : "Níor éirigh leis an nuashonrú.  Tuairiscigh an tsaincheist seo do <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">phobal Nextcloud </a> le do thoil.",
-    "Continue to {productName}" : "Lean ar aghaidh chuig {productName}",
-    "_The update was successful. Redirecting you to {productName} in %n second._::_The update was successful. Redirecting you to {productName} in %n seconds._" : ["D'éirigh leis an nuashonrú. Tú á atreorú chuig {productName} i gceann %n soicind.","The update was successful. Redirecting you to {productName} in %n seconds.","D'éirigh leis an nuashonrú. Tú á atreorú chuig {productName} i gceann %n soicind.","D'éirigh leis an nuashonrú. Tú á atreorú chuig {productName} i gceann %n soicind.","D'éirigh leis an nuashonrú. Tú á atreorú chuig {productName} i gceann %n soicind."],
     "Done" : "Déanta",
+    "Scan QR code to log in" : "Scanáil an cód QR le logáil isteach",
+    "Use {productName} mobile client you want to connect to scan the code" : "Bain úsáid as an gcliant soghluaiste {productName} ar mian leat ceangal leis chun an cód a scanadh",
+    "Code will expire {timeCountdown} or after use" : "Rachaidh an cód in éag {timeCountdown} nó tar éis úsáide",
     "Applications menu" : "Roghchlár feidhmchlár",
     "Apps" : "Feidhmchláir",
     "More apps" : "Tuilleadh apps",
@@ -311,10 +308,14 @@ OC.L10N.register(
     "Loading your contacts …" : "Ag lódáil do theagmhálaithe …",
     "Looking for {term} …" : "Ag lorg {term} …",
     "Search contacts" : "Cuardaigh teagmhálaithe",
-    "Reset search" : "Athshocraigh cuardach",
+    "Filter by team" : "Scag de réir foirne",
+    "All teams" : "Gach foireann",
+    "Search contacts in team {team}" : "Cuardaigh teagmhálaithe i bhfoireann {team}",
     "Search contacts …" : "Cuardaigh teagmhálaithe …",
+    "Reset search" : "Athshocraigh cuardach",
     "Could not load your contacts" : "Níorbh fhéidir do theagmhálaithe a lódáil",
     "No contacts found" : "Níor aimsíodh aon teagmhálaí",
+    "Contacts list" : "Liosta teagmhálaithe",
     "Show all contacts" : "Taispeáin gach teagmháil",
     "Install the Contacts app" : "Suiteáil an app Teagmhálacha",
     "Search" : "Cuardach",
@@ -331,13 +332,17 @@ OC.L10N.register(
     "Login form is disabled." : "Tá an fhoirm logáil isteach díchumasaithe.",
     "The Nextcloud login form is disabled. Use another login option if available or contact your administration." : "Tá foirm logáil isteach Nextcloud díchumasaithe. Úsáid rogha logáil isteach eile má tá sé ar fáil nó déan teagmháil le do lucht riaracháin.",
     "Connect to your account" : "Ceangail le do chuntas",
+    "Please log in before granting \"{client}\" access to your {instanceName} account." : "Logáil isteach le do thoil sula dtugann tú rochtain do \"{client}\" ar do chuntas {instanceName}.",
     "Security warning" : "Rabhadh slándála",
     "If you are not trying to set up a new device or app, someone is trying to trick you into granting them access to your data. In this case do not proceed and instead contact your system administrator." : "Mura bhfuil tú ag iarraidh gléas nó aip nua a chur ar bun, tá duine éigin ag iarraidh bob a bhualadh ort rochtain a thabhairt dóibh ar do shonraí. Sa chás seo, ná téigh ar aghaidh agus ina ionad sin déan teagmháil le riarthóir do chórais.",
+    "Log in using password" : "Logáil isteach ag baint úsáide as pasfhocal",
     "Alternative log in using app password" : "Logáil isteach malartach ag baint úsáide as pasfhocal app",
     "Account connected" : "Cuntas ceangailte",
     "Your client should now be connected!" : "Ba chóir go mbeadh do chliant ceangailte anois!",
     "You can close this window." : "Is féidir leat an fhuinneog seo a dhúnadh.",
     "Account access" : "Rochtain chuntais",
+    "Currently logged in as {userDisplayName} ({userId})." : "Logáilte isteach faoi láthair mar {userDisplayName} ({userId}).",
+    "You are about to grant \"{client}\" access to your {instanceName} account." : "Tá tú ar tí rochtain a dheonú do \"{client}\" ar do chuntas {instanceName}.",
     "More actions" : "Tuilleadh gníomhartha",
     "User menu" : "Roghchlár úsáideora",
     "Your guest name: {user}" : "Ainm d'aoi: {user}",
@@ -352,6 +357,7 @@ OC.L10N.register(
     "You are not authorized to request a password for this share" : "Níl tú údaraithe pasfhocal a iarraidh don sciar seo",
     "Email address" : "Seoladh ríomhphoist",
     "Request password" : "Iarr pasfhocal",
+    "Forgot password" : "Pasfhocal dearmadta",
     "Password is too weak" : "Tá pasfhocal ró-lag",
     "Password is weak" : "Tá pasfhocal lag",
     "Password is average" : "Is pasfhocal meánach",
@@ -394,6 +400,32 @@ OC.L10N.register(
     "Your browser is not supported. Please upgrade to a newer version or a supported one." : "Ní thacaítear le do bhrabhsálaí. Uasghrádaigh go leagan níos nuaí nó go leagan a dtacaítear leis le do thoil.",
     "Continue with this unsupported browser" : "Lean ar aghaidh leis an mbrabhsálaí seo nach dtacaítear leis",
     "Supported versions" : "Leaganacha tacaithe",
+    "The update completed with warnings. Please check the details for more information." : "Críochnaíodh an nuashonrú le rabhaidh. Seiceáil na sonraí le haghaidh tuilleadh eolais.",
+    "The update completed successfully." : "Críochnaíodh an nuashonrú go rathúil.",
+    "Preparing update…" : "Nuashonrú á ullmhú…",
+    "You will be redirected to {productName} in {count} seconds." : "Déanfar tú a atreorú chuig {productName} i gceann {count} soicind.",
+    "The update is in progress, leaving this page might interrupt the process in some environments." : "Tá an nuashonrú ar siúl, agus d'fhéadfadh go gcuirfí isteach ar an bpróiseas i dtimpeallachtaí áirithe dá bhfágfaí an leathanach seo.",
+    "App update required" : "Nuashonrú aip ag teastáil",
+    "{productName} will be updated to version {version}" : "Nuashonrófar {productName} go leagan {version}",
+    "The theme {oldTheme} has been disabled." : "Tá an téama {oldTheme} díchumasaithe.",
+    "These incompatible apps will be disabled:" : "Díchumasófar na haipeanna neamh-chomhoiriúnacha seo:",
+    "Incompatible apps" : "Aipeanna neamh-chomhoiriúnacha",
+    "These apps will be updated:" : "Déanfar na haipeanna seo a nuashonrú:",
+    "Apps to update" : "Aipeanna le nuashonrú",
+    "{app} from {oldVersion} to {version}" : "{app} ó {oldVersion} go {version}",
+    "Please make sure that the database, the config folder and the data folder have been backed up before proceeding." : "Cinntigh, le do thoil, go bhfuil an bunachar sonraí, an fillteán cumraíochta agus an fillteán sonraí cúltacaithe sula dtéann tú ar aghaidh.",
+    "To avoid timeouts with larger installations, you can instead run the following command from your installation directory:" : "Chun sosanna ama a sheachaint le suiteálacha níos mó, is féidir leat an t-ordú seo a leanas a rith ó do eolaire suiteála:",
+    "Start update" : "Tosaigh nuashonrú",
+    "Continue to {productName}" : "Lean ar aghaidh chuig {productName}",
+    "Update to {version}" : "Nuashonraigh go {version}",
+    "Hide details" : "Folaigh sonraí",
+    "Show details" : "Sonraí a thaispeáint",
+    "Update details" : "Nuashonraigh sonraí",
+    "Update needed" : "Nuashonrú ag teastáil",
+    "Please use the command line updater because you have a big instance with more than 50 accounts." : "Bain úsáid as an nuashonrú líne ordaithe toisc go bhfuil ásc mór agat le níos mó ná 50 cuntas le do thoil.",
+    "Documentation" : "Doiciméadúchán",
+    "I know that if I continue doing the update via web UI has the risk, that the request runs into a timeout and could cause data loss, but I have a backup and know how to restore my instance in case of a failure." : "Tá a fhios agam má leanann mé ar aghaidh ag déanamh an nuashonraithe trí Chomhéadain Gréasáin go bhfuil an baol ann go n-imeoidh an t-iarratas isteach in am istigh agus go bhféadfadh sé a bheith ina chúis le caillteanas sonraí, ach tá cúltaca agam agus tá a fhios agam conas mo chás a chur ar ais i gcás teipe.",
+    "Upgrade via web on my own risk" : "Uasghrádú tríd an ngréasán ar mo phriacal féin",
     "Search {types} …" : "Cuardaigh {types} …",
     "Choose {file}" : "Roghnaigh {file}",
     "Choose" : "Roghnaigh",
@@ -419,19 +451,13 @@ OC.L10N.register(
     "Group list is empty" : "Tá liosta an ghrúpa folamh",
     "Unable to retrieve the group list" : "Ní féidir liosta na ngrúpaí a fháil",
     "seconds ago" : "soicind ó shin",
-    "Connection to server lost" : "Ceangal leis an bhfreastalaí caillte",
-    "_Problem loading page, reloading in %n second_::_Problem loading page, reloading in %n seconds_" : ["Fadhb le lódáil an leathanaigh, á athlódáil i %n soicind ","Fadhb le lódáil an leathanaigh, á athlódáil i %n soicind ","Fadhb le lódáil an leathanaigh, á athlódáil i %n soicind ","Fadhb le lódáil an leathanaigh, á athlódáil i %n soicind ","Fadhb le lódáil an leathanaigh, á athlódáil i %n soicind "],
     "Add to a project" : "Cuir le tionscadal",
-    "Show details" : "Sonraí a thaispeáint",
-    "Hide details" : "Folaigh sonraí",
     "Rename project" : "Athainmnigh an tionscadal",
     "Failed to rename the project" : "Theip ar an tionscadal a athainmniú",
     "Failed to create a project" : "Theip ar thionscadal a chruthú",
     "Failed to add the item to the project" : "Theip ar an mír a chur leis an tionscadal",
     "Connect items to a project to make them easier to find" : "Ceangail míreanna le tionscadal chun iad a dhéanamh níos éasca iad a aimsiú",
     "Type to search for existing projects" : "Clóscríobh chun tionscadail atá ann cheana a chuardach",
-    "New in" : "Nua isteach",
-    "View changelog" : "Féach ar loga na n-athruithe",
     "Close \"{dialogTitle}\" dialog" : "Dún dialóg \"{dialogTitle}\".",
     "Email length is at max (255)" : "Tá fad an ríomhphoist ag uasmhéid (255)",
     "Clipboard not available, please copy manually" : "Níl an gearrthaisce ar fáil, cóipeáil de láimh",
@@ -483,20 +509,6 @@ OC.L10N.register(
     "Access through untrusted domain" : "Rochtain trí fhearann neamhiontaofa",
     "Please contact your administrator. If you are an administrator, edit the \"trusted_domains\" setting in config/config.php like the example in config.sample.php." : "Déan teagmháil le do riarthóir le do thoil. Más riarthóir thú, cuir an socrú \"trusted_domains\" in eagar i config/config.php cosúil leis an sampla i config.sample.php.",
     "Further information how to configure this can be found in the %1$sdocumentation%2$s." : "Tá tuilleadh eolais ar conas é seo a chumrú le fáil sa cháipéisíocht %1$s%2$s.",
-    "App update required" : "Nuashonrú aip ag teastáil",
-    "%1$s will be updated to version %2$s" : "%1$s a nuashonrú go leagan %2$s",
-    "The following apps will be updated:" : "Déanfar na haipeanna seo a leanas a nuashonrú:",
-    "These incompatible apps will be disabled:" : "Díchumasófar na haipeanna neamh-chomhoiriúnacha seo:",
-    "The theme %s has been disabled." : "Díchumasaíodh an téama %s.",
-    "Please make sure that the database, the config folder and the data folder have been backed up before proceeding." : "Cinntigh, le do thoil, go bhfuil an bunachar sonraí, an fillteán cumraíochta agus an fillteán sonraí cúltacaithe sula dtéann tú ar aghaidh.",
-    "Start update" : "Tosaigh nuashonrú",
-    "To avoid timeouts with larger installations, you can instead run the following command from your installation directory:" : "Chun sosanna ama a sheachaint le suiteálacha níos mó, is féidir leat an t-ordú seo a leanas a rith ó do eolaire suiteála:",
-    "Detailed logs" : "Logchomhaid mhionsonraithe",
-    "Update needed" : "Nuashonrú ag teastáil",
-    "Please use the command line updater because you have a big instance with more than 50 accounts." : "Bain úsáid as an nuashonrú líne ordaithe toisc go bhfuil ásc mór agat le níos mó ná 50 cuntas le do thoil.",
-    "For help, see the  <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">documentation</a>." : "Chun cabhair a fháil, féach an  <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">documentation</a>.",
-    "I know that if I continue doing the update via web UI has the risk, that the request runs into a timeout and could cause data loss, but I have a backup and know how to restore my instance in case of a failure." : "Tá a fhios agam má leanann mé ar aghaidh ag déanamh an nuashonraithe trí Chomhéadain Gréasáin go bhfuil an baol ann go n-imeoidh an t-iarratas isteach in am istigh agus go bhféadfadh sé a bheith ina chúis le caillteanas sonraí, ach tá cúltaca agam agus tá a fhios agam conas mo chás a chur ar ais i gcás teipe.",
-    "Upgrade via web on my own risk" : "Uasghrádú tríd an ngréasán ar mo phriacal féin",
     "Maintenance mode" : "Modh cothabhála",
     "This %s instance is currently in maintenance mode, which may take a while." : "Tá an cás %s seo i mód cothabhála faoi láthair, agus seans go dtógfaidh sé sin tamall.",
     "This page will refresh itself when the instance is available again." : "Athnóidh an leathanach seo é féin nuair a bheidh an t-ásc ar fáil arís.",
@@ -511,6 +523,11 @@ OC.L10N.register(
     "<strong>These are your search results<script>alert(1)</script></strong>" : "<strong>Seo iad do thorthaí cuardaigh<script>foláireamh(1)</script></strong>",
     "new" : "nua",
     "_download %n file_::_download %n files_" : ["íoslódáil %n comhad","íoslódáil %n comhaid","íoslódáil %n comhaid","íoslódáil %n comhaid","íoslódáil %n comhaid"],
+    "An error occurred." : "Tharla earráid.",
+    "Please reload the page." : "Athlódáil an leathanach le do thoil.",
+    "The update was unsuccessful. For more information <a href=\"{url}\">check our forum post</a> covering this issue." : "Níor éirigh leis an nuashonrú. Le haghaidh tuilleadh faisnéise <a href=\"{url}\">seiceáil ár bpost fóraim</a> a chlúdaíonn an tsaincheist seo.",
+    "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud community</a>." : "Níor éirigh leis an nuashonrú.  Tuairiscigh an tsaincheist seo do <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">phobal Nextcloud </a> le do thoil.",
+    "_The update was successful. Redirecting you to {productName} in %n second._::_The update was successful. Redirecting you to {productName} in %n seconds._" : ["D'éirigh leis an nuashonrú. Tú á atreorú chuig {productName} i gceann %n soicind.","The update was successful. Redirecting you to {productName} in %n seconds.","D'éirigh leis an nuashonrú. Tú á atreorú chuig {productName} i gceann %n soicind.","D'éirigh leis an nuashonrú. Tú á atreorú chuig {productName} i gceann %n soicind.","D'éirigh leis an nuashonrú. Tú á atreorú chuig {productName} i gceann %n soicind."],
     "Direct link copied to clipboard" : "Cóipeáladh nasc díreach chuig an ngearrthaisce",
     "Searching …" : "Ag cuardach…",
     "Logging in …" : "Ag logáil isteach…",
@@ -523,6 +540,10 @@ OC.L10N.register(
     "Loading more results …" : "Tuilleadh torthaí á lódáil…",
     "Search {types} …" : "Cuardaigh {types} …",
     "Saving …" : "Shábháil …",
+    "Connection to server lost" : "Ceangal leis an bhfreastalaí caillte",
+    "_Problem loading page, reloading in %n second_::_Problem loading page, reloading in %n seconds_" : ["Fadhb le lódáil an leathanaigh, á athlódáil i %n soicind ","Fadhb le lódáil an leathanaigh, á athlódáil i %n soicind ","Fadhb le lódáil an leathanaigh, á athlódáil i %n soicind ","Fadhb le lódáil an leathanaigh, á athlódáil i %n soicind ","Fadhb le lódáil an leathanaigh, á athlódáil i %n soicind "],
+    "New in" : "Nua isteach",
+    "View changelog" : "Féach ar loga na n-athruithe",
     "Very weak password" : "Pasfhocal an-lag",
     "Weak password" : "Pasfhocal lag",
     "So-so password" : "mar sin-sin pasfhocal",
@@ -549,6 +570,11 @@ OC.L10N.register(
     "Installing …" : "Suiteáil…",
     "Please log in before granting %1$s access to your %2$s account." : "Logáil isteach sula dtabharfaidh tú rochtain do %1$s ar do chuntas %2$s.",
     "Currently logged in as %1$s (%2$s)." : "Logáilte isteach mar %1$s (%2$s) faoi láthair.",
-    "You are about to grant %1$s access to your %2$s account." : "Tá tú ar tí rochtain a thabhairt do %1$s ar do chuntas %2$s."
+    "You are about to grant %1$s access to your %2$s account." : "Tá tú ar tí rochtain a thabhairt do %1$s ar do chuntas %2$s.",
+    "%1$s will be updated to version %2$s" : "%1$s a nuashonrú go leagan %2$s",
+    "The following apps will be updated:" : "Déanfar na haipeanna seo a leanas a nuashonrú:",
+    "The theme %s has been disabled." : "Díchumasaíodh an téama %s.",
+    "Detailed logs" : "Logchomhaid mhionsonraithe",
+    "For help, see the  <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">documentation</a>." : "Chun cabhair a fháil, féach an  <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">documentation</a>."
 },
 "nplurals=5; plural=(n==1 ? 0 : n==2 ? 1 : n<7 ? 2 : n<11 ? 3 : 4);");
