@@ -45,6 +45,8 @@ OC.L10N.register(
     "Input text is too long" : "O texto de entrada é demasiado longo",
     "Requested task type does not exist" : "O tipo de tarefa solicitado non existe",
     "Necessary language model provider is not available" : "O provedor de modelos de linguaxe necesario non está dispoñíbel",
+    "Cannot generate more than 12 images" : "Non é posíbel xerar máis de 12 imaxes",
+    "Cannot generate less than 1 image" : "Non é posíbel xerar menos de 1 imaxe",
     "No text to image provider is available" : "Non hai ningún provedor de texto a imaxe dispoñíbel",
     "Image not found" : "Non se atopou a imaxe",
     "No translation provider available" : "Non hai ningún provedor de tradución dispoñíbel",
@@ -198,14 +200,6 @@ OC.L10N.register(
     "Matroska video" : "Vídeo Matroska",
     "Windows Media video" : "Vídeo Windows Media",
     "AVI video" : "Vídeo AVI",
-    "The update is in progress, leaving this page might interrupt the process in some environments." : "A actualización está en proceso, saír desta páxina podería interromper o proceso nalgúns contornos.",
-    "Update to {version}" : "Actualizar a {version}",
-    "An error occurred." : "Produciuse un erro",
-    "Please reload the page." : "Volva cargar a páxina.",
-    "The update was unsuccessful. For more information <a href=\"{url}\">check our forum post</a> covering this issue." : "Fallou a actualización. Obteña máis información <a href=\"{url}\">consultando o noso artigo no foro</a> para arranxar esta incidencia.",
-    "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud community</a>." : "Fallou a actualización. Informe desta incidencia na <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">comunidade de Nextcloud</a>.",
-    "Continue to {productName}" : "Continuar a {productName}",
-    "_The update was successful. Redirecting you to {productName} in %n second._::_The update was successful. Redirecting you to {productName} in %n seconds._" : ["A actualización foi satisfactoria. Redirixindoo a {productName} en %n segundo.","A actualización foi satisfactoria. Redirixindoo a {productName} en %n segundos."],
     "Done" : "Feito",
     "Scan QR code to log in" : "Escanee o código QR para acceder",
     "Use {productName} mobile client you want to connect to scan the code" : "Empregue o cliente móbil {productName} ao que quere conectarse para escanear o código",
@@ -314,10 +308,14 @@ OC.L10N.register(
     "Loading your contacts …" : "Cargando os seus contactos…",
     "Looking for {term} …" : "Buscando {term}…",
     "Search contacts" : "Buscar contactos",
-    "Reset search" : "Restabelecer a busca",
+    "Filter by team" : "Filtrar polo equipo",
+    "All teams" : "Todos os equipos",
+    "Search contacts in team {team}" : "Buscar contactos no equipo {team}",
     "Search contacts …" : "Buscar contactos…",
+    "Reset search" : "Restabelecer a busca",
     "Could not load your contacts" : "Non foi posíbel cargar os seus contactos",
     "No contacts found" : "Non se atopou ningún contacto.",
+    "Contacts list" : "Lista de contactos",
     "Show all contacts" : "Amosar todos os contactos",
     "Install the Contacts app" : "Instalar a aplicación de Contactos",
     "Search" : "Buscar",
@@ -402,6 +400,32 @@ OC.L10N.register(
     "Your browser is not supported. Please upgrade to a newer version or a supported one." : "O seu navegador non é compatíbel. Actualice a unha versión máis recente ou a unha compatíbel.",
     "Continue with this unsupported browser" : "Continuar con este navegador non compatíbel",
     "Supported versions" : "Versións compatíbeis",
+    "The update completed with warnings. Please check the details for more information." : "A actualización completouse con advertencias. Consulte os detalles para obter máis información.",
+    "The update completed successfully." : "A actualización completouse correctamente",
+    "Preparing update…" : "Preparando a actualización…",
+    "You will be redirected to {productName} in {count} seconds." : "Vostede vai ser redirixido a {productName} en {count} segundos.",
+    "The update is in progress, leaving this page might interrupt the process in some environments." : "A actualización está en proceso, saír desta páxina podería interromper o proceso nalgúns contornos.",
+    "App update required" : "Precísase de actualizar a aplicación",
+    "{productName} will be updated to version {version}" : "{productName} actualizarase á versión {version}",
+    "The theme {oldTheme} has been disabled." : "O tema {oldTheme} foi desactivado.",
+    "These incompatible apps will be disabled:" : "Desactivaranse estas aplicacións incompatíbeis:",
+    "Incompatible apps" : "Aplicacións incompatíbeis",
+    "These apps will be updated:" : "Estas aplicacións van ser actualizadas:",
+    "Apps to update" : "Aplicacións a actualizar",
+    "{app} from {oldVersion} to {version}" : "{app} de {oldVersion} a {version}",
+    "Please make sure that the database, the config folder and the data folder have been backed up before proceeding." : "Asegúrese de ter feito unha copia de seguranza da base de datos, do cartafol de configuración e do cartafol de datos, antes de proceder.",
+    "To avoid timeouts with larger installations, you can instead run the following command from your installation directory:" : "Para evitar tempos de espera nas instalacións grandes, en troques pode executar a seguinte orde desde o directorio de instalación:",
+    "Start update" : "Iniciar a actualización",
+    "Continue to {productName}" : "Continuar a {productName}",
+    "Update to {version}" : "Actualizar a {version}",
+    "Hide details" : "Agochar os detalles",
+    "Show details" : "Amosar os detalles",
+    "Update details" : "Detalles da actualización",
+    "Update needed" : "É necesario actualizar",
+    "Please use the command line updater because you have a big instance with more than 50 accounts." : "Vde. ten unha instancia moi grande con máis de 50 contas, faga a actualización empregando a liña de ordes.",
+    "Documentation" : "Documentación",
+    "I know that if I continue doing the update via web UI has the risk, that the request runs into a timeout and could cause data loss, but I have a backup and know how to restore my instance in case of a failure." : "Sei que se continúo facendo a actualización a través da interface web, corro o risco de que a solicitude non se execute no tempo de espera e provoque a perda de información pero teño unha copia de seguranza dos datos e sei como restaurala.",
+    "Upgrade via web on my own risk" : "Anovar a través da web, correndo o risco baixo a miña responsabilidade",
     "Search {types} …" : "Buscando {types}…",
     "Choose {file}" : "Escoller {file}",
     "Choose" : "Escoller",
@@ -427,19 +451,13 @@ OC.L10N.register(
     "Group list is empty" : "A lista de grupos está baleira",
     "Unable to retrieve the group list" : "Non é posíbel recuperar a lista de grupos",
     "seconds ago" : "segundos atrás",
-    "Connection to server lost" : "Falta a conexión co servidor",
-    "_Problem loading page, reloading in %n second_::_Problem loading page, reloading in %n seconds_" : ["Produciuse un problema a cargar a páxina, volverá cargar en %n segundo","Produciuse un problema ao cargar a páxina, volverá cargar en %n segundos"],
     "Add to a project" : "Engadir a un proxecto",
-    "Show details" : "Amosar os detalles",
-    "Hide details" : "Agochar os detalles",
     "Rename project" : "Cambiar o nome do proxecto",
     "Failed to rename the project" : "Produciuse un fallo ao cambiarlle o nome ao proxecto",
     "Failed to create a project" : "Produciuse un fallo ao crear un proxecto",
     "Failed to add the item to the project" : "Produciuse un fallo ao engadir un elemento o proxecto",
     "Connect items to a project to make them easier to find" : "Conecte os elementos a un proxecto para que sexan máis doados de atopar",
     "Type to search for existing projects" : "Escriba para buscar proxectos existentes",
-    "New in" : "Novo en",
-    "View changelog" : "Ver as notas da versión",
     "Close \"{dialogTitle}\" dialog" : "Pechar o diálogo «{dialogTitle}».",
     "Email length is at max (255)" : "Acadouse a lonxitude máxima do correo-e (255)",
     "Clipboard not available, please copy manually" : "O portapapeis non está dispoñíbel, cópieo manualmente",
@@ -491,20 +509,6 @@ OC.L10N.register(
     "Access through untrusted domain" : "Acceso a través dun dominio non fiábel",
     "Please contact your administrator. If you are an administrator, edit the \"trusted_domains\" setting in config/config.php like the example in config.sample.php." : "Contacte coa administración do sistema. Se Vde. é un administrador, edite o axuste de «trusted_domains» en config/config.php coma no exemplo en config.sample.php. ",
     "Further information how to configure this can be found in the %1$sdocumentation%2$s." : "Pode atopar máis información sobre cómo configurar isto na %1$sdocumentación%2$s.",
-    "App update required" : "Precísase de actualizar a aplicación",
-    "%1$s will be updated to version %2$s" : "%1$s actualizarase á versión %2$s",
-    "The following apps will be updated:" : "As seguintes aplicacións foron actualizadas:",
-    "These incompatible apps will be disabled:" : "Desactivaranse estas aplicacións incompatíbeis:",
-    "The theme %s has been disabled." : "O tema %s foi desactivado.",
-    "Please make sure that the database, the config folder and the data folder have been backed up before proceeding." : "Asegúrese de ter feito unha copia de seguranza da base de datos, do cartafol de configuración e do cartafol de datos, antes de proceder.",
-    "Start update" : "Iniciar a actualización",
-    "To avoid timeouts with larger installations, you can instead run the following command from your installation directory:" : "Para evitar tempos de espera nas instalacións grandes, en troques pode executar a seguinte orde desde o directorio de instalación:",
-    "Detailed logs" : "Rexistros detallados",
-    "Update needed" : "É necesario actualizar",
-    "Please use the command line updater because you have a big instance with more than 50 accounts." : "Vde. ten unha instancia moi grande con máis de 50 contas, faga a actualización empregando a liña de ordes.",
-    "For help, see the  <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">documentation</a>." : "Para obter axuda, vexa a <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">documentación</a>.",
-    "I know that if I continue doing the update via web UI has the risk, that the request runs into a timeout and could cause data loss, but I have a backup and know how to restore my instance in case of a failure." : "Sei que se continúo facendo a actualización a través da interface web, corro o risco de que a solicitude non se execute no tempo de espera e provoque a perda de información pero teño unha copia de seguranza dos datos e sei como restaurala.",
-    "Upgrade via web on my own risk" : "Anovar a través da web, correndo o risco baixo a miña responsabilidade",
     "Maintenance mode" : "Modo de mantemento",
     "This %s instance is currently in maintenance mode, which may take a while." : "Esta instancia de %s atopase en modo de mantemento, isto pode levar un anaco.",
     "This page will refresh itself when the instance is available again." : "Esta páxina actualizarase automaticamente cando a instancia estea dispoñíbel de novo.",
@@ -519,6 +523,11 @@ OC.L10N.register(
     "<strong>These are your search results<script>alert(1)</script></strong>" : "<strong>Estes son os resultados da súa busca<script>alert(1)</script></strong>",
     "new" : "novo",
     "_download %n file_::_download %n files_" : ["descargar %n ficheiro","descargar %n ficheiros"],
+    "An error occurred." : "Produciuse un erro",
+    "Please reload the page." : "Volva cargar a páxina.",
+    "The update was unsuccessful. For more information <a href=\"{url}\">check our forum post</a> covering this issue." : "Fallou a actualización. Obteña máis información <a href=\"{url}\">consultando o noso artigo no foro</a> para arranxar esta incidencia.",
+    "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud community</a>." : "Fallou a actualización. Informe desta incidencia na <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">comunidade de Nextcloud</a>.",
+    "_The update was successful. Redirecting you to {productName} in %n second._::_The update was successful. Redirecting you to {productName} in %n seconds._" : ["A actualización foi satisfactoria. Redirixindoo a {productName} en %n segundo.","A actualización foi satisfactoria. Redirixindoo a {productName} en %n segundos."],
     "Direct link copied to clipboard" : "A ligazón directa foi copiada no portapapeis",
     "Searching …" : "Buscando…",
     "Logging in …" : "Acceder…",
@@ -531,6 +540,10 @@ OC.L10N.register(
     "Loading more results …" : "Cargando máis resultados…",
     "Search {types} …" : "Buscando {types}…",
     "Saving …" : "Gardando…",
+    "Connection to server lost" : "Falta a conexión co servidor",
+    "_Problem loading page, reloading in %n second_::_Problem loading page, reloading in %n seconds_" : ["Produciuse un problema a cargar a páxina, volverá cargar en %n segundo","Produciuse un problema ao cargar a páxina, volverá cargar en %n segundos"],
+    "New in" : "Novo en",
+    "View changelog" : "Ver as notas da versión",
     "Very weak password" : "Contrasinal moi feble",
     "Weak password" : "Contrasinal feble",
     "So-so password" : "Contrasinal non moi aló",
@@ -557,6 +570,11 @@ OC.L10N.register(
     "Installing …" : "Instalando…",
     "Please log in before granting %1$s access to your %2$s account." : "Acceda antes de concederlle a %1$s acceso á súa conta %2$s.",
     "Currently logged in as %1$s (%2$s)." : "Agora está conectado como %1$s (%2$s).",
-    "You are about to grant %1$s access to your %2$s account." : "Está a piques de concederlle a %1$s permiso para acceder á súa conta %2$s."
+    "You are about to grant %1$s access to your %2$s account." : "Está a piques de concederlle a %1$s permiso para acceder á súa conta %2$s.",
+    "%1$s will be updated to version %2$s" : "%1$s actualizarase á versión %2$s",
+    "The following apps will be updated:" : "As seguintes aplicacións van ser actualizadas:",
+    "The theme %s has been disabled." : "O tema %s foi desactivado.",
+    "Detailed logs" : "Rexistros detallados",
+    "For help, see the  <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">documentation</a>." : "Para obter axuda, vexa a <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">documentación</a>."
 },
 "nplurals=2; plural=(n != 1);");
