@@ -45,6 +45,8 @@ OC.L10N.register(
     "Input text is too long" : "入力テキストが長すぎます",
     "Requested task type does not exist" : "要求されたタスクの種類が存在しません",
     "Necessary language model provider is not available" : "必要な言語モデルプロバイダーが利用できません",
+    "Cannot generate more than 12 images" : "12枚以上の画像を生成できません",
+    "Cannot generate less than 1 image" : "1枚未満の画像を生成できません",
     "No text to image provider is available" : "テキストを画像に変換するプロバイダーはありません",
     "Image not found" : "画像が見つかりません",
     "No translation provider available" : "利用可能な翻訳プロバイダーがありません",
@@ -198,15 +200,10 @@ OC.L10N.register(
     "Matroska video" : "Matroskaビデオ",
     "Windows Media video" : "Windows Mediaビデオ",
     "AVI video" : "AVI ビデオ",
-    "The update is in progress, leaving this page might interrupt the process in some environments." : "更新が進行中です。このページを離れると一部の環境では処理が中断されてしまう可能性があります。",
-    "Update to {version}" : "{version} にアップデート",
-    "An error occurred." : "エラーが発生しました。",
-    "Please reload the page." : "ページをリロードしてください。",
-    "The update was unsuccessful. For more information <a href=\"{url}\">check our forum post</a> covering this issue." : "アップデートできませんでした。この問題に対する詳細な情報については、<a href=\"{url}\">フォーラムの投稿を確認してください</a> ",
-    "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud community</a>." : "アップデートできませんでした。<a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud コミュニティ</a> に問題を報告してください。",
-    "Continue to {productName}" : "{productName} に進む",
-    "_The update was successful. Redirecting you to {productName} in %n second._::_The update was successful. Redirecting you to {productName} in %n seconds._" : ["アップデートできました。%n秒で {productName}にリダイレクトします。"],
     "Done" : "完了",
+    "Scan QR code to log in" : "QRコードをスキャンしてログイン",
+    "Use {productName} mobile client you want to connect to scan the code" : "接続したい{productName}モバイルクライアントでコードをスキャンしてください",
+    "Code will expire {timeCountdown} or after use" : "コードは{timeCountdown}で期限切れ、または使用後に失効します",
     "Applications menu" : "アプリケーションメニュー",
     "Apps" : "アプリ",
     "More apps" : "さらにアプリ",
@@ -251,11 +248,13 @@ OC.L10N.register(
     "Results" : "結果",
     "Load more results" : "次の結果を読み込む",
     "Search in" : "検索対象",
+    "Partial matches" : "部分一致",
     "Log in" : "ログイン",
     "Logging in …" : "ログイン中...",
     "Log in to {productName}" : "{productName} へログイン",
     "Wrong login or password." : "ログイン名またはパスワードが間違っています。",
     "This account is disabled" : "アカウントが無効化されています",
+    "Too many incorrect login attempts. Please try again in 30 seconds." : "ログイン試行の回数が多すぎます。30秒後にもう一度お試しください。",
     "Account name or email" : "アカウント名またはメールアドレス",
     "Account name" : "アカウント名",
     "Server side authentication failed!" : "サーバーサイドの認証に失敗しました！",
@@ -309,10 +308,14 @@ OC.L10N.register(
     "Loading your contacts …" : "連絡先を読み込み中...",
     "Looking for {term} …" : "{term} を確認中 ...",
     "Search contacts" : "連絡先を検索",
-    "Reset search" : "検索をリセットする",
+    "Filter by team" : "チームによるフィルター",
+    "All teams" : "全てのチーム",
+    "Search contacts in team {team}" : "チーム {team}内の連絡先を検索",
     "Search contacts …" : "連絡先を検索...",
+    "Reset search" : "検索をリセットする",
     "Could not load your contacts" : "連絡先を読み込めませんでした",
     "No contacts found" : "連絡先が見つかりません",
+    "Contacts list" : "連絡先リスト",
     "Show all contacts" : "すべての連絡先を表示",
     "Install the Contacts app" : "連絡先アプリをインストール",
     "Search" : "検索",
@@ -329,13 +332,17 @@ OC.L10N.register(
     "Login form is disabled." : "ログインフォームは無効です。",
     "The Nextcloud login form is disabled. Use another login option if available or contact your administration." : "Nextcloud ログインフォームは無効になっています。 利用可能な場合は別のログインオプションを使用するか、管理者に問い合わせてください。",
     "Connect to your account" : "あなたのアカウントに接続する",
+    "Please log in before granting \"{client}\" access to your {instanceName} account." : "\"{client}\"にあなたの{instanceName}アカウントへのアクセスを許可する前にログインしてください。",
     "Security warning" : "セキュリティ警告",
     "If you are not trying to set up a new device or app, someone is trying to trick you into granting them access to your data. In this case do not proceed and instead contact your system administrator." : "新しいデバイスやアプリを設定しようとしていないのに、今この画面が表示された場合、誰かがあなたを騙してデータへのアクセス権を奪取しようとしています。その場合は、ここで止めてシステム管理者に連絡してください。",
+    "Log in using password" : "パスワードでログイン",
     "Alternative log in using app password" : "アプリパスワードを使用した代替ログイン",
     "Account connected" : "アカウントに接続しました",
     "Your client should now be connected!" : "クライアントはもう接続されているはずです！",
     "You can close this window." : "このウィンドウは閉じてしまって構いません。",
     "Account access" : "アカウントによるアクセス許可",
+    "Currently logged in as {userDisplayName} ({userId})." : "現在 {userDisplayName} ({userId}) としてログインしています。",
+    "You are about to grant \"{client}\" access to your {instanceName} account." : "\"{client}\" にあなたの {instanceName} アカウントへのアクセスを付与しようとしています。",
     "More actions" : "その他のアクション",
     "User menu" : "ユーザーメニュー",
     "Your guest name: {user}" : "ゲスト名: {user}",
@@ -393,6 +400,32 @@ OC.L10N.register(
     "Your browser is not supported. Please upgrade to a newer version or a supported one." : "お使いのブラウザーはサポート対象外です。新しいバージョンにアップグレードするかサポートされているブラウザーへ切り替えてください",
     "Continue with this unsupported browser" : "サポート対象外のブラウザーで継続する",
     "Supported versions" : "サポート対象バージョン",
+    "The update completed with warnings. Please check the details for more information." : "更新は警告とともに完了しました。詳細については情報を確認してください。",
+    "The update completed successfully." : "アップデートは正常に完了しました。",
+    "Preparing update…" : "更新を準備中…",
+    "You will be redirected to {productName} in {count} seconds." : "{count}秒後に {productName}にリダイレクトされます。",
+    "The update is in progress, leaving this page might interrupt the process in some environments." : "更新が進行中です。このページを離れると一部の環境では処理が中断されてしまう可能性があります。",
+    "App update required" : "アプリの更新が必要",
+    "{productName} will be updated to version {version}" : "{productName} は バーション {version} にアップデートされます",
+    "The theme {oldTheme} has been disabled." : "テーマ {oldTheme} が無効になっています。",
+    "These incompatible apps will be disabled:" : "無効になる互換性のないアプリ:",
+    "Incompatible apps" : "互換性のないアプリ",
+    "These apps will be updated:" : "次のアプリがアップデートされます：",
+    "Apps to update" : "更新するアプリ",
+    "{app} from {oldVersion} to {version}" : "{app}を {oldVersion}から{version} にアップデートする",
+    "Please make sure that the database, the config folder and the data folder have been backed up before proceeding." : "データベースを確認してください。実行前にconfigフォルダーとdataフォルダーをバックアップします。",
+    "To avoid timeouts with larger installations, you can instead run the following command from your installation directory:" : "大規模なサイトの場合、ブラウザーがタイムアウトする可能性があるため、インストールディレクトリで次のコマンドを実行することもできます。",
+    "Start update" : "アップデートを開始",
+    "Continue to {productName}" : "{productName} に進む",
+    "Update to {version}" : "{version} にアップデート",
+    "Hide details" : "詳細を隠す",
+    "Show details" : "詳細を表示",
+    "Update details" : "詳細を更新する",
+    "Update needed" : "更新が必要です",
+    "Please use the command line updater because you have a big instance with more than 50 accounts." : "50人以上のアカウントを持つ大規模なインスタンスの場合は、コマンドラインのアップデータを使用してください。",
+    "Documentation" : "ドキュメント",
+    "I know that if I continue doing the update via web UI has the risk, that the request runs into a timeout and could cause data loss, but I have a backup and know how to restore my instance in case of a failure." : "Web 画面から続行すると危険性があることを理解しています。この操作がタイムアウトすると、データが失われる危険性があることを理解しています。もし失敗した場合には取得済みのバックアップから修復する方法を理解しています。",
+    "Upgrade via web on my own risk" : "危険性を理解した上でWeb画面からアップグレード",
     "Search {types} …" : "{types} を検索…",
     "Choose {file}" : "{file}を選択",
     "Choose" : "選択",
@@ -418,19 +451,13 @@ OC.L10N.register(
     "Group list is empty" : "グループリストが空です",
     "Unable to retrieve the group list" : "グループリストを取得できません",
     "seconds ago" : "数秒前",
-    "Connection to server lost" : "サーバーとの接続が切断されました",
-    "_Problem loading page, reloading in %n second_::_Problem loading page, reloading in %n seconds_" : ["ページの読み込み中に問題が発生しました。%n秒後に再読み込みします"],
     "Add to a project" : "プロジェクトに追加",
-    "Show details" : "詳細を表示",
-    "Hide details" : "詳細を隠す",
     "Rename project" : "プロジェクト名を変更",
     "Failed to rename the project" : "プロジェクト名の変更に失敗",
     "Failed to create a project" : "プロジェクトの作成に失敗",
     "Failed to add the item to the project" : "プロジェクトへのアイテムの追加に失敗",
     "Connect items to a project to make them easier to find" : "アイテムをプロジェクトに接続して見つけやすくする",
     "Type to search for existing projects" : "入力して既存のプロジェクトを検索します",
-    "New in" : "新機能",
-    "View changelog" : "変更履歴を確認する",
     "Close \"{dialogTitle}\" dialog" : "\"{dialogTitle}\"ダイアログを閉じる",
     "Email length is at max (255)" : "メールアドレスの長さは 255文字 以下です",
     "Clipboard not available, please copy manually" : "クリップボードが使用できません。手動でコピーしてください",
@@ -482,20 +509,6 @@ OC.L10N.register(
     "Access through untrusted domain" : "信頼できないドメインを介したアクセス",
     "Please contact your administrator. If you are an administrator, edit the \"trusted_domains\" setting in config/config.php like the example in config.sample.php." : "管理者に連絡してください。 管理者の場合は、config.sample.phpを参照して config/config.phpの \"trusted_domains\" を設定してください。",
     "Further information how to configure this can be found in the %1$sdocumentation%2$s." : "これを構成する方法の詳細は、%1$sドキュメント%2$sにあります。",
-    "App update required" : "アプリの更新が必要",
-    "%1$s will be updated to version %2$s" : "%1$s は バーション %2$s にアップデートされます",
-    "The following apps will be updated:" : "以下のアプリはアップデートされます:",
-    "These incompatible apps will be disabled:" : "無効になる互換性のないアプリ:",
-    "The theme %s has been disabled." : "テーマ %s が無効になっています。",
-    "Please make sure that the database, the config folder and the data folder have been backed up before proceeding." : "データベースを確認してください。実行前にconfigフォルダーとdataフォルダーをバックアップします。",
-    "Start update" : "アップデートを開始",
-    "To avoid timeouts with larger installations, you can instead run the following command from your installation directory:" : "大規模なサイトの場合、ブラウザーがタイムアウトする可能性があるため、インストールディレクトリで次のコマンドを実行することもできます。",
-    "Detailed logs" : "詳細ログ",
-    "Update needed" : "更新が必要です",
-    "Please use the command line updater because you have a big instance with more than 50 accounts." : "50人以上のアカウントを持つ大規模なインスタンスの場合は、コマンドラインのアップデータを使用してください。",
-    "For help, see the  <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">documentation</a>." : "不明な場合、  <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">ドキュメント</a>を参照してください。",
-    "I know that if I continue doing the update via web UI has the risk, that the request runs into a timeout and could cause data loss, but I have a backup and know how to restore my instance in case of a failure." : "Web 画面から続行すると危険性があることを理解しています。この操作がタイムアウトすると、データが失われる危険性があることを理解しています。もし失敗した場合には取得済みのバックアップから修復する方法を理解しています。",
-    "Upgrade via web on my own risk" : "危険性を理解した上でWeb画面からアップグレード",
     "Maintenance mode" : "メンテナンスモード",
     "This %s instance is currently in maintenance mode, which may take a while." : "このサーバー %s は現在メンテナンスモードです。しばらくお待ちください。",
     "This page will refresh itself when the instance is available again." : "この画面は、サーバー の再起動後に自動的に更新されます。",
@@ -510,6 +523,11 @@ OC.L10N.register(
     "<strong>These are your search results<script>alert(1)</script></strong>" : "<strong>これが検索結果です<script>alert(1)</script></strong>",
     "new" : "新規",
     "_download %n file_::_download %n files_" : ["%n個のファイルをダウンロード"],
+    "An error occurred." : "エラーが発生しました。",
+    "Please reload the page." : "ページをリロードしてください。",
+    "The update was unsuccessful. For more information <a href=\"{url}\">check our forum post</a> covering this issue." : "アップデートできませんでした。この問題に対する詳細な情報については、<a href=\"{url}\">フォーラムの投稿を確認してください</a> ",
+    "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud community</a>." : "アップデートできませんでした。<a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud コミュニティ</a> に問題を報告してください。",
+    "_The update was successful. Redirecting you to {productName} in %n second._::_The update was successful. Redirecting you to {productName} in %n seconds._" : ["アップデートできました。%n秒で {productName}にリダイレクトします。"],
     "Direct link copied to clipboard" : "クリップボードにコピーされた直接リンク",
     "Searching …" : "検索しています…",
     "Logging in …" : "ログイン中...",
@@ -522,6 +540,10 @@ OC.L10N.register(
     "Loading more results …" : "次の結果を読み込み中 ...",
     "Search {types} …" : "{types} を検索…",
     "Saving …" : "保存中...",
+    "Connection to server lost" : "サーバーとの接続が切断されました",
+    "_Problem loading page, reloading in %n second_::_Problem loading page, reloading in %n seconds_" : ["ページの読み込み中に問題が発生しました。%n秒後に再読み込みします"],
+    "New in" : "新機能",
+    "View changelog" : "変更履歴を確認する",
     "Very weak password" : "非常に弱いパスワード",
     "Weak password" : "弱いパスワード",
     "So-so password" : "まずまずのパスワード",
@@ -548,6 +570,11 @@ OC.L10N.register(
     "Installing …" : "インストールしています…",
     "Please log in before granting %1$s access to your %2$s account." : "あなたの %2$s アカウントに %1$s アクセスを許可する前にログインしてください。",
     "Currently logged in as %1$s (%2$s)." : "現在、%1$s (%2$s)としてログインしています。",
-    "You are about to grant %1$s access to your %2$s account." : "%2$s アカウントに あなたのアカウント %1$s へのアクセスを許可"
+    "You are about to grant %1$s access to your %2$s account." : "%2$s アカウントに あなたのアカウント %1$s へのアクセスを許可",
+    "%1$s will be updated to version %2$s" : "%1$s は バーション %2$s にアップデートされます",
+    "The following apps will be updated:" : "以下のアプリはアップデートされます:",
+    "The theme %s has been disabled." : "テーマ %s が無効になっています。",
+    "Detailed logs" : "詳細ログ",
+    "For help, see the  <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">documentation</a>." : "不明な場合、  <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">ドキュメント</a>を参照してください。"
 },
 "nplurals=1; plural=0;");
