@@ -73,14 +73,6 @@ OC.L10N.register(
     "The following apps have been disabled: %s" : "The following apps have been disabled: %s",
     "Already up to date" : "Already up to date",
     "Unknown" : "Unknown",
-    "The update is in progress, leaving this page might interrupt the process in some environments." : "The update is in progress, leaving this page might interrupt the process in some environments.",
-    "Update to {version}" : "Update to {version}",
-    "An error occurred." : "An error occurred.",
-    "Please reload the page." : "Please reload the page.",
-    "The update was unsuccessful. For more information <a href=\"{url}\">check our forum post</a> covering this issue." : "The update was unsuccessful. For more information <a href=\"{url}\">check our forum post</a> covering this issue.",
-    "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud community</a>." : "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud community</a>.",
-    "Continue to {productName}" : "Continue to {productName}",
-    "_The update was successful. Redirecting you to {productName} in %n second._::_The update was successful. Redirecting you to {productName} in %n seconds._" : ["The update was successful. Redirecting you to {productName} in %n second.","The update was successful. Redirecting you to {productName} in %n seconds."],
     "Done" : "დასრულდა",
     "Applications menu" : "Applications menu",
     "Apps" : "Apps",
@@ -228,6 +220,20 @@ OC.L10N.register(
     "Your browser is not supported. Please upgrade to a newer version or a supported one." : "Your browser is not supported. Please upgrade to a newer version or a supported one.",
     "Continue with this unsupported browser" : "Continue with this unsupported browser",
     "Supported versions" : "Supported versions",
+    "The update is in progress, leaving this page might interrupt the process in some environments." : "The update is in progress, leaving this page might interrupt the process in some environments.",
+    "App update required" : "App update required",
+    "These incompatible apps will be disabled:" : "These incompatible apps will be disabled:",
+    "Please make sure that the database, the config folder and the data folder have been backed up before proceeding." : "Please make sure that the database, the config folder and the data folder have been backed up before proceeding.",
+    "To avoid timeouts with larger installations, you can instead run the following command from your installation directory:" : "To avoid timeouts with larger installations, you can instead run the following command from your installation directory:",
+    "Start update" : "Start update",
+    "Continue to {productName}" : "Continue to {productName}",
+    "Update to {version}" : "Update to {version}",
+    "Hide details" : "Hide details",
+    "Show details" : "Show details",
+    "Update needed" : "Update needed",
+    "Documentation" : "Documentation",
+    "I know that if I continue doing the update via web UI has the risk, that the request runs into a timeout and could cause data loss, but I have a backup and know how to restore my instance in case of a failure." : "I know that if I continue doing the update via web UI has the risk, that the request runs into a timeout and could cause data loss, but I have a backup and know how to restore my instance in case of a failure.",
+    "Upgrade via web on my own risk" : "Upgrade via web on my own risk",
     "Choose {file}" : "Choose {file}",
     "Choose" : "Choose",
     "Copy to {target}" : "Copy to {target}",
@@ -252,19 +258,13 @@ OC.L10N.register(
     "Group list is empty" : "Group list is empty",
     "Unable to retrieve the group list" : "Unable to retrieve the group list",
     "seconds ago" : "seconds ago",
-    "Connection to server lost" : "Connection to server lost",
-    "_Problem loading page, reloading in %n second_::_Problem loading page, reloading in %n seconds_" : ["Problem loading page, reloading in %n second","Problem loading page, reloading in %n seconds"],
     "Add to a project" : "Add to a project",
-    "Show details" : "Show details",
-    "Hide details" : "Hide details",
     "Rename project" : "Rename project",
     "Failed to rename the project" : "Failed to rename the project",
     "Failed to create a project" : "Failed to create a project",
     "Failed to add the item to the project" : "Failed to add the item to the project",
     "Connect items to a project to make them easier to find" : "Connect items to a project to make them easier to find",
     "Type to search for existing projects" : "Type to search for existing projects",
-    "New in" : "New in",
-    "View changelog" : "View changelog",
     "Close \"{dialogTitle}\" dialog" : "Close \"{dialogTitle}\" dialog",
     "Personal" : "Personal",
     "Accounts" : "Accounts",
@@ -312,19 +312,6 @@ OC.L10N.register(
     "Access through untrusted domain" : "Access through untrusted domain",
     "Please contact your administrator. If you are an administrator, edit the \"trusted_domains\" setting in config/config.php like the example in config.sample.php." : "Please contact your administrator. If you are an administrator, edit the \"trusted_domains\" setting in config/config.php like the example in config.sample.php.",
     "Further information how to configure this can be found in the %1$sdocumentation%2$s." : "Further information how to configure this can be found in the %1$sdocumentation%2$s.",
-    "App update required" : "App update required",
-    "%1$s will be updated to version %2$s" : "%1$s will be updated to version %2$s",
-    "The following apps will be updated:" : "The following apps will be updated:",
-    "These incompatible apps will be disabled:" : "These incompatible apps will be disabled:",
-    "The theme %s has been disabled." : "The theme %s has been disabled.",
-    "Please make sure that the database, the config folder and the data folder have been backed up before proceeding." : "Please make sure that the database, the config folder and the data folder have been backed up before proceeding.",
-    "Start update" : "Start update",
-    "To avoid timeouts with larger installations, you can instead run the following command from your installation directory:" : "To avoid timeouts with larger installations, you can instead run the following command from your installation directory:",
-    "Detailed logs" : "Detailed logs",
-    "Update needed" : "Update needed",
-    "For help, see the  <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">documentation</a>." : "For help, see the  <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">documentation</a>.",
-    "I know that if I continue doing the update via web UI has the risk, that the request runs into a timeout and could cause data loss, but I have a backup and know how to restore my instance in case of a failure." : "I know that if I continue doing the update via web UI has the risk, that the request runs into a timeout and could cause data loss, but I have a backup and know how to restore my instance in case of a failure.",
-    "Upgrade via web on my own risk" : "Upgrade via web on my own risk",
     "Maintenance mode" : "Maintenance mode",
     "This %s instance is currently in maintenance mode, which may take a while." : "This %s instance is currently in maintenance mode, which may take a while.",
     "This page will refresh itself when the instance is available again." : "This page will refresh itself when the instance is available again.",
@@ -339,6 +326,11 @@ OC.L10N.register(
     "<strong>These are your search results<script>alert(1)</script></strong>" : "<strong>These are your search results<script>alert(1)</script></strong>",
     "new" : "new",
     "_download %n file_::_download %n files_" : ["download %n file","download %n files"],
+    "An error occurred." : "An error occurred.",
+    "Please reload the page." : "Please reload the page.",
+    "The update was unsuccessful. For more information <a href=\"{url}\">check our forum post</a> covering this issue." : "The update was unsuccessful. For more information <a href=\"{url}\">check our forum post</a> covering this issue.",
+    "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud community</a>." : "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud community</a>.",
+    "_The update was successful. Redirecting you to {productName} in %n second._::_The update was successful. Redirecting you to {productName} in %n seconds._" : ["The update was successful. Redirecting you to {productName} in %n second.","The update was successful. Redirecting you to {productName} in %n seconds."],
     "Searching …" : "Searching …",
     "Logging in …" : "Logging in …",
     "We have detected multiple invalid login attempts from your IP. Therefore your next login is throttled up to 30 seconds." : "We have detected multiple invalid login attempts from your IP. Therefore your next login is throttled up to 30 seconds.",
@@ -350,6 +342,10 @@ OC.L10N.register(
     "Loading more results …" : "შედეგი იტვირთება …",
     "Search {types} …" : "Search {types} …",
     "Saving …" : "Saving …",
+    "Connection to server lost" : "Connection to server lost",
+    "_Problem loading page, reloading in %n second_::_Problem loading page, reloading in %n seconds_" : ["Problem loading page, reloading in %n second","Problem loading page, reloading in %n seconds"],
+    "New in" : "New in",
+    "View changelog" : "View changelog",
     "Very weak password" : "Very weak password",
     "Weak password" : "Weak password",
     "So-so password" : "So-so password",
@@ -372,6 +368,11 @@ OC.L10N.register(
     "Installing …" : "Installing …",
     "Please log in before granting %1$s access to your %2$s account." : "Please log in before granting %1$s access to your %2$s account.",
     "Currently logged in as %1$s (%2$s)." : "Currently logged in as %1$s (%2$s).",
-    "You are about to grant %1$s access to your %2$s account." : "You are about to grant %1$s access to your %2$s account."
+    "You are about to grant %1$s access to your %2$s account." : "You are about to grant %1$s access to your %2$s account.",
+    "%1$s will be updated to version %2$s" : "%1$s will be updated to version %2$s",
+    "The following apps will be updated:" : "The following apps will be updated:",
+    "The theme %s has been disabled." : "The theme %s has been disabled.",
+    "Detailed logs" : "Detailed logs",
+    "For help, see the  <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">documentation</a>." : "For help, see the  <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">documentation</a>."
 },
 "nplurals=2; plural=(n!=1);");
