@@ -198,15 +198,10 @@ OC.L10N.register(
     "Matroska video" : "Matroska видео",
     "Windows Media video" : "Windows Media видео",
     "AVI video" : "AVI видео",
-    "The update is in progress, leaving this page might interrupt the process in some environments." : "Во тек е надградба на системот, доколку ја напуштите оваа страница може да дојде до прекин на некој процес во некој дел.",
-    "Update to {version}" : "Надгради на {version}",
-    "An error occurred." : "Се случи грешка",
-    "Please reload the page." : "Превчитајте ја страницата.",
-    "The update was unsuccessful. For more information <a href=\"{url}\">check our forum post</a> covering this issue." : "Надградбата не беше успешна. За повеќе информации <a href=\"{url}\">проверете го нашиот форум</a> што го покрива овој проблем.",
-    "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud community</a>." : "Надградбата не беше успешна. Ве молиме овој проблем да го пријавите во <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">заедницата</a>.",
-    "Continue to {productName}" : "Продолжи кон {productName}",
-    "_The update was successful. Redirecting you to {productName} in %n second._::_The update was successful. Redirecting you to {productName} in %n seconds._" : ["Ажурирањето беше успешно. Пренасочување кон {productName} за %n секунда.","Ажурирањето беше успешно. Пренасочување кон {productName} за %n секунди."],
     "Done" : "Готово",
+    "Scan QR code to log in" : "Скенирај го QR кодот за да се најавиш",
+    "Use {productName} mobile client you want to connect to scan the code" : "Користи {productName} за мобилен за да се најавиш со скенирање на кодот",
+    "Code will expire {timeCountdown} or after use" : "Кодот ќе истече за {timeCountdown} или одкога ќе го искористиш",
     "Applications menu" : "Мени со апликации",
     "Apps" : "Аппликации",
     "More apps" : "Повеќе апликации",
@@ -311,8 +306,8 @@ OC.L10N.register(
     "Loading your contacts …" : "Вчитување на вашите контакти …",
     "Looking for {term} …" : "Пребарување за {term} …",
     "Search contacts" : "Пребарување контакти",
-    "Reset search" : "Ресетирај пребарување",
     "Search contacts …" : "Пребарување контакти …",
+    "Reset search" : "Ресетирај пребарување",
     "Could not load your contacts" : "Неможат да се вчитаат вашите контакти",
     "No contacts found" : "Не се пронајдени контакти",
     "Show all contacts" : "Прикажи ги сите контакти",
@@ -331,13 +326,17 @@ OC.L10N.register(
     "Login form is disabled." : "Формата за најава е оневозможена.",
     "The Nextcloud login form is disabled. Use another login option if available or contact your administration." : "Формуларот за најавување на Nextcloud е оневозможен. Користете друга опција за најавување доколку е достапна или контактирајте ја вашата администрација.",
     "Connect to your account" : "Поврзани со вашата сметка",
+    "Please log in before granting \"{client}\" access to your {instanceName} account." : "Најави се пред да му овозможиш на \"{client}\" да пристапи до твојата {instanceName} сметка.",
     "Security warning" : "Безбедносно предупредување",
     "If you are not trying to set up a new device or app, someone is trying to trick you into granting them access to your data. In this case do not proceed and instead contact your system administrator." : "Доколку не се обидувате да додадете нов уред, некој се обидува да ве надитри и да обезбеди пристап до вашите податоци. Во тој случај не продолжувајте понатаму и веднаш контактирајте го администраторот.",
+    "Log in using password" : "Најви се со лозинка",
     "Alternative log in using app password" : "Алтернативен начин на најава со користење на лозинка за апликација",
     "Account connected" : "Сметката е поврзана",
     "Your client should now be connected!" : "Вашиот клиент сега треба да биде поврзан!",
     "You can close this window." : "Можете да го затворите овој прозорец.",
     "Account access" : "Пристап до сметка",
+    "Currently logged in as {userDisplayName} ({userId})." : "Моментално сте најавени како {userDisplayName} ({userId}).",
+    "You are about to grant \"{client}\" access to your {instanceName} account." : "Ќе му овозможите пристап на \"{client}\" да пристапи на вашата {instanceName} сметка.",
     "More actions" : "Повеќе акции",
     "User menu" : "Корисничко мени",
     "Your guest name: {user}" : "Вашето гостинско име: {user}",
@@ -352,6 +351,7 @@ OC.L10N.register(
     "You are not authorized to request a password for this share" : "Не сте авторизиран за да побарате лозинка за ова споделување",
     "Email address" : "Е-пошта адреси",
     "Request password" : "Барање на лозинка",
+    "Forgot password" : "Заборавена лозинка",
     "Password is too weak" : "Лозинката е премногу слаба",
     "Password is weak" : "Лозинката е слава",
     "Password is average" : "Лозинката е просечна",
@@ -394,6 +394,32 @@ OC.L10N.register(
     "Your browser is not supported. Please upgrade to a newer version or a supported one." : "Вашиот прелистувач не е поддржан. Надградете на понова или поддржана верзија.",
     "Continue with this unsupported browser" : "Продолжете со овој неподдржан прелистувач",
     "Supported versions" : "Поддржани верзии",
+    "The update completed with warnings. Please check the details for more information." : "Ажурирањето заврши со некој предупредувања. Проверете ги деталите за повеќе информации.",
+    "The update completed successfully." : "Ажурирањето е успешно.",
+    "Preparing update…" : "Подготовка за ажурирање...",
+    "You will be redirected to {productName} in {count} seconds." : "Ќе бидете пренасочени кон {productName} за {count} секунди.",
+    "The update is in progress, leaving this page might interrupt the process in some environments." : "Во тек е надградба на системот, доколку ја напуштите оваа страница може да дојде до прекин на некој процес во некој дел.",
+    "App update required" : "Потребна е надградба на апликацијата",
+    "{productName} will be updated to version {version}" : "{productName} ќе биде ажурирана во верзија {version}",
+    "The theme {oldTheme} has been disabled." : "Темета {oldTheme} е оневозможена.",
+    "These incompatible apps will be disabled:" : "Овие апликации се некомпатабилни и ќе бидат оневозможени:",
+    "Incompatible apps" : "Некомпатибилни апликации",
+    "These apps will be updated:" : "Следните апликации чќе бидат надградени:",
+    "Apps to update" : "Апликации што ќе се ажурираат",
+    "{app} from {oldVersion} to {version}" : "{app} од {oldVersion} во {version}",
+    "Please make sure that the database, the config folder and the data folder have been backed up before proceeding." : "Ве молиме осигурајте се дека базата на податоци, конфигурациониот директориум и директориумот со податоци се безбедно копирани  пред да продолжите.",
+    "To avoid timeouts with larger installations, you can instead run the following command from your installation directory:" : "За да избегнете тајм аут за големи инсталации, можете да ја извршите следнава команда во директориумот за инсталација:",
+    "Start update" : "Започни ја надградбата",
+    "Continue to {productName}" : "Продолжи кон {productName}",
+    "Update to {version}" : "Надгради на {version}",
+    "Hide details" : "Сокриј детали",
+    "Show details" : "Прикажи детали",
+    "Update details" : "Детали за ажурирањето",
+    "Update needed" : "Потребно е ажутирање",
+    "Please use the command line updater because you have a big instance with more than 50 accounts." : "Ве молиме користете ја командната линија за ажурирање бидејќи имате голема истанца со повеќе од 50 корисници.",
+    "Documentation" : "Документација",
+    "I know that if I continue doing the update via web UI has the risk, that the request runs into a timeout and could cause data loss, but I have a backup and know how to restore my instance in case of a failure." : "Знам дека има ризик ако продолжам со ажурирањето преку веб-интерфејс, и да застане во тајм аут и може да предизвика загуба на податоци, но имам резервна копија и знам како да ја вратам мојата истанца во случај на дефект.",
+    "Upgrade via web on my own risk" : "Надоградба преку веб-интерфејс на сопствен ризик",
     "Search {types} …" : "Пребарување {types} …",
     "Choose {file}" : "Избери {file}",
     "Choose" : "Избери",
@@ -419,19 +445,13 @@ OC.L10N.register(
     "Group list is empty" : "Листата во групата е празна",
     "Unable to retrieve the group list" : "Неможе да се вчита листата со групи",
     "seconds ago" : "пред неколку секунди",
-    "Connection to server lost" : "Изгубена е врската со серверот",
-    "_Problem loading page, reloading in %n second_::_Problem loading page, reloading in %n seconds_" : ["Проблем при вчитување на страницата, превчитување за %n секунда","Проблем при вчитување на страницата, превчитување за %n секунди"],
     "Add to a project" : "Додади во проект",
-    "Show details" : "Прикажи детали",
-    "Hide details" : "Сокриј детали",
     "Rename project" : "Преименувај проект",
     "Failed to rename the project" : "Неуспешно преименување на проектот",
     "Failed to create a project" : "Неуспешно креирање на проектот",
     "Failed to add the item to the project" : "Неуспешно додавање на ставката во проектот",
     "Connect items to a project to make them easier to find" : "Поврзете ги датотеките и папките во проект за да може полесно да ги пронаоѓате",
     "Type to search for existing projects" : "Пребарувај за постоечки проекти",
-    "New in" : "Ново во",
-    "View changelog" : "Види ги промените",
     "Close \"{dialogTitle}\" dialog" : "Затвори \"{dialogTitle}\"",
     "Email length is at max (255)" : "Должината на Е-пошта е максимум (255)",
     "Clipboard not available, please copy manually" : "Клипбоард не е достапен, копирај рачно",
@@ -483,20 +503,6 @@ OC.L10N.register(
     "Access through untrusted domain" : "Пристап преку недоверлив домен.",
     "Please contact your administrator. If you are an administrator, edit the \"trusted_domains\" setting in config/config.php like the example in config.sample.php." : "Ве молиме контактирајте го администраторот. Доколку сте администратор, променете го \"trusted_domains\" подесувањето во config/config.php како во примерот config.sample.php.",
     "Further information how to configure this can be found in the %1$sdocumentation%2$s." : "Дополнителни информации како да го конфигурирате ова може да најдете во %1$sдокоментацијата%2$s.",
-    "App update required" : "Потребна е надградба на апликацијата",
-    "%1$s will be updated to version %2$s" : "%1$s ќе биде ажурирана во верзија %2$s",
-    "The following apps will be updated:" : "Следните апликации ќе бидат ажурирани:",
-    "These incompatible apps will be disabled:" : "Овие апликации се некомпатабилни и ќе бидат оневозможени:",
-    "The theme %s has been disabled." : "Темета %s е оневозможена.",
-    "Please make sure that the database, the config folder and the data folder have been backed up before proceeding." : "Ве молиме осигурајте се дека базата на податоци, конфигурациониот директориум и директориумот со податоци се безбедно копирани  пред да продолжите.",
-    "Start update" : "Започни ја надградбата",
-    "To avoid timeouts with larger installations, you can instead run the following command from your installation directory:" : "За да избегнете тајм аут за големи инсталации, можете да ја извршите следнава команда во директориумот за инсталација:",
-    "Detailed logs" : "Детални записи",
-    "Update needed" : "Потребно е ажутирање",
-    "Please use the command line updater because you have a big instance with more than 50 accounts." : "Ве молиме користете ја командната линија за ажурирање бидејќи имате голема истанца со повеќе од 50 корисници.",
-    "For help, see the  <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">documentation</a>." : "За помош, прочитајте ја <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">документацијата</a>.",
-    "I know that if I continue doing the update via web UI has the risk, that the request runs into a timeout and could cause data loss, but I have a backup and know how to restore my instance in case of a failure." : "Знам дека има ризик ако продолжам со ажурирањето преку веб-интерфејс, и да застане во тајм аут и може да предизвика загуба на податоци, но имам резервна копија и знам како да ја вратам мојата истанца во случај на дефект.",
-    "Upgrade via web on my own risk" : "Надоградба преку веб-интерфејс на сопствен ризик",
     "Maintenance mode" : "Мод за одржување",
     "This %s instance is currently in maintenance mode, which may take a while." : "Истанцата %s моментално е во режим на одржување, што значи дека може да потрае некое време.",
     "This page will refresh itself when the instance is available again." : "Оваа веб страница ќе се рефрешира кога истанцата ќе биде повторно достапна.",
@@ -511,6 +517,11 @@ OC.L10N.register(
     "<strong>These are your search results<script>alert(1)</script></strong>" : "<strong>Ова се вашите резултати од пребарувањето<script>alert(1)</script></strong>",
     "new" : "ново",
     "_download %n file_::_download %n files_" : ["преземи %n датотека","преземи %n датотеки"],
+    "An error occurred." : "Се случи грешка",
+    "Please reload the page." : "Превчитајте ја страницата.",
+    "The update was unsuccessful. For more information <a href=\"{url}\">check our forum post</a> covering this issue." : "Надградбата не беше успешна. За повеќе информации <a href=\"{url}\">проверете го нашиот форум</a> што го покрива овој проблем.",
+    "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud community</a>." : "Надградбата не беше успешна. Ве молиме овој проблем да го пријавите во <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">заедницата</a>.",
+    "_The update was successful. Redirecting you to {productName} in %n second._::_The update was successful. Redirecting you to {productName} in %n seconds._" : ["Ажурирањето беше успешно. Пренасочување кон {productName} за %n секунда.","Ажурирањето беше успешно. Пренасочување кон {productName} за %n секунди."],
     "Direct link copied to clipboard" : "Линкот е копиран во клипборд",
     "Searching …" : "Пребарување ...",
     "Logging in …" : "Најава ...",
@@ -523,6 +534,10 @@ OC.L10N.register(
     "Loading more results …" : "Вчитување на повеќе резултати ...",
     "Search {types} …" : "Пребарување {types} …",
     "Saving …" : "Зачувува ...",
+    "Connection to server lost" : "Изгубена е врската со серверот",
+    "_Problem loading page, reloading in %n second_::_Problem loading page, reloading in %n seconds_" : ["Проблем при вчитување на страницата, превчитување за %n секунда","Проблем при вчитување на страницата, превчитување за %n секунди"],
+    "New in" : "Ново во",
+    "View changelog" : "Види ги промените",
     "Very weak password" : "Многу слаба лозинка",
     "Weak password" : "Слаба лозинка",
     "So-so password" : "Така така лозинка",
@@ -549,6 +564,11 @@ OC.L10N.register(
     "Installing …" : "Инсталирање ...",
     "Please log in before granting %1$s access to your %2$s account." : "Ве молиме најавете се пред да доделите пристап на %1$s во вашата %2$s сметка.",
     "Currently logged in as %1$s (%2$s)." : "Најавени сте како %1$s (%2$s).",
-    "You are about to grant %1$s access to your %2$s account." : "Ќе доделите пристап на %1$s во вашата %2$s сметка."
+    "You are about to grant %1$s access to your %2$s account." : "Ќе доделите пристап на %1$s во вашата %2$s сметка.",
+    "%1$s will be updated to version %2$s" : "%1$s ќе биде ажурирана во верзија %2$s",
+    "The following apps will be updated:" : "Следните апликации ќе бидат ажурирани:",
+    "The theme %s has been disabled." : "Темета %s е оневозможена.",
+    "Detailed logs" : "Детални записи",
+    "For help, see the  <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">documentation</a>." : "За помош, прочитајте ја <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">документацијата</a>."
 },
 "nplurals=2; plural=(n % 10 == 1 && n % 100 != 11) ? 0 : 1;");
