@@ -198,14 +198,6 @@ OC.L10N.register(
     "Matroska video" : "Matroska-video",
     "Windows Media video" : "Windows Media video",
     "AVI video" : "AVI-video",
-    "The update is in progress, leaving this page might interrupt the process in some environments." : "De update is bezig, deze pagina verlaten kan het updateproces in sommige omgevingen onderbreken.",
-    "Update to {version}" : "Geüpdatet naar {version}",
-    "An error occurred." : "Er heeft zich een fout voorgedaan.",
-    "Please reload the page." : "Herlaad deze pagina.",
-    "The update was unsuccessful. For more information <a href=\"{url}\">check our forum post</a> covering this issue." : "De update was niet succesvol. Voor meer informatie <a href=\"{url}\">zie ons bericht op het forum</a> over dit probleem.",
-    "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud community</a>." : "De update is mislukt. Meld dit probleem aan de <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud community</a>.",
-    "Continue to {productName}" : "Verder naar {productName}",
-    "_The update was successful. Redirecting you to {productName} in %n second._::_The update was successful. Redirecting you to {productName} in %n seconds._" : ["De update was succesvol. Redirecten naar {productName} over %nseconde.","De update was succesvol. Redirecten naar {productName} over %n seconden."],
     "Done" : "Klaar",
     "Scan QR code to log in" : "Scan de QR-code om in te loggen",
     "Use {productName} mobile client you want to connect to scan the code" : "Gebruik {productName} mobiele client waarmee u verbinding wilt maken om de code te scannen.",
@@ -270,7 +262,7 @@ OC.L10N.register(
     "An internal error occurred." : "Er heeft zich een interne fout voorgedaan.",
     "Please try again or contact your administrator." : "Probeer het opnieuw of neem contact op met je beheerder.",
     "Password" : "Wachtwoord",
-    "Remember me" : "Onthoudt mij",
+    "Remember me" : "Onthoud mij",
     "Log in with a device" : "Inloggen met een apparaat",
     "Login or email" : "Login of email",
     "Your account is not setup for passwordless login." : "Je account is niet ingesteld voor inloggen zonder wachtwoord.",
@@ -314,8 +306,8 @@ OC.L10N.register(
     "Loading your contacts …" : "Je contacten worden geladen ...",
     "Looking for {term} …" : "Zoeken naar {term}",
     "Search contacts" : "Zoek contacten",
-    "Reset search" : "Zoekopdracht wissen",
     "Search contacts …" : "Zoek contacten ...",
+    "Reset search" : "Zoekopdracht wissen",
     "Could not load your contacts" : "Kon je contactpersonenen niet laden",
     "No contacts found" : "Geen contacten gevonden",
     "Show all contacts" : "Toon alle contactpersonen",
@@ -402,6 +394,32 @@ OC.L10N.register(
     "Your browser is not supported. Please upgrade to a newer version or a supported one." : "Deze browser wordt niet ondersteunt. Upgrade a.u.b naar een nieuwere versie of een browser die wel ondersteunt wordt.",
     "Continue with this unsupported browser" : "Ga verder met deze niet-ondersteunde browser",
     "Supported versions" : "Ondersteunde versies",
+    "The update completed with warnings. Please check the details for more information." : "De update is voltooid met waarschuwingen. Bekijk de details voor meer informatie.",
+    "The update completed successfully." : "De update is met succes voltooid.",
+    "Preparing update…" : "Update voorbereiden...",
+    "You will be redirected to {productName} in {count} seconds." : "Je wordt doorgeleid naar {productName} over {count} seconden.",
+    "The update is in progress, leaving this page might interrupt the process in some environments." : "De update is bezig, deze pagina verlaten kan het updateproces in sommige omgevingen onderbreken.",
+    "App update required" : "Bijwerken App vereist",
+    "{productName} will be updated to version {version}" : "{productName} wordt bijgewerkt naar versie {version}",
+    "The theme {oldTheme} has been disabled." : "Het thema {oldTheme} is uitgeschakeld.",
+    "These incompatible apps will be disabled:" : "De volgende incompatibele apps worden uitgeschakeld:",
+    "Incompatible apps" : "Incompatibele apps",
+    "These apps will be updated:" : "Deze apps worden bijgewerkt:",
+    "Apps to update" : "Apps om bij te werken",
+    "{app} from {oldVersion} to {version}" : "{app} van{oldVersion} naar{version}",
+    "Please make sure that the database, the config folder and the data folder have been backed up before proceeding." : "Let erop dat de database, de config-map en de data-map zijn geback-upt voordat je verder gaat.",
+    "To avoid timeouts with larger installations, you can instead run the following command from your installation directory:" : "Om time-outs tijdens grotere installaties te voorkomen, kun je in plaats hiervan de volgende opdracht geven vanaf je installatiedirectory:",
+    "Start update" : "Begin de update",
+    "Continue to {productName}" : "Verder naar {productName}",
+    "Update to {version}" : "Geüpdatet naar {version}",
+    "Hide details" : "Verberg details",
+    "Show details" : "Bekijk details",
+    "Update details" : "Update details",
+    "Update needed" : "Update vereist",
+    "Please use the command line updater because you have a big instance with more than 50 accounts." : "Gebruik alsjeblieft de commandoregel updater omdat je een installatie hebt met meer dan 50 gebruikers.",
+    "Documentation" : "Documentatie",
+    "I know that if I continue doing the update via web UI has the risk, that the request runs into a timeout and could cause data loss, but I have a backup and know how to restore my instance in case of a failure." : "De update via de web UI heeft risico's. Het verzoek leidt mogelijk tot een time-out en kan tot verlies van gegevens leiden. Ik heb een back-up gemaakt en weet hoe deze te herstellen in het geval van een update mislukking.",
+    "Upgrade via web on my own risk" : "Web opwaarding is op eigen risico",
     "Search {types} …" : "Zoeken naar {types}…",
     "Choose {file}" : "Kies {file}",
     "Choose" : "Kies",
@@ -427,19 +445,13 @@ OC.L10N.register(
     "Group list is empty" : "Groepenlijst is leeg",
     "Unable to retrieve the group list" : "Kan groepenoverzicht niet ophalen",
     "seconds ago" : "seconden geleden",
-    "Connection to server lost" : "Verbinding met server verbroken",
-    "_Problem loading page, reloading in %n second_::_Problem loading page, reloading in %n seconds_" : ["Probleem met laden pagina, herladen over %n seconde","Probleem met laden pagina, herladen over %n seconden"],
     "Add to a project" : "Toevoegen aan een project",
-    "Show details" : "Bekijk details",
-    "Hide details" : "Verberg details",
     "Rename project" : "Hernoem project",
     "Failed to rename the project" : "Hernoemen van project is mislukt",
     "Failed to create a project" : "Aanmaken van project is mislukt",
     "Failed to add the item to the project" : "Item toevoegen aan project mislukt",
     "Connect items to a project to make them easier to find" : "Verbind items aan een project om ze eenvoudiger terug te vinden",
     "Type to search for existing projects" : "Type om bestaande projecten te vinden",
-    "New in" : "Nieuw in",
-    "View changelog" : "Bekijk wijzigingsoverzicht",
     "Close \"{dialogTitle}\" dialog" : "Sluit \"{dialogTitle}\" dialoog",
     "Email length is at max (255)" : "E-maillengte is op maximum (255)",
     "Clipboard not available, please copy manually" : "Klembord niet beschikbaar, kopieer handmatig a.u.b.",
@@ -491,20 +503,6 @@ OC.L10N.register(
     "Access through untrusted domain" : "Toegang via een niet vertrouwd domein",
     "Please contact your administrator. If you are an administrator, edit the \"trusted_domains\" setting in config/config.php like the example in config.sample.php." : "Neem contact op met je beheerder. Wanneer je een beheerder bent kun je de \"trusted_domains\" instelling bewerken in config/config.php zoals in het voorbeeld config.sample.php. ",
     "Further information how to configure this can be found in the %1$sdocumentation%2$s." : "Verdere informatie over hoe je dit instelt staat in de %1$s documentatie  %2$s.",
-    "App update required" : "Bijwerken App vereist",
-    "%1$s will be updated to version %2$s" : "%1$s wordt bijgewerkt naar versie %2$s",
-    "The following apps will be updated:" : "Deze apps worden bijgewerkt:",
-    "These incompatible apps will be disabled:" : "De volgende incompatibele apps worden uitgeschakeld:",
-    "The theme %s has been disabled." : "Het thema %s is uitgeschakeld.",
-    "Please make sure that the database, the config folder and the data folder have been backed up before proceeding." : "Let erop dat de database, de config-map en de data-map zijn geback-upt voordat je verder gaat.",
-    "Start update" : "Begin de update",
-    "To avoid timeouts with larger installations, you can instead run the following command from your installation directory:" : "Om time-outs tijdens grotere installaties te voorkomen, kun je in plaats hiervan de volgende opdracht geven vanaf je installatiedirectory:",
-    "Detailed logs" : "Gedetailleerde logs",
-    "Update needed" : "Update vereist",
-    "Please use the command line updater because you have a big instance with more than 50 accounts." : "Gebruik alsjeblieft de commandoregel updater omdat je een installatie hebt met meer dan 50 gebruikers.",
-    "For help, see the  <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">documentation</a>." : "Bekijk de <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">documentatie</a> voor hulp.",
-    "I know that if I continue doing the update via web UI has the risk, that the request runs into a timeout and could cause data loss, but I have a backup and know how to restore my instance in case of a failure." : "De update via de web UI heeft risico's. Het verzoek leidt mogelijk tot een time-out en kan tot verlies van gegevens leiden. Ik heb een back-up gemaakt en weet hoe deze te herstellen in het geval van een update mislukking.",
-    "Upgrade via web on my own risk" : "Web opwaarding is op eigen risico",
     "Maintenance mode" : "Onderhoudsmodus",
     "This %s instance is currently in maintenance mode, which may take a while." : "Deze %s staat momenteel in de onderhoudsstand, dat kan enige tijd duren.",
     "This page will refresh itself when the instance is available again." : "Deze pagina wordt ververst als de server weer beschikbaar is.",
@@ -519,6 +517,11 @@ OC.L10N.register(
     "<strong>These are your search results<script>alert(1)</script></strong>" : "<strong>Dit zijn je zoekresultaten<script>alert(1)</script></strong>",
     "new" : "nieuw",
     "_download %n file_::_download %n files_" : ["download %n bestand","download %n bestanden"],
+    "An error occurred." : "Er heeft zich een fout voorgedaan.",
+    "Please reload the page." : "Herlaad deze pagina.",
+    "The update was unsuccessful. For more information <a href=\"{url}\">check our forum post</a> covering this issue." : "De update was niet succesvol. Voor meer informatie <a href=\"{url}\">zie ons bericht op het forum</a> over dit probleem.",
+    "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud community</a>." : "De update is mislukt. Meld dit probleem aan de <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud community</a>.",
+    "_The update was successful. Redirecting you to {productName} in %n second._::_The update was successful. Redirecting you to {productName} in %n seconds._" : ["De update was succesvol. Redirecten naar {productName} over %nseconde.","De update was succesvol. Redirecten naar {productName} over %n seconden."],
     "Direct link copied to clipboard" : "Directe link gekopieerd naar klembord",
     "Searching …" : "Zoeken ...",
     "Logging in …" : "Inloggen...",
@@ -531,6 +534,10 @@ OC.L10N.register(
     "Loading more results …" : "Meer resultaten laden ...",
     "Search {types} …" : "Zoeken naar {types}…",
     "Saving …" : "Opslaan ...",
+    "Connection to server lost" : "Verbinding met server verbroken",
+    "_Problem loading page, reloading in %n second_::_Problem loading page, reloading in %n seconds_" : ["Probleem met laden pagina, herladen over %n seconde","Probleem met laden pagina, herladen over %n seconden"],
+    "New in" : "Nieuw in",
+    "View changelog" : "Bekijk wijzigingsoverzicht",
     "Very weak password" : "Zeer zwak wachtwoord",
     "Weak password" : "Zwak wachtwoord",
     "So-so password" : "Matig wachtwoord",
@@ -557,6 +564,11 @@ OC.L10N.register(
     "Installing …" : "Installeren …",
     "Please log in before granting %1$s access to your %2$s account." : "Eerst inloggen voordat je %1$s toegang geeft tot je %2$s account.",
     "Currently logged in as %1$s (%2$s)." : "Ingelogd als %1$s (%2$s).",
-    "You are about to grant %1$s access to your %2$s account." : "Je staat op het punt om %1$s toegang te verlenen tot je %2$s account."
+    "You are about to grant %1$s access to your %2$s account." : "Je staat op het punt om %1$s toegang te verlenen tot je %2$s account.",
+    "%1$s will be updated to version %2$s" : "%1$s wordt bijgewerkt naar versie %2$s",
+    "The following apps will be updated:" : "Deze apps worden bijgewerkt:",
+    "The theme %s has been disabled." : "Het thema %s is uitgeschakeld.",
+    "Detailed logs" : "Gedetailleerde logs",
+    "For help, see the  <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">documentation</a>." : "Bekijk de <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">documentatie</a> voor hulp."
 },
 "nplurals=2; plural=(n != 1);");
