@@ -198,15 +198,10 @@ OC.L10N.register(
     "Matroska video" : "Видеофайл в формате Matroska",
     "Windows Media video" : "Видеофайл в формате Windows Media",
     "AVI video" : "Видеофайл в формате AVI",
-    "The update is in progress, leaving this page might interrupt the process in some environments." : "Выполняется обновление. Не уходите с этой страницы, т.к. в некоторых случаях может прервать процесс.",
-    "Update to {version}" : "Обновление до версии {version}",
-    "An error occurred." : "Произошла ошибка.",
-    "Please reload the page." : "Обновите страницу.",
-    "The update was unsuccessful. For more information <a href=\"{url}\">check our forum post</a> covering this issue." : "Обновление не удалось. Больше информации  о данной проблеме можно найти <a href=\"{url}\">в сообщении на нашем форуме</a>.",
-    "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud community</a>." : "Обновление не удалось. Сообщите об этой проблеме <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">сообществу Nextcloud</a>.",
-    "Continue to {productName}" : "Перейти к {productName}",
-    "_The update was successful. Redirecting you to {productName} in %n second._::_The update was successful. Redirecting you to {productName} in %n seconds._" : ["Обновление выполнено успешно. Перенаправление в {productName} через %n секунду.","Обновление выполнено успешно. Перенаправление в {productName} через %n секунды.","Обновление выполнено успешно. Перенаправление в {productName} через %n секунд.","Обновление выполнено успешно. Перенаправление в {productName} через %n секунд."],
     "Done" : "Выполненные",
+    "Scan QR code to log in" : "Используйте QR-код для входа",
+    "Use {productName} mobile client you want to connect to scan the code" : "Используйте мобильное приложение {productName}, которое вы ходите подключить, для сканирования QR-кода.",
+    "Code will expire {timeCountdown} or after use" : "Срок действия кода истечёт через {timeCountdown} или после использования",
     "Applications menu" : "Меню приложений",
     "Apps" : "Приложения",
     "More apps" : "Ещё приложения",
@@ -230,7 +225,7 @@ OC.L10N.register(
     "Search in current app" : "Поиск в текущем приложении",
     "Clear search" : "Очистить поиск",
     "Search everywhere" : "Искать везде",
-    "Searching …" : "Поиск …",
+    "Searching …" : "Поиск…",
     "Start typing to search" : "Начните вводить символы для поиска",
     "Minimum search length is {minSearchLength} characters" : "Минимальная длина поиска - {minSearchLength} символов",
     "No matching results" : "Нет совпадающих результатов",
@@ -251,11 +246,13 @@ OC.L10N.register(
     "Results" : "Результаты",
     "Load more results" : "Загрузить дополнительные результаты",
     "Search in" : "Искать в",
+    "Partial matches" : "Частичные совпадения",
     "Log in" : "Войти",
     "Logging in …" : "Вход в систему …",
     "Log in to {productName}" : "Вход в {productName}",
     "Wrong login or password." : "Неверное имя пользователя или пароль.",
     "This account is disabled" : "Эта учётная запись отключена",
+    "Too many incorrect login attempts. Please try again in 30 seconds." : "Достигнуто максимально допустимое количество попыток входа. Попробуйте снова через 30 секунд.",
     "Account name or email" : "Учётная запись или адрес эл. почты",
     "Account name" : "Имя учётной записи",
     "Server side authentication failed!" : "Ошибка аутентификации на стороне сервера!",
@@ -309,10 +306,14 @@ OC.L10N.register(
     "Loading your contacts …" : "Загрузка контактов …",
     "Looking for {term} …" : "Поиск {term} …",
     "Search contacts" : "Поиск контактов",
-    "Reset search" : "Очистить поиск",
+    "Filter by team" : "Отбор по команде",
+    "All teams" : "Все команды",
+    "Search contacts in team {team}" : "Поиск контактов в команде {team}",
     "Search contacts …" : "Поиск контактов …",
+    "Reset search" : "Очистить поиск",
     "Could not load your contacts" : "Ошибка получения контактов",
     "No contacts found" : "Контактов не найдено",
+    "Contacts list" : "Список контактов",
     "Show all contacts" : "Показать все контакты",
     "Install the Contacts app" : "Установить приложение Контакты",
     "Search" : "Найти",
@@ -329,13 +330,17 @@ OC.L10N.register(
     "Login form is disabled." : "Форма входа отключена.",
     "The Nextcloud login form is disabled. Use another login option if available or contact your administration." : "Диалог входа отключен. Используйте другой способ входа или свяжитесь с администратором.",
     "Connect to your account" : "Вход в систему",
+    "Please log in before granting \"{client}\" access to your {instanceName} account." : "Для предоставления {client} доступа к своей учётной записи {instanceName} необходимо войти в систему.",
     "Security warning" : "Предупреждение безопасности",
     "If you are not trying to set up a new device or app, someone is trying to trick you into granting them access to your data. In this case do not proceed and instead contact your system administrator." : "Если вы не пытались настроить новое устройство или приложение, значит, кто-то пытается получить доступ к вашим данным. В этом случае свяжитесь с администратором системы.",
+    "Log in using password" : "Войти по паролю",
     "Alternative log in using app password" : "Другой способ входа с использованием пароля приложения",
     "Account connected" : "Аккаунт подключен",
     "Your client should now be connected!" : "Приложение-клиент подключено.",
     "You can close this window." : "Можете закрыть это окно.",
     "Account access" : "Доступ к аккаунту",
+    "Currently logged in as {userDisplayName} ({userId})." : "Вход в систему выполнен под именем {userDisplayName} ({userId}).",
+    "You are about to grant \"{client}\" access to your {instanceName} account." : "Вы предоставляете «{client}» доступ к своей учётной записи {instanceName}.",
     "More actions" : "Больше действий",
     "User menu" : "Меню пользователя",
     "Your guest name: {user}" : "Ваше гостевое имя: {user}",
@@ -383,8 +388,8 @@ OC.L10N.register(
     "Database tablespace" : "Табличное пространство базы данных",
     "Please specify the port number along with the host name (e.g., localhost:5432)." : "Пожалуйста укажите номер порта вместе с именем хоста (напр. localhost:5432)",
     "Database host" : "Хост базы данных",
-    "localhost" : "локальный хост",
-    "Installing …" : "Установка …",
+    "localhost" : "localhost",
+    "Installing …" : "Выполняется установка…",
     "Install" : "Установить",
     "Need help?" : "Требуется помощь?",
     "See the documentation" : "Посмотреть документацию",
@@ -393,6 +398,32 @@ OC.L10N.register(
     "Your browser is not supported. Please upgrade to a newer version or a supported one." : "Используемый браузер не поддерживается. Обновитесь до более новой версии или используйте другой браузер.",
     "Continue with this unsupported browser" : "Продолжить с использованием неподдерживаемого браузера",
     "Supported versions" : "Поддерживаемые версии",
+    "The update completed with warnings. Please check the details for more information." : "Обновление выполнено с предупреждениями, дополнительная информация доступна в подробных сведениях.",
+    "The update completed successfully." : "Обновление успешно завершено.",
+    "Preparing update…" : "Подготовка к обновлению…",
+    "You will be redirected to {productName} in {count} seconds." : "Перенаправление в {productName} через {count} сек.",
+    "The update is in progress, leaving this page might interrupt the process in some environments." : "Выполняется обновление. Не уходите с этой страницы, т.к. в некоторых случаях может прервать процесс.",
+    "App update required" : "Требуется обновление приложения",
+    "{productName} will be updated to version {version}" : "Приложение {productName} будет обновлено до версии {version}",
+    "The theme {oldTheme} has been disabled." : "Оформление {oldTheme} отключено.",
+    "These incompatible apps will be disabled:" : "Эти несовместимые приложения будут отключены:",
+    "Incompatible apps" : "Несовместимые приложения",
+    "These apps will be updated:" : "Следующие приложения будут обновлены:",
+    "Apps to update" : "Обновляемые приложения",
+    "{app} from {oldVersion} to {version}" : "{app} с версии {oldVersion} до версии {version}",
+    "Please make sure that the database, the config folder and the data folder have been backed up before proceeding." : "Перед продолжением убедитесь, что вы сделали резервную копию базы данных, каталога конфигурации и каталога с данными.",
+    "To avoid timeouts with larger installations, you can instead run the following command from your installation directory:" : "Чтобы избежать тайм-аутов в крупных установках, вместо этого можно выполнить следующую команду в каталоге установки:",
+    "Start update" : "Запустить обновление",
+    "Continue to {productName}" : "Перейти к {productName}",
+    "Update to {version}" : "Обновление до версии {version}",
+    "Hide details" : "Скрыть подробные сведения",
+    "Show details" : "Подробные сведения",
+    "Update details" : "Подробные сведения",
+    "Update needed" : "Требуется обновление",
+    "Please use the command line updater because you have a big instance with more than 50 accounts." : "Используйте инструмент командной строки для выполнения обновления, так как в этом развёртывании создано более 50 пользователей. ",
+    "Documentation" : "Документация",
+    "I know that if I continue doing the update via web UI has the risk, that the request runs into a timeout and could cause data loss, but I have a backup and know how to restore my instance in case of a failure." : "Я знаю, что в случае продолжения обновления через веб-интерфейс возникает риск тайм-аута запроса, который может привести к потере данных. У меня есть резервная копия, и я знаю, как восстановить систему в случае сбоя.",
+    "Upgrade via web on my own risk" : "Обновить используя веб-интерфейс на мой страх и риск",
     "Search {types} …" : "Поиск {types} …",
     "Choose {file}" : "Выбран «{file}»",
     "Choose" : "Выбрать",
@@ -418,19 +449,13 @@ OC.L10N.register(
     "Group list is empty" : "Список групп пуст",
     "Unable to retrieve the group list" : "Не удалось получить список групп",
     "seconds ago" : "только что",
-    "Connection to server lost" : "Потеряно подключение к серверу",
-    "_Problem loading page, reloading in %n second_::_Problem loading page, reloading in %n seconds_" : ["Возникла проблема при загрузке страницы, повторная попытка через %n секунду","Возникла проблема при загрузке страницы, повторная попытка через %n секунды","Возникла проблема при загрузке страницы, повторная попытка через %n секунд","Возникла проблема при загрузке страницы, повторная попытка через %n секунд"],
     "Add to a project" : "Добавить к проекту",
-    "Show details" : "Подробные сведения",
-    "Hide details" : "Скрыть подробные сведения",
     "Rename project" : "Переименовать проект",
     "Failed to rename the project" : "Не удалось переименовать проект",
     "Failed to create a project" : "Не удалось создать проект",
     "Failed to add the item to the project" : "Не удалось добавить элемент к проекту",
     "Connect items to a project to make them easier to find" : "Добавьте объекты в проект, чтобы их было легче найти",
     "Type to search for existing projects" : "Нажмите, чтобы найти существующий проект",
-    "New in" : "Новые возможности",
-    "View changelog" : "Просмотреть изменения",
     "Close \"{dialogTitle}\" dialog" : "Закрыть «{dialogTitle}»",
     "Email length is at max (255)" : "Максимальная длина адреса эл. почты (255 символов)",
     "Clipboard not available, please copy manually" : "Буфер обмена недоступен, пожалуйста, скопируйте вручную",
@@ -482,20 +507,6 @@ OC.L10N.register(
     "Access through untrusted domain" : "Доступ через недоверенный домен",
     "Please contact your administrator. If you are an administrator, edit the \"trusted_domains\" setting in config/config.php like the example in config.sample.php." : "Обратитесь к администратору. Если вы являетесь администратором этого сервера, отредактируйте параметр «trusted_domains» в файле «config/config.php». Пример настройки можно найти в файле «config/config.sample.php».",
     "Further information how to configure this can be found in the %1$sdocumentation%2$s." : "Дополнительная информация как это настроить может быть найдена в %1$sдокументации %2$s",
-    "App update required" : "Требуется обновление приложения",
-    "%1$s will be updated to version %2$s" : "%1$s будет обновлено до версии %2$s",
-    "The following apps will be updated:" : "Следующие приложения будут обновлены:",
-    "These incompatible apps will be disabled:" : "Эти несовместимые приложения будут отключены:",
-    "The theme %s has been disabled." : "Тема %s была отключена.",
-    "Please make sure that the database, the config folder and the data folder have been backed up before proceeding." : "Перед продолжением убедитесь, что вы сделали резервную копию базы данных, каталога конфигурации и каталога с данными.",
-    "Start update" : "Запустить обновление",
-    "To avoid timeouts with larger installations, you can instead run the following command from your installation directory:" : "Чтобы избежать тайм-аутов в крупных установках, вместо этого можно выполнить следующую команду в каталоге установки:",
-    "Detailed logs" : "Подробные журналы",
-    "Update needed" : "Требуется обновление",
-    "Please use the command line updater because you have a big instance with more than 50 accounts." : "Используйте инструмент командной строки для выполнения обновления, так как в этом развёртывании создано более 50 пользователей. ",
-    "For help, see the  <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">documentation</a>." : "Для получения помощи обратитесь к <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">документации</a>.",
-    "I know that if I continue doing the update via web UI has the risk, that the request runs into a timeout and could cause data loss, but I have a backup and know how to restore my instance in case of a failure." : "Я знаю, что в случае продолжения обновления через веб-интерфейс возникает риск тайм-аута запроса, который может привести к потере данных. У меня есть резервная копия, и я знаю, как восстановить систему в случае сбоя.",
-    "Upgrade via web on my own risk" : "Обновить используя веб-интерфейс на мой страх и риск",
     "Maintenance mode" : "Режим обслуживания",
     "This %s instance is currently in maintenance mode, which may take a while." : "Этот сервер %s находится в режиме технического обслуживания, которое может занять некоторое время.",
     "This page will refresh itself when the instance is available again." : "Эта страница обновится автоматически когда сервер снова станет доступен.",
@@ -510,6 +521,11 @@ OC.L10N.register(
     "<strong>These are your search results<script>alert(1)</script></strong>" : "<strong>Эти результаты поиска<script>alert(1)</script></strong>",
     "new" : "новый",
     "_download %n file_::_download %n files_" : ["скачать %n файл","скачать %n файла","скачать %n файлов","скачать %n файла"],
+    "An error occurred." : "Произошла ошибка.",
+    "Please reload the page." : "Обновите страницу.",
+    "The update was unsuccessful. For more information <a href=\"{url}\">check our forum post</a> covering this issue." : "Обновление не удалось. Больше информации  о данной проблеме можно найти <a href=\"{url}\">в сообщении на нашем форуме</a>.",
+    "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud community</a>." : "Обновление не удалось. Сообщите об этой проблеме <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">сообществу Nextcloud</a>.",
+    "_The update was successful. Redirecting you to {productName} in %n second._::_The update was successful. Redirecting you to {productName} in %n seconds._" : ["Обновление выполнено успешно. Перенаправление в {productName} через %n секунду.","Обновление выполнено успешно. Перенаправление в {productName} через %n секунды.","Обновление выполнено успешно. Перенаправление в {productName} через %n секунд.","Обновление выполнено успешно. Перенаправление в {productName} через %n секунд."],
     "Direct link copied to clipboard" : "Прямая ссылка, скопированная в буфер обмена",
     "Searching …" : "Поиск…",
     "Logging in …" : "Вход в систему…",
@@ -522,6 +538,10 @@ OC.L10N.register(
     "Loading more results …" : "Загрузка дополнительных результатов…",
     "Search {types} …" : "Поиск {types}…",
     "Saving …" : "Сохранение…",
+    "Connection to server lost" : "Потеряно подключение к серверу",
+    "_Problem loading page, reloading in %n second_::_Problem loading page, reloading in %n seconds_" : ["Возникла проблема при загрузке страницы, повторная попытка через %n секунду","Возникла проблема при загрузке страницы, повторная попытка через %n секунды","Возникла проблема при загрузке страницы, повторная попытка через %n секунд","Возникла проблема при загрузке страницы, повторная попытка через %n секунд"],
+    "New in" : "Новые возможности",
+    "View changelog" : "Просмотреть изменения",
     "Very weak password" : "Очень слабый пароль",
     "Weak password" : "Слабый пароль",
     "So-so password" : "Так себе пароль",
@@ -548,6 +568,11 @@ OC.L10N.register(
     "Installing …" : "Установка ...",
     "Please log in before granting %1$s access to your %2$s account." : "Для предоставления %1$s доступа к учётной записи %2$s необходимо войти в систему.",
     "Currently logged in as %1$s (%2$s)." : "Вход в систему выполнен под именем %1$s (%2$s).",
-    "You are about to grant %1$s access to your %2$s account." : "Вы собираетесь разрешить приложению %1$s доступ к своей учётной записи %2$s."
+    "You are about to grant %1$s access to your %2$s account." : "Вы собираетесь разрешить приложению %1$s доступ к своей учётной записи %2$s.",
+    "%1$s will be updated to version %2$s" : "%1$s будет обновлено до версии %2$s",
+    "The following apps will be updated:" : "Следующие приложения будут обновлены:",
+    "The theme %s has been disabled." : "Тема %s была отключена.",
+    "Detailed logs" : "Подробные журналы",
+    "For help, see the  <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">documentation</a>." : "Для получения помощи обратитесь к <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">документации</a>."
 },
 "nplurals=4; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<12 || n%100>14) ? 1 : n%10==0 || (n%10>=5 && n%10<=9) || (n%100>=11 && n%100<=14)? 2 : 3);");
