@@ -64,14 +64,6 @@ OC.L10N.register(
     "The following apps have been disabled: %s" : "Is aplicatziones in fatu sunt istadas disativadas: %s",
     "Already up to date" : "Giai agiornadu",
     "Unknown" : "Disconnotu",
-    "The update is in progress, leaving this page might interrupt the process in some environments." : "S'agiornamentu est in cursu, lassende sa pàgina su protzessu si diat pòdere  suspèndere.",
-    "Update to {version}" : "Agiorna a {version}",
-    "An error occurred." : "B'at àpidu un'errore.",
-    "Please reload the page." : "Torra a carrigare sa pàgina.",
-    "The update was unsuccessful. For more information <a href=\"{url}\">check our forum post</a> covering this issue." : "S'agiornamentu est andadu male. Pro àteras informatziones <a href=\"{url}\">controlla sa publicatzione subra de custu </a> in su forum.",
-    "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud community</a>." : "S'agiornamentu no est andadu bene. Sinnala custu problema a sa <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">comunidade de Nextcloud </a>.",
-    "Continue to {productName}" : "Sighi a {productName}",
-    "_The update was successful. Redirecting you to {productName} in %n second._::_The update was successful. Redirecting you to {productName} in %n seconds._" : ["S'agiornamentu est andadu bene. Indiritzende·ti a {productName} intre %n segundu.","S'agiornamentu est andadu bene. Indiritzende·ti a {productName} intre %n segundos."],
     "Applications menu" : "Menù de aplicatziones",
     "Apps" : "Aplicatziones",
     "More apps" : "Àteras aplicatziones",
@@ -192,6 +184,21 @@ OC.L10N.register(
     "Your browser is not supported. Please upgrade to a newer version or a supported one." : "Su navigadore tuo no est cumpatìbile. Atualiza·ddu a una versione noa o càmbia a unu navigadore cumpatìbile.",
     "Continue with this unsupported browser" : "Abarra in custu navigadore non cumpatìbile",
     "Supported versions" : "Versiones cumpatìbiles",
+    "The update is in progress, leaving this page might interrupt the process in some environments." : "S'agiornamentu est in cursu, lassende sa pàgina su protzessu si diat pòdere  suspèndere.",
+    "App update required" : "Agiornamentu de aplicatzione rechertu",
+    "These incompatible apps will be disabled:" : "Custas aplicatziones non cumpatìbiles ant a èssere disativadas:",
+    "These apps will be updated:" : "Custas aplicatziones ant a èssere agiornadas:",
+    "Please make sure that the database, the config folder and the data folder have been backed up before proceeding." : "Prima de sighire, assegura·ti ca sa base de datos, sa cartella de cunfiguratzione e cussa de is datos tenent una còpia de seguresa.",
+    "To avoid timeouts with larger installations, you can instead run the following command from your installation directory:" : "Pro evitare pasadas cun installatziones mannas, podes dare su cumandu in fatu dae sa cartella de installatzione:",
+    "Start update" : "Cumintza agiornamentu",
+    "Continue to {productName}" : "Sighi a {productName}",
+    "Update to {version}" : "Agiorna a {version}",
+    "Hide details" : "Cua detàllios",
+    "Show details" : "Mustra detàllios",
+    "Update needed" : "Tocat de agiornare",
+    "Documentation" : "Documentatzione",
+    "I know that if I continue doing the update via web UI has the risk, that the request runs into a timeout and could cause data loss, but I have a backup and know how to restore my instance in case of a failure." : "Giai dd'isco ca chi sigu cun s'agiornamentu via internet UI ddoe at s'arriscu chi sa rechesta arribet a una pasada e podet causare sa pèrdida de is datos, ma tèngio una còpia de seguresa e isco comente recuperare s'istàntzia in casu de errore.",
+    "Upgrade via web on my own risk" : "Agiorna via web suta responsabilidade mia",
     "Choose {file}" : "Sèbera {file}",
     "Choose" : "Sèbera",
     "Copy to {target}" : "Còpia a {target}",
@@ -216,19 +223,13 @@ OC.L10N.register(
     "Group list is empty" : "S'elencu de is grupos est bòida",
     "Unable to retrieve the group list" : "Non faghet a recuperare s'elencu de is grupos",
     "seconds ago" : "segundos a immoe",
-    "Connection to server lost" : "Connessione a su serbidore pèrdida",
-    "_Problem loading page, reloading in %n second_::_Problem loading page, reloading in %n seconds_" : ["Si seletzionas ambas is versiones, su documentu copiadu at a tènnere unu nùmeru in agiunta a su nùmene.","Problema in su carrigamentu de sa pàgina, torrende a carrigare intre %n segundos"],
     "Add to a project" : "Agiunghe a unu progetu",
-    "Show details" : "Mustra detàllios",
-    "Hide details" : "Cua detàllios",
     "Rename project" : "Torra a numenare su progetu",
     "Failed to rename the project" : "Impossìbile a numenare su progetu",
     "Failed to create a project" : "Impossìbile a creare unu progetu",
     "Failed to add the item to the project" : "No at fatu a agiunghere s'elementu a su progetu",
     "Connect items to a project to make them easier to find" : "Connete elementos a unu progetu pro chi siat prus fàtzile a ddos agatare",
     "Type to search for existing projects" : "Iscrie pro chircare is progetos chi ddoe sunt giai",
-    "New in" : "Prima borta in",
-    "View changelog" : "Càstia su registru de is càmbios",
     "Close \"{dialogTitle}\" dialog" : "Serra su cuadru de diàlogu \"{dialogTitle}\"",
     "Personal" : "Personale",
     "Accounts" : "Accounts",
@@ -275,19 +276,6 @@ OC.L10N.register(
     "Access through untrusted domain" : "Atzessu cun domìniu non seguru",
     "Please contact your administrator. If you are an administrator, edit the \"trusted_domains\" setting in config/config.php like the example in config.sample.php." : "Please contact your administrator. If you are an administrator, edit the \"trusted_domains\" setting in config/config.php like the example in config.sample.php.",
     "Further information how to configure this can be found in the %1$sdocumentation%2$s." : "Àteras informatziones pro sa cunfiguratzione ddas podes agatare in sa %1$sdocumentatzione%2$s.",
-    "App update required" : "Agiornamentu de aplicatzione rechertu",
-    "%1$s will be updated to version %2$s" : "%1$s at a èssere agiornada a sa versione %2$s",
-    "The following apps will be updated:" : "Is aplicatziones in fatu ant a èssere agiornadas:",
-    "These incompatible apps will be disabled:" : "Custas aplicatziones non cumpatìbiles ant a èssere disativadas:",
-    "The theme %s has been disabled." : "Su tema %s est istadu disativadu.",
-    "Please make sure that the database, the config folder and the data folder have been backed up before proceeding." : "Prima de sighire, assegura·ti ca sa base de datos, sa cartella de cunfiguratzione e cussa de is datos tenent una còpia de seguresa.",
-    "Start update" : "Cumintza agiornamentu",
-    "To avoid timeouts with larger installations, you can instead run the following command from your installation directory:" : "Pro evitare pasadas cun installatziones mannas, podes dare su cumandu in fatu dae sa cartella de installatzione:",
-    "Detailed logs" : "Registros detalliados",
-    "Update needed" : "Tocat de agiornare",
-    "For help, see the  <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">documentation</a>." : "Pro agiudos, càstia sa  <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">documentatzione</a>.",
-    "I know that if I continue doing the update via web UI has the risk, that the request runs into a timeout and could cause data loss, but I have a backup and know how to restore my instance in case of a failure." : "Giai dd'isco ca chi sigu cun s'agiornamentu via internet UI ddoe at s'arriscu chi sa rechesta arribet a una pasada e podet causare sa pèrdida de is datos, ma tèngio una còpia de seguresa e isco comente recuperare s'istàntzia in casu de errore.",
-    "Upgrade via web on my own risk" : "Agiorna via web suta responsabilidade mia",
     "Maintenance mode" : "Modalidade de mantenidura",
     "This %s instance is currently in maintenance mode, which may take a while." : "Immoe custa istàntzia de %s est in modalidade de mantenidura, e podet trigare unu pagu.",
     "This page will refresh itself when the instance is available again." : "Custa pàgina s'at a atualizare cando s'istàntzia at a èssere torra a disponimentu.",
@@ -302,6 +290,11 @@ OC.L10N.register(
     "<strong>These are your search results<script>alert(1)</script></strong>" : "<strong>Custos sunt is resurtados de sa chirca <script>avisu(1)</script></strong>",
     "new" : "nou",
     "_download %n file_::_download %n files_" : ["iscàrriga %n documentu","iscàrriga %narchìvios"],
+    "An error occurred." : "B'at àpidu un'errore.",
+    "Please reload the page." : "Torra a carrigare sa pàgina.",
+    "The update was unsuccessful. For more information <a href=\"{url}\">check our forum post</a> covering this issue." : "S'agiornamentu est andadu male. Pro àteras informatziones <a href=\"{url}\">controlla sa publicatzione subra de custu </a> in su forum.",
+    "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud community</a>." : "S'agiornamentu no est andadu bene. Sinnala custu problema a sa <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">comunidade de Nextcloud </a>.",
+    "_The update was successful. Redirecting you to {productName} in %n second._::_The update was successful. Redirecting you to {productName} in %n seconds._" : ["S'agiornamentu est andadu bene. Indiritzende·ti a {productName} intre %n segundu.","S'agiornamentu est andadu bene. Indiritzende·ti a {productName} intre %n segundos."],
     "Searching …" : "Chirchende …",
     "Logging in …" : "Intrende ...",
     "We have detected multiple invalid login attempts from your IP. Therefore your next login is throttled up to 30 seconds." : "Amus agatadu tentativos meda de atzessu dae s'IP tuo. Duncas s'atzessu tuo imbeniente dd'as a pòdere fàghere intre 30 segundos.",
@@ -313,6 +306,10 @@ OC.L10N.register(
     "Loading more results …" : "Carrighende àteros resurtados ...",
     "Search {types} …" : "Chirca {types} …",
     "Saving …" : "Sarvende …",
+    "Connection to server lost" : "Connessione a su serbidore pèrdida",
+    "_Problem loading page, reloading in %n second_::_Problem loading page, reloading in %n seconds_" : ["Si seletzionas ambas is versiones, su documentu copiadu at a tènnere unu nùmeru in agiunta a su nùmene.","Problema in su carrigamentu de sa pàgina, torrende a carrigare intre %n segundos"],
+    "New in" : "Prima borta in",
+    "View changelog" : "Càstia su registru de is càmbios",
     "Very weak password" : "Crae dèbile meda",
     "Weak password" : "Crae dèbile",
     "So-so password" : "Crae aici aici",
@@ -334,6 +331,11 @@ OC.L10N.register(
     "Only %s is available." : "%s isceti est a disponimentu.",
     "Installing …" : "Installende ...",
     "Please log in before granting %1$s access to your %2$s account." : "Faghe s'atzessu prima de permìtere a %1$s de intrare a su contu tuo de %2$s.",
-    "You are about to grant %1$s access to your %2$s account." : "Ses acanta de donare %1$s atzessu a su contu %2$s tuo."
+    "You are about to grant %1$s access to your %2$s account." : "Ses acanta de donare %1$s atzessu a su contu %2$s tuo.",
+    "%1$s will be updated to version %2$s" : "%1$s at a èssere agiornada a sa versione %2$s",
+    "The following apps will be updated:" : "Is aplicatziones in fatu ant a èssere agiornadas:",
+    "The theme %s has been disabled." : "Su tema %s est istadu disativadu.",
+    "Detailed logs" : "Registros detalliados",
+    "For help, see the  <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">documentation</a>." : "Pro agiudos, càstia sa  <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">documentatzione</a>."
 },
 "nplurals=2; plural=(n != 1);");
