@@ -197,14 +197,6 @@ OC.L10N.register(
     "Matroska video" : "Matroska видео",
     "Windows Media video" : "Windows Media видео",
     "AVI video" : "AVI видео",
-    "The update is in progress, leaving this page might interrupt the process in some environments." : "Ажурирање је у току. У неким окружењима, напуштање ове стране може да прекине овај процес.",
-    "Update to {version}" : "Ажурирај на {version}",
-    "An error occurred." : "Дошло је до грешке.",
-    "Please reload the page." : "Поново учитајте страницу.",
-    "The update was unsuccessful. For more information <a href=\"{url}\">check our forum post</a> covering this issue." : "Ажурирање није успело. За више информација <a href=\"{url}\">погледајте нашу објаву на форуму</a> која обрађује ову тему.",
-    "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud community</a>." : "Ажурирање није успело. Пријавите овај проблем <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Некстклауд заједници</a>.",
-    "Continue to {productName}" : "Наставите на {productName}",
-    "_The update was successful. Redirecting you to {productName} in %n second._::_The update was successful. Redirecting you to {productName} in %n seconds._" : ["Ажурирање је било успешно. Преусмеравате се на {productName} за %n секунду.","Ажурирање је било успешно. Преусмеравате се на {productName} за %n секунде.","Ажурирање је било успешно. Преусмеравате се на {productName} за  %n секунди."],
     "Done" : "Завршено",
     "Applications menu" : "Мени апликација",
     "Apps" : "Апликације",
@@ -307,8 +299,8 @@ OC.L10N.register(
     "Loading your contacts …" : "Учитавају се ваши контакти …",
     "Looking for {term} …" : "Тражи се {term}  …",
     "Search contacts" : "Претрага контакта",
-    "Reset search" : "Ресетуј претрагу",
     "Search contacts …" : "Претрага контаката …",
+    "Reset search" : "Ресетуј претрагу",
     "Could not load your contacts" : "Не могу да учитам Ваше контакте",
     "No contacts found" : "Контакти нису нађени",
     "Show all contacts" : "Прикажи све контакте",
@@ -391,6 +383,21 @@ OC.L10N.register(
     "Your browser is not supported. Please upgrade to a newer version or a supported one." : "Ваш веб читач није подржан. Молимо вас да га ажурирате на новију верзију, или да инсталирате подржани читач.",
     "Continue with this unsupported browser" : "Настави са овим неподржаним читачем",
     "Supported versions" : "Подржане верзије",
+    "The update is in progress, leaving this page might interrupt the process in some environments." : "Ажурирање је у току. У неким окружењима, напуштање ове стране може да прекине овај процес.",
+    "App update required" : "Потребно ажурирање апликације",
+    "These incompatible apps will be disabled:" : "Ове неусаглашене апликације биће онемогућене:",
+    "Please make sure that the database, the config folder and the data folder have been backed up before proceeding." : "Проверите да ли сте направили резервну копију фасцикли са подешавањима и подацима пре него што наставите.",
+    "To avoid timeouts with larger installations, you can instead run the following command from your installation directory:" : "Да избегнете прекорачење времена одзива на већим инсталацијама, можете покренути следећу команду у инсталационом директоријуму:",
+    "Start update" : "Почни ажурирање",
+    "Continue to {productName}" : "Наставите на {productName}",
+    "Update to {version}" : "Ажурирај на {version}",
+    "Hide details" : "Сакриј детаље",
+    "Show details" : "Прикажи детаље",
+    "Update needed" : "Потребно је ажурирање",
+    "Please use the command line updater because you have a big instance with more than 50 accounts." : "Молимо вас да употребите ажурирање из конзоле пошто имате велику инстанцу са више од 50 налога.",
+    "Documentation" : "Документација",
+    "I know that if I continue doing the update via web UI has the risk, that the request runs into a timeout and could cause data loss, but I have a backup and know how to restore my instance in case of a failure." : "Свестан сам да уколико наставим ажурирање преко веб сучеља, постоји ризик да захтеву истекне време за извршење и да то може да изазове губитак података, али имам резервну копију и знам како да је повратим у случају грешке.",
+    "Upgrade via web on my own risk" : "Надогради преко веба на сопствену одговорност",
     "Search {types} …" : "Претрага {types} …",
     "Choose {file}" : "Изабери {file}",
     "Choose" : "Изаберите",
@@ -416,19 +423,13 @@ OC.L10N.register(
     "Group list is empty" : "Списак група је празан",
     "Unable to retrieve the group list" : "Не могу да добавим списак група",
     "seconds ago" : "пре пар секунди",
-    "Connection to server lost" : "Изгубљена је веза са сервером",
-    "_Problem loading page, reloading in %n second_::_Problem loading page, reloading in %n seconds_" : ["Грешка приликом учитавања стране, пробам поново за %n секунду","Грешка приликом учитавања стране, пробам поново за %n секунде","Грешка приликом учитавања стране, пробам поново за %n секунди"],
     "Add to a project" : "Додај у пројекат",
-    "Show details" : "Прикажи детаље",
-    "Hide details" : "Сакриј детаље",
     "Rename project" : "Преименуј пројекат",
     "Failed to rename the project" : "Грешка при преименовању пројекат",
     "Failed to create a project" : "Грешка при креирању пројекта",
     "Failed to add the item to the project" : "Грешка приликом додавања ставке у пројекат",
     "Connect items to a project to make them easier to find" : "Повежите ставке у пројекат да Вам буде лакше да их нађете",
     "Type to search for existing projects" : "Крените да куцате да тражите постојеће пројекте",
-    "New in" : "Ново у",
-    "View changelog" : "Погледајте дневник измена",
     "Close \"{dialogTitle}\" dialog" : "Затвори дијалог „{dialogTitle}”",
     "Email length is at max (255)" : "Дужина и-мејла је максимална (255)",
     "Clipboard not available, please copy manually" : "Клипборд није доступан, молимо вас да ручно копирате",
@@ -480,20 +481,6 @@ OC.L10N.register(
     "Access through untrusted domain" : "Приступ кроз небезбедни домен",
     "Please contact your administrator. If you are an administrator, edit the \"trusted_domains\" setting in config/config.php like the example in config.sample.php." : "Контактирајте Вашег администратора. Ако сте Ви администратор, измените \"trusted_domains\" подешавање у config/config.php као у примеру config.sample.php.",
     "Further information how to configure this can be found in the %1$sdocumentation%2$s." : "Више информација о томе како ово подесити можете да нађете у %1$s документацији%2$s.",
-    "App update required" : "Потребно ажурирање апликације",
-    "%1$s will be updated to version %2$s" : "%1$s ће бити ажуриран на верзију %2$s",
-    "The following apps will be updated:" : "Следеће апликације ће бити ажуриране:",
-    "These incompatible apps will be disabled:" : "Ове неусаглашене апликације биће онемогућене:",
-    "The theme %s has been disabled." : "Тема %s је онемогућена.",
-    "Please make sure that the database, the config folder and the data folder have been backed up before proceeding." : "Проверите да ли сте направили резервну копију фасцикли са подешавањима и подацима пре него што наставите.",
-    "Start update" : "Почни ажурирање",
-    "To avoid timeouts with larger installations, you can instead run the following command from your installation directory:" : "Да избегнете прекорачење времена одзива на већим инсталацијама, можете покренути следећу команду у инсталационом директоријуму:",
-    "Detailed logs" : "Детаљни дневници",
-    "Update needed" : "Потребно је ажурирање",
-    "Please use the command line updater because you have a big instance with more than 50 accounts." : "Молимо вас да употребите ажурирање из конзоле пошто имате велику инстанцу са више од 50 налога.",
-    "For help, see the  <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">documentation</a>." : "За помоћ, погледајте <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">документацију</a>.",
-    "I know that if I continue doing the update via web UI has the risk, that the request runs into a timeout and could cause data loss, but I have a backup and know how to restore my instance in case of a failure." : "Свестан сам да уколико наставим ажурирање преко веб сучеља, постоји ризик да захтеву истекне време за извршење и да то може да изазове губитак података, али имам резервну копију и знам како да је повратим у случају грешке.",
-    "Upgrade via web on my own risk" : "Надогради преко веба на сопствену одговорност",
     "Maintenance mode" : "Режим одржавања",
     "This %s instance is currently in maintenance mode, which may take a while." : "Овај %s је тренутно у режиму одржавања што може потрајати.",
     "This page will refresh itself when the instance is available again." : "Ова страница ће се сама освежити када инстанца постане поново доступна.",
@@ -508,6 +495,11 @@ OC.L10N.register(
     "<strong>These are your search results<script>alert(1)</script></strong>" : "<strong>Ово су резултати Ваше претраге<script>alert(1)</script></strong>",
     "new" : "ново",
     "_download %n file_::_download %n files_" : ["преузми %n фајл","преузми %n фајла","преузми %n фајлова"],
+    "An error occurred." : "Дошло је до грешке.",
+    "Please reload the page." : "Поново учитајте страницу.",
+    "The update was unsuccessful. For more information <a href=\"{url}\">check our forum post</a> covering this issue." : "Ажурирање није успело. За више информација <a href=\"{url}\">погледајте нашу објаву на форуму</a> која обрађује ову тему.",
+    "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud community</a>." : "Ажурирање није успело. Пријавите овај проблем <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Некстклауд заједници</a>.",
+    "_The update was successful. Redirecting you to {productName} in %n second._::_The update was successful. Redirecting you to {productName} in %n seconds._" : ["Ажурирање је било успешно. Преусмеравате се на {productName} за %n секунду.","Ажурирање је било успешно. Преусмеравате се на {productName} за %n секунде.","Ажурирање је било успешно. Преусмеравате се на {productName} за  %n секунди."],
     "Direct link copied to clipboard" : "Директни линк је копиран у клипборд",
     "Searching …" : "Тражим…",
     "Logging in …" : "Пријављивање …",
@@ -520,6 +512,10 @@ OC.L10N.register(
     "Loading more results …" : "Учитавам још резултата…",
     "Search {types} …" : "Претражи {types}…",
     "Saving …" : "Чувам…",
+    "Connection to server lost" : "Изгубљена је веза са сервером",
+    "_Problem loading page, reloading in %n second_::_Problem loading page, reloading in %n seconds_" : ["Грешка приликом учитавања стране, пробам поново за %n секунду","Грешка приликом учитавања стране, пробам поново за %n секунде","Грешка приликом учитавања стране, пробам поново за %n секунди"],
+    "New in" : "Ново у",
+    "View changelog" : "Погледајте дневник измена",
     "Very weak password" : "Веома слаба лозинка",
     "Weak password" : "Слаба лозинка",
     "So-so password" : "Осредња лозинка",
@@ -546,6 +542,11 @@ OC.L10N.register(
     "Installing …" : "Инсталирам ...",
     "Please log in before granting %1$s access to your %2$s account." : "Прво се пријавите пре него што одобрите привилегију %1$s приступ Вашем налогу %2$s.",
     "Currently logged in as %1$s (%2$s)." : "Тренутно пријављен као %1$s (%2$s).",
-    "You are about to grant %1$s access to your %2$s account." : "Управо ћете одобрити %1$s приступ Вашем %2$s налогу."
+    "You are about to grant %1$s access to your %2$s account." : "Управо ћете одобрити %1$s приступ Вашем %2$s налогу.",
+    "%1$s will be updated to version %2$s" : "%1$s ће бити ажуриран на верзију %2$s",
+    "The following apps will be updated:" : "Следеће апликације ће бити ажуриране:",
+    "The theme %s has been disabled." : "Тема %s је онемогућена.",
+    "Detailed logs" : "Детаљни дневници",
+    "For help, see the  <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">documentation</a>." : "За помоћ, погледајте <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">документацију</a>."
 },
 "nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);");
