@@ -90,14 +90,6 @@ OC.L10N.register(
     "Microsoft Access database" : "ฐานข้อมูล Microsoft Access",
     "Microsoft OneNote document" : "เอกสาร Microsoft OneNote",
     "Unknown" : "ไม่ทราบ",
-    "The update is in progress, leaving this page might interrupt the process in some environments." : "กำลังดำเนินการอัปเกรด หากออกจากหน้านี้อาจเกิดปัญหาในบางสภาพแวดล้อม",
-    "Update to {version}" : "อัปเดตเป็น {version}",
-    "An error occurred." : "เกิดข้อผิดพลาด",
-    "Please reload the page." : "โปรดโหลดหน้าเว็บใหม่",
-    "The update was unsuccessful. For more information <a href=\"{url}\">check our forum post</a> covering this issue." : "การอัปเดตไม่สำเร็จ สำหรับข้อมูลเพิ่มเติม <a href=\"{url}\">ดูโพสต์ของเราในฟอรัม</a>เกี่ยวกับปัญหานี้",
-    "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud community</a>." : "การอัปเดตไม่สำเร็จ กรุณารายงานปัญหานี้ไปยัง<a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">ชุมชน Nextcloud</a>",
-    "Continue to {productName}" : "เข้าสู่ {productName}",
-    "_The update was successful. Redirecting you to {productName} in %n second._::_The update was successful. Redirecting you to {productName} in %n seconds._" : ["การอัปเดตเสร็จสมบูรณ์ กำลังนำคุณไปที่ {productName} ใน %n วินาที"],
     "Applications menu" : "เมนูแอปพลิเคชัน",
     "Apps" : "แอป",
     "More apps" : "แอปเพิ่มเติม",
@@ -218,6 +210,21 @@ OC.L10N.register(
     "Your browser is not supported. Please upgrade to a newer version or a supported one." : "เบราว์เซอร์ของคุณไม่ได้รับการสนับสนุน กรุณาอัปเกรดเป็นรุ่นที่ใหม่กว่าหรือเบราว์เซอร์ที่สนับสนุน",
     "Continue with this unsupported browser" : "ดำเนินการต่อด้วยเบราว์เซอร์นี้ที่ไม่สนับสนุน",
     "Supported versions" : "รุ่นที่สนับสนุน",
+    "The update is in progress, leaving this page might interrupt the process in some environments." : "กำลังดำเนินการอัปเกรด หากออกจากหน้านี้อาจเกิดปัญหาในบางสภาพแวดล้อม",
+    "App update required" : "จำเป็นต้องอัปเดตแอป",
+    "These incompatible apps will be disabled:" : "แอปเหล่านี้เข้ากันไม่ได้ และจะถูกปิดการใช้งาน:",
+    "These apps will be updated:" : "แอพพลิเคชันเหล่านี้จะถูกอัพเดท:",
+    "Please make sure that the database, the config folder and the data folder have been backed up before proceeding." : "โปรดตรวจสอบว่าได้ทำการสำรองข้อมูลของฐานข้อมูล โฟลเดอร์ config และโฟลเดอร์ data ก่อนดำเนินการ",
+    "To avoid timeouts with larger installations, you can instead run the following command from your installation directory:" : "เพื่อหลีกเลี่ยงการหมดเวลากับการติดตั้งขนาดใหญ่ คุณสามารถเรียกใช้คำสั่งต่อไปนี้จากไดเรกทอรีการติดตั้งของคุณ:",
+    "Start update" : "เริ่มต้นอัปเดต",
+    "Continue to {productName}" : "เข้าสู่ {productName}",
+    "Update to {version}" : "อัปเดตเป็น {version}",
+    "Hide details" : "ซ่อนข้อมูล",
+    "Show details" : "แสดงข้อมูล",
+    "Update needed" : "จำเป็นต้องอัปเดต",
+    "Documentation" : "เอกสารประกอบ",
+    "I know that if I continue doing the update via web UI has the risk, that the request runs into a timeout and could cause data loss, but I have a backup and know how to restore my instance in case of a failure." : "ฉันทราบว่าการดำเนินการอัปเดตผ่าน UI เว็บมีความเสี่ยง และหากคำขอหมดเวลาอาจทำให้ข้อมูลสูญหาย แต่ฉันได้สำรองข้อมูลไว้แล้วและทราบวิธีการกู้คืนข้อมูลหากเกิดข้อผิดพลาด",
+    "Upgrade via web on my own risk" : "อัปเกรดผ่านเว็บบนความเสี่ยงของฉัน",
     "Choose {file}" : "เลือก {file}",
     "Choose" : "เลือก",
     "Copy to {target}" : "คัดลอกไปยัง {target}",
@@ -241,19 +248,13 @@ OC.L10N.register(
     "Group list is empty" : "รายชื่อกลุ่มว่างอยู่",
     "Unable to retrieve the group list" : "ไม่สามารถดึงรายชื่อกลุ่ม",
     "seconds ago" : "วินาทีที่แล้ว",
-    "Connection to server lost" : "การเชื่อมต่อไปยังเซิร์ฟเวอร์สูญหาย",
-    "_Problem loading page, reloading in %n second_::_Problem loading page, reloading in %n seconds_" : ["เกิดปัญหาขณะโหลดหน้าเว็บ จะโหลดหน้าเว็บใหม่ใน %n วินาที"],
     "Add to a project" : "เพิ่มไปยังโครงการ",
-    "Show details" : "แสดงข้อมูล",
-    "Hide details" : "ซ่อนข้อมูล",
     "Rename project" : "เปลี่ยนชื่อโครงการ",
     "Failed to rename the project" : "ไม่สามารถเปลี่ยนชื่อโครงการ",
     "Failed to create a project" : "ไม่สามารถสร้างโครงการ",
     "Failed to add the item to the project" : "ไม่สามารถเพิ่มรายการเข้าสู่โครงการ",
     "Connect items to a project to make them easier to find" : "เชื่อมต่อรายการต่าง ๆ เข้าสู่โครงการเพื่อให้หาได้ง่ายขึ้น",
     "Type to search for existing projects" : "พิมพ์เพื่อค้นหาโครงการที่มีอยู่",
-    "New in" : "ใหม่ใน",
-    "View changelog" : "ดูบันทึกการเปลี่ยนแปลง",
     "Close \"{dialogTitle}\" dialog" : "ปิดกล่องโต้ตอบ \"{dialogTitle}\"",
     "Personal" : "ส่วนตัว",
     "Accounts" : "บัญชี",
@@ -301,19 +302,6 @@ OC.L10N.register(
     "Access through untrusted domain" : "เข้าใช้งานผ่านโดเมนที่ไม่เชื่อถือ",
     "Please contact your administrator. If you are an administrator, edit the \"trusted_domains\" setting in config/config.php like the example in config.sample.php." : "กรุณาติดต่อผู้ดูแลระบบของคุณ ถ้าคุณเป็นผู้ดูแลระบบ ให้แก้ไขการตั้งค่า \"trusted_domains\" ใน config/config.php ตามตัวอย่างใน config.sample.php",
     "Further information how to configure this can be found in the %1$sdocumentation%2$s." : "ข้อมูลเพิ่มเติมสำหรับวิธีการกำหนดค่านี้อยู่ใน%1$sเอกสารประกอบ%2$s",
-    "App update required" : "จำเป็นต้องอัปเดตแอป",
-    "%1$s will be updated to version %2$s" : "%1$s จะถูกอัปเดตเป็นรุ่น %2$s",
-    "The following apps will be updated:" : "แอปต่อไปนี้จะถูกอัปเดต:",
-    "These incompatible apps will be disabled:" : "แอปเหล่านี้เข้ากันไม่ได้ และจะถูกปิดการใช้งาน:",
-    "The theme %s has been disabled." : "ธีม %s ถูกปิดการใช้งาน",
-    "Please make sure that the database, the config folder and the data folder have been backed up before proceeding." : "โปรดตรวจสอบว่าได้ทำการสำรองข้อมูลของฐานข้อมูล โฟลเดอร์ config และโฟลเดอร์ data ก่อนดำเนินการ",
-    "Start update" : "เริ่มต้นอัปเดต",
-    "To avoid timeouts with larger installations, you can instead run the following command from your installation directory:" : "เพื่อหลีกเลี่ยงการหมดเวลากับการติดตั้งขนาดใหญ่ คุณสามารถเรียกใช้คำสั่งต่อไปนี้จากไดเรกทอรีการติดตั้งของคุณ:",
-    "Detailed logs" : "บันทึกอย่างละเอียด",
-    "Update needed" : "จำเป็นต้องอัปเดต",
-    "For help, see the  <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">documentation</a>." : "สำหรับความช่วยเหลือ ดู<a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">เอกสารประกอบ</a>",
-    "I know that if I continue doing the update via web UI has the risk, that the request runs into a timeout and could cause data loss, but I have a backup and know how to restore my instance in case of a failure." : "ฉันทราบว่าการดำเนินการอัปเดตผ่าน UI เว็บมีความเสี่ยง และหากคำขอหมดเวลาอาจทำให้ข้อมูลสูญหาย แต่ฉันได้สำรองข้อมูลไว้แล้วและทราบวิธีการกู้คืนข้อมูลหากเกิดข้อผิดพลาด",
-    "Upgrade via web on my own risk" : "อัปเกรดผ่านเว็บบนความเสี่ยงของฉัน",
     "Maintenance mode" : "โหมดการบำรุงรักษา",
     "This %s instance is currently in maintenance mode, which may take a while." : "เซิร์ฟเวอร์ %s นี้อยู่ในโหมดการบำรุงรักษา ซึ่งอาจใช้เวลาสักครู่",
     "This page will refresh itself when the instance is available again." : "หน้านี้จะรีเฟรชตัวเองเมื่อเซิร์ฟเวอร์สามารถใช้ได้อีกครั้ง",
@@ -328,6 +316,11 @@ OC.L10N.register(
     "<strong>These are your search results<script>alert(1)</script></strong>" : "<strong>ผลลัพธ์การค้นหาของคุณ<script>alert(1)</script></strong>",
     "new" : "ใหม่",
     "_download %n file_::_download %n files_" : ["ดาวน์โหลด %n ไฟล์"],
+    "An error occurred." : "เกิดข้อผิดพลาด",
+    "Please reload the page." : "โปรดโหลดหน้าเว็บใหม่",
+    "The update was unsuccessful. For more information <a href=\"{url}\">check our forum post</a> covering this issue." : "การอัปเดตไม่สำเร็จ สำหรับข้อมูลเพิ่มเติม <a href=\"{url}\">ดูโพสต์ของเราในฟอรัม</a>เกี่ยวกับปัญหานี้",
+    "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud community</a>." : "การอัปเดตไม่สำเร็จ กรุณารายงานปัญหานี้ไปยัง<a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">ชุมชน Nextcloud</a>",
+    "_The update was successful. Redirecting you to {productName} in %n second._::_The update was successful. Redirecting you to {productName} in %n seconds._" : ["การอัปเดตเสร็จสมบูรณ์ กำลังนำคุณไปที่ {productName} ใน %n วินาที"],
     "Searching …" : "กำลังค้นหา …",
     "Logging in …" : "กำลังเข้าสู่ระบบ ...",
     "We have detected multiple invalid login attempts from your IP. Therefore your next login is throttled up to 30 seconds." : "เราตรวจพบการเข้าสู่ระบบที่ไม่ถูกต้องจากที่อยู่ IP ของคุณหลายครั้ง การเข้าสู่ระบบถัดไปของคุณถูกควบคุมเป็นเวลาอย่างมาก 30 วินาที",
@@ -339,6 +332,10 @@ OC.L10N.register(
     "Loading more results …" : "กำลังโหลดผลลัพธ์เพิ่มเติม …",
     "Search {types} …" : "ค้นหา {types} …",
     "Saving …" : "กำลังบันทึก …",
+    "Connection to server lost" : "การเชื่อมต่อไปยังเซิร์ฟเวอร์สูญหาย",
+    "_Problem loading page, reloading in %n second_::_Problem loading page, reloading in %n seconds_" : ["เกิดปัญหาขณะโหลดหน้าเว็บ จะโหลดหน้าเว็บใหม่ใน %n วินาที"],
+    "New in" : "ใหม่ใน",
+    "View changelog" : "ดูบันทึกการเปลี่ยนแปลง",
     "Very weak password" : "รหัสผ่านระดับต่ำมาก",
     "Weak password" : "รหัสผ่านระดับต่ำ",
     "So-so password" : "รหัสผ่านระดับปกติ",
@@ -362,6 +359,11 @@ OC.L10N.register(
     "Installing …" : "กำลังติดตั้ง …",
     "Please log in before granting %1$s access to your %2$s account." : "กรุณาเข้าสู่ระบบก่อนอนุญาตให้ %1$s เข้าถึงบัญชี %2$s ของคุณ",
     "Currently logged in as %1$s (%2$s)." : "ขณะนี้เข้าสู่ระบบเป็น %1$s (%2$s)",
-    "You are about to grant %1$s access to your %2$s account." : "คุณกำลังจะอนุญาตให้ %1$s เข้าถึงบัญชี %2$s ของคุณ"
+    "You are about to grant %1$s access to your %2$s account." : "คุณกำลังจะอนุญาตให้ %1$s เข้าถึงบัญชี %2$s ของคุณ",
+    "%1$s will be updated to version %2$s" : "%1$s จะถูกอัปเดตเป็นรุ่น %2$s",
+    "The following apps will be updated:" : "แอปต่อไปนี้จะถูกอัปเดต:",
+    "The theme %s has been disabled." : "ธีม %s ถูกปิดการใช้งาน",
+    "Detailed logs" : "บันทึกอย่างละเอียด",
+    "For help, see the  <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">documentation</a>." : "สำหรับความช่วยเหลือ ดู<a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">เอกสารประกอบ</a>"
 },
 "nplurals=1; plural=0;");
