@@ -45,6 +45,8 @@ OC.L10N.register(
     "Input text is too long" : "Введений текст задовгий",
     "Requested task type does not exist" : "Запитаний вид завдання відсутній",
     "Necessary language model provider is not available" : "Постачальний потрібної мовної моделі недоступний",
+    "Cannot generate more than 12 images" : "Можна зґенерувати не більше 12 зображень",
+    "Cannot generate less than 1 image" : "Зґенерувати можна не менше 1 зображення",
     "No text to image provider is available" : "Відсутній постачальник конвертування тексту у зображення",
     "Image not found" : "Зображення відсутнє",
     "No translation provider available" : "Постачальник послуг перекладу недоступний",
@@ -198,15 +200,10 @@ OC.L10N.register(
     "Matroska video" : "Відео Matroska",
     "Windows Media video" : "Відео Windows Media",
     "AVI video" : "Відео AVI",
-    "The update is in progress, leaving this page might interrupt the process in some environments." : "Відбувається оновлення. Не залишайте цю сторінку, це може перервати процес у деяких середовищах.",
-    "Update to {version}" : "Оновлення до {version}",
-    "An error occurred." : "Виникла помилка.",
-    "Please reload the page." : "Будь ласка, перезавантажте сторінку.",
-    "The update was unsuccessful. For more information <a href=\"{url}\">check our forum post</a> covering this issue." : "Оновлення не вдалося. За інформацією <a href=\"{url}\">зверніться до повідомлення на форумі</a>, що описує цю проблему.",
-    "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud community</a>." : "Оновлення не вдалося. Будь ласка, повідомте про це питання в <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">спільноту Nextcloud</a>.",
-    "Continue to {productName}" : "Перейти до {productName}",
-    "_The update was successful. Redirecting you to {productName} in %n second._::_The update was successful. Redirecting you to {productName} in %n seconds._" : ["Оновлення пройшло успішно. Переспрямування на {productName} за %n секунду.","Оновлення пройшло успішно. Переспрямування до {productName} за лічені %n секунди.","Оновлення пройшло успішно. Переспрямування до {productName} за лічені %n секунди.","Оновлення пройшло успішно. Переспрямування до {productName} за лічені %n секунди."],
     "Done" : "Готово",
+    "Scan QR code to log in" : "Відскануйте код QR для входу",
+    "Use {productName} mobile client you want to connect to scan the code" : "Скористайтеся мобільним застосунком {productName}, до якого ви бажаєте під'єднатися, щоби відсканувати код",
+    "Code will expire {timeCountdown} or after use" : "Термін дії коду завершиться через {timeCountdown} або після використання",
     "Applications menu" : "Меню застосунків",
     "Apps" : "Застосунки",
     "More apps" : "Більше застосунків",
@@ -220,7 +217,7 @@ OC.L10N.register(
     "Failed to add the public link to your Nextcloud" : "Не вдалося додати публічне посилання до вашого Nextcloud",
     "Federated user" : "Обʼєднаний користувач",
     "user@your-nextcloud.org" : "користувач@ваш-nextcloud.org",
-    "Create share" : "Передати у публічний доступ",
+    "Create share" : "Створити спільний ресурс",
     "Direct link copied" : "Пряме посилання скопійовано",
     "Please copy the link manually:" : "Будь ласка, скопіюйте посилання вручну:",
     "Custom date range" : "Власний вибір проміжку",
@@ -260,7 +257,7 @@ OC.L10N.register(
     "Too many incorrect login attempts. Please try again in 30 seconds." : "Забагато спроб неправильного входу. Спробуйте ще раз за 30 секунд.",
     "Account name or email" : "Ім'я користувача або електронна пошта",
     "Account name" : "Назва облікового запису",
-    "Server side authentication failed!" : "Невдала авторизація на стороні сервера!",
+    "Server side authentication failed!" : "Невдала автентифікація на стороні сервера!",
     "Please contact your administrator." : "Будь ласка, зверніться до вашого Адміністратора.",
     "Session error" : "Помилка сеансу",
     "It appears your session token has expired, please refresh the page and try again." : "Здається, термін дії вашого токену сеансу закінчився, будь ласка, оновіть сторінку і спробуйте ще раз.",
@@ -281,7 +278,7 @@ OC.L10N.register(
     "Couldn't send reset email. Please contact your administrator." : "Не вдалося надіслати повідомлення для відновлення пароля. Прохання сконтактувати з адміністратором.",
     "Password cannot be changed. Please contact your administrator." : "Пароль не можна змінити. Будь ласка, зверніться до свого адміністратора.",
     "New password" : "Новий пароль",
-    "Your files are encrypted. There will be no way to get your data back after your password is reset. If you are not sure what to do, please contact your administrator before you continue. Do you really want to continue?" : "Ваші файли зашифровано. У разі перевстановлення паролю ви не зможете отримати доступ до них. Якщо ви не впевнені, що робити, будь ласка, сконтактуйте з адміністратором перед продовженням. Дійсно продовжити?",
+    "Your files are encrypted. There will be no way to get your data back after your password is reset. If you are not sure what to do, please contact your administrator before you continue. Do you really want to continue?" : "Ваші файли зашифровано. У разі перевстановлення пароля ви не зможете отримати доступ до них. Якщо ви не впевнені, що робити, будь ласка, сконтактуйте з адміністратором перед продовженням. Дійсно продовжити?",
     "I know what I'm doing" : "Я знаю що роблю",
     "Resetting password" : "Відновлення пароля",
     "Schedule work & meetings, synced with all your devices." : "Планування роботи та зустрічей із синхронізацією зі всіма вашими пристроями",
@@ -311,10 +308,14 @@ OC.L10N.register(
     "Loading your contacts …" : "Завантаження контактів ...",
     "Looking for {term} …" : "Шукайте {term}...",
     "Search contacts" : "Шукати контакти",
-    "Reset search" : "Повторити пошук",
+    "Filter by team" : "Фільтр за командою",
+    "All teams" : "Всі команди",
+    "Search contacts in team {team}" : "Шукати контакти в команді {team}",
     "Search contacts …" : "Пошук контактів ...",
+    "Reset search" : "Повторити пошук",
     "Could not load your contacts" : "Неможливо завантажити ваші контакти",
     "No contacts found" : "Контактів не знайдено",
+    "Contacts list" : "Список контактів",
     "Show all contacts" : "Показувати всі контакти",
     "Install the Contacts app" : "Встановіть застосунок Контакти",
     "Search" : "Пошук",
@@ -329,15 +330,19 @@ OC.L10N.register(
     "Back to login form" : "Повернутися на сторінку входу",
     "Back" : "Назад",
     "Login form is disabled." : "Форма входу вимкнена.",
-    "The Nextcloud login form is disabled. Use another login option if available or contact your administration." : "Форму авторизації у хмарі Nextcloud вимкнено. Скористайтеся іншим способом входу, якщо є така можливість, або сконтактуйте з адміністратором.",
+    "The Nextcloud login form is disabled. Use another login option if available or contact your administration." : "Форму входу до хмари Nextcloud вимкнено. Скористайтеся іншим способом входу, якщо є така можливість, або сконтактуйте з адміністратором.",
     "Connect to your account" : "Увійти до вашого облікового запису",
+    "Please log in before granting \"{client}\" access to your {instanceName} account." : "Увійдіть перед тим, як надати доступ \"{client}\" до вашого облікового запису у {instanceName}.",
     "Security warning" : "Попередження безпеки",
     "If you are not trying to set up a new device or app, someone is trying to trick you into granting them access to your data. In this case do not proceed and instead contact your system administrator." : "Якщо ви не намагаєтеся налаштувати новий пристрій або застосунок, то це може означати, що хтось намагається обманом змусити вас надати доступ до ваших даних. У цьому випадку не продовжуйте, а зверніться до системного адміністратора.",
+    "Log in using password" : "Увійти за допомогою пароля",
     "Alternative log in using app password" : "Альтернативний логін, використовуючи пароль застосунку",
     "Account connected" : "Обліковий запис під’єднано",
     "Your client should now be connected!" : "Зараз ваш клієнт має бути приєднано!",
     "You can close this window." : "Ви можете закрити це вікно.",
     "Account access" : "Доступ до облікового запису",
+    "Currently logged in as {userDisplayName} ({userId})." : "Ви увійшли як {userDisplayName} ({userId}).",
+    "You are about to grant \"{client}\" access to your {instanceName} account." : "Ви намагаєтеся надати доступ \"{client}\" до вашого облікового запису у {instanceName}.",
     "More actions" : "Більше дій",
     "User menu" : "Меню користувача",
     "Your guest name: {user}" : "Ваше ім'я гостя: {user}",
@@ -352,13 +357,14 @@ OC.L10N.register(
     "You are not authorized to request a password for this share" : "Ви не маєте права запитувати пароль для цього ресурсу",
     "Email address" : "Адреса ел.пошти",
     "Request password" : "Запит пароля",
+    "Forgot password" : "Забули пароль",
     "Password is too weak" : "Занадто простий пароль ",
     "Password is weak" : "Простий пароль",
     "Password is average" : "Пароль середньої складності",
     "Password is strong" : "Надійний пароль ",
     "Password is very strong" : "Пароль дуже надійний",
     "Password is extremely strong" : "Надзвичайно надійний пароль",
-    "Unknown password strength" : "Невідома ефективність паролю",
+    "Unknown password strength" : "Невідома ефективність пароля",
     "Your data directory and files are probably accessible from the internet because the <code>.htaccess</code> file does not work." : "Ваш каталог з даними та файли скоріш за все публічно доступні в Інтернеті, оскільки файл <code>.htaccess</code> не налаштовано відповідним чином. ",
     "For information how to properly configure your server, please {linkStart}see the documentation{linkEnd}" : "Ознайомтеся з{linkStart}документацію{linkEnd} з налаштування сервера.",
     "Autoconfig file detected" : "Виявлено файл автоконфігурації",
@@ -394,6 +400,32 @@ OC.L10N.register(
     "Your browser is not supported. Please upgrade to a newer version or a supported one." : "Ваш бравзер не підтримується. Будь ласка, оновіть бравзер до новішої версії або скористайтеся таким, що підтримується.",
     "Continue with this unsupported browser" : "Продовжити з бравзером, що не підтримується.",
     "Supported versions" : "Підтримувані версії",
+    "The update completed with warnings. Please check the details for more information." : "Оновлення виконано із застереженнями. Перегляньте деталі для отримання додаткової інформації.",
+    "The update completed successfully." : "Оновлення успішно виконано.",
+    "Preparing update…" : "Підготовка до оновлення",
+    "You will be redirected to {productName} in {count} seconds." : "Переспрямування до {productName} за {count} сек.",
+    "The update is in progress, leaving this page might interrupt the process in some environments." : "Відбувається оновлення. Не залишайте цю сторінку, це може перервати процес у деяких середовищах.",
+    "App update required" : "Застосунок потребує оновлення",
+    "{productName} will be updated to version {version}" : "{productName} буде оновлено до версії {version}",
+    "The theme {oldTheme} has been disabled." : "Тема {oldTheme} є неактивною.",
+    "These incompatible apps will be disabled:" : "Такі несумісні застосунки буде вимкнено:",
+    "Incompatible apps" : "Несумісні застосунки",
+    "These apps will be updated:" : "Ці застосунки буде оновлено:",
+    "Apps to update" : "Застосунки до оновлення",
+    "{app} from {oldVersion} to {version}" : "{app} із {oldVersion} до {version}",
+    "Please make sure that the database, the config folder and the data folder have been backed up before proceeding." : "Перед продовженням переконайтеся, що ви зробили резервну копію бази даних, каталог з конфігурацією та каталоги з даними користувачів.",
+    "To avoid timeouts with larger installations, you can instead run the following command from your installation directory:" : "Щоб уникнути затримок у великих встановленнях, ви можете виконати наступну команду в каталозі встановлення:",
+    "Start update" : "Почати оновлення",
+    "Continue to {productName}" : "Перейти до {productName}",
+    "Update to {version}" : "Оновлення до {version}",
+    "Hide details" : "Приховати деталі",
+    "Show details" : "Показати деталі",
+    "Update details" : "Деталі оновлення",
+    "Update needed" : "Оновлення необхідно",
+    "Please use the command line updater because you have a big instance with more than 50 accounts." : "Будь ласка, скористайтеся запуском оновлення з командного рядка, оскільки у вас є понад 50 облікових записів.",
+    "Documentation" : "Документація",
+    "I know that if I continue doing the update via web UI has the risk, that the request runs into a timeout and could cause data loss, but I have a backup and know how to restore my instance in case of a failure." : "Я знаю, що, якщо я продовжую виконувати оновлення через вебінтерфейс, існує ризик того, що запит завершиться по тайм-ауту, що може призвести до втрати даних, але я маю резервну копію та знаю, як відновити мій сервер у випадку невдачі.",
+    "Upgrade via web on my own risk" : "Оновлення через веб-інтерфейс на свій страх і ризик",
     "Search {types} …" : "Пошук {types}...",
     "Choose {file}" : "Виберіть {file}",
     "Choose" : "Вибрати",
@@ -419,19 +451,13 @@ OC.L10N.register(
     "Group list is empty" : "Список груп порожній",
     "Unable to retrieve the group list" : "Неможливо отримати список груп",
     "seconds ago" : "кілька секунд тому",
-    "Connection to server lost" : "З'єднання з сервером втрачено",
-    "_Problem loading page, reloading in %n second_::_Problem loading page, reloading in %n seconds_" : ["Проблема під час завантаження сторінки, повторне завантаження за %n секунду.","Проблема під час завантаження сторінки, повторне завантаження за %n секунди.","Проблема під час завантаження сторінки, повторне завантаження за %n секунд.","Проблема під час завантаження сторінки, повторне завантаження за %n секунд."],
     "Add to a project" : "Додати до проєкту",
-    "Show details" : "Показати деталі",
-    "Hide details" : "Приховати деталі",
     "Rename project" : "Перейменувати проєкт",
     "Failed to rename the project" : "Помилка з перейменуванням проєкту",
     "Failed to create a project" : "Помилка зі створенням проєкту",
     "Failed to add the item to the project" : "Помилка з додаванням елементу до цього проєкту",
     "Connect items to a project to make them easier to find" : "Приєднайте окремі елементи до проєкту для полегшення пошуку",
     "Type to search for existing projects" : "Зазначте для пошуку серед наявних проєктів",
-    "New in" : "Нові можливості",
-    "View changelog" : "Подивитись зміни",
     "Close \"{dialogTitle}\" dialog" : "Закрити меню \"{dialogTitle}\"",
     "Email length is at max (255)" : "Досягнуто максимальну довжина адреси ел.пошти (255 символів)",
     "Clipboard not available, please copy manually" : "Буфер обміну не доступний, скопіюйте вручну",
@@ -447,10 +473,10 @@ OC.L10N.register(
     "Too many requests" : "Забагато запитів",
     "There were too many requests from your network. Retry later or contact your administrator if this is an error." : "Забагато запитів із вашої мережі. Повторіть спробу пізніше або зверніться до адміністратора, якщо це помилка.",
     "Error" : "Помилка",
-    "Internal Server Error" : "Внутрішня помилка серверу",
+    "Internal Server Error" : "Внутрішня помилка сервера",
     "The server was unable to complete your request." : "Сервер не зміг обробити ваш запит.",
     "If this happens again, please send the technical details below to the server administrator." : "Якщо це станеться знову, надішліть технічні подробиці адміністратору сервера.",
-    "More details can be found in the server log." : "Більше деталей може бути в журналі серверу.",
+    "More details can be found in the server log." : "Більше деталей може бути в журналі сервера.",
     "For more details see the documentation ↗." : "Для додаткової інформації дивіться документацію ↗.",
     "Technical details" : "Технічні деталі",
     "Remote Address: %s" : "Віддалена адреса: %s",
@@ -469,39 +495,25 @@ OC.L10N.register(
     "Go to %s" : "Перейти до %s",
     "Get your own free account" : "Отримати безкоштовний обліковий запис",
     "Previous" : "Назад",
-    "Two-factor authentication" : "Двофакторна авторизація",
-    "Enhanced security is enabled for your account. Choose a second factor for authentication:" : "Для вашого облікового запису налаштовано посилену безпеку. Виберіть другий фактор авторизації.",
-    "Could not load at least one of your enabled two-factor auth methods. Please contact your admin." : "Неможливо завантажити щонайменше один з активованих вами способів двофакторної авторизації. Будь ласка, сконтактуйте з адміністратором.",
-    "Two-factor authentication is enforced but has not been configured on your account. Contact your admin for assistance." : "Двофакторну авторизацію увімкнено, але не налаштовано для вашого облікового запису. Будь ласка, сконтактуйте з вашим адміністратором для отримання допомоги.",
-    "Two-factor authentication is enforced but has not been configured on your account. Please continue to setup two-factor authentication." : "Двофакторну авторизацію увімкнено, але не налаштовано для вашого облікового запису. Будь ласка, налаштуйте далі двофакторну авторизацію.",
-    "Set up two-factor authentication" : "Налаштувати двофакторну авторизацію",
-    "Two-factor authentication is enforced but has not been configured on your account. Use one of your backup codes to log in or contact your admin for assistance." : "Двофакторну авторизацію увімкнено, але не налаштовано для вашого облікового запису. Будь ласка, скористайтеся одним з резервних кодів для входу або сконтактуйте з вашим адміністратором для отримання допомоги.",
+    "Two-factor authentication" : "Двофакторна автентифікація",
+    "Enhanced security is enabled for your account. Choose a second factor for authentication:" : "Для вашого облікового запису налаштовано посилену безпеку. Виберіть другий фактор автентифікації.",
+    "Could not load at least one of your enabled two-factor auth methods. Please contact your admin." : "Неможливо завантажити щонайменше один з активованих вами способів двофакторної автентифікації. Будь ласка, сконтактуйте з адміністратором.",
+    "Two-factor authentication is enforced but has not been configured on your account. Contact your admin for assistance." : "Двофакторну автентифікацію увімкнено, але не налаштовано для вашого облікового запису. Будь ласка, сконтактуйте з вашим адміністратором для отримання допомоги.",
+    "Two-factor authentication is enforced but has not been configured on your account. Please continue to setup two-factor authentication." : "Двофакторну автентифікацію увімкнено, але не налаштовано для вашого облікового запису. Будь ласка, налаштуйте далі двофакторну автентифікацію.",
+    "Set up two-factor authentication" : "Налаштувати двофакторну автентифікацію",
+    "Two-factor authentication is enforced but has not been configured on your account. Use one of your backup codes to log in or contact your admin for assistance." : "Двофакторну автентифікацію увімкнено, але не налаштовано для вашого облікового запису. Будь ласка, скористайтеся одним з резервних кодів для входу або сконтактуйте з вашим адміністратором для отримання допомоги.",
     "Use backup code" : "Використати резервний код",
     "Cancel login" : "Скасувати вхід",
-    "Enhanced security is enforced for your account. Choose which provider to set up:" : "Двофакторну авторизацію увімкнено для вашого облікового запису. Будь ласка, виберіть провайдера для налаштування:",
-    "Error while validating your second factor" : "Помилка під час перевірки вашого другого фактору",
+    "Enhanced security is enforced for your account. Choose which provider to set up:" : "Двофакторну автентифікацію увімкнено для вашого облікового запису. Будь ласка, виберіть провайдера для налаштування:",
+    "Error while validating your second factor" : "Помилка під час перевірки вашого другого фактора",
     "Access through untrusted domain" : "Доступ з не довіреного домену",
     "Please contact your administrator. If you are an administrator, edit the \"trusted_domains\" setting in config/config.php like the example in config.sample.php." : "Будь ласка, зверніться до свого адміністратора. Якщо ви адміністратор, відредагуйте параметр \"trusted_domains\" у config/config.php, як у прикладі у config.sample.php.",
     "Further information how to configure this can be found in the %1$sdocumentation%2$s." : "Подальшу інформацію з налаштуваннями можна переглянути на сторінці %1$sДокументація%2$s.",
-    "App update required" : "Застосунок потребує оновлення",
-    "%1$s will be updated to version %2$s" : "%1$s буде оновлено до версії %2$s",
-    "The following apps will be updated:" : "Ці застосунки буде оновлено:",
-    "These incompatible apps will be disabled:" : "Такі несумісні застосунки буде вимкнено:",
-    "The theme %s has been disabled." : "Тему %s було вимкнено.",
-    "Please make sure that the database, the config folder and the data folder have been backed up before proceeding." : "Перед продовженням переконайтеся, що ви зробили резервну копію бази даних, каталог з конфігурацією та каталоги з даними користувачів.",
-    "Start update" : "Почати оновлення",
-    "To avoid timeouts with larger installations, you can instead run the following command from your installation directory:" : "Щоб уникнути затримок у великих встановленнях, ви можете виконати наступну команду в каталозі встановлення:",
-    "Detailed logs" : "Деталізований журнал",
-    "Update needed" : "Оновлення необхідно",
-    "Please use the command line updater because you have a big instance with more than 50 accounts." : "Будь ласка, скористайтеся запуском оновлення з командного рядка, оскільки у вас є понад 50 облікових записів.",
-    "For help, see the  <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">documentation</a>." : "Щоб отримати допомогу, перегляньте  <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">документацію</a>.",
-    "I know that if I continue doing the update via web UI has the risk, that the request runs into a timeout and could cause data loss, but I have a backup and know how to restore my instance in case of a failure." : "Я знаю, що, якщо я продовжую виконувати оновлення через вебінтерфейс, існує ризик того, що запит завершиться по тайм-ауту, що може призвести до втрати даних, але я маю резервну копію та знаю, як відновити мій сервер у випадку невдачі.",
-    "Upgrade via web on my own risk" : "Оновлення через веб-інтерфейс на свій страх і ризик",
     "Maintenance mode" : "Режим технічного обслуговування",
     "This %s instance is currently in maintenance mode, which may take a while." : "Для сервера хмари %s увімкнено режим технічного обслуговування.",
-    "This page will refresh itself when the instance is available again." : "Ця сторінка оновиться автоматично, коли сервер знову стане доступний.",
+    "This page will refresh itself when the instance is available again." : "Сторінка оновиться автоматично, щойно сервер знову стане доступний.",
     "Contact your system administrator if this message persists or appeared unexpectedly." : "Зверніться до вашого системного адміністратора, якщо це повідомлення не зникає або з'явилося несподівано.",
-    "Error occurred while checking server setup" : "При перевірці налаштувань серверу сталася помилка",
+    "Error occurred while checking server setup" : "При перевірці налаштувань сервера сталася помилка",
     "For more details see the {linkstart}documentation ↗{linkend}." : "Додаткову інформацію див. у {linkstart}документації ↗{linkend}.",
     "unknown text" : "невідомий текст",
     "Hello world!" : "Привіт, світе!",
@@ -511,6 +523,11 @@ OC.L10N.register(
     "<strong>These are your search results<script>alert(1)</script></strong>" : "<strong>Це ваші результати пошуку<script>alert(1)</script></strong>",
     "new" : "новий",
     "_download %n file_::_download %n files_" : ["звантаження %n файлу","звантаження %n файлів","звантаження %n файлів","звантаження %n файлів"],
+    "An error occurred." : "Виникла помилка.",
+    "Please reload the page." : "Будь ласка, перезавантажте сторінку.",
+    "The update was unsuccessful. For more information <a href=\"{url}\">check our forum post</a> covering this issue." : "Оновлення не вдалося. За інформацією <a href=\"{url}\">зверніться до повідомлення на форумі</a>, що описує цю проблему.",
+    "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud community</a>." : "Оновлення не вдалося. Будь ласка, повідомте про це питання в <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">спільноту Nextcloud</a>.",
+    "_The update was successful. Redirecting you to {productName} in %n second._::_The update was successful. Redirecting you to {productName} in %n seconds._" : ["Оновлення пройшло успішно. Переспрямування на {productName} за %n секунду.","Оновлення пройшло успішно. Переспрямування до {productName} за лічені %n секунди.","Оновлення пройшло успішно. Переспрямування до {productName} за лічені %n секунди.","Оновлення пройшло успішно. Переспрямування до {productName} за лічені %n секунди."],
     "Direct link copied to clipboard" : "Посилання прямого доступу скопійовано в буфер обміну",
     "Searching …" : "Пошук ...",
     "Logging in …" : "Вхід ...",
@@ -523,6 +540,10 @@ OC.L10N.register(
     "Loading more results …" : "Завантаження інших результатів…",
     "Search {types} …" : "Пошук {types} …",
     "Saving …" : "Збереження …",
+    "Connection to server lost" : "З'єднання з сервером втрачено",
+    "_Problem loading page, reloading in %n second_::_Problem loading page, reloading in %n seconds_" : ["Проблема під час завантаження сторінки, повторне завантаження за %n секунду.","Проблема під час завантаження сторінки, повторне завантаження за %n секунди.","Проблема під час завантаження сторінки, повторне завантаження за %n секунд.","Проблема під час завантаження сторінки, повторне завантаження за %n секунд."],
+    "New in" : "Нові можливості",
+    "View changelog" : "Подивитись зміни",
     "Very weak password" : "Дуже слабкий пароль",
     "Weak password" : "Слабкий пароль",
     "So-so password" : "Такий собі пароль",
@@ -549,6 +570,11 @@ OC.L10N.register(
     "Installing …" : "Встановлення…",
     "Please log in before granting %1$s access to your %2$s account." : "Для надання %1$s доступу до облікового запису %2$s необхідно увійти в систему.",
     "Currently logged in as %1$s (%2$s)." : "Зараз увійшли як %1$s (%2$s).",
-    "You are about to grant %1$s access to your %2$s account." : "Ви збираєтесь надати %1$s доступ до свого облікового запису %2$s."
+    "You are about to grant %1$s access to your %2$s account." : "Ви збираєтесь надати %1$s доступ до свого облікового запису %2$s.",
+    "%1$s will be updated to version %2$s" : "%1$s буде оновлено до версії %2$s",
+    "The following apps will be updated:" : "Ці застосунки буде оновлено:",
+    "The theme %s has been disabled." : "Тему %s було вимкнено.",
+    "Detailed logs" : "Деталізований журнал",
+    "For help, see the  <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">documentation</a>." : "Щоб отримати допомогу, перегляньте  <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">документацію</a>."
 },
 "nplurals=4; plural=(n % 1 == 0 && n % 10 == 1 && n % 100 != 11 ? 0 : n % 1 == 0 && n % 10 >= 2 && n % 10 <= 4 && (n % 100 < 12 || n % 100 > 14) ? 1 : n % 1 == 0 && (n % 10 ==0 || (n % 10 >=5 && n % 10 <=9) || (n % 100 >=11 && n % 100 <=14 )) ? 2: 3);");
