@@ -45,6 +45,8 @@ OC.L10N.register(
     "Input text is too long" : "輸入文字太長",
     "Requested task type does not exist" : "請求的任務類型不存在",
     "Necessary language model provider is not available" : "沒有可用的語言模型程式",
+    "Cannot generate more than 12 images" : "無法產生超過 12 張影像",
+    "Cannot generate less than 1 image" : "無法產生少於 1 張影像",
     "No text to image provider is available" : "沒有可用的文字轉影像提供者",
     "Image not found" : "找不到影像",
     "No translation provider available" : "沒有可用的翻譯提供者",
@@ -198,14 +200,6 @@ OC.L10N.register(
     "Matroska video" : "Matroska 視訊",
     "Windows Media video" : "Windows 媒體視訊",
     "AVI video" : "AVI 視訊",
-    "The update is in progress, leaving this page might interrupt the process in some environments." : "正在更新，離開本頁面在某些情況下可能會導致更新中斷。",
-    "Update to {version}" : "更新到 {version}",
-    "An error occurred." : "發生錯誤。",
-    "Please reload the page." : "請重新載入頁面。",
-    "The update was unsuccessful. For more information <a href=\"{url}\">check our forum post</a> covering this issue." : "更新失敗。<a href=\"{url}\">參閱論壇上的文章</a>了解問題的更多資訊。",
-    "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud community</a>." : "更新失敗。請前往 <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud 社群</a>回報此問題。",
-    "Continue to {productName}" : "繼續使用 {productName}",
-    "_The update was successful. Redirecting you to {productName} in %n second._::_The update was successful. Redirecting you to {productName} in %n seconds._" : ["更新成功。將在 %n 秒後重新導向至 {productName}。"],
     "Done" : "完成",
     "Scan QR code to log in" : "掃描 QR code 以登入",
     "Use {productName} mobile client you want to connect to scan the code" : "使用您要連線的 {productName} 行動裝置客戶端掃描此條碼",
@@ -314,10 +308,14 @@ OC.L10N.register(
     "Loading your contacts …" : "正在載入您的聯絡人 ……",
     "Looking for {term} …" : "正在尋找 {term} ……",
     "Search contacts" : "搜尋聯絡人",
-    "Reset search" : "重設搜尋",
+    "Filter by team" : "按團隊篩選",
+    "All teams" : "所有團隊",
+    "Search contacts in team {team}" : "在團隊 {team} 中搜尋聯絡人",
     "Search contacts …" : "搜尋聯絡人 ……",
+    "Reset search" : "重設搜尋",
     "Could not load your contacts" : "無法載入您的聯絡人",
     "No contacts found" : "查無聯絡人",
+    "Contacts list" : "聯絡人清單",
     "Show all contacts" : "顯示所有聯絡人",
     "Install the Contacts app" : "安裝「聯絡人」應用程式",
     "Search" : "搜尋",
@@ -402,6 +400,32 @@ OC.L10N.register(
     "Your browser is not supported. Please upgrade to a newer version or a supported one." : "不支援您的瀏覽器。請升級至較新或受支援的版本。",
     "Continue with this unsupported browser" : "繼續使用不受支援的瀏覽器",
     "Supported versions" : "支援的版本",
+    "The update completed with warnings. Please check the details for more information." : "更新已完成，但出現警告。請檢查詳細資訊以取得更多資訊。",
+    "The update completed successfully." : "更新已成功完成。",
+    "Preparing update…" : "正在準備更新……",
+    "You will be redirected to {productName} in {count} seconds." : "將會在{count}秒重新導向至 {productName}。",
+    "The update is in progress, leaving this page might interrupt the process in some environments." : "正在更新，離開本頁面在某些情況下可能會導致更新中斷。",
+    "App update required" : "需要更新應用程式",
+    "{productName} will be updated to version {version}" : "{productName} 將會更新至 {version} 版",
+    "The theme {oldTheme} has been disabled." : "已停用佈景主題 {oldTheme}。",
+    "These incompatible apps will be disabled:" : "將停用這些不相容的應用程式：",
+    "Incompatible apps" : "不相容的應用程式",
+    "These apps will be updated:" : "將會更新這些應用程式",
+    "Apps to update" : "要更新的應用程式",
+    "{app} from {oldVersion} to {version}" : "{app} 從 {oldVersion} 到 {version}",
+    "Please make sure that the database, the config folder and the data folder have been backed up before proceeding." : "在繼續之前，請備份資料庫、config 資料夾及 data 資料夾。",
+    "To avoid timeouts with larger installations, you can instead run the following command from your installation directory:" : "在服務規模較大的安裝上，為了避免請求逾時，您也可以在安裝目錄執行下列指令：",
+    "Start update" : "開始更新",
+    "Continue to {productName}" : "繼續使用 {productName}",
+    "Update to {version}" : "更新到 {version}",
+    "Hide details" : "隱藏詳細資訊",
+    "Show details" : "顯示詳細資訊",
+    "Update details" : "更新詳細資訊",
+    "Update needed" : "需要更新",
+    "Please use the command line updater because you have a big instance with more than 50 accounts." : "因為您有超過 50 個帳號，服務規模較大，請透過命令列介面更新。",
+    "Documentation" : "文件",
+    "I know that if I continue doing the update via web UI has the risk, that the request runs into a timeout and could cause data loss, but I have a backup and know how to restore my instance in case of a failure." : "我知道如果還是要透過網頁介面更新，會有風險，像是可能發生請求逾時，並導致資料遺失。萬一更新失敗，我已準備好備份，並且明白如何讓站台回復運作。",
+    "Upgrade via web on my own risk" : "願意承擔透過網頁更新的風險",
     "Search {types} …" : "搜尋 {types} ……",
     "Choose {file}" : "選擇 {file}",
     "Choose" : "選擇",
@@ -427,19 +451,13 @@ OC.L10N.register(
     "Group list is empty" : "群組列表空白",
     "Unable to retrieve the group list" : "無法擷取群組列表",
     "seconds ago" : "幾秒前",
-    "Connection to server lost" : "伺服器連線中斷",
-    "_Problem loading page, reloading in %n second_::_Problem loading page, reloading in %n seconds_" : ["載入頁面時發生問題，%n 秒後重新整理"],
     "Add to a project" : "新增至專案",
-    "Show details" : "顯示詳細資訊",
-    "Hide details" : "隱藏詳細資訊",
     "Rename project" : "重新命名專案",
     "Failed to rename the project" : "重新命名專案失敗",
     "Failed to create a project" : "建立專案失敗",
     "Failed to add the item to the project" : "新增項目至專案時失敗",
     "Connect items to a project to make them easier to find" : "將項目連結到專案以便尋找",
     "Type to search for existing projects" : "搜尋現有專案",
-    "New in" : "新加入",
-    "View changelog" : "檢視版本更新紀錄",
     "Close \"{dialogTitle}\" dialog" : "關閉「{dialogTitle}」對話方塊",
     "Email length is at max (255)" : "電子郵件長度最長 (255)",
     "Clipboard not available, please copy manually" : "無法使用剪貼簿，請手動複製",
@@ -491,20 +509,6 @@ OC.L10N.register(
     "Access through untrusted domain" : "經由不可信任的網域存取",
     "Please contact your administrator. If you are an administrator, edit the \"trusted_domains\" setting in config/config.php like the example in config.sample.php." : "請聯絡您的管理員。如果您就是管理員，請參考 config.sample.php 範例編輯 config/config.php 的「trusted_domains」設定。",
     "Further information how to configure this can be found in the %1$sdocumentation%2$s." : "關於組態設定的更多資訊，請參閱%1$s文件%2$s。",
-    "App update required" : "需要更新應用程式",
-    "%1$s will be updated to version %2$s" : "%1$s 將會更新至版本 %2$s",
-    "The following apps will be updated:" : "將更新以下的應用程式：",
-    "These incompatible apps will be disabled:" : "將停用這些不相容的應用程式：",
-    "The theme %s has been disabled." : "佈景主題 %s 已被停用。",
-    "Please make sure that the database, the config folder and the data folder have been backed up before proceeding." : "在繼續之前，請備份資料庫、config 資料夾及 data 資料夾。",
-    "Start update" : "開始更新",
-    "To avoid timeouts with larger installations, you can instead run the following command from your installation directory:" : "在服務規模較大的安裝上，為了避免請求逾時，您也可以在安裝目錄執行下列指令：",
-    "Detailed logs" : "詳細記錄檔",
-    "Update needed" : "需要更新",
-    "Please use the command line updater because you have a big instance with more than 50 accounts." : "因為您有超過 50 個帳號，服務規模較大，請透過命令列介面更新。",
-    "For help, see the  <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">documentation</a>." : "若需要協助，請參閱<a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">說明文件</a>。",
-    "I know that if I continue doing the update via web UI has the risk, that the request runs into a timeout and could cause data loss, but I have a backup and know how to restore my instance in case of a failure." : "我知道如果還是要透過網頁介面更新，會有風險，像是可能發生請求逾時，並導致資料遺失。萬一更新失敗，我已準備好備份，並且明白如何讓站台回復運作。",
-    "Upgrade via web on my own risk" : "願意承擔透過網頁更新的風險",
     "Maintenance mode" : "維護模式",
     "This %s instance is currently in maintenance mode, which may take a while." : "這個 %s 站台目前處於維護模式，需要一段時間恢復。",
     "This page will refresh itself when the instance is available again." : "在站台恢復可用之後，本頁會自動重新整理。",
@@ -519,6 +523,11 @@ OC.L10N.register(
     "<strong>These are your search results<script>alert(1)</script></strong>" : "<strong>以下是您的搜尋結果<script>警告(1)</script></strong>",
     "new" : "新",
     "_download %n file_::_download %n files_" : ["下載 %n 個檔案"],
+    "An error occurred." : "發生錯誤。",
+    "Please reload the page." : "請重新載入頁面。",
+    "The update was unsuccessful. For more information <a href=\"{url}\">check our forum post</a> covering this issue." : "更新失敗。<a href=\"{url}\">參閱論壇上的文章</a>了解問題的更多資訊。",
+    "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud community</a>." : "更新失敗。請前往 <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud 社群</a>回報此問題。",
+    "_The update was successful. Redirecting you to {productName} in %n second._::_The update was successful. Redirecting you to {productName} in %n seconds._" : ["更新成功。將在 %n 秒後重新導向至 {productName}。"],
     "Direct link copied to clipboard" : "直接連結已複製到剪貼簿",
     "Searching …" : "正在搜尋…",
     "Logging in …" : "正在登入…",
@@ -531,6 +540,10 @@ OC.L10N.register(
     "Loading more results …" : "正在載入更多結果…",
     "Search {types} …" : "搜尋 {types} 中…",
     "Saving …" : "正在儲存…",
+    "Connection to server lost" : "伺服器連線中斷",
+    "_Problem loading page, reloading in %n second_::_Problem loading page, reloading in %n seconds_" : ["載入頁面時發生問題，%n 秒後重新整理"],
+    "New in" : "新加入",
+    "View changelog" : "檢視版本更新紀錄",
     "Very weak password" : "密碼安全性極弱",
     "Weak password" : "密碼安全性弱",
     "So-so password" : "密碼安全性普通",
@@ -557,6 +570,11 @@ OC.L10N.register(
     "Installing …" : "正在安裝…",
     "Please log in before granting %1$s access to your %2$s account." : "請登入後再授權「%1$s」存取您的 %2$s 帳號。",
     "Currently logged in as %1$s (%2$s)." : "目前登入為 %1$s（%2$s）。",
-    "You are about to grant %1$s access to your %2$s account." : "您將授權「%1$s」存取您的 %2$s 帳號。"
+    "You are about to grant %1$s access to your %2$s account." : "您將授權「%1$s」存取您的 %2$s 帳號。",
+    "%1$s will be updated to version %2$s" : "%1$s 將會更新至版本 %2$s",
+    "The following apps will be updated:" : "將更新以下的應用程式：",
+    "The theme %s has been disabled." : "佈景主題 %s 已被停用。",
+    "Detailed logs" : "詳細記錄檔",
+    "For help, see the  <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">documentation</a>." : "若需要協助，請參閱<a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">說明文件</a>。"
 },
 "nplurals=1; plural=0;");
