@@ -93,6 +93,8 @@ OC.L10N.register(
     "Destination does not exist" : "Cíl neexistuje",
     "Destination is not creatable" : "Cíl není možné vytvořit",
     "Dot files are not allowed" : "Názvy souborů, začínající na tečku nejsou dovolené",
+    "%1$s (renamed)" : "%1$s (přejmenované)",
+    "renamed file" : "přejmenovaný soubor",
     "\"%1$s\" is a forbidden file or folder name." : "„%1$s“ je zakázáno v názvu souboru nebo složky.",
     "\"%1$s\" is a forbidden prefix for file or folder names." : "„%1$s“ je zakázaná předpona pro názvy souborů či složek.",
     "\"%1$s\" is not allowed inside a file or folder name." : "„%1$s“ není povoleno v rámci názvu souboru či složky.",
@@ -127,6 +129,8 @@ OC.L10N.register(
     "Settings" : "Nastavení",
     "Log out" : "Odhlásit se",
     "Accounts" : "Účty",
+    "Bluesky" : "Bluesky",
+    "View %s on Bluesky" : "Zobrazit %s na Bluesky",
     "Email" : "E-mail",
     "Mail %s" : "Poslat e-mail %s",
     "Fediverse" : "Fediverse",
@@ -142,7 +146,7 @@ OC.L10N.register(
     "About" : "O uživateli",
     "Display name" : "Zobrazované jméno",
     "Headline" : "Nadpis",
-    "Organisation" : "Organizace",
+    "Organization" : "Organizování",
     "Role" : "Role",
     "Pronouns" : "Zájmena",
     "Unknown account" : "Neznámý účet",
@@ -156,7 +160,7 @@ OC.L10N.register(
     "Oracle connection could not be established" : "Spojení s Oracle nemohlo být navázáno",
     "Oracle Login and/or password not valid" : "Neplatné přihlašovací jméno a/nebo heslo do Oracle",
     "PostgreSQL Login and/or password not valid" : "Neplatné přihlašovací jméno a/nebo heslo do PostgreSQL",
-    "Mac OS X is not supported and %s will not work properly on this platform. Use it at your own risk!" : "macOS není podporován a %s nebude na této platformě správně fungovat. Používejte pouze na vlastní nebezpečí!",
+    "macOS is not supported and %s will not work properly on this platform." : "macOS není podporován a %s nebude fungovat správně na této platformě.",
     "For the best results, please consider using a GNU/Linux server instead." : "Místo toho zvažte pro nejlepší funkčnost použití GNU/Linux serveru.",
     "It seems that this %s instance is running on a 32-bit PHP environment and the open_basedir has been configured in php.ini. This will lead to problems with files over 4 GB and is highly discouraged." : "Zdá se, že tato instance %s je provozována v 32-bitovém PHP prostředí a v php.ini je nastavena volba open_basedir. Toto povede k problémům se soubory většími než 4 GB a silně není doporučováno.",
     "Please remove the open_basedir setting within your php.ini or switch to 64-bit PHP." : "Odstraňte z php.ini nastavení volby open_basedir nebo přejděte na 64-bitové PHP.",
@@ -221,6 +225,8 @@ OC.L10N.register(
     "Could not find category \"%s\"" : "Nedaří se nalézt kategorii „%s“",
     "Input text" : "Zadejte text",
     "The input text" : "Vstupní text",
+    "Cannot generate more than 12 images" : "Není možné vytvořit více než 12 obrázků",
+    "Cannot generate less than 1 image" : "Není možné vytvořit méně než 1 obrázek",
     "Sunday" : "neděle",
     "Monday" : "pondělí",
     "Tuesday" : "úterý",
@@ -273,6 +279,7 @@ OC.L10N.register(
     "A valid Login must be provided" : "Je třeba zadat platné přihlašovací jméno",
     "Login contains whitespace at the beginning or at the end" : "Přihlašovací jméno je chybné – na jeho začátku či konci se nachází prázdný znak (mezera, tabulátor, atp.)",
     "Login must not consist of dots only" : "Přihlašovací jméno se nemůže skládat pouze ze samých teček",
+    "Username is too long" : "Uživatelské jméno je příliš dlouhé",
     "Login is invalid because files already exist for this user" : "Přihlašovací jméno není platné, protože protože pro tohoto uživatele už existují soubory",
     "Account disabled" : "Účet znepřístupněn",
     "Login canceled by app" : "Přihlášení zrušeno aplikací",
@@ -285,8 +292,6 @@ OC.L10N.register(
     "Cannot write into \"config\" directory." : "Nedaří se zapisovat do adresáře „config“.",
     "This can usually be fixed by giving the web server write access to the config directory. See %s" : "Toto obvykle lze vyřešit udělením oprávnění k zápisu do kořenové složky webu pro účet, pod kterým je provozován webový server. Viz %s",
     "Or, if you prefer to keep config.php file read only, set the option \"config_is_read_only\" to true in it. See %s" : "Nebo, pokud chcete mít soubor config.php pouze pro čtení, nastavte v něm volbu „config_is_read_only“ na hodnotu true. Viz %s",
-    "Cannot write into \"apps\" directory." : "Nedaří se zapisovat do adresáře „apps“.",
-    "This can usually be fixed by giving the web server write access to the apps directory or disabling the App Store in the config file." : "Toto je obvykle možné napravit udělením přístupu ke čtení adresáře s aplikací pro webový server nebo vypnutím katalogu s aplikacemi v souboru s nastaveními.",
     "Cannot create \"data\" directory." : "Nedaří se vytvořit adresář „data“.",
     "This can usually be fixed by giving the web server write access to the root directory. See %s" : "Toto obvykle lze vyřešit udělením oprávnění k zápisu do kořenové složky webu pro účet, pod kterým je provozován webový server. Viz %s",
     "Permissions can usually be fixed by giving the web server write access to the root directory. See %s." : "Oprávnění lze obvykle napravit umožněním zápisu do kořene webu pro účet, pod kterým je provozován webový server. Viz %s.",
@@ -297,8 +302,6 @@ OC.L10N.register(
     "Please ask your server administrator to install the module." : "Požádejte správce serveru, který využíváte o instalaci tohoto modulu.",
     "PHP setting \"%s\" is not set to \"%s\"." : "Hodnota v konfiguraci PHP „%s“ není nastavená na „%s“.",
     "Adjusting this setting in php.ini will make Nextcloud run again" : "Úprava tohoto nastavení v php.ini umožní Nextcloud opět zprovoznit",
-    "<code>mbstring.func_overload</code> is set to <code>%s</code> instead of the expected value <code>0</code>." : "<code>mbstring.func_overload</code> je nastaveno na <code>%s</code> namísto očekávané hodnoty <code>0</code>.",
-    "To fix this issue set <code>mbstring.func_overload</code> to <code>0</code> in your php.ini." : "Pro nápravu nastavte v souboru php.ini parametr <code>mbstring.func_overload</code> na <code>0</code>.",
     "PHP is apparently set up to strip inline doc blocks. This will make several core apps inaccessible." : "PHP je patrně nastaveno tak, aby odstraňovalo bloky komentářů. Toto bude mít za následek znepřístupnění mnoha důležitých aplikací.",
     "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "Toto je pravděpodobně způsobeno aplikacemi pro urychlení načítání jako jsou Zend OPcache nebo eAccelerator.",
     "PHP modules have been installed, but they are still listed as missing?" : "PHP moduly jsou nainstalovány, přesto jsou uváděny jako chybějící?",
@@ -323,25 +326,48 @@ OC.L10N.register(
     "Storage is temporarily not available" : "Úložiště je dočasně nedostupné",
     "Storage connection timeout. %s" : "Překročen časový limit připojování k úložišti. %s",
     "To allow this check to run you have to make sure that your Web server can connect to itself. Therefore it must be able to resolve and connect to at least one of its `trusted_domains` or the `overwrite.cli.url`. This failure may be the result of a server-side DNS mismatch or outbound firewall rule." : "Aby bylo možné možné povolit spuštění této kontroly je třeba zajistit, aby se webový server mohl připojit sám na sebe. Proto je třeba, aby bylo možné přeložit na IP adresu a připojit se k alespoň jedné z `trusted_domains` nebo `overwrite.cli.url`. Tento nezdar může být výsledkem neshody DNS na serveru nebo odchozího pravidla na bráně firewall.",
+    "Analyze images" : "Analyzovat obrázky",
+    "Ask a question about the given images." : "Zeptejte se ohledně daných obrázků.",
+    "Images" : "Obrázky",
+    "Images to ask a question about" : "Obrázky ohledně kterých se zeptat",
+    "Question" : "Otázka",
+    "What to ask about the images." : "Na co se zeptat ohledně obrázků.",
+    "Generated response" : "Vygenerovaná odpověď",
+    "The answer to the question" : "Odpověď na dotaz",
+    "Audio chat" : "Zvukový chat",
+    "Voice chat with the assistant" : "Hlasový chat s asistentem",
+    "System prompt" : "Systémový prompt",
+    "Define rules and assumptions that the assistant should follow during the conversation." : "Definujte pravidla a předpoklady která by měl asistent v konverzaci následovat.",
+    "Chat voice message" : "Hlasová zpráva v chatu",
+    "Describe a task that you want the assistant to do or ask a question." : "Popište úkol který chcete aby asistent udělal nebo položte dotaz.",
+    "Chat history" : "Historie chatu",
+    "The history of chat messages before the current message, starting with a message by the user." : "Historie zpráv v chatu před stávající zprávou, počínaje zprávou od uživatele.",
+    "Input transcript" : "Přepis vstupu",
+    "Transcription of the audio input" : "Přepis zvukového vstupu",
+    "Response voice message" : "Odpovědět na zvukovou zprávu",
+    "The generated voice response as part of the conversation" : "Vytvořená hlasová odpověď jako součást konverzace",
+    "Output transcript" : "Výstup přepisu",
+    "Transcription of the audio output" : "Přepis zvukového výstupu",
     "Transcribe audio" : "Vytvořit text ze zvukové nahrávky",
     "Transcribe the things said in an audio" : "Vytvořit zápis věcí řečených ve zvukovém záznamu",
     "Audio input" : "Zvukový vstup",
     "The audio to transcribe" : "Nahrávka k přepisu",
     "Transcription" : "Přepis do textu",
     "The transcribed text" : "Přepsaný text",
-    "Chat with an agent" : "Chatovat s agentem",
-    "Chat message" : "Zpráva v chatu",
-    "A chat message to send to the agent." : "Zpráva chatu, kterou poslat agentovi.",
+    "Chat by voice with an agent" : "Hlasový chat s agentem",
+    "Describe a task that you want the agent to do or ask a question." : "Popište úkol který chcete aby agent udělal nebo položte dotaz",
     "Confirmation" : "Potvrzení",
     "Whether to confirm previously requested actions: 0 for denial and 1 for confirmation." : "Zda potvrdit dříve vyžádané akce: 0 (nula) pro odepření a 1 pro potvrzení.",
     "Conversation token" : "Token konverzace",
     "A token representing the conversation." : "Token představující konverzaci.",
-    "Generated response" : "Vygenerovaná odpověď",
-    "The response from the chat model." : "Odpověď z modelu chatu.",
     "The new conversation token" : "Token nové konverzace",
     "Send this along with the next interaction." : "Odeslat toto společně s příští interakcí.",
     "Requested actions by the agent" : "Akce vyžádané agentem",
     "Actions that the agent would like to carry out in JSON format." : "Akce které by agent rád provedl (v JSON formátu).",
+    "Chat with an agent" : "Chatovat s agentem",
+    "Chat message" : "Zpráva v chatu",
+    "A chat message to send to the agent." : "Zpráva chatu, kterou poslat agentovi.",
+    "The response from the chat model." : "Odpověď z modelu chatu.",
     "Context write" : "Kontextový zápis",
     "Writes text in a given style based on the provided source material." : "Napíše text v daném stylu na základě poskytnutého zdrojového materiálu.",
     "Writing style" : "Styl zápisu",
@@ -355,6 +381,12 @@ OC.L10N.register(
     "The text to generate an emoji for" : "Text pro který vytvořit emotikonu",
     "Generated emoji" : "Vytvořená emotikona",
     "The generated emoji based on the input text" : "Emotikona vytvořená na základě vstupního textu",
+    "Optical character recognition" : "Optické rozpoznávání znaků",
+    "Extract text from files like images or PDFs" : "Vyzískat text ze souborů jako jsou obrázky nebo PDF dokumenty",
+    "Input files" : "Vstupní soubory",
+    "The files to extract text from" : "Soubory, ze kterých vyzískat text",
+    "Output texts" : "Výstupní texty",
+    "The texts that were extracted from the files" : "Texty které byly vyzískány ze souborů",
     "Generate image" : "Vytvořit obrázek",
     "Generate an image from a text prompt" : "Vytvoření obrázku dle textového zadání",
     "Prompt" : "Výzva",
@@ -363,6 +395,11 @@ OC.L10N.register(
     "How many images to generate" : "Kolik obrázků vytvořit",
     "Output images" : "Výstupní obrázky",
     "The generated images" : "Vytvořené obrázky",
+    "Generate speech" : "Vytvořit řeč",
+    "Generate speech from a transcript" : "Vytvořit řeč z přepisu",
+    "Write transcript that you want the assistant to generate speech from" : "Napište přepis, ze kterého chcete, aby asistent vytvořil řeč",
+    "Output speech" : "Výstupní řeč",
+    "The generated speech" : "Vytvořená řeč",
     "Free text to text prompt" : "Volný text na textový prompt",
     "Runs an arbitrary prompt through a language model that returns a reply" : "Spouští libovolnou výzvu skrze jazykový model který vrací odpověď",
     "Describe a task that you want the assistant to do or ask a question" : "Popište úkol který chcete aby asistent udělal nebo položte dotaz",
@@ -376,9 +413,6 @@ OC.L10N.register(
     "The rewritten text in the desired tone, written by the assistant:" : "Text přepsaný v požadovaném tónu, napsaný asistentem:",
     "Chat" : "Chat",
     "Chat with the assistant" : "Chat s pomocníkem",
-    "System prompt" : "Systémový prompt",
-    "Define rules and assumptions that the assistant should follow during the conversation." : "Definujte pravidla a předpoklady která by měl asistent v konverzaci následovat.",
-    "Chat history" : "Historie chatu",
     "The history of chat messages before the current message, starting with a message by the user" : "Historie zpráv v chatu před stávající zprávou, počínaje zprávou od uživatele",
     "Response message" : "Zpráva s odpovědí",
     "The generated response as part of the conversation" : "Vytvořená odpověď jako součást konverzace",
@@ -442,20 +476,12 @@ OC.L10N.register(
     "Generate headline" : "Vytvořit nadpis",
     "Summarizes text by reducing its length without losing key information." : "Vytvoří stručný souhrn textu tím, že zkrátí jeho délku aniž by byly ztraceny klíčové informace",
     "Extracts topics from a text and outputs them separated by commas." : "Vyzíská témata z textu a vypíše je oddělované čárkami.",
-    "Education Edition" : "Vydání pro vzdělávací instituce",
-    "File name is a reserved word" : "Název souboru je rezervované slovo",
-    "File name contains at least one invalid character" : "Název souboru obsahuje přinejmenším jeden neplatný znak",
-    "File name is too long" : "Název souboru je příliš dlouhý",
-    "Users" : "Uživatelé",
-    "%1$s shared »%2$s« with you and wants to add:" : "%1$s sdílí „%2$s“ a dodává:",
-    "%1$s shared »%2$s« with you and wants to add" : "%1$s sdílí „%2$s“ a dodává",
-    "»%s« added a note to a file shared with you" : "„%s“ dodává poznámku k nasdílenému souboru ",
-    "Open »%s«" : "Otevřít „%s“",
-    "%1$s shared »%2$s« with you" : "%1$s vám sdílí „%2$s“",
-    "%1$s shared »%2$s« with you." : "%1$s vám nasdílel(a) „%2$s“.",
-    "Click the button below to open it." : "Pro otevření klikněte na tlačítko níže.",
-    "File is currently busy, please try again later" : "Soubor je nyní používán, zkuste to později",
-    "Cannot download file" : "Soubor se nedaří stáhnout",
-    "Ensure there is a file called \".ocdata\" in the root of the data directory." : "Ověřte, že v kořeni datového adresáře je soubor s názvem „.ocdata“."
+    "Organisation" : "Organizace",
+    "Mac OS X is not supported and %s will not work properly on this platform. Use it at your own risk!" : "macOS není podporován a %s nebude na této platformě správně fungovat. Používejte pouze na vlastní nebezpečí!",
+    "Login is too long" : "Přihlašovací jméno je příliš dlouhé",
+    "Cannot write into \"apps\" directory." : "Nedaří se zapisovat do adresáře „apps“.",
+    "This can usually be fixed by giving the web server write access to the apps directory or disabling the App Store in the config file." : "Toto je obvykle možné napravit udělením přístupu ke čtení adresáře s aplikací pro webový server nebo vypnutím katalogu s aplikacemi v souboru s nastaveními.",
+    "<code>mbstring.func_overload</code> is set to <code>%s</code> instead of the expected value <code>0</code>." : "<code>mbstring.func_overload</code> je nastaveno na <code>%s</code> namísto očekávané hodnoty <code>0</code>.",
+    "To fix this issue set <code>mbstring.func_overload</code> to <code>0</code> in your php.ini." : "Pro nápravu nastavte v souboru php.ini parametr <code>mbstring.func_overload</code> na <code>0</code>."
 },
 "nplurals=4; plural=(n == 1 && n % 1 == 0) ? 0 : (n >= 2 && n <= 4 && n % 1 == 0) ? 1: (n % 1 != 0 ) ? 2 : 3;");
