@@ -225,6 +225,8 @@ OC.L10N.register(
     "Could not find category \"%s\"" : "Die Kategorie \"%s\" konnte nicht gefunden werden",
     "Input text" : "Texteingabe",
     "The input text" : "Der Eingabetext",
+    "Cannot generate more than 12 images" : "Es können nicht mehr als 12 Bilder erstellt werden",
+    "Cannot generate less than 1 image" : "Es kann nicht weniger als 1 Bild erstellt werden",
     "Sunday" : "Sonntag",
     "Monday" : "Montag",
     "Tuesday" : "Dienstag",
