@@ -160,6 +160,7 @@ OC.L10N.register(
     "Oracle connection could not be established" : "Oracleへの接続が確立できませんでした。",
     "Oracle Login and/or password not valid" : "Oracleのログイン名またはパスワードが有効ではありません",
     "PostgreSQL Login and/or password not valid" : "PostgreSQLのログイン名またはパスワードが有効ではありません",
+    "macOS is not supported and %s will not work properly on this platform." : "macOS はサポートされておらず、%s はこのプラットフォームでは正常に動作しません。",
     "For the best results, please consider using a GNU/Linux server instead." : "最も良い方法としては、代わりにGNU/Linuxサーバーを利用することをご検討ください。",
     "It seems that this %s instance is running on a 32-bit PHP environment and the open_basedir has been configured in php.ini. This will lead to problems with files over 4 GB and is highly discouraged." : "このインスタンス %s は、32bit PHP 環境で動作しており、php.ini に open_basedir が設定されているようです。4GB以上のファイルで問題が発生するため、この設定を利用しないことをお勧めします。",
     "Please remove the open_basedir setting within your php.ini or switch to 64-bit PHP." : "php.ini から open_basedir 設定を削除するか、64bit PHPに切り替えてください。",
@@ -224,6 +225,8 @@ OC.L10N.register(
     "Could not find category \"%s\"" : "カテゴリ \"%s\" が見つかりませんでした",
     "Input text" : "テキストを入力",
     "The input text" : "入力テキスト",
+    "Cannot generate more than 12 images" : "12枚以上の画像を生成できません",
+    "Cannot generate less than 1 image" : "1枚未満の画像を生成できません",
     "Sunday" : "日曜日",
     "Monday" : "月曜日",
     "Tuesday" : "火曜日",
@@ -379,6 +382,11 @@ OC.L10N.register(
     "Generated emoji" : "生成された絵文字",
     "The generated emoji based on the input text" : "入力テキストに基づいて生成された絵文字",
     "Optical character recognition" : "OCR",
+    "Extract text from files like images or PDFs" : "画像やPDFのようなファイルからテキストを抽出する",
+    "Input files" : "入力ファイル",
+    "The files to extract text from" : "テキストを抽出するファイル",
+    "Output texts" : "出力テキスト",
+    "The texts that were extracted from the files" : "ファイルから抽出されたテキスト",
     "Generate image" : "画像生成",
     "Generate an image from a text prompt" : "テキストプロンプトから画像を生成する",
     "Prompt" : "プロンプト",
