@@ -221,6 +221,8 @@ OC.L10N.register(
     "Could not find category \"%s\"" : "Nemožno nájsť danú kategóriu \"%s\"",
     "Input text" : "Vstupný text",
     "The input text" : "Vstupný text",
+    "Cannot generate more than 12 images" : "Nie je možné vygenerovať viac ako 12 obrázkov",
+    "Cannot generate less than 1 image" : "Nie je možné vygenerovať menej ako 1 obrázok",
     "Sunday" : "Nedeľa",
     "Monday" : "Pondelok",
     "Tuesday" : "Utorok",
@@ -319,9 +321,13 @@ OC.L10N.register(
     "Storage is temporarily not available" : "Úložisko je dočasne nedostupné",
     "Storage connection timeout. %s" : "Vypršanie pripojenia k úložisku. %s",
     "To allow this check to run you have to make sure that your Web server can connect to itself. Therefore it must be able to resolve and connect to at least one of its `trusted_domains` or the `overwrite.cli.url`. This failure may be the result of a server-side DNS mismatch or outbound firewall rule." : "Ak chcete povoliť spustenie tejto kontroly, musíte sa uistiť, že váš webový server sa môže pripojiť sám k sebe. Preto musí byť schopný rozpoznať a pripojiť sa aspoň k jednej zo svojich `trusted_domains` alebo `overwrite.cli.url`.  Výsledkom nesprávneho nastavenia môže byť nesúlad DNS na strane servera alebo pravidla brány firewall pre výstup.",
+    "Analyze images" : "Analyzovať obrázky",
+    "Ask a question about the given images." : "Opýtať sa otázku týkajúcu sa daných obrázkov.",
     "Images" : "Obrázky",
+    "Images to ask a question about" : "Obrázky na položenie otázky",
     "Question" : "Otázka",
     "Generated response" : "Vygenerovaná odpoveď",
+    "The answer to the question" : "Odpoveď na otázku",
     "Voice chat with the assistant" : "Hlasový chat s asistentom",
     "System prompt" : "Systémová výzva",
     "Define rules and assumptions that the assistant should follow during the conversation." : "Definovať pravidlá a predpoklady, ktoré by mal asistent počas rozhovoru dodržiavať.",
@@ -373,6 +379,11 @@ OC.L10N.register(
     "How many images to generate" : "Koľko obrázkov sa bude generovať",
     "Output images" : "Výstupné obrázky",
     "The generated images" : "Vygenerované obrázky",
+    "Generate speech" : "Generovať reč",
+    "Generate speech from a transcript" : "Generovať reč z prepisu",
+    "Write transcript that you want the assistant to generate speech from" : "Napíšte prepis, z ktorého chcete, aby asistent generoval reč",
+    "Output speech" : "Výstupná reč",
+    "The generated speech" : "Vygenerovaná reč",
     "Free text to text prompt" : "Výzva pre voľný text na text",
     "Runs an arbitrary prompt through a language model that returns a reply" : "Spustí ľubovoľnú výzvu cez jazykový model, ktorý vráti odpoveď",
     "Describe a task that you want the assistant to do or ask a question" : "Opíšte úlohu, ktorú má asistent vykonať, alebo položte otázku",
