@@ -160,6 +160,7 @@ OC.L10N.register(
     "Oracle connection could not be established" : "无法建立 Oracle 连接",
     "Oracle Login and/or password not valid" : "Oracle 用户名或密码无效",
     "PostgreSQL Login and/or password not valid" : "PostgreSQL 用户名或密码无效",
+    "macOS is not supported and %s will not work properly on this platform." : "macOS 不受支持，%s 在此平台上无法正常工作。",
     "For the best results, please consider using a GNU/Linux server instead." : "为了达到最好的效果，请考虑使用 GNU/Linux 服务器。",
     "It seems that this %s instance is running on a 32-bit PHP environment and the open_basedir has been configured in php.ini. This will lead to problems with files over 4 GB and is highly discouraged." : "看起来这个 %s 实例运行在32位 PHP 环境中并且已在 php.ini 中配置open_basedir。这将在文件超过4GB时出现问题，强烈不建议这样做。",
     "Please remove the open_basedir setting within your php.ini or switch to 64-bit PHP." : "请删除 php.ini 中的 open_basedir 设置或切换到64位PHP。",
@@ -224,6 +225,8 @@ OC.L10N.register(
     "Could not find category \"%s\"" : "无法找到分类 \"%s\"",
     "Input text" : "输入文本",
     "The input text" : "输入文本",
+    "Cannot generate more than 12 images" : "无法产生超过12张图片",
+    "Cannot generate less than 1 image" : "至少需要生成一张图片",
     "Sunday" : "星期日",
     "Monday" : "星期一",
     "Tuesday" : "星期二",
