@@ -160,6 +160,7 @@ OC.L10N.register(
     "Oracle connection could not be established" : "無法建立 Oracle 資料庫連線",
     "Oracle Login and/or password not valid" : "Oracle 帳號或密碼不正確",
     "PostgreSQL Login and/or password not valid" : "PostgreSQL 帳號或密碼無效",
+    "macOS is not supported and %s will not work properly on this platform." : "不支援 macOS，%s 在此平台上無法正常運作。",
     "For the best results, please consider using a GNU/Linux server instead." : "請考慮改用 GNU/Linux 伺服器以獲得最佳結果。",
     "It seems that this %s instance is running on a 32-bit PHP environment and the open_basedir has been configured in php.ini. This will lead to problems with files over 4 GB and is highly discouraged." : "%s 站台似乎是在 32 位元 PHP 環境執行，且似乎設定了 php.ini 中的 open_basedir。這將導致超過 4 GB 的檔案出現問題，因此強烈建議不要這麼做。",
     "Please remove the open_basedir setting within your php.ini or switch to 64-bit PHP." : "請移除 php.ini 中的 open_basedir 設定，或是改用 64 位元的 PHP。",
@@ -224,6 +225,8 @@ OC.L10N.register(
     "Could not find category \"%s\"" : "找不到分類：「%s」",
     "Input text" : "輸入文字",
     "The input text" : "輸入文字",
+    "Cannot generate more than 12 images" : "無法產生超過 12 張影像",
+    "Cannot generate less than 1 image" : "無法產生少於 1 張影像",
     "Sunday" : "週日",
     "Monday" : "週一",
     "Tuesday" : "週二",
