@@ -36,4 +36,11 @@ interface IFilterCollection extends IteratorAggregate {
 	 * @since 28.0.0
 	 */
 	public function getIterator(): \Traversable;
+
+	/**
+	 * Return the number of filters
+	 *
+	 * @since 32.0.1
+	 */
+	public function count(): int;
 }
